<?php

defined( 'ABSPATH' ) or die;

$GLOBALS['processed_terms'] = array();
$GLOBALS['processed_posts'] = array();

require_once ABSPATH . 'wp-admin/includes/post.php';
require_once ABSPATH . 'wp-admin/includes/taxonomy.php';
require_once ABSPATH . 'wp-admin/includes/image.php';

function themify_import_post( $post ) {
	global $processed_posts, $processed_terms;

	if ( ! post_type_exists( $post['post_type'] ) ) {
		return;
	}

	/* Menu items don't have reliable post_title, skip the post_exists check */
	if( $post['post_type'] !== 'nav_menu_item' ) {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
		if ( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
			$processed_posts[ intval( $post['ID'] ) ] = intval( $post_exists );
			return;
		}
	}

	if( $post['post_type'] == 'nav_menu_item' ) {
		if( ! isset( $post['tax_input']['nav_menu'] ) || ! term_exists( $post['tax_input']['nav_menu'], 'nav_menu' ) ) {
			return;
		}
		$_menu_item_type = $post['meta_input']['_menu_item_type'];
		$_menu_item_object_id = $post['meta_input']['_menu_item_object_id'];

		if ( 'taxonomy' == $_menu_item_type && isset( $processed_terms[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_terms[ intval( $_menu_item_object_id ) ];
		} else if ( 'post_type' == $_menu_item_type && isset( $processed_posts[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_posts[ intval( $_menu_item_object_id ) ];
		} else if ( 'custom' != $_menu_item_type ) {
			// associated object is missing or not imported yet, we'll retry later
			// $missing_menu_items[] = $item;
			return;
		}
	}

	$post_parent = ( $post['post_type'] == 'nav_menu_item' ) ? $post['meta_input']['_menu_item_menu_item_parent'] : (int) $post['post_parent'];
	$post['post_parent'] = 0;
	if ( $post_parent ) {
		// if we already know the parent, map it to the new local ID
		if ( isset( $processed_posts[ $post_parent ] ) ) {
			if( $post['post_type'] == 'nav_menu_item' ) {
				$post['meta_input']['_menu_item_menu_item_parent'] = $processed_posts[ $post_parent ];
			} else {
				$post['post_parent'] = $processed_posts[ $post_parent ];
			}
		}
	}

	/**
	 * for hierarchical taxonomies, IDs must be used so wp_set_post_terms can function properly
	 * convert term slugs to IDs for hierarchical taxonomies
	 */
	if( ! empty( $post['tax_input'] ) ) {
		foreach( $post['tax_input'] as $tax => $terms ) {
			if( is_taxonomy_hierarchical( $tax ) ) {
				$terms = explode( ', ', $terms );
				$post['tax_input'][ $tax ] = array_map( 'themify_get_term_id_by_slug', $terms, array_fill( 0, count( $terms ), $tax ) );
			}
		}
	}

	$post['post_author'] = (int) get_current_user_id();
	$post['post_status'] = 'publish';

	$old_id = $post['ID'];

	unset( $post['ID'] );
	$post_id = wp_insert_post( $post, true );
	if( is_wp_error( $post_id ) ) {
		return false;
	} else {
		$processed_posts[ $old_id ] = $post_id;

		if( isset( $post['has_thumbnail'] ) && $post['has_thumbnail'] ) {
			$placeholder = themify_get_placeholder_image();
			if( ! is_wp_error( $placeholder ) ) {
				set_post_thumbnail( $post_id, $placeholder );
			}
		}

		return $post_id;
	}
}

function themify_get_placeholder_image() {
	static $placeholder_image = null;

	if( $placeholder_image == null ) {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}
		WP_Filesystem();
		global $wp_filesystem;
		$upload = wp_upload_bits( $post['post_name'] . '.jpg', null, $wp_filesystem->get_contents( THEMIFY_DIR . '/img/image-placeholder.jpg' ) );

		if ( $info = wp_check_filetype( $upload['file'] ) )
			$post['post_mime_type'] = $info['type'];
		else
			return new WP_Error( 'attachment_processing_error', __( 'Invalid file type', 'themify' ) );

		$post['guid'] = $upload['url'];
		$post_id = wp_insert_attachment( $post, $upload['file'] );
		wp_update_attachment_metadata( $post_id, wp_generate_attachment_metadata( $post_id, $upload['file'] ) );

		$placeholder_image = $post_id;
	}

	return $placeholder_image;
}

function themify_import_term( $term ) {
	global $processed_terms;

	if( $term_id = term_exists( $term['slug'], $term['taxonomy'] ) ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term['term_id'] ) )
			$processed_terms[ intval( $term['term_id'] ) ] = (int) $term_id;
		return (int) $term_id;
	}

	if ( empty( $term['parent'] ) ) {
		$parent = 0;
	} else {
		$parent = term_exists( $term['parent'], $term['taxonomy'] );
		if ( is_array( $parent ) ) $parent = $parent['term_id'];
	}

	$id = wp_insert_term( $term['name'], $term['taxonomy'], array(
		'parent' => $parent,
		'slug' => $term['slug'],
		'description' => $term['description'],
	) );
	if ( ! is_wp_error( $id ) ) {
		if ( isset( $term['term_id'] ) ) {
			$processed_terms[ intval($term['term_id']) ] = $id['term_id'];
			return $term['term_id'];
		}
	}

	return false;
}

function themify_get_term_id_by_slug( $slug, $tax ) {
	$term = get_term_by( 'slug', $slug, $tax );
	if( $term ) {
		return $term->term_id;
	}

	return false;
}

function themify_undo_import_term( $term ) {
	$term_id = term_exists( $term['slug'], $term['taxonomy'] );
	if ( $term_id ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term_id ) ) {
			wp_delete_term( $term_id, $term['taxonomy'] );
		}
	}
}

/**
 * Determine if a post exists based on title, content, and date
 *
 * @global wpdb $wpdb WordPress database abstraction object.
 *
 * @param array $args array of database parameters to check
 * @return int Post ID if post exists, 0 otherwise.
 */
function themify_post_exists( $args = array() ) {
	global $wpdb;

	$query = "SELECT ID FROM $wpdb->posts WHERE 1=1";
	$db_args = array();

	foreach ( $args as $key => $value ) {
		$value = wp_unslash( sanitize_post_field( $key, $value, 0, 'db' ) );
		if( ! empty( $value ) ) {
			$query .= ' AND ' . $key . ' = %s';
			$db_args[] = $value;
		}
	}

	if ( !empty ( $args ) )
		return (int) $wpdb->get_var( $wpdb->prepare($query, $args) );

	return 0;
}

function themify_undo_import_post( $post ) {
	if( $post['post_type'] == 'nav_menu_item' ) {
		$post_exists = themify_post_exists( array(
			'post_name' => $post['post_name'],
			'post_modified' => $post['post_date'],
			'post_type' => 'nav_menu_item',
		) );
	} else {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
	}
	if( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
		/**
		 * check if the post has been modified, if so leave it be
		 *
		 * NOTE: posts are imported using wp_insert_post() which modifies post_modified field
		 * to be the same as post_date, hence to check if the post has been modified,
		 * the post_modified field is compared against post_date in the original post.
		 */
		if( $post['post_date'] == get_post_field( 'post_modified', $post_exists ) ) {
			wp_delete_post( $post_exists, true ); // true: bypass trash
		}
	}
}

function themify_do_demo_import() {

	if ( isset( $GLOBALS["ThemifyBuilder_Data_Manager"] ) ) {
		remove_action( "save_post", array( $GLOBALS["ThemifyBuilder_Data_Manager"], "save_builder_text_only"), 10, 3 );
	}
$term = array (
  'term_id' => 33,
  'name' => 'Blog',
  'slug' => 'blog',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 8,
  'name' => 'Travel',
  'slug' => 'travel',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 33,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 9,
  'name' => 'Photography',
  'slug' => 'photography',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 33,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 10,
  'name' => 'View',
  'slug' => 'view',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 33,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 11,
  'name' => 'Work',
  'slug' => 'work',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 33,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 21,
  'name' => 'Video',
  'slug' => 'video',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 33,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 7,
  'name' => 'View',
  'slug' => 'view',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 18,
  'name' => 'Shoes',
  'slug' => 'shoes',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 19,
  'name' => 'Top',
  'slug' => 'top',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 20,
  'name' => 'Bag',
  'slug' => 'bag',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 29,
  'name' => 'Accessories',
  'slug' => 'accessories',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 50,
  'name' => 'Pants',
  'slug' => 'pants',
  'term_group' => 0,
  'taxonomy' => 'product_cat',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 12,
  'name' => 'Cameras',
  'slug' => 'cameras',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 13,
  'name' => 'Products',
  'slug' => 'products',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 16,
  'name' => 'Photos',
  'slug' => 'photos',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 17,
  'name' => 'Fashion',
  'slug' => 'fashion',
  'term_group' => 0,
  'taxonomy' => 'portfolio-category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 23,
  'name' => 'Personal Page Menu',
  'slug' => 'personal-page-menu',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 24,
  'name' => 'Event Page Menu',
  'slug' => 'event-page-menu',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 25,
  'name' => 'Wedding Page Menu',
  'slug' => 'wedding-page-menu',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 27,
  'name' => 'Footer Menu 2',
  'slug' => 'footer-menu-2',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 46,
  'name' => 'Main Nav',
  'slug' => 'main-nav',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 47,
  'name' => 'Right Pane',
  'slug' => 'right-pane',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 48,
  'name' => 'Header Overlay Menu',
  'slug' => 'header-overlay-menu',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$post = array (
  'ID' => 3379,
  'post_date' => '2014-04-14 20:42:26',
  'post_date_gmt' => '2014-04-14 20:42:26',
  'post_content' => 'Donec egestas lectus et magna vulputate vestibulum. Phasellus pellentesque molestie purus at rhoncus. Morbi et turpis dapibus, interdum nisi in, lacinia urna. Nunc tincidunt arcu egestas, condimentum lorem ut, pretium nulla. Suspendisse scelerisque fermentum erat, semper condimentum sem ullamcorper non. Curabitur lorem nisi, tincidunt ut tristique et, cursus a turpis.',
  'post_title' => 'Vimeo Video',
  'post_excerpt' => '',
  'post_name' => 'vimeo-video',
  'post_modified' => '2017-08-21 01:11:25',
  'post_modified_gmt' => '2017-08-21 01:11:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3379',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'video_url' => 'https://vimeo.com/channels/staffpicks/124509897',
    'body_background_repeat' => 'fullcover',
    'header_wrap' => 'video',
    'background_repeat' => 'fullcover',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'video, view',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3198,
  'post_date' => '2015-04-09 17:33:31',
  'post_date_gmt' => '2015-04-09 17:33:31',
  'post_content' => 'Donec vitae volutpat erat. Donec non molestie lacus. Integer euismod leo euismod, fermentum tellus sed, consequat leo. Cras lobortis nisl non dapibus tempor. Donec a finibus tellus. Vivamus laoreet lacinia imperdiet. Fusce tincidunt metus ac sapien feugiat, sit amet laoreet lorem aliquam. Integer pharetra egestas mi vel aliquam.',
  'post_title' => 'Amazing Posts',
  'post_excerpt' => '',
  'post_name' => 'amazing-posts',
  'post_modified' => '2017-08-21 01:11:22',
  'post_modified_gmt' => '2017-08-21 01:11:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3198',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'body_background_repeat' => 'fullcover',
    'header_wrap' => 'video',
    'background_repeat' => 'fullcover',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'view',
    'post_tag' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3202,
  'post_date' => '2015-04-09 17:46:12',
  'post_date_gmt' => '2015-04-09 17:46:12',
  'post_content' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vitae quam sed leo luctus sagittis. Fusce ut metus scelerisque dui facilisis auctor at sit amet eros. Donec sit amet nibh ac ipsum commodo tempor a a nibh. Suspendisse ornare neque id massa sollicitudin maximus. Vivamus vel dui a velit varius pellentesque nec sed felis. Vestibulum eu mauris viverra ante dictum imperdiet. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae;',
  'post_title' => 'Long Drive Adventures',
  'post_excerpt' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vitae quam sed leo luctus sagittis. Fusce ut metus scelerisque dui facilisis auctor...',
  'post_name' => 'long-drive-adventures',
  'post_modified' => '2017-08-21 01:11:19',
  'post_modified_gmt' => '2017-08-21 01:11:19',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3202',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'body_background_repeat' => 'fullcover',
    'header_wrap' => 'video',
    'background_repeat' => 'fullcover',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'travel',
    'post_tag' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3205,
  'post_date' => '2015-04-09 17:47:44',
  'post_date_gmt' => '2015-04-09 17:47:44',
  'post_content' => 'Massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.

&nbsp;',
  'post_title' => 'My Photography Post',
  'post_excerpt' => '',
  'post_name' => 'my-photography-post',
  'post_modified' => '2017-08-21 01:09:48',
  'post_modified_gmt' => '2017-08-21 01:09:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3205',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography',
    'post_tag' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3208,
  'post_date' => '2015-04-09 17:48:26',
  'post_date_gmt' => '2015-04-09 17:48:26',
  'post_content' => 'Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.

&nbsp;',
  'post_title' => 'City Sunrise',
  'post_excerpt' => '',
  'post_name' => 'city-sunrise',
  'post_modified' => '2017-08-21 01:09:47',
  'post_modified_gmt' => '2017-08-21 01:09:47',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3208',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'view',
    'post_tag' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3212,
  'post_date' => '2015-04-09 17:50:20',
  'post_date_gmt' => '2015-04-09 17:50:20',
  'post_content' => 'Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.

&nbsp;',
  'post_title' => 'In the Wild',
  'post_excerpt' => '',
  'post_name' => 'in-the-wild',
  'post_modified' => '2017-08-21 01:09:47',
  'post_modified_gmt' => '2017-08-21 01:09:47',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3212',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3216,
  'post_date' => '2015-04-09 19:48:45',
  'post_date_gmt' => '2015-04-09 19:48:45',
  'post_content' => 'Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.',
  'post_title' => 'Coffee Shop Office',
  'post_excerpt' => '',
  'post_name' => 'coffee-shop-office',
  'post_modified' => '2017-08-21 01:09:46',
  'post_modified_gmt' => '2017-08-21 01:09:46',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3216',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'work',
    'post_tag' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3228,
  'post_date' => '2015-04-09 20:00:21',
  'post_date_gmt' => '2015-04-09 20:00:21',
  'post_content' => 'Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante.Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.',
  'post_title' => 'Work/Life Balance',
  'post_excerpt' => '',
  'post_name' => 'worklife-balance',
  'post_modified' => '2017-08-21 01:09:22',
  'post_modified_gmt' => '2017-08-21 01:09:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3228',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'work',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3229,
  'post_date' => '2015-04-09 19:56:54',
  'post_date_gmt' => '2015-04-09 19:56:54',
  'post_content' => 'Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus.Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.',
  'post_title' => 'Travel Shots',
  'post_excerpt' => 'Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. ',
  'post_name' => 'travel-shots',
  'post_modified' => '2017-08-21 01:11:51',
  'post_modified_gmt' => '2017-08-21 01:11:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3229',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, travel, view',
    'post_tag' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3234,
  'post_date' => '2015-04-09 20:02:06',
  'post_date_gmt' => '2015-04-09 20:02:06',
  'post_content' => 'Donec vitae volutpat erat. Donec non molestie lacus. Integer euismod leo euismod, fermentum tellus sed, consequat leo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem Cras lobortis nisl non dapibus tempor. Donec a finibus tellus. Vivamus laoreet lacinia imperdiet. Fusce tincidunt metus ac sapien feugiat, sit amet laoreet lorem aliquam. Integer pharetra egestas mi vel aliquam.',
  'post_title' => 'Underwater Scuba Trip',
  'post_excerpt' => 'Donec vitae volutpat erat. Donec non molestie lacus. Integer euismod leo euismod, fermentum tellus sed, consequat leo. Cras lobortis.',
  'post_name' => 'underwater-scuba-trip',
  'post_modified' => '2017-08-21 01:09:20',
  'post_modified_gmt' => '2017-08-21 01:09:20',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3234',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'travel',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3238,
  'post_date' => '2015-04-09 20:03:51',
  'post_date_gmt' => '2015-04-09 20:03:51',
  'post_content' => '<div id="lipsum">

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Night Life',
  'post_excerpt' => 'Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id.',
  'post_name' => 'night-life',
  'post_modified' => '2017-08-21 01:09:19',
  'post_modified_gmt' => '2017-08-21 01:09:19',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3238',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, travel',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3241,
  'post_date' => '2015-04-09 20:05:08',
  'post_date_gmt' => '2015-04-09 20:05:08',
  'post_content' => '<div id="lipsum">

In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatemPraesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'New York Shot',
  'post_excerpt' => 'In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus.',
  'post_name' => 'new-york-shot',
  'post_modified' => '2017-08-21 01:09:18',
  'post_modified_gmt' => '2017-08-21 01:09:18',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3241',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, travel',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3244,
  'post_date' => '2015-04-09 20:08:17',
  'post_date_gmt' => '2015-04-09 20:08:17',
  'post_content' => '<div id="lipsum">

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat.

</div>
&nbsp;',
  'post_title' => '2 Left Sidebars',
  'post_excerpt' => 'Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id.',
  'post_name' => '2-left-sidebars',
  'post_modified' => '2017-08-21 01:09:14',
  'post_modified_gmt' => '2017-08-21 01:09:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3244',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar2 content-right',
    'body_background_repeat' => 'fullcover',
    'header_wrap' => 'video',
    'background_repeat' => 'fullcover',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'travel',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3247,
  'post_date' => '2015-04-09 20:10:27',
  'post_date_gmt' => '2015-04-09 20:10:27',
  'post_content' => '<div id="lipsum">

Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque.

</div>
&nbsp;',
  'post_title' => '2 Right Sidebars',
  'post_excerpt' => '',
  'post_name' => '2-right-sidebars',
  'post_modified' => '2017-08-21 01:08:33',
  'post_modified_gmt' => '2017-08-21 01:08:33',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3247',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar2 content-left',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3250,
  'post_date' => '2015-04-09 20:11:44',
  'post_date_gmt' => '2015-04-09 20:11:44',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

&nbsp;',
  'post_title' => 'Left & Right Sidebars',
  'post_excerpt' => '',
  'post_name' => 'left-right-sidebars',
  'post_modified' => '2017-08-21 01:08:32',
  'post_modified_gmt' => '2017-08-21 01:08:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3250',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar2',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'work',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3253,
  'post_date' => '2015-04-09 20:12:41',
  'post_date_gmt' => '2015-04-09 20:12:41',
  'post_content' => 'Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.',
  'post_title' => 'Fullwidth With Sidebar',
  'post_excerpt' => '',
  'post_name' => 'fullwidth-with-sidebar',
  'post_modified' => '2018-11-14 23:53:06',
  'post_modified_gmt' => '2018-11-14 23:53:06',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3253',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar1',
    'post_layout' => 'fullwidth',
    'mobile_menu_styles' => 'default',
    'header_wrap' => 'video',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"5301efb\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"c09833b\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, work',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3259,
  'post_date' => '2015-04-09 20:22:34',
  'post_date_gmt' => '2015-04-09 20:22:34',
  'post_content' => 'Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Et harum quidem rerum facilis est et expedita distinctio.Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae. Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandaem.',
  'post_title' => 'Right Sidebar',
  'post_excerpt' => 'Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris.',
  'post_name' => 'right-sidebar',
  'post_modified' => '2017-08-21 01:08:27',
  'post_modified_gmt' => '2017-08-21 01:08:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3259',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar1',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography, travel',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3266,
  'post_date' => '2015-04-09 20:26:22',
  'post_date_gmt' => '2015-04-09 20:26:22',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus.',
  'post_title' => 'Left Sidebar',
  'post_excerpt' => '',
  'post_name' => 'left-sidebar',
  'post_modified' => '2017-08-21 01:08:23',
  'post_modified_gmt' => '2017-08-21 01:08:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3266',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar1 sidebar-left',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'work',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3269,
  'post_date' => '2015-04-09 20:13:21',
  'post_date_gmt' => '2015-04-09 20:13:21',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. <a href="https://themify.me">Praesent</a> finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem',
  'post_title' => 'Classic Fullwidth',
  'post_excerpt' => '',
  'post_name' => 'classic-fullwidth',
  'post_modified' => '2017-08-21 01:08:27',
  'post_modified_gmt' => '2017-08-21 01:08:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3269',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'classic',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5075,
  'post_date' => '2016-06-06 22:33:37',
  'post_date_gmt' => '2016-06-06 22:33:37',
  'post_content' => 'Officia deserunt mollitia animi, id est laborum et dolorum fuga. Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat',
  'post_title' => 'Split Layout',
  'post_excerpt' => '',
  'post_name' => 'split-layout',
  'post_modified' => '2017-08-21 01:08:17',
  'post_modified_gmt' => '2017-08-21 01:08:17',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5075',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'split',
    'image_width' => '800',
    'image_height' => '1000',
    'header_design' => 'header-top-bar',
    'footer_design' => 'none',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'travel',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5080,
  'post_date' => '2016-06-06 22:39:22',
  'post_date_gmt' => '2016-06-06 22:39:22',
  'post_content' => 'Aenean dis mus arcu vel posuere porta tristique. Magnis maecenas cum maecenas suspendisse consectetur sed, scelerisque augue placerat ullamcorper. Augue torquent et dictumst lacinia at scelerisque turpis class pellentesque sodales cras lectus! Neque eu eget vitae suspendisse integer dapibus fermentum laoreet? Ullamcorper tristique facilisis ullamcorper phasellus nam semper scelerisque! Viverra ornare dignissim nam, molestie tortor scelerisque! Vehicula quam tempor imperdiet quisque. Quisque suscipit!',
  'post_title' => 'Slider Layout',
  'post_excerpt' => '',
  'post_name' => 'slider-layout',
  'post_modified' => '2017-08-21 01:08:15',
  'post_modified_gmt' => '2017-08-21 01:08:15',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5080',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'slider',
    'post_layout_slider' => '[gallery size="full" link="file" ids="3308,3290,3287,3273"]',
    'image_width' => '1400',
    'image_height' => '700',
    'header_design' => 'header-horizontal',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'photography',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5088,
  'post_date' => '2016-06-07 22:48:24',
  'post_date_gmt' => '2016-06-07 22:48:24',
  'post_content' => 'Mauris sit natoque dolor condimentum himenaeos curabitur imperdiet fringilla, mollis platea consequat consectetur. Risus sapien hac tristique. Praesent magnis cursus proin etiam condimentum hac. Viverra praesent, ad proin lorem est class blandit id maecenas felis. Metus dictum interdum parturient viverra magnis curae; id potenti tellus. Tempor massa ullamcorper est turpis molestie penatibus dictumst dui nam. Bibendum suspendisse mauris condimentum auctor mollis integer sagittis nascetur ante rutrum molestie. Himenaeos sociosqu aliquam porta magnis sodales nulla in etiam duis faucibus.<!--more-->
<h3>Sub Heading</h3>
Mauris sit natoque dolor condimentum himenaeos curabitur imperdiet fringilla, mollis platea consequat consectetur. Risus sapien hac tristique. Praesent magnis cursus proin etiam condimentum hac. Viverra praesent, ad proin lorem est class blandit id maecenas felis. Metus dictum interdum parturient viverra magnis curae; id potenti tellus. Tempor massa ullamcorper est turpis molestie penatibus dictumst dui nam.',
  'post_title' => 'Gallery Layout',
  'post_excerpt' => '',
  'post_name' => 'gallery-layout',
  'post_modified' => '2017-08-21 01:08:11',
  'post_modified_gmt' => '2017-08-21 01:08:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5088',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'gallery',
    'post_layout_gallery' => '[gallery link="file" size="large" columns="5" ids="5089,4997,4760,4216,4212,4099,4149,3915,3907,3841"]',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5101,
  'post_date' => '2016-04-26 22:56:01',
  'post_date_gmt' => '2016-04-26 22:56:01',
  'post_content' => 'Lectus facilisi pulvinar natoque non molestie varius tincidunt class leo at varius non. Aliquam libero vulputate dui est varius tempor lectus nascetur tellus sit. Mus nascetur, elit malesuada posuere eleifend magnis mus donec congue fusce! Litora dictum purus auctor hac dapibus himenaeos. Sagittis nascetur per sociis per erat nascetur gravida. Ligula id, dictumst viverra imperdiet. Similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga. Et harum quidem rerum facilis est et expedita distinctio.',
  'post_title' => 'Fullwidth Layout',
  'post_excerpt' => '',
  'post_name' => 'fullwidth-layout',
  'post_modified' => '2017-08-21 01:08:19',
  'post_modified_gmt' => '2017-08-21 01:08:19',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5101',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'fullwidth',
    'header_design' => 'header-top-bar',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'view',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3584,
  'post_date' => '2015-04-20 22:26:13',
  'post_date_gmt' => '2015-04-20 22:26:13',
  'post_content' => '',
  'post_title' => 'Footer Block',
  'post_excerpt' => '',
  'post_name' => 'footer-block',
  'post_modified' => '2017-08-21 01:13:17',
  'post_modified_gmt' => '2017-08-21 01:13:17',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3584',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'header_design' => 'none',
    'header_wrap' => 'transparent',
    'footer_design' => 'footer-block',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3586,
  'post_date' => '2015-04-20 22:31:22',
  'post_date_gmt' => '2015-04-20 22:31:22',
  'post_content' => '',
  'post_title' => 'Footer Left Column',
  'post_excerpt' => '',
  'post_name' => 'footer-left-column',
  'post_modified' => '2017-08-21 01:13:21',
  'post_modified_gmt' => '2017-08-21 01:13:21',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3586',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'header_design' => 'none',
    'header_wrap' => 'transparent',
    'footer_design' => 'footer-left-col',
    'exclude_footer_widgets' => 'no',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3588,
  'post_date' => '2015-04-20 22:32:04',
  'post_date_gmt' => '2015-04-20 22:32:04',
  'post_content' => '',
  'post_title' => 'Footer Right Column',
  'post_excerpt' => '',
  'post_name' => 'footer-right-column',
  'post_modified' => '2017-08-21 01:14:44',
  'post_modified_gmt' => '2017-08-21 01:14:44',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3588',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'header_design' => 'none',
    'header_wrap' => 'transparent',
    'footer_design' => 'footer-right-col',
    'exclude_footer_widgets' => 'no',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6916,
  'post_date' => '2018-02-28 18:43:18',
  'post_date_gmt' => '2018-02-28 18:43:18',
  'post_content' => '<!--themify_builder_static--><h1>Product Branding &amp; marketing</h1> 
 <a href="https://themify.me/" > TELL ME MORE</a> 
 
 
 
 <h3>Inventions</h3> <p>Temporibus autem quibusdam et aut officiis debitis aut rerum necess saepe eveniet ut.</p> 
 
 
 
 
 <h3>Patents</h3> <p>Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis.</p> 
 
 
 
 
 <h3>Phenomenal</h3> <p>At vero eos et accusamus et iusto odio dignist simos ducimus qui blanditiis praesentium.</p> 
 
<h2>Research<br/></h2>
 <h3>We always believe in research. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod.</h3> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2017/02/research-1.jpg" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/06/logo-1.png" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/06/logo-2.png" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/06/logo-3.png" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/06/logo-4.png" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/06/logo-5.png" alt="" /> 
 <h2>Plan</h2> 
 <h2>Execute</h2> 
 <h2>Launch</h2> 
<h2>Thinking out of the box<br/></h2>
 <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip</p> 
 <a href="https://themify.me/" > JOIN US</a><!--/themify_builder_static-->',
  'post_title' => 'Top Widgets',
  'post_excerpt' => '',
  'post_name' => 'top-widgets',
  'post_modified' => '2018-07-17 16:55:01',
  'post_modified_gmt' => '2018-07-17 16:55:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=6916',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-turquoise',
    'header_design' => 'header-top-widgets',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Product Branding &amp; marketing<\\\\/h1>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"bounceIn\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"TELL ME MORE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"black\\",\\"icon\\":\\"fa-arrow-circle-right\\",\\"icon_alignment\\":\\"left\\"}],\\"animation_effect\\":\\"bounceIn\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/header.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_position\\":\\"center-bottom\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"checkbox_c_m_apply_all\\":\\"1\\",\\"checkbox_c_b_apply_all\\":\\"1\\",\\"title_feature\\":\\"Inventions\\",\\"content_feature\\":\\"<p>Temporibus autem quibusdam et aut officiis debitis aut rerum necess saepe eveniet ut.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-cogs\\",\\"icon_color_feature\\":\\"525252\\",\\"link_options\\":\\"regular\\",\\"animation_effect\\":\\"slideInLeft\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Patents\\",\\"content_feature\\":\\"<p>Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-file-text-o\\",\\"icon_color_feature\\":\\"525252\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInUp\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"link_options\\":\\"\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Phenomenal\\",\\"content_feature\\":\\"<p>At vero eos et accusamus et iusto odio dignist simos ducimus qui blanditiis praesentium.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-lightbulb-o\\",\\"icon_color_feature\\":\\"525252\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"slideInRight\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"link_options\\":\\"\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_color\\":\\"f5f5f5_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"fancy-heading\\",\\"mod_settings\\":{\\"heading\\":\\"Research\\",\\"heading_tag\\":\\"h2\\",\\"text_alignment\\":\\"themify-text-center\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>We always believe in research. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}],\\"gutter\\":\\"gutter-none\\",\\"col_tablet\\":\\"tablet-full\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2017\\\\/02\\\\/research-1.jpg\\",\\"auto_fullwidth\\":\\"1\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/logo-1.png\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/logo-2.png\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/logo-3.png\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/logo-4.png\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/logo-5.png\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_color\\":\\"f5f5f5_1.00\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Plan<\\\\/h2>\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"20\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"5\\",\\"margin_right_unit\\":\\"%\\",\\"margin_bottom\\":\\"5\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"5\\",\\"margin_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"ffffff_1.00\\",\\"border_top_width\\":\\"2\\",\\"border_right_color\\":\\"ffffff_1.00\\",\\"border_right_width\\":\\"2\\",\\"border_bottom_color\\":\\"ffffff_1.00\\",\\"border_bottom_width\\":\\"2\\",\\"border_left_color\\":\\"ffffff_1.00\\",\\"border_left_width\\":\\"2\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/plan.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.21\\",\\"cover_color_hover\\":\\"000000_0.48\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Execute<\\\\/h2>\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"20\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"5\\",\\"margin_right_unit\\":\\"%\\",\\"margin_bottom\\":\\"5\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"5\\",\\"margin_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"ffffff_1.00\\",\\"border_top_width\\":\\"2\\",\\"border_right_color\\":\\"ffffff_1.00\\",\\"border_right_width\\":\\"2\\",\\"border_bottom_color\\":\\"ffffff_1.00\\",\\"border_bottom_width\\":\\"2\\",\\"border_left_color\\":\\"ffffff_1.00\\",\\"border_left_width\\":\\"2\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/execute.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_position\\":\\"center-center\\",\\"cover_color\\":\\"000000_0.26\\",\\"cover_color_hover\\":\\"000000_0.48\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Launch<\\\\/h2>\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"20\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"5\\",\\"margin_right_unit\\":\\"%\\",\\"margin_bottom\\":\\"5\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"5\\",\\"margin_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"ffffff_1.00\\",\\"border_top_width\\":\\"2\\",\\"border_right_color\\":\\"ffffff_1.00\\",\\"border_right_width\\":\\"2\\",\\"border_bottom_color\\":\\"ffffff_1.00\\",\\"border_bottom_width\\":\\"2\\",\\"border_left_color\\":\\"ffffff_1.00\\",\\"border_left_width\\":\\"2\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2017\\\\/02\\\\/launch-1.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_position\\":\\"center-center\\",\\"cover_color\\":\\"000000_0.15\\",\\"cover_color_hover\\":\\"000000_0.48\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"underline\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"padding_top\\":\\"0\\",\\"padding_right\\":\\"0\\",\\"padding_bottom\\":\\"0\\",\\"padding_left\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"0\\",\\"margin_right\\":\\"0\\",\\"margin_bottom\\":\\"0\\",\\"margin_left\\":\\"0\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"fancy-heading\\",\\"mod_settings\\":{\\"heading\\":\\"Thinking out of the box\\",\\"heading_tag\\":\\"h2\\",\\"text_alignment\\":\\"themify-text-center\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"bounceIn\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"JOIN US\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"icon\\":\\"fa-sign-in\\"}],\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"bounceIn\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/06\\\\/pexels-photo-69040.png\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"cover_color\\":\\"595959_0.85\\",\\"cover_color_hover\\":\\"545454_0.93\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3590,
  'post_date' => '2015-04-20 22:32:27',
  'post_date_gmt' => '2015-04-20 22:32:27',
  'post_content' => '',
  'post_title' => 'Footer Horizontal Left',
  'post_excerpt' => '',
  'post_name' => 'footer-horizontal-left',
  'post_modified' => '2017-08-21 01:13:18',
  'post_modified_gmt' => '2017-08-21 01:13:18',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3590',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'hide_page_title' => 'no',
    'header_design' => 'none',
    'header_wrap' => 'transparent',
    'footer_design' => 'footer-horizontal-left',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3592,
  'post_date' => '2015-04-20 22:32:46',
  'post_date_gmt' => '2015-04-20 22:32:46',
  'post_content' => '',
  'post_title' => 'Footer Horizontal Right',
  'post_excerpt' => '',
  'post_name' => 'footer-horizontal-right',
  'post_modified' => '2017-08-21 01:13:20',
  'post_modified_gmt' => '2017-08-21 01:13:20',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3592',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'header_design' => 'none',
    'header_wrap' => 'transparent',
    'footer_design' => 'footer-horizontal-right',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6922,
  'post_date' => '2018-02-28 18:45:08',
  'post_date_gmt' => '2018-02-28 18:45:08',
  'post_content' => '<!--themify_builder_static--><h1 style="text-align: left;">Get Paid Faster</h1> <p style="text-align: left;">Sign up for our complete <strong>ePayment</strong> solutions to accept credit and debit payments in the world.</p> 
 <a href="http://themify.me/" >Get Started Today</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/paypal-logos.png" alt="Classic Header" /> 
 <h2>Get started with ePayment</h2> <p>Your clients can pay you faster. All invoice management tools included.</p> 
 <a href="https://www.youtube.com/watch?v=SENb0osYYXs" > 
 
 </a> 
 
 
 <h2>Jim can now focus on his work, not tracking invoices.</h2> <p>This could be your story.</p> 
 <a href="https://themify.me/" >Learn More</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2018/05/item-purchase.png" width="560" height="325" alt="Classic Header" /> 
 <h3>Add ePayment to your invoices.</h3> <p>Lorem ipsum dolor sit amet, nam ea dicit feugiat, te nec stet persecuti sadipscing. Ea graeco scripserit has, in qui equidem labores corrumpit. Quo ad aperiri delicata, latine intellegam mei te, nec tollit feugait ne. His dico intellegebat te, cum alterum docendi in. Deserunt erroribus mel no, vel aliquid graecis reformidans ad, ad quem purto pri.</p> 
 <a href="https://themify.me/" > Learn More</a> 
 
 
 
 
 
 <h2>No more invoice reminders. Boost productivity by 30%.</h2> <p>Now you can focus on your work, not your invoices.</p> 
 <a href="https://themify.me/" > Learn More</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2018/05/ipad-invoice-transparent.png" width="673" height="602" alt="Classic Header" /> 
 <h2>All of your invoices in one simple account.</h2> 
 <h3>Experience the 5-min speedy setup.</h3> 
 <a href="http://themify.me/" >Sign Up ePayment Now</a> 
 <ul data-id="testimonial-slider-0-" data-visible="1" data-mob-visible="" data-scroll="1" data-auto-scroll="off" data-speed="1" data-wrap="yes" data-arrow="yes" data-pagination="yes" data-effect="scroll" data-height="variable" data-pause-on-hover="resume" > <li> 
 <h3>“Since using ePayment, I no longer have to manually create invoices, send my clients follow up emails. And my clients like it. They can pay instantly and get payment receipts.”</h3> John Smith CEO, X-corporation </li> <li> 
 <h3>“Lorem ipsum dolor sit amet, nam ea dicit feugiat, te nec stet persecuti sadipscing. Ea graeco scripserit has, in qui equidem labores corrumpit. Quo ad aperiri delicata, latine intellegam mei.”</h3> Lauren Jolie Marketer, Impact Marketing </li> <li> 
 <h3>“Dolor sit amet, nam ea dicit feugiat, te nec stet persecuti sadipscing. Ea graeco scripserit has, in qui equidem labores corrumpit. His dico intellegebat te, cum alterum docendi in.”</h3> Peter Jameson Manager, Global Firm </li> </ul><!--/themify_builder_static-->',
  'post_title' => 'Classic Header',
  'post_excerpt' => '',
  'post_name' => 'classic-header',
  'post_modified' => '2018-07-03 07:12:01',
  'post_modified_gmt' => '2018-07-03 07:12:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=6922',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-purple',
    'header_design' => 'header-classic',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"h1_margin_top\\":\\"0\\",\\"h1_margin_bottom\\":\\"10\\",\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Get Paid Faster<\\\\/h1>\\\\n<p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Sign up for our complete <strong>ePayment<\\\\/strong> solutions to accept credit and debit payments in the world.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_bottom\\":\\"30\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30px\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"circle\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Get Started Today\\",\\"link\\":\\"http:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"blue\\",\\"icon_alignment\\":\\"left\\"}]}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/paypal-logos.png\\",\\"param_image\\":\\"regular\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\"}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/woman-typing-1024x693.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"right-center\\",\\"cover_color-type\\":\\"cover_gradient\\",\\"cover_color\\":\\"#000000_0.40\\",\\"cover_gradient-gradient-angle\\":\\"90\\",\\"cover_gradient-gradient\\":\\"0% rgba(0, 0, 0, 0.68)|100% rgba(0, 0, 0, 0.32)\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"link_color\\":\\"ffffff\\",\\"padding_top\\":\\"12\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Get started with ePayment<\\\\/h2>\\\\n<p>Your clients can pay you faster. All invoice management tools included.<\\\\/p>\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\"},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffffff_1.00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-play\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/watch?v=SENb0osYYXs\\",\\"link_options\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"10\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Jim can now focus on his work, not tracking invoices.<\\\\/h2>\\\\n<p>This could be your story.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Learn More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"}]}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/mechanic-646923-1024x597.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.38\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"cover_color_hover\\":\\"#000000_0.55\\",\\"font_color\\":\\"#ffffff\\",\\"link_color\\":\\"#ffffff\\",\\"padding_top\\":\\"12\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"12\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2018\\\\/05\\\\/item-purchase.png\\",\\"width_image\\":\\"560\\",\\"height_image\\":\\"325\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInLeft\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h3>Add ePayment to your invoices.<\\\\/h3>\\\\n<p>Lorem ipsum dolor sit amet, nam ea dicit feugiat, te nec stet persecuti sadipscing. Ea graeco scripserit has, in qui equidem labores corrumpit. Quo ad aperiri delicata, latine intellegam mei te, nec tollit feugait ne. His dico intellegebat te, cum alterum docendi in. Deserunt erroribus mel no, vel aliquid graecis reformidans ad, ad quem purto pri.<\\\\/p>\\",\\"animation_effect\\":\\"fadeInRight\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"rounded\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Learn More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"blue\\",\\"icon\\":\\"ti-angle-right\\",\\"icon_alignment\\":\\"left\\"}],\\"animation_effect\\":\\"fadeInRightBig\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\"}]}],\\"styling\\":{\\"row_anchor\\":\\"about\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"7\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffffff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-diamond\\",\\"icon_color_feature\\":\\"ffffff\\",\\"link_options\\":\\"regular\\",\\"animation_effect\\":\\"pulse\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>No more invoice reminders. Boost productivity by 30%.<\\\\/h2>\\\\n<p>Now you can focus on your work, not your invoices.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Learn More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"icon\\":\\"ti-angle-right\\",\\"icon_alignment\\":\\"left\\"}]}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2018\\\\/05\\\\/ipad-invoice-transparent.png\\",\\"width_image\\":\\"673\\",\\"height_image\\":\\"602\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"styling\\":{\\"background_type\\":\\"gradient\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_gradient-gradient\\":\\"0% rgba(28, 191, 255, 0.99)|98% rgba(18, 88, 186, 0.99)\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"10\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>All of your invoices in one simple account.<\\\\/h2>\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h3>Experience the 5-min speedy setup.<\\\\/h3>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_bottom\\":\\"30\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"xlarge\\",\\"buttons_style\\":\\"circle\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Sign Up ePayment Now\\",\\"link\\":\\"http:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"blue\\",\\"icon_alignment\\":\\"left\\"}],\\"animation_effect\\":\\"swing\\"}},{\\"mod_name\\":\\"testimonial-slider\\",\\"mod_settings\\":{\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_testimonial\\":\\"image-top\\",\\"tab_content_testimonial\\":[{\\"content_testimonial\\":\\"<h3>“Since using ePayment, I no longer have to manually create invoices, send my clients follow up emails. And my clients like it. They can pay instantly and get payment receipts.”<\\\\/h3>\\",\\"person_name_testimonial\\":\\"John Smith\\",\\"person_position_testimonial\\":\\"CEO, X-corporation\\"},{\\"content_testimonial\\":\\"<h3>“Lorem ipsum dolor sit amet, nam ea dicit feugiat, te nec stet persecuti sadipscing. Ea graeco scripserit has, in qui equidem labores corrumpit. Quo ad aperiri delicata, latine intellegam mei.”<\\\\/h3>\\",\\"person_name_testimonial\\":\\"Lauren Jolie\\",\\"person_position_testimonial\\":\\"Marketer, Impact Marketing\\"},{\\"content_testimonial\\":\\"<h3>“Dolor sit amet, nam ea dicit feugiat, te nec stet persecuti sadipscing. Ea graeco scripserit has, in qui equidem labores corrumpit. His dico intellegebat te, cum alterum docendi in.”<\\\\/h3>\\",\\"person_name_testimonial\\":\\"Peter Jameson\\",\\"person_position_testimonial\\":\\"Manager, Global Firm\\"}],\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"off\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"height_slider\\":\\"variable\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5132,
  'post_date' => '2016-06-08 20:33:21',
  'post_date_gmt' => '2016-06-08 20:33:21',
  'post_content' => '<!--themify_builder_static--><img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/personal-300x300.jpg" width="300" height="300" alt="" /> 
 <h3 style="text-align: center;">Catherine Moon</h3> <p style="text-align: center;"><em>UI Designer</em></p> 
 <a href="https://www.facebook.com/themify"> </a> <a href="https://twitter.com/themify"> </a> <a href="https://plus.google.com/u/2/b/109280316400365629341/109280316400365629341"> </a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/personal-2-1024x1024-400x400.jpg" width="400" alt="" /> 
 <p>Hi! My names Stephanie Moon. Welcome to my personal page that I\'ve designed to showcase my skills and expertise that I\'ve accumulated over the year. I\'ve also placed a contact form below and all my social links on my header, feel free to connect with me. I\'d love to be given the opportunity to hear from you.</p><h4>A Little Bit About Me...</h4><p>I\'m a UI Designer with over 10 years experience in web design and content marketing. I\'m very fortunate to be given the opportunity to work for amazing companies that allowed me to grow with my skills as a UI designer. Aside from that experience, I\'ve also been a very passionate tech writer. Blogging content that focuses on increasing a site SEO. </p> 
 <h2 style="text-align: center;">My Skills</h2><p style="text-align: center;">Below is a breakdown of my skills in both design and programming. I\'ve created an animated bar graph that showcases the level of expertise I have for each of them. </p><p style="text-align: center;">**Purchase the <a href="https://themify.me/addons/progress-bar">Progress Bar Addon</a> to get the same looking progress bar to show off your skills**</p> 
 <h3>Design</h3> <i>Photoshop</i> <i>Illustrator</i> <i>Indesign</i> <i>Corel</i> 
 <h3>Programming</h3> <i>HTML</i> <i>CSS</i> <i>JS</i> <i>PHP</i> 
 <h2 style="text-align: center;">Work Experience</h2><p style="text-align: center;">**Purchase the <a href="https://themify.me/addons/timeline">Timeline Addon</a> to recreate this beautiful timeline resume layout**</p> 
 <ul> <li id="timeline-0">
 2011 - Present 
 
 <h2>Lead Designer</h2> <p><em>Amazing Designs</em></p><p>Responsible for conceptualization and implementation of design of solutions that meet marketing strategies from concept to completion. Senior graphic designers often have the designation of “senior” because of their authority in decision-making. Or, they will play the lead role on projects and supervise intermediate and junior designer(s) in creating concepts, comps, layouts and final art.</p> 
 </li>
 <li id="timeline-1">
 2007 - 2011 
 
 <h2>Creative Director</h2> <p><i>Ocean\'s Media</i></p><p>Charged with determining the best ways for us to visually represent our company’s identity online. It\'s very much a people-oriented job, involving development of high-level concepts for design projects. It also involves working with internal and external clients, pitching designs, and understanding client needs. At times, we require you to develop visual designs, and at other times, the Creative Director will be responsible for recruiting and managing third party design firms as well as internal design resources.</p> 
 </li>
 <li id="timeline-2">
 2002 - 2007 
 
 <h2>Frontend Designer</h2> <p><i>Themify</i></p><p><strong>Duties and Expectations</strong></p><p>A front-end web developer is generally expected to:</p><ul><li>Develop functional and appealing web applications based on usability</li><li>Provide website maintenance and enhancements</li><li>Use a combination of markup languages to write web pages</li><li>Write functional requirement documents and specifications</li><li>Create quality mock-ups and prototypes on tight timelines</li></ul> 
 </li>
 </ul> 
 <h2 style="text-align: center;">Status</h2> 
 
 
 
 <h3>4 Years Experience</h3> 
 
 
 
 
 <h3>65 Completed Projects</h3> 
 
 
 
 
 <h3>89 Happy Clients</h3> 
 
 <h2 style="text-align: center;">Portfolio</h2> 
 <p>[portfolio style="grid3" limit="3" image_w="366" image_h="260"]</p> 
 <a href="https://www.facebook.com/themify" > 
 
 </a> 
 <p style="text-align: center;">Facebook</p> 
 
 <a href="https://ca.linkedin.com/" > 
 
 </a> 
 <p style="text-align: center;">Linked In</p> 
 
 <a href="https://www.twitter.com/themify" > 
 
 </a> 
 <p style="text-align: center;">Twitter</p> 
 
 <a href="https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341" > 
 
 </a> 
 <p style="text-align: center;">Google+</p> 
 
 <h2 style="text-align: center;">Contact</h2> 
<h3></h3><iframe frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="https://maps.google.com/maps?q=Toronto%2C+ON&amp;t=m&amp;z=8&amp;output=embed&amp;iwloc=near"></iframe>
 <p>[themify_icon icon="fa-map-marker" ] 250 King Str. West <br />[themify_icon icon="fa-phone" ] 647-992-4231</p> 
 <p>**Purchase the <a href="https://themify.me/addons/contact">Contact Addon </a>to recreate this contact form layout**</p> 
 <form action="https://themify.me/demo/themes/ultra/wp-admin/admin-ajax.php" id="contact-0--form" method="post"> 
 <label for="contact-0--contact-name">Name *</label> <input type="text" name="contact-name" placeholder="" id="contact-0--contact-name" value="" required /> 
 <label for="contact-0--contact-email">Email *</label> <input type="text" name="contact-email" placeholder="" id="contact-0--contact-email" value="" required /> 
 <label for="contact-0--contact-message">Message *</label> <textarea name="contact-message" placeholder="" id="contact-0--contact-message" rows="8" cols="45" required></textarea> <button type="submit"> Send </button> </form><!--/themify_builder_static-->',
  'post_title' => 'Split Menu',
  'post_excerpt' => '',
  'post_name' => 'split-menu',
  'post_modified' => '2018-07-17 16:35:51',
  'post_modified_gmt' => '2018-07-17 16:35:51',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=5132',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'custom_menu' => 'personal-page-menu',
    'header_design' => 'header-menu-split',
    'exclude_site_tagline' => 'yes',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'yes',
    'exclude_social_widget' => 'yes',
    'header_wrap' => 'transparent',
    'footer_design' => 'none',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/personal-300x300.jpg\\",\\"appearance_image\\":\\"rounded|circle\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"300\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Catherine Moon<\\\\/h3>\\\\n<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>UI Designer<\\\\/em><\\\\/p>\\\\n\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\"}},{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"icon_size\\":\\"xlarge\\",\\"icon_style\\":\\"none\\",\\"content_icon\\":[{\\"icon\\":\\"fa-facebook-f\\",\\"link\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\",\\"new_window\\":\\"\\",\\"icon_color_bg\\":\\"\\"},{\\"icon\\":\\"fa-twitter\\",\\"link\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\",\\"new_window\\":\\"\\",\\"icon_color_bg\\":\\"\\"},{\\"icon\\":\\"fa-google-plus\\",\\"link\\":\\"https:\\\\/\\\\/plus.google.com\\\\/u\\\\/2\\\\/b\\\\/109280316400365629341\\\\/109280316400365629341\\",\\"new_window\\":\\"\\",\\"icon_color_bg\\":\\"\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"text_decoration\\":\\"none\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_left\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"icon_position\\":\\"icon_position_left\\"}}]}],\\"styling\\":{\\"row_anchor\\":\\"welcome\\",\\"background_type\\":\\"video\\",\\"background_video\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/demo-videos\\\\/stockholm1.mp4\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/demo-videos\\\\/personal-page-fallback-1024x584.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"5d6366_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/personal-2-1024x1024-400x400.jpg\\",\\"appearance_image\\":\\"rounded|circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"0\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Hi! My names Stephanie Moon. Welcome to my personal page that I\\\\\\\\\\\'ve designed to showcase my skills and expertise that I\\\\\\\\\\\'ve accumulated over the year. I\\\\\\\\\\\'ve also placed a contact form below and all my social links on my header, feel free to connect with me. I\\\\\\\\\\\'d love to be given the opportunity to hear from you.<\\\\/p><h4>A Little Bit About Me...<\\\\/h4><p>I\\\\\\\\\\\'m a UI Designer with over 10 years experience in web design and content marketing. I\\\\\\\\\\\'m very fortunate to be given the opportunity to work for amazing companies that allowed me to grow with my skills as a UI designer. Aside from that experience, I\\\\\\\\\\\'ve also been a very passionate tech writer. Blogging content that focuses on increasing a site SEO. <\\\\/p>\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"row_anchor\\":\\"about\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">My Skills<\\\\/h2><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Below is a breakdown of my skills in both design and programming. I\\\\\\\\\\\'ve created an animated bar graph that showcases the level of expertise I have for each of them. <\\\\/p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">**Purchase the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/progress-bar\\\\\\\\\\\\\\">Progress Bar Addon<\\\\/a> to get the same looking progress bar to show off your skills**<\\\\/p>\\",\\"link_color\\":\\"a23ab0_1.00\\",\\"text_decoration\\":\\"underline\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"progressbar\\",\\"mod_settings\\":{\\"mod_title_progressbar\\":\\"Design\\",\\"progress_bars\\":[{\\"bar_label\\":\\"Photoshop\\",\\"bar_percentage\\":\\"90\\",\\"bar_color\\":\\"e267eb_1.00\\"},{\\"bar_label\\":\\"Illustrator\\",\\"bar_percentage\\":\\"80\\",\\"bar_color\\":\\"e86464_1.00\\"},{\\"bar_label\\":\\"Indesign\\",\\"bar_percentage\\":\\"70\\",\\"bar_color\\":\\"ffcb5c_1.00\\"},{\\"bar_label\\":\\"Corel\\",\\"bar_percentage\\":\\"60\\",\\"bar_color\\":\\"949494_1.00\\"}],\\"hide_percentage_text\\":\\"yes\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"progressbar\\",\\"mod_settings\\":{\\"mod_title_progressbar\\":\\"Programming\\",\\"progress_bars\\":[{\\"bar_label\\":\\"HTML\\",\\"bar_percentage\\":\\"80\\",\\"bar_color\\":\\"68d2ed_1.00\\"},{\\"bar_label\\":\\"CSS\\",\\"bar_percentage\\":\\"73\\",\\"bar_color\\":\\"eb659f_1.00\\"},{\\"bar_label\\":\\"JS\\",\\"bar_percentage\\":\\"65\\",\\"bar_color\\":\\"ff36de_1.00\\"},{\\"bar_label\\":\\"PHP\\",\\"bar_percentage\\":\\"30\\",\\"bar_color\\":\\"9ec737_1.00\\"}],\\"hide_percentage_text\\":\\"yes\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"edf6ff_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"row_anchor\\":\\"skills\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Work Experience<\\\\/h2><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">**Purchase the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/timeline\\\\\\\\\\\\\\">Timeline Addon<\\\\/a> to recreate this beautiful timeline resume layout**<\\\\/p>\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"underline\\"}},{\\"mod_name\\":\\"timeline\\",\\"mod_settings\\":{\\"template_timeline\\":\\"list\\",\\"source_timeline\\":\\"text\\",\\"category_post_timeline\\":\\"|single\\",\\"order_post_timeline\\":\\"desc\\",\\"orderby_post_timeline\\":\\"date\\",\\"display_post_timeline\\":\\"excerpt\\",\\"hide_feat_img_post_timeline\\":\\"no\\",\\"text_source_timeline\\":[{\\"title_timeline\\":\\"Lead Designer\\",\\"icon_timeline\\":\\"fa-thumbs-up\\",\\"iconcolor_timeline\\":\\"000000_1.00\\",\\"date_timeline\\":\\"2011 - Present\\",\\"content_timeline\\":\\"<p><em>Amazing Designs<\\\\/em><\\\\/p><p>Responsible for conceptualization and implementation of design of solutions that meet marketing strategies from concept to completion. Senior graphic designers often have the designation of “senior” because of their authority in decision-making. Or, they will play the lead role on projects and supervise intermediate and junior designer(s) in creating concepts, comps, layouts and final art.<\\\\/p>\\"},{\\"title_timeline\\":\\"Creative Director\\",\\"icon_timeline\\":\\"fa-paint-brush\\",\\"iconcolor_timeline\\":\\"000000_1.00\\",\\"date_timeline\\":\\"2007 - 2011\\",\\"content_timeline\\":\\"<p><i>Ocean\\\\\\\\\\\'s Media<\\\\/i><\\\\/p><p>Charged with determining the best ways for us to visually represent our company’s identity online. It\\\\\\\\\\\'s very much a people-oriented job, involving development of high-level concepts for design projects. It also involves working with internal and external clients, pitching designs, and understanding client needs. At times, we require you to develop visual designs, and at other times, the Creative Director will be responsible for recruiting and managing third party design firms as well as internal design resources.<\\\\/p>\\"},{\\"title_timeline\\":\\"Frontend Designer\\",\\"icon_timeline\\":\\"fa-star-o\\",\\"iconcolor_timeline\\":\\"000000_1.00\\",\\"date_timeline\\":\\"2002 - 2007\\",\\"content_timeline\\":\\"<p><i>Themify<\\\\/i><\\\\/p><p><strong>Duties and Expectations<\\\\/strong><\\\\/p><p>A front-end web developer is generally expected to:<\\\\/p><ul><li>Develop functional and appealing web applications based on usability<\\\\/li><li>Provide website maintenance and enhancements<\\\\/li><li>Use a combination of markup languages to write web pages<\\\\/li><li>Write functional requirement documents and specifications<\\\\/li><li>Create quality mock-ups and prototypes on tight timelines<\\\\/li><\\\\/ul>\\"}]}}]}],\\"styling\\":{\\"row_anchor\\":\\"resume\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"96e0eb_1.00\\",\\"font_color\\":\\"000000_1.00\\",\\"link_color\\":\\"fffa70_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Status<\\\\/h2>\\",\\"link_color\\":\\"ffffff_1.00\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"4 Years Experience\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffffff_1.00\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-calendar\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_options\\":\\"\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"65 Completed Projects\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffffff_1.00\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-check-square\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_options\\":\\"\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"89 Happy Clients\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffffff_1.00\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-heart\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_options\\":\\"\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/173422046.png\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"row_anchor\\":\\"status\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Portfolio<\\\\/h2>\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[portfolio style=\\\\\\\\\\\\\\"grid3\\\\\\\\\\\\\\" limit=\\\\\\\\\\\\\\"3\\\\\\\\\\\\\\" image_w=\\\\\\\\\\\\\\"366\\\\\\\\\\\\\\" image_h=\\\\\\\\\\\\\\"260\\\\\\\\\\\\\\"]<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"row_anchor\\":\\"portfolio\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_feature\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Facebook<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-facebook\\",\\"icon_color_feature\\":\\"000000\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_feature\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Linked In<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-linkedin\\",\\"icon_color_feature\\":\\"000000\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/ca.linkedin.com\\\\/\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_feature\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Twitter<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-twitter\\",\\"icon_color_feature\\":\\"000000\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.twitter.com\\\\/themify\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_feature\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Google+<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-google-plus\\",\\"icon_color_feature\\":\\"000000\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/plus.google.com\\\\/u\\\\/0\\\\/b\\\\/109280316400365629341\\\\/109280316400365629341\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]}]}]}],\\"styling\\":{\\"row_anchor\\":\\"connect\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"e6ae6a_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Contact<\\\\/h2>\\",\\"link_color\\":\\"b751d6_1.00\\",\\"text_decoration\\":\\"underline\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"mod_settings\\":{\\"address_map\\":\\"Toronto, ON\\",\\"zoom_map\\":\\"8\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"h_map\\":\\"200\\",\\"type_map\\":\\"TERRAIN\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"info_window_map\\":\\"Call me @ 647-992-4231\\",\\"w_map_static\\":\\"500\\",\\"map_display_type\\":\\"dynamic\\",\\"w_map_unit\\":\\"%\\",\\"unit_h\\":\\"-1\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[themify_icon icon=\\\\\\\\\\\\\\"fa-map-marker\\\\\\\\\\\\\\" ] 250 King Str. West <br \\\\/>[themify_icon icon=\\\\\\\\\\\\\\"fa-phone\\\\\\\\\\\\\\" ] 647-992-4231<\\\\/p>\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>**Purchase the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/contact\\\\\\\\\\\\\\">Contact Addon <\\\\/a>to recreate this contact form layout**<\\\\/p>\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"contact\\",\\"mod_settings\\":{\\"layout_contact\\":\\"style1\\"}}]}]}]}],\\"styling\\":{\\"row_anchor\\":\\"contact\\",\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6167,
  'post_date' => '2017-01-13 04:45:46',
  'post_date_gmt' => '2017-01-13 04:45:46',
  'post_content' => '<!--themify_builder_static--><h1>All Layouts</h1>
 <h4>17 Header/Page Styles</h4> <p>Select a header/page design from 17 styles (the no header option is perfect for making landing pages where you don&#8217;t want to have header navigation). And yes, there is a sticky header option and this design list is growing!</p>
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/classic-header/" > <img src="https://themify.me/wp-content/uploads/2018/03/header-classic-1.png" width="160" height="135" title="Header Classic (*New)" alt="Header Classic (*New)" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/classic-header/" > Header Classic (*New) </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/top-widgets/" > <img src="https://themify.me/wp-content/uploads/2018/03/header-top-widget-1.png" width="160" height="135" title="Top Widget (*New)" alt="Top Widget (*New)" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/top-widgets/" > Top Widget (*New) </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/magazine-header/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/magazine-header-2-160x135.png" width="160" height="135" title="Header Magazine" alt="Header Magazine" srcset="https://themify.me/demo/themes/ultra/files/2016/11/magazine-header-2.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/magazine-header-2-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/magazine-header/" > Header Magazine </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/split-menu/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/menu-split-160x135.png" width="160" height="135" title="Split Menu " alt="Split Menu " srcset="https://themify.me/demo/themes/ultra/files/2016/11/menu-split.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/menu-split-150x126.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/split-menu/" > Split Menu </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/block/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/header-block-160x135.png" width="160" height="135" title="Header Block" alt="Header Block" srcset="https://themify.me/demo/themes/ultra/files/2016/11/header-block.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/header-block-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/block/" > Header Block </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/header-horizontal-160x135.png" width="160" height="135" title="Header Horizontal" alt="Header Horizontal" srcset="https://themify.me/demo/themes/ultra/files/2016/11/header-horizontal.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/header-horizontal-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal/" > Header Horizontal </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-content/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/boxed-content-193x162.png" width="160" height="135" title="Header Boxed Content" alt="Header Boxed Content" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-content/" > Header Boxed Content </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-layout/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/boxed-layout-160x135.png" width="160" height="135" title="Header Boxed Layout" alt="Header Boxed Layout" srcset="https://themify.me/demo/themes/ultra/files/2016/11/boxed-layout.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/boxed-layout-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-layout/" > Header Boxed Layout </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/left-pane/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/left-pane-160x135.png" width="160" height="135" title="Header Left Pane" alt="Header Left Pane" srcset="https://themify.me/demo/themes/ultra/files/2016/11/left-pane.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/left-pane-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/left-pane/" > Header Left Pane </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/min-bar/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/min-bar-160x135.png" width="160" height="135" title="Header Min Bar" alt="Header Min Bar" srcset="https://themify.me/demo/themes/ultra/files/2016/11/min-bar.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/min-bar-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/min-bar/" > Header Min Bar </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/top-bar/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/top-bar-160x135.png" width="160" height="135" title="Header Top Bar" alt="Header Top Bar" srcset="https://themify.me/demo/themes/ultra/files/2016/11/top-bar.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/top-bar-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/top-bar/" > Header Top Bar </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-compact/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/boxed-compact-160x135.png" width="160" height="135" title="Header Boxed Compact" alt="Header Boxed Compact" srcset="https://themify.me/demo/themes/ultra/files/2016/11/boxed-compact.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/boxed-compact-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-compact/" > Header Boxed Compact </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/stripe/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/header-stripe-1-160x135.png" width="160" height="135" title="Header Stripe" alt="Header Stripe" srcset="https://themify.me/demo/themes/ultra/files/2016/11/header-stripe-1.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/header-stripe-1-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/stripe/" > Header Stripe </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/overlay/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/overlay-160x135.png" width="160" height="135" title="Header Overlay" alt="Header Overlay" srcset="https://themify.me/demo/themes/ultra/files/2016/11/overlay.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/overlay-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/overlay/" > Header Overlay </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/slide-out/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/slide-out-160x135.png" width="160" height="135" title="Header Slide Out" alt="Header Slide Out" srcset="https://themify.me/demo/themes/ultra/files/2016/11/slide-out.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/slide-out-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2016/11/slide-out-1x1.png 1w, https://themify.me/demo/themes/ultra/files/2016/11/slide-out-11x9.png 11w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/slide-out/" > Header Slide Out </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/right-pane/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/right-pane-160x135.png" width="160" height="135" title="Header Right Pane" alt="Header Right Pane" srcset="https://themify.me/demo/themes/ultra/files/2016/11/right-pane.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/right-pane-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/right-pane/" > Header Right Pane </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/no-header/" > <img src="https://themify.me/wp-content/uploads/2016/06/no-header.png" width="160" height="135" title="No Header" alt="No Header" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/no-header/" > No Header </a> </h3> 
 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/header-more-to-come-160x135.png" width="160" height="135" title="More to come..." alt="More to come..." srcset="https://themify.me/demo/themes/ultra/files/2016/11/header-more-to-come.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/header-more-to-come-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> <h3> More to come... </h3> 
 <h4>6 Header Background Options</h4><p>Header background allows you to: upload a background image, pick a solid color, insert a slider, upload a video, set animating colors, or have it transparent if you want.</p>
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/image/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/image-background-160x135.png" width="160" height="135" title="Image" alt="Image" srcset="https://themify.me/demo/themes/ultra/files/2016/11/image-background.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/image-background-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/image/" > Image </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/transparent/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/transparent-160x135.png" width="160" height="135" title="Transparent" alt="Transparent" srcset="https://themify.me/demo/themes/ultra/files/2016/11/transparent.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/transparent-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/transparent/" > Transparent </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/slider/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/slider-1-160x135.png" width="160" height="135" title="Slider" alt="Slider" srcset="https://themify.me/demo/themes/ultra/files/2016/11/slider-1.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/slider-1-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/slider/" > Slider </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/split-menu/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/video-160x135.png" width="160" height="135" title="Video" alt="Video" srcset="https://themify.me/demo/themes/ultra/files/2016/11/video.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/video-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/split-menu/" > Video </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/animating-color/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/animation-160x135.png" width="160" height="135" title="Animating Colors" alt="Animating Colors" srcset="https://themify.me/demo/themes/ultra/files/2016/11/animation.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/animation-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/animating-color/" > Animating Colors </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-compact/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/any-color-160x135.png" width="160" height="135" title="Any Color" alt="Any Color" srcset="https://themify.me/demo/themes/ultra/files/2016/11/any-color.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/any-color-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/boxed-compact/" > Any Color </a> </h3> 
 <h4>6 Footer Layouts</h4><p>6 footer layout choices with options to toggle visibility of footer logo, menu, widget, and credit text.</p>
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-default/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/footer-block-160x135.png" width="160" height="135" title="Footer Block" alt="Footer Block" srcset="https://themify.me/demo/themes/ultra/files/2016/11/footer-block.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/footer-block-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-default/" > Footer Block </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-left-column/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/footer-left-column-160x135.png" width="160" height="135" title="Footer Left Column" alt="Footer Left Column" srcset="https://themify.me/demo/themes/ultra/files/2016/11/footer-left-column-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/footer-left-column-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2016/11/footer-left-column.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-left-column/" > Footer Left Column </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-right-column/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/footer-right-column-160x135.png" width="160" height="135" title="Footer Right Column" alt="Footer Right Column" srcset="https://themify.me/demo/themes/ultra/files/2016/11/footer-right-column-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/footer-right-column-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2016/11/footer-right-column.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-right-column/" > Footer Right Column </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-horizontal-left/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-left-1-160x135.png" width="160" height="135" title="Footer Horizontal Left" alt="Footer Horizontal Left" srcset="https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-left-1-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-left-1-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-left-1.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-horizontal-left/" > Footer Horizontal Left </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-horizontal-right/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-right-160x135.png" width="160" height="135" title="Footer Horizontal Right" alt="Footer Horizontal Right" srcset="https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-right-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-right-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2016/11/footer-horizontal-right.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/footer-horizontal-right/" > Footer Horizontal Right </a> </h3> 
 
 <img src="https://themify.me/wp-content/uploads/2016/06/no-header.png" width="160" height="135" title="No Footer" alt="No Footer" /> <h3> No Footer </h3> 
 <h4>5 Single Post Layouts</h4><p>In term of single post layout, there is a default layout plus 4 unique layouts.</p>
 
 <a href="https://themify.me/demo/themes/ultra/2016/06/06/split-layout/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/Split-160x135.png" width="160" height="135" title="Split Layout" alt="Split Layout" srcset="https://themify.me/demo/themes/ultra/files/2016/11/Split.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/Split-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/2016/06/06/split-layout/" > Split Layout </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/2016/06/06/fullwidth-layout/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/fullwidth-160x135.png" width="160" height="135" title="Fullwidth Layout" alt="Fullwidth Layout" srcset="https://themify.me/demo/themes/ultra/files/2016/11/fullwidth.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/fullwidth-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/2016/06/06/fullwidth-layout/" > Fullwidth Layout </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/2016/06/06/slider-layout/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/slider-160x135.png" width="160" height="135" title="Slider Layout" alt="Slider Layout" srcset="https://themify.me/demo/themes/ultra/files/2016/11/slider.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/slider-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/2016/06/06/slider-layout/" > Slider Layout </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/2016/06/07/gallery-layout/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/gallery-160x135.png" width="160" height="135" title="Gallery Layout" alt="Gallery Layout" srcset="https://themify.me/demo/themes/ultra/files/2016/11/gallery.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/gallery-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/2016/06/07/gallery-layout/" > Gallery Layout </a> </h3> 
 <h4>6 Archive Layouts</h4><p>For the archive layouts, we have 6 different styles that you can choose from: slider, fullwidth, masonry, grids, polaroid, and overlay. You may also toggle the visibility of the post elements such as post title, featured image, meta, content, etc.</p>
 
 <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/slider-160x135.jpg" width="160" height="135" title="Slider" alt="Slider" srcset="https://themify.me/demo/themes/ultra/files/2016/11/slider.jpg 160w, https://themify.me/demo/themes/ultra/files/2016/11/slider-150x127.jpg 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > Slider </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/fullwidth-160x135.jpg" width="160" height="135" title="Fullwidth" alt="Fullwidth" srcset="https://themify.me/demo/themes/ultra/files/2016/11/fullwidth.jpg 160w, https://themify.me/demo/themes/ultra/files/2016/11/fullwidth-150x127.jpg 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > Fullwidth </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/mansory-160x135.jpg" width="160" height="135" title="Mansory" alt="Mansory" srcset="https://themify.me/demo/themes/ultra/files/2016/11/mansory.jpg 160w, https://themify.me/demo/themes/ultra/files/2016/11/mansory-150x127.jpg 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > Mansory </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/grid-160x135.jpg" width="160" height="135" title="Grid" alt="Grid" srcset="https://themify.me/demo/themes/ultra/files/2016/11/grid.jpg 160w, https://themify.me/demo/themes/ultra/files/2016/11/grid-150x127.jpg 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > Grid </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/polaroid-160x135.jpg" width="160" height="135" title="Polaroid" alt="Polaroid" srcset="https://themify.me/demo/themes/ultra/files/2016/11/polaroid.jpg 160w, https://themify.me/demo/themes/ultra/files/2016/11/polaroid-150x127.jpg 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > Polaroid </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/overlay-160x135.jpg" width="160" height="135" title="Overlay" alt="Overlay" srcset="https://themify.me/demo/themes/ultra/files/2016/11/overlay.jpg 160w, https://themify.me/demo/themes/ultra/files/2016/11/overlay-150x127.jpg 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/blog/all-layouts/" > Overlay </a> </h3> 
 <h4>Section Scrolling (*New)</h4> <p>Inspired by our <a href="https://themify.me/themes/fullpane">Fullpane</a> theme, full section scrolling feature allows viewers to scroll through your page design one row at a time like a presentation slideshow. Check out the demo below and see our Vertical and Horizontal section scrolling.</p>
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/slide-out-header/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/slide-out-scrolling-160x135.png" width="160" height="135" title="Vertical Slide Out Header &lt;strong&gt;(Mix*)&lt;/strong&gt;" alt="Vertical Slide Out Header &lt;strong&gt;(Mix*)&lt;/strong&gt;" srcset="https://themify.me/demo/themes/ultra/files/2016/11/slide-out-scrolling.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/slide-out-scrolling-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/slide-out-header/" > Vertical + Slide Out Header <strong>(Mix*)</strong> </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/overlay-header/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/overlay-scrolling-160x135.png" width="160" height="135" title="Vertical Overlay Header" alt="Vertical Overlay Header" srcset="https://themify.me/demo/themes/ultra/files/2016/11/overlay-scrolling.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/overlay-scrolling-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/overlay-header/" > Vertical + Overlay Header </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-min-bar-header/" > <img src="https://themify.me/demo/themes/ultra/files/2018/04/minbar-header-160x135.png" width="160" height="135" title="Horizontal Min Bar Header" alt="Horizontal Min Bar Header" srcset="https://themify.me/demo/themes/ultra/files/2018/04/minbar-header-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2018/04/minbar-header-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2018/04/minbar-header.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-min-bar-header/" > Horizontal + Min Bar Header </a> </h3> 
 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-top-bar-header/" > <img src="https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header-160x135.png" width="160" height="135" title="Horizontal Top Bar Header" alt="Horizontal Top Bar Header" srcset="https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-top-bar-header/" > Horizontal + Top Bar Header </a> </h3><!--/themify_builder_static-->',
  'post_title' => 'All Layouts',
  'post_excerpt' => '',
  'post_name' => 'all-layouts',
  'post_modified' => '2018-04-18 21:18:23',
  'post_modified_gmt' => '2018-04-18 21:18:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=6167',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'hide_page_title' => 'yes',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>All Layouts<\\\\/h1>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top_unit\\":\\"em\\",\\"margin_right_unit\\":\\"em\\",\\"margin_bottom\\":\\"2\\",\\"margin_bottom_unit\\":\\"em\\",\\"margin_left_unit\\":\\"em\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>17 Header\\\\/Page Styles<\\\\/h4>\\\\n<p>Select a header\\\\/page design from 17 styles (the no header option is perfect for making landing pages where you don\\\\\\\\\\\'t want to have header navigation). And yes, there is a sticky header option and this design list is growing!<\\\\/p>\\",\\"animation_effect\\":\\"fadeInUp\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/uploads\\\\/2018\\\\/03\\\\/header-classic-1.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Classic (*New)\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/classic-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInLeft\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/uploads\\\\/2018\\\\/03\\\\/header-top-widget-1.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Top Widget (*New)\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/top-widgets\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInLeft\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/magazine-header-2.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header  Magazine\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/magazine-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInLeft\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/menu-split.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Split Menu \\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/split-menu\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/header-block.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Block\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/block\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/header-horizontal.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Horizontal\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/horizontal\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/boxed-content-193x162.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Boxed Content\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/boxed-content\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/boxed-layout.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Boxed Layout\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/boxed-layout\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/left-pane.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Left Pane\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/left-pane\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/min-bar.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Min Bar\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/min-bar\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/top-bar.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Top Bar\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/top-bar\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/boxed-compact.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Boxed Compact\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/boxed-compact\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/header-stripe-1.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Stripe\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/stripe\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/overlay.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Overlay\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/overlay\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/slide-out.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Slide Out\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/slide-out\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/right-pane.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Header Right Pane\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/right-pane\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/uploads\\\\/2016\\\\/06\\\\/no-header.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"No Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/no-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/header-more-to-come.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"More to come...\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>6 Header Background Options<\\\\/h4><p>Header background allows you to: upload a background image, pick a solid color, insert a slider, upload a video, set animating colors, or have it transparent if you want.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/image-background.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Image\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/image\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/transparent.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Transparent\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/transparent\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/slider-1.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Slider\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/slider\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/video.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Video\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/split-menu\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/animation.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Animating Colors\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/animating-color\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/any-color.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Any Color\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/boxed-compact\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>6 Footer Layouts<\\\\/h4><p>6 footer layout choices with options to toggle visibility of footer logo, menu, widget, and credit text.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/footer-block.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Footer Block\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/footer-default\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/footer-left-column.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Footer Left Column\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/footer-left-column\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/footer-right-column.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Footer Right Column\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/footer-right-column\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/footer-horizontal-left-1.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Footer Horizontal Left\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/footer-horizontal-left\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/footer-horizontal-right.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Footer Horizontal Right\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/footer-horizontal-right\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/uploads\\\\/2016\\\\/06\\\\/no-header.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"No Footer\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>5 Single Post Layouts<\\\\/h4><p>In term of single post layout, there is a default layout plus 4 unique layouts.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"row_order\\":\\"10\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/Split.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Split Layout\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/2016\\\\/06\\\\/06\\\\/split-layout\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/fullwidth.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Fullwidth Layout\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/2016\\\\/06\\\\/06\\\\/fullwidth-layout\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/slider.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Slider Layout\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/2016\\\\/06\\\\/06\\\\/slider-layout\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/gallery.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Gallery Layout\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/2016\\\\/06\\\\/07\\\\/gallery-layout\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\"}]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>6 Archive Layouts<\\\\/h4><p>For the archive layouts, we have 6 different styles that you can choose from: slider, fullwidth, masonry, grids, polaroid, and overlay. You may also toggle the visibility of the post elements such as post title, featured image, meta, content, etc.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"row_order\\":\\"12\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/slider.jpg\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Slider\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/blog\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/fullwidth.jpg\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Fullwidth\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/blog\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/mansory.jpg\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Mansory\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/blog\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/grid.jpg\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Grid\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/blog\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/polaroid.jpg\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Polaroid\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/blog\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/overlay.jpg\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Overlay\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/blog\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Section Scrolling (*New)<\\\\/h4>\\\\n<p>Inspired by our <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/fullpane\\\\\\\\\\\\\\">Fullpane<\\\\/a> theme, full section scrolling feature allows viewers to scroll through your page design one row at a time like a presentation slideshow. Check out the demo below and see our Vertical and Horizontal section scrolling.<\\\\/p>\\",\\"animation_effect\\":\\"fadeInDown\\"}},{\\"row_order\\":\\"14\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/slide-out-scrolling.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Vertical + Slide Out Header <strong>(Mix*)<\\\\/strong>\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/slide-out-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/overlay-scrolling.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Vertical + Overlay Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/overlay-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/04\\\\/minbar-header.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Horizontal + Min Bar Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/horizontal-min-bar-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/04\\\\/top-bar-header.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Horizontal + Top Bar Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/horizontal-top-bar-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5916,
  'post_date' => '2016-10-05 18:33:19',
  'post_date_gmt' => '2016-10-05 18:33:19',
  'post_content' => '<!--themify_builder_static--><h1>New Music Landing Page.</h1><h5>We used the Audio, Button, and Pricing Table addon to show you how you can create an amazing music layout.</h5>
 <iframe width="100%" height="300" scrolling="no" frameborder="no" src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/318368285&#038;color=%23ff5500&#038;auto_play=false&#038;hide_related=false&#038;show_comments=true&#038;show_user=true&#038;show_reposts=false&#038;show_teaser=true&#038;visual=true"></iframe>
 <h2>Showcase Your Music.</h2> <p><strong>Morbi augue lacus, malesuada id cursus a, consequat vel risus. Fusce non lectus nibh. Quisque tempor augue ut porttitor auctor. Suspendisse iaculis diam non est ultrices rhoncus. </strong><strong>Suspendisse potenti. Aenean ultrices nisl quis tempor sodales. </strong></p> <h4><a href="https://themify.me/themes/landing"><b>Get it now</b></a></h4> <h4><a href="https://themify.me/themes/landing"><b>Download now</b></a></h4>
 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/ariana-grande-400x400.jpg" width="400" height="400" alt="Video" /> 
 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/jason-derulo-400x400.jpg" width="400" height="400" alt="Video" /> 
 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/kanye-west-400x400.png" width="400" height="400" alt="Video" /> 
 <h2>Broadcast Your music.</h2> <p><strong>Upload your tracks using the <a href="https://themify.me/addons/audio/">Audio addon</a>, and allow you users to get a taste of your music. Check out our <a href="https://themify.me/addons/pricing-table">Pricing Table addon</a> below.</strong></p>
 
 <ol> <li itemprop="track" itemscope="" itemtype="http://schema.org/MusicRecording"> <a href="#" itemprop="url">Helpless</a> <a href="https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3" download></a> <audio id="audio-5916-1" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3?_=1" /><a href="https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3">https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3</a></audio> </li> <li itemprop="track" itemscope="" itemtype="http://schema.org/MusicRecording"> <a href="#" itemprop="url">I\'ve Not Over Yet</a> <a href="https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3" download></a> <audio id="audio-5916-2" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3?_=2" /><a href="https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3">https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3</a></audio> </li> <li itemprop="track" itemscope="" itemtype="http://schema.org/MusicRecording"> <a href="#" itemprop="url">O Song</a> <a href="https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3" download></a> <audio id="audio-5916-3" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3?_=3" /><a href="https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3">https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3</a></audio> </li> </ol> 
 <h2>Get the new Music landing page</h2><p>Now available together with all the 25+ page layouts</p><!--/themify_builder_static-->',
  'post_title' => 'Video',
  'post_excerpt' => '',
  'post_name' => 'video',
  'post_modified' => '2017-10-27 21:54:13',
  'post_modified_gmt' => '2017-10-27 21:54:13',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=5916',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-block',
    'full_height_header' => 'yes',
    'header_wrap' => 'video',
    'video_file' => 'https://themify.me/demo/themes/ultra/files/2015/06/guitar.mp4',
    'background_image' => 'https://themify.me/demo/themes/ultra/files/2016/10/guitar-1024x576.jpg',
    'headerwrap_text_color' => '#ffffff',
    'headerwrap_link_color' => '#ffffff',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>New Music Landing Page.<\\\\/h1><h5>We used the Audio, Button, and Pricing Table addon to show you how you can create an amazing music layout.<\\\\/h5>\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c23\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\"}]}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/04\\\\/91078382.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<iframe width=\\\\\\\\\\\\\\"100%\\\\\\\\\\\\\\" height=\\\\\\\\\\\\\\"300\\\\\\\\\\\\\\" scrolling=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\" frameborder=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\" src=\\\\\\\\\\\\\\"https:\\\\/\\\\/w.soundcloud.com\\\\/player\\\\/?url=https%3A\\\\/\\\\/api.soundcloud.com\\\\/tracks\\\\/318368285&amp;color=%23ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false&amp;show_teaser=true&amp;visual=true\\\\\\\\\\\\\\"><\\\\/iframe>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth-content\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/02\\\\/139731562-1-1024x683.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"font_color\\":\\"ffffff\\",\\"link_color\\":\\"ffffff\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"45\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"10\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Showcase Your Music.<\\\\/h2>\\\\n<p><strong>Morbi augue lacus, malesuada id cursus a, consequat vel risus. Fusce non lectus nibh. Quisque tempor augue ut porttitor auctor. Suspendisse iaculis diam non est ultrices rhoncus. <\\\\/strong><strong>Suspendisse potenti. Aenean ultrices nisl quis tempor sodales. <\\\\/strong><\\\\/p>\\\\n<h4><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/landing\\\\\\\\\\\\\\"><b>Get it now<\\\\/b><\\\\/a><\\\\/h4>\\\\n<h4><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/landing\\\\\\\\\\\\\\"><b>Download now<\\\\/b><\\\\/a><\\\\/h4>\\\\n\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/ariana-grande-400x400.jpg\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"cid\\":\\"c65\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/jason-derulo-400x400.jpg\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"cid\\":\\"c73\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/kanye-west-400x400.png\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"cid\\":\\"c81\\"}}]}],\\"gutter\\":\\"gutter-none\\"},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Broadcast Your music.<\\\\/h2>\\\\n<p><strong>Upload your tracks using the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/audio\\\\/\\\\\\\\\\\\\\">Audio addon<\\\\/a>, and allow you users to get a taste of your music. Check out our <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/pricing-table\\\\\\\\\\\\\\">Pricing Table addon<\\\\/a> below.<\\\\/strong><\\\\/p>\\\\n\\",\\"background_color\\":\\"DCDDD8\\",\\"font_color\\":\\"475F77\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"D74B4B\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c85\\"}},{\\"mod_name\\":\\"audio\\",\\"mod_settings\\":{\\"music_playlist\\":[{\\"audio_name\\":\\"Helpless\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addon-audio\\\\/files\\\\/2015\\\\/06\\\\/Helpless.mp3\\"},{\\"audio_name\\":\\"I\\\\\\\\\\\'ve Not Over Yet\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addon-audio\\\\/files\\\\/2015\\\\/06\\\\/myuu-ItsNotOverYet.mp3\\"},{\\"audio_name\\":\\"O Song\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addon-audio\\\\/files\\\\/2015\\\\/06\\\\/o.mp3\\"}],\\"hide_download_audio\\":\\"no\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"border_top_color\\":\\"_1.00\\",\\"cid\\":\\"c89\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"475F77\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth-content\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Get the new Music landing page<\\\\/h2><p>Now available together with all the 25+ page layouts<\\\\/p>\\",\\"cid\\":\\"c100\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/06\\\\/193816727.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"dbdbdb_1.00\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_bottom_color\\":\\"faf205_1.00\\",\\"border_bottom_width\\":\\"5\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5153,
  'post_date' => '2016-06-08 21:18:36',
  'post_date_gmt' => '2016-06-08 21:18:36',
  'post_content' => '<!--themify_builder_static--><h1>Section Scrolling</h1> 
 <p>A built-in feature in Ultra theme.</p> 
 <a href="https://themify.me/themes/ultra" >Learn More</a> 
 <h2 style="text-align: center;">Great For Presentations</h2> 
 <h2 style="text-align: center;">Sexy Parallax Scrolling</h2> 
 <h2>Horizontal Scrolling</h2> 
 <p>Can go horizontal or vertical</p> 
 <h2>Nice &amp; Easy</h2> 
 <p>Import a pre-designed layout or design your own.</p> 
 <h2>Build Anything With Ultra</h2> 
 <a href="https://themify.me/themes/ultra" >Get Ultra Now</a><!--/themify_builder_static-->',
  'post_title' => 'Section Scrolling',
  'post_excerpt' => '',
  'post_name' => 'section-scrolling',
  'post_modified' => '2018-11-09 23:40:00',
  'post_modified_gmt' => '2018-11-09 23:40:00',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=5153',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'section_full_scrolling' => 'yes',
    'section_scrolling_mobile' => 'on',
    'header_design' => 'header-slide-out',
    'header_wrap' => 'transparent',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"5cea159\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"0d8fda7\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"a2ea799\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Section Scrolling<\\\\/h1>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"ff45d89\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_size\\":\\"1.2\\",\\"font_size_unit\\":\\"em\\",\\"line_height\\":\\"1.5\\",\\"line_height_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>A built-in feature in Ultra theme.<\\\\/p>\\",\\"animation_effect\\":\\"fadeInRight\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"09714ca\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Learn More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/ultra\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"}],\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/06\\\\/demoimage6.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"cover_gradient\\",\\"cover_color\\":\\"#000000_0.29\\",\\"cover_gradient-gradient\\":\\"0% rgba(255, 230, 161, 0.43)|98% rgba(0, 0, 0, 0.55)\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"element_id\\":\\"d26d0b9\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"867e9f0\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"11d1b92\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Great For Presentations<\\\\/h2>\\",\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage12.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"363338\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"link_color\\":\\"fff785\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth\\"}},{\\"element_id\\":\\"8fda124\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"e18a255\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"2fc8d8c\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Sexy Parallax Scrolling<\\\\/h2>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage16.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"363338\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"link_color\\":\\"fff785\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth\\",\\"row_scroll_direction\\":\\"module_row_slide\\"}},{\\"element_id\\":\\"88eb1ea\\",\\"row_order\\":\\"3\\",\\"cols\\":[{\\"element_id\\":\\"d53e830\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"1848191\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Horizontal Scrolling<\\\\/h2>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"6074527\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_size\\":\\"1.2\\",\\"font_size_unit\\":\\"em\\",\\"line_height\\":\\"1.5\\",\\"line_height_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Can go horizontal or vertical<\\\\/p>\\",\\"animation_effect\\":\\"fadeInRight\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/06\\\\/demoimage66.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_slide\\",\\"row_anchor\\":\\"horizontal-scroll\\"}},{\\"element_id\\":\\"6dfd22e\\",\\"row_order\\":\\"4\\",\\"cols\\":[{\\"element_id\\":\\"639a555\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"5b0c26d\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Nice &amp; Easy<\\\\/h2>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"ccabb9e\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_size\\":\\"1.2\\",\\"font_size_unit\\":\\"em\\",\\"line_height\\":\\"1.5\\",\\"line_height_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Import a pre-designed layout or design your own.<\\\\/p>\\",\\"animation_effect\\":\\"fadeInRight\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/06\\\\/demoimage50.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_slide\\"}},{\\"element_id\\":\\"34a4632\\",\\"row_order\\":\\"5\\",\\"cols\\":[{\\"element_id\\":\\"046b6b1\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"943b1b5\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Build Anything With Ultra<\\\\/h2>\\",\\"animation_effect\\":\\"flipInX\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"70c3a44\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"xlarge\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Get Ultra Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/ultra\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"}],\\"animation_effect\\":\\"fadeInUpBig\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/06\\\\/demoimage56.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_section\\"}},{\\"element_id\\":\\"813bd17\\",\\"row_order\\":\\"6\\",\\"cols\\":[{\\"element_id\\":\\"631d32f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4907,
  'post_date' => '2016-03-14 20:22:11',
  'post_date_gmt' => '2016-03-14 20:22:11',
  'post_content' => '<!--themify_builder_static--><img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/Apple-Watch_MockUp_typeA-1-650x662.png" width="650" alt="Overlay" /> 
 <h1>Smart Watch</h1><h3>Change the way you see time</h3>
 <h1>Why Smart Watch?</h1><h3>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere eget diam pretium cursus at ligula.</h3>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/Apple_Watch_Mockup_juank85-3-550x536.png" width="550" alt="Overlay" /> 
 <h3>Phone Connect</h3>
 
 <a href="https://themify.me/" >LEARN MORE</a> 
 <h3>Fitness Tracker</h3>
 
 <a href="https://themify.me/" >LEARN MORE</a> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/apple-watch-moxtra-app-1024x537-550x288.png" width="550" alt="Overlay" /> 
 <h1>Colors</h1><h3>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula.</h3>
 <h1>Get Smart Watch</h1><h3>Buy from our store and get 30% off</h3>
 
 <a href="http://themify.me/" >BUY NOW</a><!--/themify_builder_static-->',
  'post_title' => 'Overlay',
  'post_excerpt' => '',
  'post_name' => 'overlay',
  'post_modified' => '2018-05-03 23:18:51',
  'post_modified_gmt' => '2018-05-03 23:18:51',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4907',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'custom_menu' => 'header-overlay-menu',
    'header_design' => 'header-overlay',
    'exclude_header_widgets' => 'no',
    'footer_design' => 'none',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/Apple-Watch_MockUp_typeA-1-650x662.png\\",\\"width_image\\":\\"650\\",\\"auto_fullwidth\\":\\"1\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c16\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Smart Watch<\\\\/h1><h3>Change the way you see time<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"13\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c24\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/Apple_Watch_MockUp_typeB-4.png\\",\\"background_repeat\\":\\"fullcover\\"}}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth-content\\",\\"visibility_all\\":\\"hide_all\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Why Smart Watch?<\\\\/h1><h3>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere eget diam pretium cursus at ligula.<\\\\/h3>\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"12\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c35\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/Apple_Watch_Mockup_juank85-3-550x536.png\\",\\"width_image\\":\\"550\\",\\"cid\\":\\"c43\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat-none\\",\\"background_color\\":\\"f2f2f2\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"6\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"6\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Phone Connect<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c54\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"ffffff\\",\\"link_color_hover\\":\\"000000\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"LEARN MORE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\"}]}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/iphone-1021293_1920.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.55\\",\\"cover_color_hover\\":\\"000000_0.89\\",\\"padding_top\\":\\"0\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Fitness Tracker<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c66\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"ffffff\\",\\"link_color_hover\\":\\"000000\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"LEARN MORE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\"}]}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/fitnessmockup-1.png\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.51\\",\\"cover_color_hover\\":\\"000000_0.85\\"}}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/apple-watch-moxtra-app-1024x537-550x288.png\\",\\"width_image\\":\\"550\\",\\"padding_top\\":\\"17\\",\\"padding_top_unit\\":\\"%\\",\\"cid\\":\\"c81\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Colors<\\\\/h1><h3>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula.<\\\\/h3>\\",\\"font_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c89\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat-none\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"6\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"6\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Get Smart Watch<\\\\/h1><h3>Buy from our store and get 30% off<\\\\/h3>\\",\\"text_align\\":\\"center\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c100\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"circle\\",\\"content_button\\":[{\\"label\\":\\"BUY NOW\\",\\"link\\":\\"http:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\",\\"new_window\\":\\"0\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"20\\",\\"text_align\\":\\"center\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c104\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"f2f2f2\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"6\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"6\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4911,
  'post_date' => '2016-03-14 20:27:21',
  'post_date_gmt' => '2016-03-14 20:27:21',
  'post_content' => '<!--themify_builder_static--><h1 style="text-align: center;">Super Comp</h1><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</h3>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/Mac-Pro-main-600x880.png" width="600" alt="" /> 
 <p style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p>
 
 
 
 
 <h3> Futuristic </h3> <p style="text-align: right;">Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.</p> 
 
 
 
 
 
 <h3> High quality </h3> <p style="text-align: right;">Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.</p> 
 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/processor-382x565.jpg" width="382" alt="" /> 
 
 
 
 
 <h3> Go green </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.</p> 
 
 
 
 
 
 <h3> Recycled </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.</p> 
 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/comingsoon-500x330.jpg" width="500" height="330" alt="" /> 
 <h4><strong><a href="http://themify.me/">High Performance</a></strong></h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/core-500x330.jpg" width="500" height="330" alt="" /> 
 <h4><strong><a href="http://themify.me/">Thermal Core</a></strong></h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
 <h4><strong><a href="http://themify.me/">Strong Materials</a></strong></h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/cube-2-500x330.jpg" width="500" height="330" alt="" /> 
 <h4><strong><a href="http://themify.me/">Upgradable</a></strong></h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/upgradable-500x330.jpg" width="500" height="330" alt="" /> 
 <h2 style="text-align: center;">Coming 2016</h2><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</h3>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/memory-500x500.jpg" width="500" height="500" alt="" /> 
 
 
 
 
 <h3> Lifetime guarantee </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p> 
 
 
 
 
 
 <h3> Free shipping </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p> 
 
 
 
 
 
 <h3> 1-1 replacement </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.</p> 
 
 <h2 style="text-align: center;">Unlike Any We&#8217;ve Ever Built</h2><h3 style="text-align: center;">The Making of Super Comp</h3><p style="text-align: center;"> </p>
 
 <a href="https://www.youtube.com/watch?v=IbWOQWw1wkM" > 
 
 </a> 
 
 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/Mac-Pro-main-1-600x830.jpg" width="600" alt="" /> 
 <h1 style="text-align: center;">Super Comp</h1><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt</h3>
 
 <a href="https://themify.me/" > ORDER NOW </a><!--/themify_builder_static-->',
  'post_title' => 'Slide Out',
  'post_excerpt' => '',
  'post_name' => 'slide-out',
  'post_modified' => '2017-10-31 00:43:53',
  'post_modified_gmt' => '2017-10-31 00:43:53',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4911',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'body_background_repeat' => 'fullcover',
    'header_design' => 'header-slide-out',
    'background_repeat' => 'fullcover',
    'footer_design' => 'none',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Super Comp<\\\\/h1><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c18\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/Mac-Pro-main-600x880.png\\",\\"width_image\\":\\"600\\",\\"cid\\":\\"c22\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.<\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"10\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"10\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c26\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat-none\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_bottom_color\\":\\"36f5ff\\",\\"border_bottom_width\\":\\"1\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Futuristic\\",\\"content_feature\\":\\"<p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-arrows-h\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"right\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"2\\",\\"padding_left_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c37\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"High quality\\",\\"content_feature\\":\\"<p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-trophy\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"right\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"2\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c41\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/processor-382x565.jpg\\",\\"width_image\\":\\"382\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c49\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Go green\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-leaf\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"2\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c57\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Recycled\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit sed.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-recycle\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"7\\",\\"padding_right\\":\\"2\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c61\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"000000_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"9\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"7\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/comingsoon-500x330.jpg\\",\\"width_image\\":\\"500\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"330\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c80\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4><strong><a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/themify.me\\\\/\\\\\\\\\\\\\\">High Performance<\\\\/a><\\\\/strong><\\\\/h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"none\\",\\"padding_top\\":\\"14\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"15\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c88\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_color\\":\\"000000_1.00\\"}},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/core-500x330.jpg\\",\\"width_image\\":\\"500\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"330\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c96\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\"}},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4><strong><a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/themify.me\\\\/\\\\\\\\\\\\\\">Thermal Core<\\\\/a><\\\\/strong><\\\\/h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"none\\",\\"padding_top\\":\\"14\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"15\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c104\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_color\\":\\"000000_1.00\\"}}],\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"000000_1.00\\",\\"text_align\\":\\"center\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4><strong><a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/themify.me\\\\/\\\\\\\\\\\\\\">Strong Materials<\\\\/a><\\\\/strong><\\\\/h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"none\\",\\"padding_top\\":\\"14\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"15\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c123\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_color\\":\\"000000_1.00\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/cube-2-500x330.jpg\\",\\"width_image\\":\\"500\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"330\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c131\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\"}},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4><strong><a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/themify.me\\\\/\\\\\\\\\\\\\\">Upgradable<\\\\/a><\\\\/strong><\\\\/h4><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"none\\",\\"padding_top\\":\\"14\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"15\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c139\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_color\\":\\"000000_1.00\\"}},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/upgradable-500x330.jpg\\",\\"width_image\\":\\"500\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"330\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c147\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\"}}],\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"000000_1.00\\",\\"text_align\\":\\"center\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Coming 2016<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c158\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/memory-500x500.jpg\\",\\"width_image\\":\\"500\\",\\"height_image\\":\\"500\\",\\"padding_top\\":\\"9\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"9\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c162\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Lifetime guarantee\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-heart\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"cid\\":\\"c174\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Free shipping\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-truck\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"cid\\":\\"c182\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"1-1 replacement\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"36f5ff\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-shield\\",\\"icon_color_feature\\":\\"36f5ff\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"cid\\":\\"c190\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"030303_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Unlike Any We\\\\\\\\\\\'ve Ever Built<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">The Making of Super Comp<\\\\/h3><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"cid\\":\\"c201\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffffff_1.00\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-play\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/watch?v=IbWOQWw1wkM\\",\\"link_options\\":\\"lightbox\\",\\"text_decoration\\":\\"underline\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"cid\\":\\"c205\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/macpro_00090-2-1024x768-1024x768.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"000000\\",\\"cover_color_hover\\":\\"000000_0.77\\",\\"padding_top\\":\\"13\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"13\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_top_color\\":\\"36f5ff\\",\\"border_top_width\\":\\"1\\",\\"border_bottom_color\\":\\"36f5ff\\",\\"border_bottom_width\\":\\"1\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/Mac-Pro-main-1-600x830.jpg\\",\\"width_image\\":\\"600\\",\\"cid\\":\\"c224\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Super Comp<\\\\/h1><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"25\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"cid\\":\\"c232\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"circle\\",\\"content_button\\":[{\\"label\\":\\"ORDER NOW\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"new_window\\":\\"0\\"}],\\"font_size\\":\\"18\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"none\\",\\"cid\\":\\"c236\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"7\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3896,
  'post_date' => '2015-05-07 20:59:58',
  'post_date_gmt' => '2015-05-07 20:59:58',
  'post_content' => '',
  'post_title' => 'Blog - Grid4',
  'post_excerpt' => '',
  'post_name' => 'blog-grid4',
  'post_modified' => '2017-10-27 02:17:48',
  'post_modified_gmt' => '2017-10-27 02:17:48',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3896',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'query_category' => '0',
    'layout' => 'grid4',
    'disable_masonry' => 'no',
    'posts_per_page' => '8',
    'display_content' => 'none',
    'image_width' => '270',
    'image_height' => '180',
    'hide_meta_all' => 'yes',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6202,
  'post_date' => '2017-01-17 21:12:03',
  'post_date_gmt' => '2017-01-17 21:12:03',
  'post_content' => '',
  'post_title' => 'Boxed Post',
  'post_excerpt' => '',
  'post_name' => 'boxed-post',
  'post_modified' => '2017-08-21 01:18:14',
  'post_modified_gmt' => '2017-08-21 01:18:14',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=6202',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'query_category' => '0',
    'layout' => 'grid3',
    'post_content_layout' => 'boxed',
    'disable_masonry' => 'no',
    'posts_per_page' => '9',
    'image_width' => '370',
    'image_height' => '0',
    'hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3899,
  'post_date' => '2015-05-07 21:04:14',
  'post_date_gmt' => '2015-05-07 21:04:14',
  'post_content' => '',
  'post_title' => 'Blog',
  'post_excerpt' => '',
  'post_name' => 'blog',
  'post_modified' => '2018-06-04 03:26:44',
  'post_modified_gmt' => '2018-06-04 03:26:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3899',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_header_widgets' => 'yes',
    'query_category' => 'blog',
    'more_posts' => 'pagination',
    'posts_per_page' => '5',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7740,
  'post_date' => '2018-10-01 20:36:56',
  'post_date_gmt' => '2018-10-01 20:36:56',
  'post_content' => '<!--themify_builder_static--><h3></h3><iframe frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="https://maps.google.com/maps?q=Zb%C4%85szy%C5%84%2C+Poland&amp;t=m&amp;z=7&amp;output=embed&amp;iwloc=near"></iframe><!--/themify_builder_static-->

&nbsp;
<h1>Map Shortcode</h1>
[themify_map address="Zbąszyń, Poland" zoom="1"]

&nbsp;',
  'post_title' => 'Map Test Page',
  'post_excerpt' => '',
  'post_name' => 'map-test-page',
  'post_modified' => '2018-10-01 21:26:04',
  'post_modified_gmt' => '2018-10-01 21:26:04',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=7740',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"bf106cf\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"fb4cfc6\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"element_id\\":\\"cc6b672\\",\\"mod_settings\\":{\\"border-type\\":\\"top\\",\\"map_display_type\\":\\"dynamic\\",\\"address_map\\":\\"Zbąszyń,\\\\nPoland\\",\\"zoom_map\\":\\"7\\",\\"w_map\\":\\"100\\",\\"w_map_unit\\":\\"%\\",\\"w_map_static\\":\\"500\\",\\"h_map\\":\\"300\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"07abadc\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}}]}]},{\\"element_id\\":\\"a43957f\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"0b3a866\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2894,
  'post_date' => '2015-02-17 21:26:40',
  'post_date_gmt' => '2015-02-17 21:26:40',
  'post_content' => '<!--themify_builder_static--><h2>Auto Tiles</h2>
 <h2>List Post</h2>
 <h2>Flip Grid4</h2>
 <h2>Overlay Grid4</h2>
 <h2>Polaroid Grid3</h2>
 <h2>Grid2 Grayscale</h2>
 <h2>Masonry Grid4 Grayscale</h2>
 <h2>Grid4 No-Gutter Overlay Sepia</h2>
 <h2>Masonry Grid3 Grayscale Overlay No-gutter</h2><!--/themify_builder_static-->',
  'post_title' => 'Post Layouts',
  'post_excerpt' => '',
  'post_name' => 'all-layouts',
  'post_modified' => '2018-03-21 17:59:30',
  'post_modified_gmt' => '2018-03-21 17:59:30',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/landing/?page_id=2894',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_footer_widgets' => 'default',
    'layout' => 'slider',
    'posts_per_page' => '6',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Auto Tiles<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c19\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"auto_tiles\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"7\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"800\\",\\"img_height_post\\":\\"600\\",\\"hide_post_date_post\\":\\"no\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"tiles\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>List Post<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c34\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"list-post\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"1\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"excerpt\\",\\"img_width_post\\":\\"1160\\",\\"img_height_post\\":\\"600\\",\\"hide_post_date_post\\":\\"no\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"list-post\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Flip Grid4<\\\\/h2>\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_post\\":\\"grid4\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"post_content_layout\\":\\"flip\\",\\"post_filter\\":\\"no\\",\\"post_gutter\\":\\"no-gutter\\",\\"post_per_page_post\\":\\"8\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"290\\",\\"img_height_post\\":\\"290\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"flip\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Overlay Grid4<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c49\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid4\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_content_layout\\":\\"overlay\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"8\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"290\\",\\"img_height_post\\":\\"290\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"overlay\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Polaroid Grid3<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c64\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid3\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_content_layout\\":\\"polaroid\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"3\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"365\\",\\"img_height_post\\":\\"250\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"polaroid\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Grid2 Grayscale<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c79\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid2\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"2\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"560\\",\\"img_height_post\\":\\"380\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"css_post\\":\\"filter-grayscale filter-hover-none\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"grayscale\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Masonry Grid4 Grayscale<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c94\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid4\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_filter\\":\\"yes\\",\\"disable_masonry\\":\\"yes\\",\\"post_per_page_post\\":\\"8\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"265\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"css_post\\":\\"filter-grayscale filter-hover-none\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"masonry\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Grid4 No-Gutter Overlay Sepia<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c109\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid4\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_content_layout\\":\\"overlay\\",\\"post_filter\\":\\"no\\",\\"post_gutter\\":\\"no-gutter\\",\\"post_per_page_post\\":\\"8\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"290\\",\\"img_height_post\\":\\"290\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"css_post\\":\\"filter-sepia filter-hover-none\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"sepia\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Masonry Grid3 Grayscale Overlay No-gutter<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c124\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"grid3\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"0|multiple\\",\\"post_tag_post\\":\\"0|multiple\\",\\"product_cat_post\\":\\"0|multiple\\",\\"product_tag_post\\":\\"0|multiple\\",\\"product_shipping_class_post\\":\\"0|multiple\\",\\"portfolio-category_post\\":\\"0|multiple\\",\\"post_content_layout\\":\\"overlay\\",\\"post_filter\\":\\"no\\",\\"disable_masonry\\":\\"yes\\",\\"post_gutter\\":\\"no-gutter\\",\\"post_per_page_post\\":\\"10\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"430\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"css_post\\":\\"filter-grayscale filter-hover-none\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"6\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"masonry-no-gutter\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2896,
  'post_date' => '2015-02-17 21:27:23',
  'post_date_gmt' => '2015-02-17 21:27:23',
  'post_content' => '<h2>Slider</h2>
[themify_portfolio_posts style="slider" limit="5" visible="4" scroll="1" image_w="280" image_h="180"]
<h2>Overlay Grid 4</h2>
[themify_portfolio_posts style="grid4 overlay" limit="8" image_w="290" image_h="290"]
<h2>Polaroid Grid 3</h2>
[themify_portfolio_posts style="grid3 polaroid" limit="6" image_w="365" image_h="250"]
<h2>Grid 2 Grayscale</h2>
[themify_portfolio_posts style="grid2 filter-grayscale" limit="4" image_w="560" image_h="380"]
<h2>Grid3 Masonry Grayscale Polariod</h2>
[themify_portfolio_posts style="masonry grid3 polaroid filter-grayscale" limit="9" image_w="365" image_h="0"]
<h2>Masonry</h2>
[themify_portfolio_posts limit="10" style="grid4 masonry" image_w="265" image_h="0"]
<h2>No Gutter</h2>
[themify_portfolio_posts style="grid4 no-gutter overlay" limit="8" image_w="290" image_h="290"]
<h2>Polaroid No-Gutter Slider</h2>
[themify_portfolio_posts style="slider polaroid no-gutter" limit="4" visible="3" scroll="1" image_w="280" image_h="180"]
<h3></h3>',
  'post_title' => 'Portfolio Layouts',
  'post_excerpt' => '',
  'post_name' => 'portfolio-layouts',
  'post_modified' => '2017-08-21 01:18:34',
  'post_modified_gmt' => '2017-08-21 01:18:34',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/landing/?page_id=2896',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_footer_widgets' => 'default',
    'portfolio_layout' => 'grid3',
    'portfolio_posts_per_page' => '12',
    'portfolio_display_content' => 'none',
    'portfolio_hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7767,
  'post_date' => '2018-11-11 00:13:02',
  'post_date_gmt' => '2018-11-11 00:13:02',
  'post_content' => '<!--themify_builder_static--><h1>Ultra App</h1> <p>Speed up your mobile app development now. Simple 5-min installation. Available both on iOS and Android.</p> 
 <a href="https://themify.me/" >DOWNLOAD</a> 
 <a href="https://www.youtube.com/watch?v=P8Lte26BBN8" > <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/ipad-app.png" width="689" alt="" /> </a> 
 <h2>Quick Prototypes</h2> <p>Perfect for presenting your apps, websites and prototypes. Mainstream your design and development process without hassle exports. Simply export it any time as you want. Available to view online or any mobile device.</p> 
 <a href="https://themify.me/" >WATCH IT</a> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/app-interface.png" width="670" alt="" /> 
 <h2>Testimonials</h2> 
 <ul data-id="testimonial-slider-0-" data-visible="3" data-mob-visible="1" data-scroll="1" data-auto-scroll="off" data-speed="1" data-wrap="yes" data-arrow="yes" data-pagination="yes" data-effect="scroll" data-height="variable" data-pause-on-hover="resume" > <li> 
 <figure> <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/testimonial-client-1.jpg" width="100" height="100" alt="" /> </figure> <p>Thanks Plentific for helping us stay on top of a very stressful process! Finally exchanged and looking forward to complete.</p> Hendry Bradshaw Evernote </li> <li> 
 <figure> <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/testimonial-client-2.jpg" width="100" height="100" alt="" /> </figure> <p>Great to stay on top of the process. Especially liked to play with the financial section when viewing properties. Highly recommended!</p> Andree Shorter Invision </li> <li> 
 <figure> <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/testimonial-client-3.jpg" width="100" height="100" alt="" /> </figure> <p>Just started flat hunting. Your affordability calculator saved me some serious time to focus on what I can actually buy. Thanks so much.</p> Sofia Gerald AirBNB </li> <li> 
 <figure> <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/testimonial-client-4.jpg" width="100" height="100" alt="" /> </figure> <p>Thumbs Up, their service is magnificent, quick solution for top enterprise. Totally recommended App for your business</p> Chintya Abee Total Solution </li> </ul> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/client-1.png" width="156" height="39" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/client-2-143x37.png" width="143" height="37" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/client-3-51x36.png" width="51" height="36" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/client-4-126x37.png" width="126" height="37" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/client-5-163x37.png" width="163" height="37" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/client-6-116x35.png" width="116" height="35" alt="" /> 
 <h2>Features</h2> 
 <p>Deserun mollit anim id est laborum.Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod. Excepteur sint occaecat cupidatat.</p> 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/camera-app-icon-1.png" alt="Camera" /> 
 
 <h3>Camera</h3> <p>Sed ut perspiciatis unde omnis iste natus error.</p> 
 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/share-app-icon-1.png" alt="Share" /> 
 
 <h3>Share</h3> <p>Excepteur sint occaecat cupidatat non proident.</p> 
 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/sync-app-icon-1.png" alt="Sync" /> 
 
 <h3>Sync</h3> <p>At vero eos et accusamus et iusto odio dignissimos.</p> 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/11/iphone.png" width="345" height="679" alt="" /> 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/filter-app-icon-1.png" alt="Filter" /> 
 
 <h3>Filter</h3> <p>Neque porro quisquam est, qui dolorem ipsum quiat.</p> 
 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/edit-app-icon-1.png" alt="Edit" /> 
 
 <h3>Edit</h3> <p>Nemo enim ipsam voluptatem quia voluptas.</p> 
 
 
 <img src="https://themify.me/demo/themes/ultra-app/files/2018/05/effect-app-icon-1.png" alt="Effects" /> 
 
 <h3>Effects</h3> <p>Nam libero tempore, cum soluta nobis est eligendi.</p> 
 
 <h2>Got Questions?</h2> <p>Don’t be shy. We are here to answer your questions 24/7.</p> 
 <form action="https://themify.me/demo/themes/ultra/wp-admin/admin-ajax.php" id="contact-0--form" method="post"> 
 <label for="contact-0--contact-name">Your Name *</label> <input type="text" name="contact-name" placeholder="" id="contact-0--contact-name" value="" required /> 
 <label for="contact-0--contact-email">Your Email *</label> <input type="text" name="contact-email" placeholder="" id="contact-0--contact-email" value="" required /> 
 <label for="contact-0--contact-subject">Subject *</label> <input type="text" name="contact-subject" placeholder="" id="contact-0--contact-subject" value="" required /> <label for="contact-0--contact-message">Message *</label> <textarea name="contact-message" placeholder="" id="contact-0--contact-message" rows="8" cols="45" required></textarea> <button type="submit"> Send </button> </form><!--/themify_builder_static-->',
  'post_title' => 'Header Bottom',
  'post_excerpt' => '',
  'post_name' => 'header-bottom',
  'post_modified' => '2018-11-11 00:15:37',
  'post_modified_gmt' => '2018-11-11 00:15:37',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=7767',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-bottom',
    'mobile_menu_styles' => 'default',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"cc9232f\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"8d3bc2f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"e4b5b80\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_color\\":\\"#ffffff\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Ultra App<\\\\/h1>\\\\n<p>Speed up your mobile app development now. Simple 5-min installation. Available both on iOS and Android.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"1083050\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"circle\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"DOWNLOAD\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"blue\\",\\"icon_alignment\\":\\"left\\"}]}}],\\"styling\\":{\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_bottom\\":\\"14\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}},{\\"element_id\\":\\"2b4135c\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"ee50da5\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/ipad-app.png\\",\\"width_image\\":\\"689\\",\\"link_image\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/watch?v=P8Lte26BBN8\\",\\"param_image\\":\\"lightbox\\",\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/bg-header.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-top\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"12\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"25\\",\\"padding_bottom_unit\\":\\"%\\",\\"margin_bottom\\":\\"-22\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-top\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"22\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"margin_bottom\\":\\"0\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\"}}},{\\"element_id\\":\\"81156b6\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"768f1d1\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"2682270\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_h2\\":\\"#405cc2\\",\\"content_text\\":\\"<h2>Quick Prototypes<\\\\/h2>\\\\n<p>Perfect for presenting your apps, websites and prototypes. Mainstream your design and development process without hassle exports. Simply export it any time as you want. Available to view online or any mobile device.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"fd11bb6\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"circle\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"WATCH IT\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"purple\\",\\"icon_alignment\\":\\"left\\"}]}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}},{\\"element_id\\":\\"9ea1e08\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"68d30d6\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/app-interface.png\\",\\"width_image\\":\\"670\\",\\"auto_fullwidth\\":\\"1\\",\\"param_image\\":\\"regular\\",\\"custom_parallax_scroll_speed\\":\\"2\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"0\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"},\\"row_width\\":\\"fullwidth-content\\",\\"row_anchor\\":\\"about\\"}},{\\"element_id\\":\\"b30b340\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"a0d9c99\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"8ea00aa\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_h2\\":\\"#405cc2\\",\\"content_text\\":\\"<h2>Testimonials<\\\\/h2>\\"}},{\\"mod_name\\":\\"testimonial-slider\\",\\"element_id\\":\\"ba718ba\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_container_padding_apply_all\\":\\"1\\",\\"checkbox_container_border_apply_all\\":\\"1\\",\\"checkbox_content_padding_apply_all\\":\\"1\\",\\"checkbox_content_border_apply_all\\":\\"1\\",\\"layout_testimonial\\":\\"image-top\\",\\"tab_content_testimonial\\":[{\\"content_testimonial\\":\\"<p>Thanks Plentific for helping us stay on top of a very stressful process! Finally exchanged and looking forward to complete.<\\\\/p>\\",\\"person_picture_testimonial\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/testimonial-client-1.jpg\\",\\"person_name_testimonial\\":\\"Hendry Bradshaw\\",\\"company_testimonial\\":\\"Evernote\\"},{\\"content_testimonial\\":\\"<p>Great to stay on top of the process. Especially liked to play with the financial section when viewing properties. Highly recommended!<\\\\/p>\\",\\"person_picture_testimonial\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/testimonial-client-2.jpg\\",\\"person_name_testimonial\\":\\"Andree Shorter\\",\\"company_testimonial\\":\\"Invision\\"},{\\"content_testimonial\\":\\"<p>Just started flat hunting. Your affordability calculator saved me some serious time to focus on what I can actually buy. Thanks so much.<\\\\/p>\\",\\"person_picture_testimonial\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/testimonial-client-3.jpg\\",\\"person_name_testimonial\\":\\"Sofia Gerald\\",\\"company_testimonial\\":\\"AirBNB\\"},{\\"content_testimonial\\":\\"<p>Thumbs Up, their service is magnificent, quick solution for top enterprise. Totally recommended App for your business<\\\\/p>\\",\\"person_picture_testimonial\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/testimonial-client-4.jpg\\",\\"person_name_testimonial\\":\\"Chintya Abee\\",\\"company_testimonial\\":\\"Total Solution\\"}],\\"img_w_slider\\":\\"100\\",\\"img_h_slider\\":\\"100\\",\\"visible_opt_slider\\":\\"3\\",\\"mob_visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"off\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"height_slider\\":\\"variable\\",\\"animation_effect\\":\\"fadeIn\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"testimonials\\"}},{\\"element_id\\":\\"87393eb\\",\\"row_order\\":\\"3\\",\\"cols\\":[{\\"element_id\\":\\"d10857d\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"element_id\\":\\"9147b11\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"c4a8762\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"e07e63d\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/client-1.png\\",\\"width_image\\":\\"156\\",\\"height_image\\":\\"39\\",\\"param_image\\":\\"regular\\"}}]},{\\"element_id\\":\\"16abb5e\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"ddd3c30\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/client-2-143x37.png\\",\\"width_image\\":\\"143\\",\\"height_image\\":\\"37\\",\\"param_image\\":\\"regular\\"}}]},{\\"element_id\\":\\"abed339\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"0202ee6\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/client-3-51x36.png\\",\\"width_image\\":\\"51\\",\\"height_image\\":\\"36\\",\\"param_image\\":\\"regular\\"}}]},{\\"element_id\\":\\"325f924\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"f9e91fa\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/client-4-126x37.png\\",\\"width_image\\":\\"126\\",\\"height_image\\":\\"37\\",\\"param_image\\":\\"regular\\"}}]},{\\"element_id\\":\\"c3cbca2\\",\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"40a6550\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/client-5-163x37.png\\",\\"width_image\\":\\"163\\",\\"height_image\\":\\"37\\",\\"param_image\\":\\"regular\\"}}]},{\\"element_id\\":\\"ea71902\\",\\"column_order\\":\\"5\\",\\"grid_class\\":\\"col6-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"becd842\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/client-6-116x35.png\\",\\"width_image\\":\\"116\\",\\"height_image\\":\\"35\\",\\"param_image\\":\\"regular\\"}}]}],\\"col_mobile\\":\\"column3-1 tb_3col\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"60\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"80\\",\\"padding_bottom\\":\\"40\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/bg-section-brand.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"27\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"17\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"clients\\"}},{\\"element_id\\":\\"a22d546\\",\\"row_order\\":\\"4\\",\\"cols\\":[{\\"element_id\\":\\"729e8ec\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"82dd18a\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_h2\\":\\"#405cc2\\",\\"content_text\\":\\"<h2>Features<\\\\/h2>\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"dc03087\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"font_size\\":\\"1.2\\",\\"font_size_unit\\":\\"em\\",\\"line_height\\":\\"1.9\\",\\"line_height_unit\\":\\"em\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_h2\\":\\"#405cc2\\",\\"content_text\\":\\"<p>Deserun mollit anim id est laborum.Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod. Excepteur sint occaecat cupidatat.<\\\\/p>\\"}},{\\"element_id\\":\\"94d3bfa\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"3a4142f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"c2348ab\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"Camera\\",\\"content_feature\\":\\"<p>Sed ut perspiciatis unde omnis iste natus error.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"#405cc2\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"image_icon\\",\\"image_feature\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/camera-app-icon-1.png\\",\\"icon_color_feature\\":\\"#000\\",\\"link_options\\":\\"regular\\"}},{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"fb62852\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"Share\\",\\"content_feature\\":\\"<p>Excepteur sint occaecat cupidatat non proident.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"#405cc2\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"image_icon\\",\\"image_feature\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/share-app-icon-1.png\\",\\"icon_color_feature\\":\\"#000\\",\\"link_options\\":\\"regular\\"}},{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"67baef9\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"Sync\\",\\"content_feature\\":\\"<p>At vero eos et accusamus et iusto odio dignissimos.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"#405cc2\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"image_icon\\",\\"image_feature\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/sync-app-icon-1.png\\",\\"icon_feature\\":\\"fa-microchip\\",\\"icon_color_feature\\":\\"#405cc2\\",\\"link_options\\":\\"regular\\"}}]},{\\"element_id\\":\\"55721e4\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"330cefc\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"font_color_type\\":\\"font_color_solid\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border-type\\":\\"top\\",\\"checkbox_title_margin_apply_all\\":\\"1\\",\\"checkbox_i_t_p_apply_all\\":\\"1\\",\\"checkbox_i_t_m_apply_all\\":\\"1\\",\\"i_t_b-type\\":\\"top\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/11\\\\/iphone.png\\",\\"width_image\\":\\"345\\",\\"height_image\\":\\"679\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"cc9232f\\",\\"unstick_when_el_mod_id\\":\\"e4b5b80\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}}],\\"styling\\":{\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_bottom\\":\\"12\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}},{\\"element_id\\":\\"49a9211\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"fbeb87f\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"Filter\\",\\"content_feature\\":\\"<p>Neque porro quisquam est, qui dolorem ipsum quiat.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"#405cc2\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"image_icon\\",\\"image_feature\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/filter-app-icon-1.png\\",\\"icon_feature\\":\\"fa-microchip\\",\\"icon_color_feature\\":\\"#000\\",\\"link_options\\":\\"regular\\"}},{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"e18b9d9\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"Edit\\",\\"content_feature\\":\\"<p>Nemo enim ipsam voluptatem quia voluptas.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"#405cc2\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"image_icon\\",\\"image_feature\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/edit-app-icon-1.png\\",\\"icon_feature\\":\\"fa-space-shuttle\\",\\"icon_color_feature\\":\\"#000\\",\\"link_options\\":\\"regular\\"}},{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"1725198\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"Effects\\",\\"content_feature\\":\\"<p>Nam libero tempore, cum soluta nobis est eligendi.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"#405cc2\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"image_icon\\",\\"image_feature\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/effect-app-icon-1.png\\",\\"icon_feature\\":\\"fa-window-maximize\\",\\"icon_color_feature\\":\\"#823deb\\",\\"link_options\\":\\"regular\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_size\\":\\".9\\",\\"font_size_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_left_unit\\":\\"em\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"features\\"}},{\\"element_id\\":\\"97e918f\\",\\"row_order\\":\\"5\\",\\"cols\\":[{\\"element_id\\":\\"0d8be3a\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"element_id\\":\\"07758e1\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"37b7fa8\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"element_id\\":\\"b0d6b7c\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\"},{\\"element_id\\":\\"6c4c10f\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_slider_speed\\":\\"2000\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/files\\\\/2018\\\\/05\\\\/bg-pricing.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-top\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"border_inner-type\\":\\"top\\",\\"top-frame_type\\":\\"top-presets\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"left-frame_type\\":\\"left-presets\\",\\"right-frame_type\\":\\"right-presets\\",\\"padding_top\\":\\"11\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"18\\",\\"padding_bottom_unit\\":\\"%\\",\\"border-type\\":\\"top\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-top\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"},\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"pricing\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"cc9232f\\",\\"unstick_when_el_mod_id\\":\\"e4b5b80\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}},{\\"element_id\\":\\"a1404d5\\",\\"row_order\\":\\"6\\",\\"cols\\":[{\\"element_id\\":\\"e640881\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"0c826d0\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_h2\\":\\"#405cc2\\",\\"content_text\\":\\"<h2>Got Questions?<\\\\/h2>\\\\n<p>Don’t be shy. We are here to answer your questions 24\\\\/7.<\\\\/p>\\"}},{\\"element_id\\":\\"ead3a09\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"c09ce1f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"08e1564\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"contact\\",\\"element_id\\":\\"f4e3db6\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_border_inputs_apply_all\\":\\"1\\",\\"checkbox_border_send_apply_all\\":\\"1\\",\\"checkbox_padding_success_message_apply_all\\":\\"1\\",\\"checkbox_margin_success_message_apply_all\\":\\"1\\",\\"checkbox_border_success_message_apply_all\\":\\"1\\",\\"checkbox_padding_error_message_apply_all\\":\\"1\\",\\"checkbox_margin_error_message_apply_all\\":\\"1\\",\\"checkbox_border_error_message_apply_all\\":\\"1\\",\\"layout_contact\\":\\"animated-label\\",\\"mail_contact\\":\\"info@themify.me\\",\\"field_name_label\\":\\"Your Name\\",\\"field_email_label\\":\\"Your Email\\",\\"field_subject_label\\":\\"Subject\\",\\"field_subject_require\\":\\"yes\\",\\"field_subject_active\\":\\"yes\\",\\"field_message_label\\":\\"Message\\",\\"field_extra\\":\\"{ \\\\\\\\\\\\\\"fields\\\\\\\\\\\\\\": [] }\\",\\"field_sendcopy_label\\":\\"Send a copy to myself\\",\\"field_order\\":\\"{}\\",\\"field_send_label\\":\\"Send\\",\\"field_send_align\\":\\"center\\"}}]},{\\"element_id\\":\\"89b004c\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}],\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"contact\\"}},{\\"element_id\\":\\"abbe493\\",\\"row_order\\":\\"7\\",\\"cols\\":[{\\"element_id\\":\\"7f6d45f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3420,
  'post_date' => '2015-04-16 21:16:36',
  'post_date_gmt' => '2015-04-16 21:16:36',
  'post_content' => '',
  'post_title' => 'Appearance',
  'post_excerpt' => '',
  'post_name' => 'theme-appearance',
  'post_modified' => '2017-08-21 01:16:01',
  'post_modified_gmt' => '2017-08-21 01:16:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3420',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'hide_page_title' => 'yes',
    'custom_menu' => 'main-nav',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Page Header Design</h1>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_h1\\":\\"default\\",\\"font_family_h2\\":\\"default\\",\\"font_family_h3\\":\\"default\\",\\"font_family_h4\\":\\"default\\",\\"font_family_h5\\":\\"default\\",\\"font_family_h6\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/menu-split.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Split Menu\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/split-menu/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/header-block.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Header Block\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/block/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/header-horizontal.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Header Horizontal\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/horizontal/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/boxed-content.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Boxed Content\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/boxed-content/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"Open Sans\\",\\"font_color\\":\\"000000_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/left-pane.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Left Pane\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/left-pane/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/slide-out.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Slide Out\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/slide-out/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/min-bar.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Min Bar\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/min-bar/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/top-bar.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Top Bar\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/top-bar/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"Open Sans\\",\\"font_color\\":\\"000000_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/overlay.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Header Overlay\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/overlay/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/right-pane.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Right Pane\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/right-pane/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/boxed-layout.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Boxed Layout\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/boxed-layout/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/boxed-compact.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"Boxed Compact\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/boxed-compact/\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"Open Sans\\",\\"font_color\\":\\"000000_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/wp-content/uploads/2016/06/no-header.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"120\\",\\"auto_fullwidth\\":\\"|\\",\\"height_image\\":\\"120\\",\\"title_image\\":\\"No Header \\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra/theme-appearance/no-header/\\",\\"param_image\\":\\"regular\\",\\"image_zoom_icon\\":\\"|\\",\\"lightbox_size_unit_width\\":\\"pixels\\",\\"lightbox_size_unit_height\\":\\"pixels\\",\\"background_image-type\\":\\"image\\",\\"background_image-type_image\\":\\"image\\",\\"background_image-type_gradient\\":\\"gradient\\",\\"background_image-gradient-type\\":\\"linear\\",\\"background_image-gradient-angle\\":\\"0\\",\\"font_family\\":\\"default\\",\\"font_size_unit\\":\\"px\\",\\"line_height_unit\\":\\"px\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"border_top_style\\":\\"solid\\",\\"border_right_style\\":\\"solid\\",\\"border_bottom_style\\":\\"solid\\",\\"border_left_style\\":\\"solid\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_size_title_unit\\":\\"px\\",\\"line_height_title_unit\\":\\"px\\",\\"font_family_caption\\":\\"default\\",\\"font_size_caption_unit\\":\\"px\\",\\"line_height_caption_unit\\":\\"px\\",\\"custom_parallax_scroll_reverse\\":\\"|\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade\\":\\"|\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"Open Sans\\",\\"font_color\\":\\"000000_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"000000_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7777,
  'post_date' => '2018-11-13 21:13:32',
  'post_date_gmt' => '2018-11-13 21:13:32',
  'post_content' => '<!--themify_builder_static--><h3>Mosaic</h3> <figure> <img src="https://themify.me/demo/themes/ultra/files/2015/06/208621960-1024x786-1024x600.jpg" width="1050" height="600" alt="Gallery Layout"> <figcaption> 
 <h2>Gallery Layout</h2> <p>Mauris sit natoque dolor condimentum himenaeos curabitur imperdiet fringilla, mollis platea consequat consectetur. Risus sapien hac tristique. Praesent magnis cursus proin etiam condimentum hac. Viverra praesent, ad proin lorem est class blandit id maecenas felis. Metus dictum interdum parturient viverra magnis curae; id potenti tellus. Tempor massa ullamcorper est turpis molestie penatibus dictumst dui nam. Bibendum suspendisse mauris condimentum auctor mollis integer sagittis nascetur ante rutrum molestie. Himenaeos sociosqu aliquam porta magnis sodales nulla in etiam duis faucibus.</p> 
 <a href="https://themify.me/demo/themes/ultra/gallery-layout/" >View more</a> </figcaption> 
 Blog </figure>
 <figure> <img src="https://themify.me/demo/themes/ultra/files/2015/06/model-6-1024x1024-750x300.jpg" width="750" height="300" alt="Slider Layout"> <figcaption> 
 <h2>Slider Layout</h2> <p>Aenean dis mus arcu vel posuere porta tristique. Magnis maecenas cum maecenas suspendisse consectetur sed, scelerisque augue placerat ullamcorper. Augue torquent et dictumst lacinia at scelerisque turpis class pellentesque sodales cras lectus! Neque eu eget vitae suspendisse integer dapibus fermentum laoreet? Ullamcorper tristique facilisis ullamcorper phasellus nam semper scelerisque! Viverra ornare dignissim nam, molestie tortor scelerisque! Vehicula quam tempor imperdiet quisque. Quisque suscipit!</p> 
 <a href="https://themify.me/demo/themes/ultra/slider-layout/" >View more</a> </figcaption> 
 Photography </figure>
 <figure> <img src="https://themify.me/demo/themes/ultra/files/2015/05/99811742-1024x1024-750x300.jpg" width="750" height="300" alt="Split Layout"> <figcaption> 
 <h2>Split Layout</h2> <p>Officia deserunt mollitia animi, id est laborum et dolorum fuga. Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat</p> 
 <a href="https://themify.me/demo/themes/ultra/split-layout/" >View more</a> </figcaption> 
 Travel </figure>
 <figure> <img src="https://themify.me/demo/themes/ultra/files/2015/10/188185553-1024x678-1024x300.jpg" width="1800" height="300" alt="Fullwidth Layout"> <figcaption> 
 <h2>Fullwidth Layout</h2> <p>Lectus facilisi pulvinar natoque non molestie varius tincidunt class leo at varius non. Aliquam libero vulputate dui est varius tempor lectus nascetur tellus sit. Mus nascetur, elit malesuada posuere eleifend magnis mus donec congue fusce! Litora dictum purus auctor hac dapibus himenaeos. Sagittis nascetur per sociis per erat nascetur gravida. Ligula id, dictumst viverra imperdiet. Similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga. Et harum quidem rerum facilis est et expedita distinctio.</p> 
 <a href="https://themify.me/demo/themes/ultra/fullwidth-layout/" >View more</a> </figcaption> 
 View </figure>
 <figure> <img src="https://themify.me/demo/themes/ultra/files/2015/02/192449156-1024x683-1024x300.jpg" width="1800" height="300" alt="Left Sidebar"> <figcaption> 
 <h2>Left Sidebar</h2> <p>Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus.</p> 
 <a href="https://themify.me/demo/themes/ultra/left-sidebar/" >View more</a> </figcaption> 
 Work </figure><!--/themify_builder_static-->',
  'post_title' => 'Test Mosaic',
  'post_excerpt' => '',
  'post_name' => 'test-mosaic',
  'post_modified' => '2018-11-13 21:17:05',
  'post_modified_gmt' => '2018-11-13 21:17:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=7777',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'mobile_menu_styles' => 'default',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"7389394\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"e11d121\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"mosaic\\",\\"element_id\\":\\"af69864\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border-type\\":\\"top\\",\\"checkbox_m_tc_p_apply_all\\":\\"1\\",\\"m_tc_b-type\\":\\"top\\",\\"checkbox_m_t_p_apply_all\\":\\"1\\",\\"checkbox_m_t_m_apply_all\\":\\"1\\",\\"m_t_b-type\\":\\"top\\",\\"checkbox_m_cn_p_apply_all\\":\\"1\\",\\"checkbox_m_cn_m_apply_all\\":\\"1\\",\\"m_cn_b-type\\":\\"top\\",\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"b_i_hv_ov-type\\":\\"image\\",\\"b_r_hv_ov\\":\\"repeat\\",\\"b_p_hv_ov\\":\\"left-top\\",\\"checkbox_m_ov_p_apply_all\\":\\"1\\",\\"checkbox_m_ov_m_apply_all\\":\\"1\\",\\"m_ov_b-type\\":\\"top\\",\\"checkbox_m_pg_p_apply_all\\":\\"1\\",\\"m_pg_b-type\\":\\"top\\",\\"checkbox_m_n_pg_p_apply_all\\":\\"1\\",\\"m_n_pg_b-type\\":\\"top\\",\\"mod_title\\":\\"Mosaic\\",\\"template\\":\\"[{\\\\\\\\\\\\\\"x\\\\\\\\\\\\\\":0,\\\\\\\\\\\\\\"y\\\\\\\\\\\\\\":0,\\\\\\\\\\\\\\"width\\\\\\\\\\\\\\":7,\\\\\\\\\\\\\\"height\\\\\\\\\\\\\\":4},{\\\\\\\\\\\\\\"x\\\\\\\\\\\\\\":7,\\\\\\\\\\\\\\"y\\\\\\\\\\\\\\":0,\\\\\\\\\\\\\\"width\\\\\\\\\\\\\\":5,\\\\\\\\\\\\\\"height\\\\\\\\\\\\\\":2},{\\\\\\\\\\\\\\"x\\\\\\\\\\\\\\":7,\\\\\\\\\\\\\\"y\\\\\\\\\\\\\\":2,\\\\\\\\\\\\\\"width\\\\\\\\\\\\\\":5,\\\\\\\\\\\\\\"height\\\\\\\\\\\\\\":2},{\\\\\\\\\\\\\\"x\\\\\\\\\\\\\\":0,\\\\\\\\\\\\\\"y\\\\\\\\\\\\\\":4,\\\\\\\\\\\\\\"width\\\\\\\\\\\\\\":12,\\\\\\\\\\\\\\"height\\\\\\\\\\\\\\":2},{\\\\\\\\\\\\\\"x\\\\\\\\\\\\\\":0,\\\\\\\\\\\\\\"y\\\\\\\\\\\\\\":6,\\\\\\\\\\\\\\"width\\\\\\\\\\\\\\":12,\\\\\\\\\\\\\\"height\\\\\\\\\\\\\\":2}]\\",\\"tiled_posts_display\\":\\"posts\\",\\"post_type\\":\\"post\\",\\"tax\\":\\"category\\",\\"tax_category\\":\\"0|multiple\\",\\"tax_post_tag\\":\\"0|multiple\\",\\"order\\":\\"desc\\",\\"orderby\\":\\"date\\",\\"gallery_link_to\\":\\"file\\",\\"query_products\\":\\"onsale\\",\\"category_products\\":\\"0|multiple\\",\\"hide_child_products\\":\\"no\\",\\"free_products\\":\\"show\\",\\"outofstock_products\\":\\"show\\",\\"orderby_products\\":\\"date\\",\\"order_products\\":\\"desc\\",\\"files_orderby\\":\\"name\\",\\"files_order\\":\\"ASC\\",\\"show_as\\":\\"grid\\",\\"slides_count\\":\\"3\\",\\"min_width\\":\\"600\\",\\"gutter\\":\\"10\\",\\"effect\\":\\"lily\\",\\"entrance_effect\\":\\"fadeIn\\",\\"hide_title\\":\\"no\\",\\"hide_caption\\":\\"no\\",\\"hide_badge\\":\\"no\\",\\"pagination\\":\\"disabled\\",\\"slider_auto_scroll\\":\\"off\\",\\"slider_speed\\":\\"normal\\",\\"slider_effect\\":\\"scroll\\",\\"slider_pause\\":\\"resume\\",\\"slider_wrap\\":\\"yes\\",\\"slider_pagination\\":\\"yes\\",\\"slider_arrows\\":\\"yes\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"7389394\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}}]}]},{\\"element_id\\":\\"5a4030e\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"2fe6924\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4194,
  'post_date' => '2015-06-19 19:23:10',
  'post_date_gmt' => '2015-06-19 19:23:10',
  'post_content' => '<!--themify_builder_static--><h1>The Menu<br/>Great Food Starts Here</h1>
 <h2>Breakfast</h2> 
 Chef Selection <h4>Bacon and Cheddar Omelette</h4> $14.95 <br /> Ham, red peppers, green peppers, red onions and cheddar cheese in a three egg omelette 
 <h4>Ham and Swiss Omelette</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h4>Deluxe Omelette</h4> $14.95 <br /> Bacan, sausage, ham, red peppers, green peppers, red onions, and mushrooms in a three egg omelette 
 <h4>Eggs Benedict</h4> $14.95 <br /> Poached eggs served on a toasted English muffin, layered with peameal bacon and topped with Hollandaise sauce. Served with breakfast potatoes 
 <h4>Eggs Florentine</h4> $14.95 <br /> Poached eggs served on a toasted English muffin, layered with cooked spinach and topped with Hollandaise sauce. Served with breakfast potatoes 
 <h4>Ham and Beacon Omelette</h4> $14.95 <br /> Three egg omelette with ham and beacon cheese 
 <h2>Lunch</h2> 
 <h4>Old Fashioned Burger</h4> $14.95 <br /> Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo 
 <h4>Mayan Burger</h4> $14.95 <br /> Prime rib burger, house-made avocado salsa 
 Chef Selection <h4>Farmhouse Burger</h4> $14.95 <br /> Prime rib burger, fried egg, peameat bacon 
 <h4>Spicy Thai Basil Noodle</h4> $14.95 <br /> Prawns, chicken, coconut milk and basic infused chili sauce 
 <h4>Old Fashioned Burger</h4> $14.95 <br /> Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo 
 <h4>Mayan Burger</h4> $14.95 <br /> Prime rib burger, house-made avocado salsa 
 <h4>Farmhouse Burger</h4> $14.95 <br /> Prime rib burger, fried egg, peameat bacon 
 <h4>Spicy Thai Basil Noodle</h4> $14.95 <br /> Prawns, chicken, coconut milk and basic infused chili sauce 
 <h2>Dinner</h2> 
 <h4>Old Fashioned Burger</h4> $14.95 <br /> Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo 
 <h4>Mayan Burger</h4> $14.95 <br /> Prime rib burger, house-made avocado salsa 
 Chef Selection <h4>Farmhouse Burger</h4> $14.95 <br /> Prime rib burger, fried egg, peameat bacon 
 <h4>Spicy Thai Basil Noodle</h4> $14.95 <br /> Prawns, chicken, coconut milk and basic infused chili sauce 
 <h4>Old Fashioned Burger</h4> $14.95 <br /> Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo 
 <h4>Mayan Burger</h4> $14.95 <br /> Prime rib burger, house-made avocado salsa 
 <h4>Farmhouse Burger</h4> $14.95 <br /> Prime rib burger, fried egg, peameat bacon 
 <h4>Spicy Thai Basil Noodle</h4> $14.95 <br /> Prawns, chicken, coconut milk and basic infused chili sauce 
 <h2>Drinks</h2> 
 <h4>Chocolate</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h4>Lime</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h4>Strawberry Rhubarb Parfait</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h4>Artisanal Cheese</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h4>Fruit</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h4>Artisanal melon</h4> $14.95 <br /> Three egg omelette with ham and swiss cheese 
 <h2>Compagne on us</h2> 
 <p>Every Monday, Tuesday and Wednesday evening, we’re offering groups of 10 or more that book an area in our bar a complimentary bottle of Champagne.</p> 
 <p>Call our reservations team on <a href="tel:027-8338-145">(027) 8338 145</a> or simply hit the button below for more information.</p> 
 <a href="https://themify.me/demo/themes/ultra-restaurant/contact-us/" >Contact Us</a><!--/themify_builder_static-->',
  'post_title' => 'Boxed Compact',
  'post_excerpt' => '',
  'post_name' => 'boxed-compact',
  'post_modified' => '2018-08-24 18:32:13',
  'post_modified_gmt' => '2018-08-24 18:32:13',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4194',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'body_background_image' => 'https://themify.me/demo/themes/ultra/files/2018/06/food-background.jpg',
    'body_background_repeat' => 'fullcover',
    'color_design' => 'theme-color-burgundy',
    'header_design' => 'boxed-compact',
    'exclude_site_logo' => 'no',
    'exclude_site_tagline' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'no',
    'exclude_social_widget' => 'no',
    'exclude_menu_navigation' => 'no',
    'footer_design' => 'footer-left-col',
    'exclude_footer_widgets' => 'no',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"fancy-heading\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"heading\\":\\"The Menu\\",\\"sub_heading\\":\\"Great Food Starts Here\\",\\"heading_tag\\":\\"h1\\",\\"text_alignment\\":\\"themify-text-center\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-restaurant\\\\/files\\\\/2016\\\\/08\\\\/breakfast-690128_1280.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"b8b8b8_1.00\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.37\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff_1\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"14\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"25\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Breakfast<\\\\/h2>\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col2-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"background_color\\":\\"#ffe552_0.23\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Bacon and Cheddar Omelette\\",\\"description_service_menu\\":\\"Ham, red peppers, green peppers, red onions and cheddar cheese in a three egg omelette\\",\\"price_service_menu\\":\\"$14.95\\",\\"link_options\\":\\"regular\\",\\"highlight_service_menu\\":\\"highlight\\",\\"highlight_text_service_menu\\":\\"Chef Selection\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Ham and Swiss Omelette\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Deluxe Omelette\\",\\"description_service_menu\\":\\"Bacan, sausage, ham, red peppers, green peppers, red onions, and mushrooms in a three egg omelette\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col2-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Eggs Benedict\\",\\"description_service_menu\\":\\"Poached eggs served on a toasted English muffin, layered with peameal bacon and topped with Hollandaise sauce. Served with breakfast potatoes\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Eggs Florentine\\",\\"description_service_menu\\":\\"Poached eggs served on a toasted English muffin, layered with cooked spinach and topped with Hollandaise sauce. Served with breakfast potatoes\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Ham and Beacon Omelette\\",\\"description_service_menu\\":\\"Three egg omelette with ham and beacon cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"link_options\\":\\"regular\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"#fffae3\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Lunch<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-restaurant\\\\/files\\\\/2016\\\\/08\\\\/lunch-min-2-1024x256.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.27\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff_1\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"11.5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"8.5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Old Fashioned Burger\\",\\"description_service_menu\\":\\"Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Mayan Burger\\",\\"description_service_menu\\":\\"Prime rib burger, house-made avocado salsa\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"background_color\\":\\"#ffe552_0.23\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Farmhouse Burger\\",\\"description_service_menu\\":\\"Prime rib burger, fried egg, peameat bacon\\",\\"price_service_menu\\":\\"$14.95\\",\\"link_options\\":\\"regular\\",\\"highlight_service_menu\\":\\"highlight\\",\\"highlight_text_service_menu\\":\\"Chef Selection\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Spicy Thai Basil Noodle\\",\\"description_service_menu\\":\\"Prawns, chicken, coconut milk and basic infused chili sauce\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Old Fashioned Burger\\",\\"description_service_menu\\":\\"Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Mayan Burger\\",\\"description_service_menu\\":\\"Prime rib burger, house-made avocado salsa\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Farmhouse Burger\\",\\"description_service_menu\\":\\"Prime rib burger, fried egg, peameat bacon\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Spicy Thai Basil Noodle\\",\\"description_service_menu\\":\\"Prawns, chicken, coconut milk and basic infused chili sauce\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Dinner<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-restaurant\\\\/files\\\\/2016\\\\/08\\\\/dinner-min-1-1024x256.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.27\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff_1\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"11.5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"8.5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Old Fashioned Burger\\",\\"description_service_menu\\":\\"Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Mayan Burger\\",\\"description_service_menu\\":\\"Prime rib burger, house-made avocado salsa\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"background_color\\":\\"#ffe552_0.23\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Farmhouse Burger\\",\\"description_service_menu\\":\\"Prime rib burger, fried egg, peameat bacon\\",\\"price_service_menu\\":\\"$14.95\\",\\"link_options\\":\\"regular\\",\\"highlight_service_menu\\":\\"highlight\\",\\"highlight_text_service_menu\\":\\"Chef Selection\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Spicy Thai Basil Noodle\\",\\"description_service_menu\\":\\"Prawns, chicken, coconut milk and basic infused chili sauce\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Old Fashioned Burger\\",\\"description_service_menu\\":\\"Prime rib burger, double-smoked bacon, aged Cheddar cheese, mayo\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Mayan Burger\\",\\"description_service_menu\\":\\"Prime rib burger, house-made avocado salsa\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Farmhouse Burger\\",\\"description_service_menu\\":\\"Prime rib burger, fried egg, peameat bacon\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Spicy Thai Basil Noodle\\",\\"description_service_menu\\":\\"Prawns, chicken, coconut milk and basic infused chili sauce\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"none\\",\\"border_right_style\\":\\"none\\",\\"border_bottom_style\\":\\"none\\",\\"border_left_style\\":\\"none\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Drinks<\\\\/h2>\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Chocolate\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Lime\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Strawberry Rhubarb Parfait\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Artisanal Cheese\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Fruit\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"service-menu\\",\\"mod_settings\\":{\\"style_service_menu\\":\\"image-center\\",\\"title_service_menu\\":\\"Artisanal melon\\",\\"description_service_menu\\":\\"Three egg omelette with ham and swiss cheese\\",\\"price_service_menu\\":\\"$14.95\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"#fff5e0\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Compagne on us<\\\\/h2>\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_size\\":\\"1.2\\",\\"font_size_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Every Monday, Tuesday and Wednesday evening, we’re offering groups of 10 or more that book an area in our bar a complimentary bottle of Champagne.<\\\\/p>\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Call our reservations team on <a href=\\\\\\\\\\\\\\"tel:027-8338-145\\\\\\\\\\\\\\">(027) 8338 145<\\\\/a> or simply hit the button below for more information.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Contact Us\\",\\"link\\":\\"https://themify.me/demo/themes/ultra-restaurant\\\\/contact-us\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"yellow\\",\\"icon_alignment\\":\\"left\\"}]}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"7\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"7\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"0\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"0\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra-restaurant\\\\/files\\\\/2016\\\\/08\\\\/bg-min-1.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.63\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#ffd561\\",\\"padding_top\\":\\"3.75\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"6.5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7789,
  'post_date' => '2018-11-21 01:12:23',
  'post_date_gmt' => '2018-11-21 01:12:23',
  'post_content' => '',
  'post_title' => 'Test Slider Pro Speed',
  'post_excerpt' => '',
  'post_name' => 'test-slider-pro-speed',
  'post_modified' => '2018-11-21 01:16:39',
  'post_modified_gmt' => '2018-11-21 01:16:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=7789',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'mobile_menu_styles' => 'default',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"a3bc577\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"4087ddd\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"pro-slider\\",\\"element_id\\":\\"8f5799b\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border-type\\":\\"top\\",\\"checkbox_p_arrow_apply_all\\":\\"1\\",\\"checkbox_p_b_apply_all\\":\\"1\\",\\"b_b-type\\":\\"top\\",\\"checkbox_margin_button_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border-type\\":\\"top\\",\\"checkbox_p_arrow_apply_all\\":\\"1\\",\\"checkbox_p_b_apply_all\\":\\"1\\",\\"b_b-type\\":\\"top\\",\\"checkbox_margin_button_apply_all\\":\\"1\\"},\\"builder_slider_pro_slides\\":[{\\"builder_ps_layout\\":\\"bsp-slide-content-left\\",\\"builder_ps_slide_type\\":\\"Image\\",\\"builder-ps-bg-image\\":\\"http:\\\\/\\\\/www.photomatestudios.com\\\\/wp-content\\\\/uploads\\\\/2018\\\\/10\\\\/Aditi-Kuntal-2-1.jpg\\",\\"builder_ps_tranzition\\":\\"fade\\",\\"builder_ps_tranzition_duration\\":\\"fast\\"},{\\"builder_ps_layout\\":\\"bsp-slide-content-left\\",\\"builder_ps_slide_type\\":\\"Image\\",\\"builder-ps-bg-image\\":\\"http:\\\\/\\\\/www.photomatestudios.com\\\\/wp-content\\\\/uploads\\\\/2018\\\\/10\\\\/PhotoMate-Studios-2.jpg\\",\\"builder_ps_tranzition\\":\\"fade\\",\\"builder_ps_tranzition_duration\\":\\"fast\\"},{\\"builder_ps_layout\\":\\"bsp-slide-content-left\\",\\"builder_ps_slide_type\\":\\"Image\\",\\"builder-ps-bg-image\\":\\"http:\\\\/\\\\/www.photomatestudios.com\\\\/wp-content\\\\/uploads\\\\/2018\\\\/10\\\\/ss-1.jpg\\",\\"builder_ps_tranzition\\":\\"fade\\",\\"builder_ps_tranzition_duration\\":\\"fast\\"},{\\"builder_ps_layout\\":\\"bsp-slide-content-left\\",\\"builder_ps_slide_type\\":\\"Image\\",\\"builder-ps-bg-image\\":\\"http:\\\\/\\\\/www.photomatestudios.com\\\\/wp-content\\\\/uploads\\\\/2018\\\\/10\\\\/IMG_2945-Edit.jpg\\",\\"builder_ps_tranzition\\":\\"fade\\",\\"builder_ps_tranzition_duration\\":\\"fast\\"},{\\"builder_ps_layout\\":\\"bsp-slide-content-left\\",\\"builder_ps_slide_type\\":\\"Image\\",\\"builder-ps-bg-image\\":\\"http:\\\\/\\\\/www.photomatestudios.com\\\\/wp-content\\\\/uploads\\\\/2018\\\\/10\\\\/Photomate-Studios.jpg\\",\\"builder_ps_tranzition\\":\\"fade\\",\\"builder_ps_tranzition_duration\\":\\"fast\\"}],\\"builder_ps_triggers_position\\":\\"none\\",\\"builder_ps_triggers_type\\":\\"circle\\",\\"builder_ps_thumb_width\\":\\"30\\",\\"builder_ps_thumb_height\\":\\"30\\",\\"builder_ps_aa\\":\\"5000\\",\\"builder_ps_hover_pause\\":\\"none\\",\\"builder_ps_fullscreen\\":\\"fullscreen\\",\\"animation_effect\\":\\"fadeOut\\",\\"stick_at_position\\":\\"top\\",\\"unstick_when_element\\":\\"builder_end\\",\\"unstick_when_el_row_id\\":\\"b48a956\\",\\"unstick_when_el_mod_id\\":\\"cc7b627\\",\\"unstick_when_condition\\":\\"hits\\",\\"unstick_when_pos\\":\\"this\\"}}]}]},{\\"element_id\\":\\"6207534\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"2f88b52\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7033,
  'post_date' => '2018-04-10 19:38:23',
  'post_date_gmt' => '2018-04-10 19:38:23',
  'post_content' => '<!--themify_builder_static--><h1>Fullpane Theme</h1> 
 <h4>by Themify</h4> 
 <a href="https://themify.me/demo/themes/fullpane/home/demo-2/" >Features</a> <a href="https://themify.me/themes/fullpane" >Learn More</a> 
 <h1>Horizontal Scrolling</h1> 
 <h4>Can scroll vertical &amp; horizontal.</h4> 
 <h1>Hand Crafted</h1> 
 <h4>With love.</h4> 
 <h1>Drag &amp; Drop Builder</h1> 
 <h4>The possibility is limitless with Themify Builder.</h4> 
 <h1>Features</h1> 
 <h4>Gallery, Portfolio, Testimonial, Team, Testimonial, and more.</h4> 
 <a href="https://themify.me/demo/themes/fullpane/demo-2" >View Features Page</a> 
 <h1>Explore More</h1> 
 <a href="https://themify.me/demo/themes/fullpane/home/demo-2/" >DEMO 2</a> <a href="https://themify.me/demo/themes/fullpane/home/demo-3/" >DEMO 3</a><!--/themify_builder_static-->',
  'post_title' => 'Horizontal Min Bar Header',
  'post_excerpt' => '',
  'post_name' => 'horizontal-min-bar-header',
  'post_modified' => '2018-10-27 23:19:05',
  'post_modified_gmt' => '2018-10-27 23:19:05',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=7033',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'section_full_scrolling' => 'yes',
    'section_scrolling_mobile' => 'on',
    'header_design' => 'header-minbar',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"e636ad1\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"f7ee3ae\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"1724043\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Fullpane Theme<\\\\/h1>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"0d52dfa\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>by Themify<\\\\/h4>\\",\\"animation_effect\\":\\"fadeInRight\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"9f114a7\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Features\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/home\\\\/demo-2\\\\/\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"},{\\"label\\":\\"Learn More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/fullpane\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"}],\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage17-1024x651.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"element_id\\":\\"07e7192\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"fa5a9ca\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"444e984\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Horizontal Scrolling<\\\\/h1>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"6ffb44b\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Can scroll vertical &amp; horizontal.<\\\\/h4>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage30-1024x683.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_slide\\"}},{\\"element_id\\":\\"edd554a\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"e4f51a9\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"5020da3\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Hand Crafted<\\\\/h1>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"ff44c54\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>With love.<\\\\/h4>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage36-1024x683.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_slide\\"}},{\\"element_id\\":\\"18bc866\\",\\"row_order\\":\\"3\\",\\"cols\\":[{\\"element_id\\":\\"c232d5d\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"9c298b4\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Drag &amp; Drop Builder<\\\\/h1>\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"27a7159\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>The possibility is limitless with Themify Builder.<\\\\/h4>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage42.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_section\\"}},{\\"element_id\\":\\"aa93c90\\",\\"row_order\\":\\"4\\",\\"cols\\":[{\\"element_id\\":\\"352b534\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"2bd3a23\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_image-gradient-angle\\":\\"0\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Features<\\\\/h1>\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"b90be06\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Gallery, Portfolio, Testimonial, Team, Testimonial, and more.<\\\\/h4>\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"0c3b3ef\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"View Features Page\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/demo-2\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"}]}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage66.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"756f68\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"e8e8e8\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"f49ac1\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"element_id\\":\\"d4b8888\\",\\"row_order\\":\\"5\\",\\"cols\\":[{\\"element_id\\":\\"9bf17eb\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"4f974f8\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Explore More<\\\\/h1>\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"43bcdfa\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"DEMO 2\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/home\\\\/demo-2\\\\/\\",\\"link_options\\":\\"regular\\"},{\\"label\\":\\"DEMO 3\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/home\\\\/demo-3\\\\/\\",\\"link_options\\":\\"regular\\"}]}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/fullpane\\\\/files\\\\/2018\\\\/06\\\\/demoimage59.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"#ffffff\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"#a6fff2\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_scroll_direction\\":\\"module_row_section\\"}},{\\"element_id\\":\\"bb5e792\\",\\"row_order\\":\\"6\\",\\"cols\\":[{\\"element_id\\":\\"8cb837d\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2693,
  'post_date' => '2015-02-06 19:02:02',
  'post_date_gmt' => '2015-02-06 19:02:02',
  'post_content' => '<!--themify_builder_static--><!--/themify_builder_static-->',
  'post_title' => 'Shop',
  'post_excerpt' => '',
  'post_name' => 'shop',
  'post_modified' => '2018-03-06 04:00:47',
  'post_modified_gmt' => '2018-03-06 04:00:47',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/landing/shop/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2694,
  'post_date' => '2015-02-06 19:02:02',
  'post_date_gmt' => '2015-02-06 19:02:02',
  'post_content' => '[woocommerce_cart]',
  'post_title' => 'Cart',
  'post_excerpt' => '',
  'post_name' => 'cart',
  'post_modified' => '2017-08-21 01:18:20',
  'post_modified_gmt' => '2017-08-21 01:18:20',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/landing/cart/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2695,
  'post_date' => '2015-02-06 19:02:02',
  'post_date_gmt' => '2015-02-06 19:02:02',
  'post_content' => '[woocommerce_checkout]',
  'post_title' => 'Checkout',
  'post_excerpt' => '',
  'post_name' => 'checkout',
  'post_modified' => '2017-08-21 01:18:21',
  'post_modified_gmt' => '2017-08-21 01:18:21',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/landing/checkout/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3975,
  'post_date' => '2015-05-08 21:45:53',
  'post_date_gmt' => '2015-05-08 21:45:53',
  'post_content' => '',
  'post_title' => 'Fullheight / Image',
  'post_excerpt' => '',
  'post_name' => 'image',
  'post_modified' => '2017-08-21 01:14:46',
  'post_modified_gmt' => '2017-08-21 01:14:46',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3975',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-block',
    'fixed_header' => 'yes',
    'full_height_header' => 'yes',
    'background_color' => '#000000',
    'background_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/Top_view.jpg',
    'background_repeat' => 'fullcover',
    'headerwrap_text_color' => '#ffffff',
    'headerwrap_link_color' => '#ffffff',
    'footer_design' => 'none',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Capture Moments</h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Eye-Spy App</h3>\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ffbb00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-play\\",\\"icon_color_feature\\":\\"ffbb00\\",\\"link_feature\\":\\"https://vimeo.com/29731100\\",\\"param_feature\\":\\"lightbox\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"fullheight\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/162596999.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"000000_0.76\\",\\"cover_color_hover\\":\\"000000_0.72\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffe733_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"ffbb00_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Download</h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Available in App Store</h3>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/download.png\\",\\"appearance_image\\":\\"rounded\\",\\"width_image\\":\\"200\\",\\"link_image\\":\\"http://store.apple.com/us\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"ffe312_1.00\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Highlights</h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. </h3>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/03/iphone6p-gold-select-2014.png\\",\\"img_title_slider\\":\\"Rose Gold\\",\\"img_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce eu mattis augue. Suspendisse lobortis elementum nunc in volutpat. Morbi vestibulum ut erat vitae luctus. Integer finibus enim sit amet accumsan posuere. In at imperdiet quam, quis placerat ipsum. Nulla facilisi. Nulla ornare a erat eu faucibus. Vivamus vel purus libero. Ut facilisis ultrices nibh, in fringilla sem venenatis nec. Praesent a sagittis justo. Duis dignissim lorem in eros aliquam cursus. Donec et enim tincidunt neque laoreet consectetur. Aenean in venenatis orci. Donec malesuada erat eget ante dignissim blandit. Praesent a efficitur lacus, id placerat eros. Suspendisse a accumsan risus, eget mattis ante.</p>\\\\n\\\\n[themify_button style=\\\\\\\\\\\\\\"large blue rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ] Go to Demo [/themify_button]\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/03/iphone6p-silver-select-2014.png\\",\\"img_title_slider\\":\\"Silver \\",\\"img_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce eu mattis augue. Suspendisse lobortis elementum nunc in volutpat. Morbi vestibulum ut erat vitae luctus. Integer finibus enim sit amet accumsan posuere. In at imperdiet quam, quis placerat ipsum. Nulla facilisi. Nulla ornare a erat eu faucibus. Vivamus vel purus libero. Ut facilisis ultrices nibh, in fringilla sem venenatis nec. Praesent a sagittis justo. Duis dignissim lorem in eros aliquam cursus. Donec et enim tincidunt neque laoreet consectetur. Aenean in venenatis orci. Donec malesuada erat eget ante dignissim blandit. Praesent a efficitur lacus, id placerat eros. Suspendisse a accumsan risus, eget mattis ante.</p>\\\\n\\\\n[themify_button style=\\\\\\\\\\\\\\"large blue rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ] Go to Demo [/themify_button]\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/03/iphone6p-gray-select-2014.png\\",\\"img_title_slider\\":\\"Space Gray \\",\\"img_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce eu mattis augue. Suspendisse lobortis elementum nunc in volutpat. Morbi vestibulum ut erat vitae luctus. Integer finibus enim sit amet accumsan posuere. In at imperdiet quam, quis placerat ipsum. Nulla facilisi. Nulla ornare a erat eu faucibus. Vivamus vel purus libero. Ut facilisis ultrices nibh, in fringilla sem venenatis nec. Praesent a sagittis justo. Duis dignissim lorem in eros aliquam cursus. Donec et enim tincidunt neque laoreet consectetur. Aenean in venenatis orci. Donec malesuada erat eget ante dignissim blandit. Praesent a efficitur lacus, id placerat eros. Suspendisse a accumsan risus, eget mattis ante.</p>\\\\n\\\\n[themify_button style=\\\\\\\\\\\\\\"large blue rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ] Go to Demo [/themify_button]\\"}],\\"video_content_slider\\":[[]],\\"text_content_slider\\":[[]],\\"layout_slider\\":\\"slider-agency\\",\\"img_w_slider\\":\\"400\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"height_slider\\":\\"variable\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Amazing Time Lapse</h4>\\",\\"font_family\\":\\"default\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"fullheight\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"video\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"https://themify.me/demo/demo-videos/Timelapse_Flower.mp4\\",\\"background_image\\":\\"https://themify.me/demo/demo-videos/flower-1024x572.jpg\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Gallery</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"gallery\\",\\"mod_settings\\":{\\"layout_gallery\\":\\"showcase\\",\\"shortcode_gallery\\":\\"[gallery path=\\\\\\\\\\\\\\"https://themify.me/demo/themes/builder-layouts/files/2016/01/93928987-1.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/59553262.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/131900372-1.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/144233608.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/146888777.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/202438066-1024x684.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/133815968.jpg,https://themify.me/demo/themes/builder-layouts/files/2016/01/203436520.jpg\\\\\\\\\\\\\\" _orderByField=\\\\\\\\\\\\\\"menu_order ID\\\\\\\\\\\\\\" ids=\\\\\\\\\\\\\\"5001,5004,5002,5003,4999,5000\\\\\\\\\\\\\\"]\\",\\"gallery_pagination\\":\\"|\\",\\"s_image_w_gallery\\":\\"560\\",\\"thumb_w_gallery\\":\\"80\\",\\"thumb_h_gallery\\":\\"60\\",\\"gallery_columns\\":\\"4\\",\\"link_opt\\":\\"file\\",\\"appearance_gallery\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">FAQ</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>What is your refund policy?</h4><p>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu.</p><h4 id=\\\\\\\\\\\\\\"2\\\\\\\\\\\\\\">Can the app do this?</h4><p>Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.</p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\".8\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 id=\\\\\\\\\\\\\\"2\\\\\\\\\\\\\\">Do you guys provide this?</h4><p>Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.</p><h4>Does it work with?</h4><p>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu.</p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\".8\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<a href=\\\\\\\\\\\\\\"https://wordpress.org/plugins/mailchimp-for-wp/\\\\\\\\\\\\\\">Mailchimp for Wordpress </a>plugin is used here\\",\\"font_family\\":\\"default\\",\\"text_align\\":\\"center\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"text_decoration\\":\\"underline\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Subscribe to Themify</h4><p>[mc4wp_form]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6279,
  'post_date' => '2017-02-18 16:56:14',
  'post_date_gmt' => '2017-02-18 16:56:14',
  'post_content' => '',
  'post_title' => 'Blog - Tiles',
  'post_excerpt' => '',
  'post_name' => 'blog-tiles',
  'post_modified' => '2017-10-28 01:34:17',
  'post_modified_gmt' => '2017-10-28 01:34:17',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=6279',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'query_category' => 'blog',
    'layout' => 'auto_tiles',
    'posts_per_page' => '7',
    'display_content' => 'none',
    'post_filter' => 'yes',
    'image_width' => '800',
    'image_height' => '600',
    'hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2696,
  'post_date' => '2015-02-06 19:02:02',
  'post_date_gmt' => '2015-02-06 19:02:02',
  'post_content' => '[woocommerce_my_account]',
  'post_title' => 'My Account',
  'post_excerpt' => '',
  'post_name' => 'my-account',
  'post_modified' => '2017-08-21 01:18:28',
  'post_modified_gmt' => '2017-08-21 01:18:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/landing/my-account/',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7052,
  'post_date' => '2018-04-10 19:51:40',
  'post_date_gmt' => '2018-04-10 19:51:40',
  'post_content' => '<!--themify_builder_static--><h2>Circle</h2> <h3>Change the way you manage your team to increase productivity</h3> 
 <a href="https://themify.me/" >Download Now</a> <a href="#read" >Read More</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/circle.png" width="294" height="596" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/workplace.jpg" width="500" height="286" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/startup-849794_1280.jpg" width="312" height="203" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/startup-593343_1920.jpg" width="350" height="203" alt="" /> 
 <h3>Simple App to connect with your member team everywhere. Easy to manage and maintain your project,  friendly platform makes you comfortable to use it. Et harum quidem rerum facilis est et expedita distinctio. </h3> 
 <a href="#feature" >Feature</a> <a href="#team" >Team</a> 
 
 
 
 <h3>Connect Your Team</h3> <p>Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae.</p> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/steve-1.png" width="294" height="596" alt="" /> 
 
 
 
 <h3>Project Report</h3> <p>Itaque earum rerum hic tenetur a sapiente delectus reiciendis.</p> 
 
 
 
 
 <h3>Project Monitoring</h3> <p>Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime.</p> 
 
 <h2>Organize Your Team Members</h2> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/discussion-2.jpg" width="300" height="199" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/smartphone-459316_1920.jpg" width="220" height="147" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/manage.png" width="294" height="596" alt="" /> 
 
 
 
 <h3>Create Teams</h3> <p>placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus.</p> 
 
 
 
 
 <h3>Sort Members</h3> <p>Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit.</p> 
 
 <h2>Team Board</h2> 
 
 <h3>Personalize Your Team Board Appearance</h3><p>Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat.</p> 
 <ul data-id="slider-0-" data-visible="1" data-mob-visible="" data-scroll="1" data-auto-scroll="4" data-speed="1" data-wrap="yes" data-arrow="no" data-pagination="yes" data-effect="scroll" data-height="variable" data-pause-on-hover="resume" > 
 <li> <a href="http://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/team-a.png" width="294" height="596" alt="" /> </a> </li> <li> <a href="http://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/taem-b.png" width="294" height="596" alt="" /> </a> </li> <li> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/taem-c.png" width="294" height="596" alt="" /> </li> </ul> 
 <h2>Users Testimonial</h2> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/team-100x100.jpg" width="100" height="100" title="Jonas Simmbaca" alt="Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi. Designer" /> <h3> Jonas Simmbaca </h3> Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi.<br> <small><i>Designer</i></small> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/105942710-100x100.jpg" width="100" height="100" title="Michael Ortiz" alt="Itaque earum rerum hic tenetur a consequatur aut perferendis doloribus asperiores necessitatibus repellat. todaypost.com" /> <h3> Michael Ortiz </h3> Itaque earum rerum hic tenetur a consequatur aut perferendis doloribus asperiores necessitatibus repellat. <br> <small><i>todaypost.com</i></small> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/135544689-100x100.jpg" width="100" height="100" title="Amanda Bryn" alt="Excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia. CEO pretty-woman.com" /> <h3> Amanda Bryn </h3> Excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia.<br> <small><i>CEO pretty-woman.com</i></small> 
 <h2>Circle for better team management</h2> 
 <a href="https://themify.me/" >Download Now</a> <a href="https://themify.me/" >Read More</a> 
 <a href="http://facebook.com/themify" > Facebook</a> <a href="http://twitter.com/themify" > Twitter</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/09/share-1.png" width="294" height="596" alt="" /><!--/themify_builder_static-->',
  'post_title' => 'Horizontal Top Bar Header',
  'post_excerpt' => '',
  'post_name' => 'horizontal-top-bar-header',
  'post_modified' => '2018-07-17 19:25:07',
  'post_modified_gmt' => '2018-07-17 19:25:07',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=7052',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'section_full_scrolling' => 'yes',
    'section_scrolling_direction' => 'horizontal',
    'header_design' => 'header-top-bar',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Circle<\\\\/h2>\\\\n<h3>Change the way you manage your team to increase productivity<\\\\/h3>\\\\n\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"xlarge\\",\\"buttons_shape\\":\\"rounded\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Download Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"light-blue\\",\\"icon_alignment\\":\\"left\\"},{\\"label\\":\\"Read More\\",\\"link\\":\\"#read\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"green\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/circle.png\\",\\"width_image\\":\\"294\\",\\"height_image\\":\\"596\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}],\\"styling\\":{\\"breakpoint_tablet\\":{\\"background_type\\":\\"image\\",\\"text_decoration\\":\\"underline\\",\\"padding_top\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\"}}}],\\"col_tablet\\":\\"tablet-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"ffffff\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/workplace.jpg\\",\\"width_image\\":\\"500\\",\\"height_image\\":\\"286\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/startup-849794_1280.jpg\\",\\"width_image\\":\\"312\\",\\"height_image\\":\\"203\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_speed\\":\\"3\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/startup-593343_1920.jpg\\",\\"width_image\\":\\"350\\",\\"height_image\\":\\"203\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_speed\\":\\"2\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"column_alignment\\":\\"col_align_top\\",\\"gutter\\":\\"gutter-none\\"},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\"}],\\"column_alignment\\":\\"col_align_top\\",\\"gutter\\":\\"gutter-none\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Simple App to connect with your member team everywhere. Easy to manage and maintain your project,  friendly platform makes you comfortable to use it. Et harum quidem rerum facilis est et expedita distinctio. <\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"padding_top\\":\\"25\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_shape\\":\\"rounded\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Feature\\",\\"link\\":\\"#feature\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"},{\\"label\\":\\"Team\\",\\"link\\":\\"#team\\",\\"link_options\\":\\"regular\\",\\"icon_alignment\\":\\"left\\"}]}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/entrepreneur-593362_19201-1024x678.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_position\\":\\"center-top\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"de7ad9_0.91\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"40\\",\\"padding_right\\":\\"40\\",\\"padding_bottom\\":\\"40\\",\\"padding_left\\":\\"40\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"gutter\\":\\"gutter-none\\",\\"col_tablet\\":\\"tablet-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"cde8fa\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"25\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"25\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"},\\"row_width\\":\\"fullwidth-content\\",\\"row_anchor\\":\\"read\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Connect Your Team\\",\\"content_feature\\":\\"<p>Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-headphones\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"7eabde\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/steve-1.png\\",\\"width_image\\":\\"294\\",\\"height_image\\":\\"596\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Project Report\\",\\"content_feature\\":\\"<p>Itaque earum rerum hic tenetur a sapiente delectus reiciendis.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-file-text\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"7eabde\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Project Monitoring\\",\\"content_feature\\":\\"<p>Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-eye\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"7eabde\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"col_tablet\\":\\"tablet-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"ffffff\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"feature\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Organize Your Team Members<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"b88fbd\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"200\\",\\"divider_align\\":\\"left\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/discussion-2.jpg\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"199\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/smartphone-459316_1920.jpg\\",\\"width_image\\":\\"220\\",\\"height_image\\":\\"147\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_speed\\":\\"3\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/manage.png\\",\\"width_image\\":\\"294\\",\\"height_image\\":\\"596\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"padding_top\\":\\"0\\",\\"padding_bottom\\":\\"25\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Create Teams\\",\\"content_feature\\":\\"<p>placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-group\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"7eabde\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Sort Members\\",\\"content_feature\\":\\"<p>Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-sitemap\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"7eabde\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\"}}]}],\\"col_tablet\\":\\"tablet-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"ffffff\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_anchor\\":\\"team\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Team Board<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"b88fbd\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"200\\",\\"divider_align\\":\\"left\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Personalize Your Team Board Appearance<\\\\/h3><p>Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repellat.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"post_type\\":\\"post\\",\\"taxonomy\\":\\"category\\",\\"blog_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/team-a.png\\",\\"img_link_slider\\":\\"http:\\\\/\\\\/themify.me\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/taem-b.png\\",\\"img_link_slider\\":\\"http:\\\\/\\\\/themify.me\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/taem-c.png\\"}],\\"layout_slider\\":\\"slider-default\\",\\"img_w_slider\\":\\"294\\",\\"img_h_slider\\":\\"596\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"no\\",\\"height_slider\\":\\"variable\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]}],\\"col_tablet\\":\\"tablet-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"ffffff\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Users Testimonial<\\\\/h2>\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"b88fbd\\",\\"bottom_margin_divider\\":\\"50\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"left\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/team-100x100.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"Jonas Simmbaca\\",\\"caption_image\\":\\"Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi.<br>\\\\n<small><i>Designer<\\\\/i><\\\\/small>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"b88fbd\\",\\"bottom_margin_divider\\":\\"50\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"left\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/105942710-100x100.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"Michael Ortiz\\",\\"caption_image\\":\\"Itaque earum rerum hic tenetur a consequatur aut perferendis doloribus asperiores necessitatibus repellat. <br>\\\\n<small><i>todaypost.com<\\\\/i><\\\\/small>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"b88fbd\\",\\"bottom_margin_divider\\":\\"50\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"left\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/135544689-100x100.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"Amanda Bryn\\",\\"caption_image\\":\\"Excepturi sint occaecati cupiditate non provident, similique sunt in culpa qui officia deserunt mollitia.<br>\\\\n<small><i>CEO pretty-woman.com<\\\\/i><\\\\/small>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"column_alignment\\":\\"col_align_top\\"}]}],\\"gutter\\":\\"gutter-none\\",\\"col_tablet\\":\\"tablet-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"ffffff\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"right\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h2>Circle for better team management<\\\\/h2>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"right\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"xlarge\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Download Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"light-blue\\",\\"icon_alignment\\":\\"left\\"},{\\"label\\":\\"Read More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"green\\"}]}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_align\\":\\"right\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"link_border_top_style\\":\\"none\\",\\"link_border_right_style\\":\\"none\\",\\"link_border_bottom_style\\":\\"none\\",\\"link_border_left_style\\":\\"none\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"rounded\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"Facebook\\",\\"link\\":\\"http:\\\\/\\\\/facebook.com\\\\/themify\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"blue\\",\\"icon\\":\\"fa-facebook\\",\\"icon_alignment\\":\\"left\\"},{\\"label\\":\\"Twitter\\",\\"link\\":\\"http:\\\\/\\\\/twitter.com\\\\/themify\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"light-blue\\",\\"icon\\":\\"fa-twitter\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/09\\\\/share-1.png\\",\\"width_image\\":\\"294\\",\\"height_image\\":\\"596\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"ffffff\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3983,
  'post_date' => '2015-05-08 22:58:34',
  'post_date_gmt' => '2015-05-08 22:58:34',
  'post_content' => '<!--themify_builder_static--><h1 style="text-align: center;">Red Agency</h1> <h3 style="text-align: center;">We focus on UX, Design, and Apps </h3> <p style="text-align: center;"> </p>
 
 <a href="#connect" > Contact Us </a> 
 <h2 style="text-align: center;">Demo Reel </h2>
 
 <iframe src="https://player.vimeo.com/video/71934862" width="1165" height="655" title="Anne lessmeister - business card production" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe> 
 
 <h2 style="text-align: center;">Services</h2>
 
 
 
 
 <h3> Writing </h3> <p>The Landing Theme is great as it comes pre-built with multiple layouts that can be loaded on any page using the <a href="https://themify.me/builder">Builder</a>. Check out this tutorial to see how the <a href="https://themify.me/docs/builder#builder-layout">Builder layouts </a>work.</p> 
 
 
 
 
 
 <h3> Apps </h3> <p>The theme is also built with various header styles. You have the option to make it transparent, hide, or place it on the left. There are also other styles that customizes the placement of your logo.</p> 
 
 
 
 
 
 <h3> Games </h3> <p>We&#8217;ve packed this theme with multiple extendable Addons. All of which, comes built into the theme allowing you have the most flexibility when managing your content!</p> 
 
 
 <h3 style="text-align: center;"><em>Landing pages is a great way for you to attract more business for your brand, or to connect with your community.</em></h3>
 <p style="text-align: center;">A blogger from <a href="http://www.inboundnow.com/">Inbound Now</a> wrote a very interesting article called &#8220;<a href="http://www.inboundnow.com/7-killer-ways-landing-pages-benefit-market-your-business/">7 Killer Ways Landing Pages Benefit &#038; Market your Business</a>&#8220;. It outlines various ways on how you can benefit from creating landing pages for your business.</p> <h3 style="text-align: center;">Get a theme that&#8217;ll enhance, market, and grow your business now!</h3>
 
 <a href="https://themify.me/themes/landing" > Buy Now </a> <a href="https://themify.me/docs/landing-documentation" > Documentation </a> 
 <h3><em> Create a testimonial section on your landing page. Simply insert an icon and an image on the row to copy the same look as this layout.</em></h3><p style="text-align: right;"> &#8211; <strong>John Purdue</strong>, <em>Themify Team</em></p>
 
 <img src="https://themify.me/demo/themes/landing/files/2015/02/157472372.jpg" width="400" height="400" alt="" /> 
 <h2 style="text-align: center;">Connect with us</h2>
 
 <a href="https://themify.me/contact" > 
 
 </a> 
 
 
 
 <a href="https://www.facebook.com/themify" > 
 
 </a> 
 
 
 
 <a href="https://www.twitter.com/themify" > 
 
 </a> 
 
 
 
 <a href="https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341" > 
 
 </a><!--/themify_builder_static-->',
  'post_title' => 'Transparent',
  'post_excerpt' => '',
  'post_name' => 'transparent',
  'post_modified' => '2018-01-18 16:57:16',
  'post_modified_gmt' => '2018-01-18 16:57:16',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3983',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-red',
    'header_design' => 'header-horizontal',
    'exclude_site_tagline' => 'yes',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'yes',
    'exclude_social_widget' => 'yes',
    'header_wrap' => 'transparent',
    'background_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/Top_view.jpg',
    'footer_design' => 'none',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Red Agency<\\\\/h1>\\\\n<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">We focus on UX, Design, and Apps <\\\\/h3>\\\\n<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <\\\\/p>\\",\\"cid\\":\\"c17\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"font_weight\\":\\"bold\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"xlarge\\",\\"buttons_style\\":\\"circle\\",\\"content_button\\":[{\\"label\\":\\"Contact Us\\",\\"link\\":\\"#connect\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"red\\"}],\\"cid\\":\\"c21\\"}}]}],\\"styling\\":{\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/54497056-b1-1024x685.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"b82c2c\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Demo Reel <\\\\/h2>\\",\\"font_color\\":\\"f03030\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"cid\\":\\"c32\\"}},{\\"mod_name\\":\\"video\\",\\"mod_settings\\":{\\"style_video\\":\\"video-top\\",\\"url_video\\":\\"http:\\\\/\\\\/vimeo.com\\\\/71934862\\",\\"text_align\\":\\"center\\",\\"margin_right\\":\\"10\\",\\"margin_right_unit\\":\\"%\\",\\"margin_left\\":\\"10\\",\\"margin_left_unit\\":\\"%\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Services<\\\\/h2>\\",\\"cid\\":\\"c47\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Writing\\",\\"content_feature\\":\\"<p>The Landing Theme is great as it comes pre-built with multiple layouts that can be loaded on any page using the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/builder\\\\\\\\\\\\\\">Builder<\\\\/a>. Check out this tutorial to see how the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/docs\\\\/builder#builder-layout\\\\\\\\\\\\\\">Builder layouts <\\\\/a>work.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"000000_1.00\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-newspaper-o\\",\\"icon_color_feature\\":\\"f03030\\",\\"cid\\":\\"c59\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Apps\\",\\"content_feature\\":\\"<p>The theme is also built with various header styles. You have the option to make it transparent, hide, or place it on the left. There are also other styles that customizes the placement of your logo.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"000000_1.00\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-flask\\",\\"icon_color_feature\\":\\"f03030\\",\\"cid\\":\\"c67\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Games\\",\\"content_feature\\":\\"<p>We\\\\\\\\\\\'ve packed this theme with multiple extendable Addons. All of which, comes built into the theme allowing you have the most flexibility when managing your content!<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"000000_1.00\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-gamepad\\",\\"icon_color_feature\\":\\"f03030\\",\\"cid\\":\\"c75\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"fafafa_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"3\\",\\"color_divider\\":\\"000000_1.00\\",\\"top_margin_divider\\":\\"30\\",\\"bottom_margin_divider\\":\\"50\\",\\"cid\\":\\"c90\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>Landing pages is a great way for you to attract more business for your brand, or to connect with your community.<\\\\/em><\\\\/h3>\\",\\"font_color\\":\\"f03030\\",\\"cid\\":\\"c94\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">A blogger from <a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/www.inboundnow.com\\\\/\\\\\\\\\\\\\\">Inbound Now<\\\\/a> wrote a very interesting article called \\\\\\\\\\\\\\"<a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/www.inboundnow.com\\\\/7-killer-ways-landing-pages-benefit-market-your-business\\\\/\\\\\\\\\\\\\\">7 Killer Ways Landing Pages Benefit &amp; Market your Business<\\\\/a>\\\\\\\\\\\\\\". It outlines various ways on how you can benefit from creating landing pages for your business.<\\\\/p>\\\\n<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Get a theme that\\\\\\\\\\\'ll enhance, market, and grow your business now!<\\\\/h3>\\",\\"cid\\":\\"c98\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"font_weight\\":\\"bold\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"20\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"Buy Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/landing\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"red\\"},{\\"label\\":\\"Documentation\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/docs\\\\/landing-documentation\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"red\\"}],\\"cid\\":\\"c102\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"fafafa_1.00\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3><em>[themify_icon icon=\\\\\\\\\\\\\\"fa-quote-left\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"large\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#f03030\\\\\\\\\\\\\\" ] Create a testimonial section on your landing page. Simply insert an icon and an image on the row to copy the same look as this layout.<\\\\/em><\\\\/h3><p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\"> - <strong>John Purdue<\\\\/strong>, <em>Themify Team<\\\\/em><\\\\/p>\\",\\"cid\\":\\"c117\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/157472372.jpg\\",\\"appearance_image\\":\\"rounded|circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"cid\\":\\"c125\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"000000_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Connect with us<\\\\/h2>\\",\\"cid\\":\\"c136\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-envelope\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"f03030\\",\\"link_feature\\":\\"https:\\\\/\\\\/themify.me\\\\/contact\\",\\"param_feature\\":\\"newtab\\",\\"cid\\":\\"c148\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_stroke_feature\\":\\"3\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-facebook\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"f03030\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\",\\"param_feature\\":\\"newtab\\",\\"margin_bottom\\":\\"40\\",\\"cid\\":\\"c156\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_stroke_feature\\":\\"3\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-twitter\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"f03030\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.twitter.com\\\\/themify\\",\\"param_feature\\":\\"newtab\\",\\"margin_bottom\\":\\"40\\",\\"cid\\":\\"c164\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_stroke_feature\\":\\"3\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"layout_feature\\":\\"icon-top\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-google-plus\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"f03030\\",\\"link_feature\\":\\"https:\\\\/\\\\/plus.google.com\\\\/u\\\\/0\\\\/b\\\\/109280316400365629341\\\\/109280316400365629341\\",\\"param_feature\\":\\"newtab\\",\\"margin_bottom\\":\\"40\\",\\"cid\\":\\"c172\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_stroke_feature\\":\\"3\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"row_anchor\\":\\"connect\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3985,
  'post_date' => '2015-05-08 23:08:38',
  'post_date_gmt' => '2015-05-08 23:08:38',
  'post_content' => '',
  'post_title' => 'Slider',
  'post_excerpt' => '',
  'post_name' => 'slider',
  'post_modified' => '2017-08-21 01:16:04',
  'post_modified_gmt' => '2017-08-21 01:16:04',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3985',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-block',
    'fixed_header' => 'yes',
    'full_height_header' => 'yes',
    'exclude_header_widgets' => 'yes',
    'header_wrap' => 'slider',
    'background_gallery' => '[gallery ids="3235,3221"]',
    'background_color' => '#000000',
    'background_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/Top_view.jpg',
    'headerwrap_text_color' => '#ffffff',
    'headerwrap_link_color' => '#ffffff',
    'footer_design' => 'footer-horizontal-left',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our <br />Vision</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>We value...</h3><p>Pellentesque in purus posuere, luctus felis vel, sodales massa. Phasellus vehicula molestie pharetra. Donec aliquam nulla et erat blandit molestie. Maecenas porta mauris convallis ante dictum, ac imperdiet neque posuere. Phasellus accumsan est non nisi ultrices, et consequat lacus sollicitudin. Proin metus mi, sollicitudin eget odio et, aliquam convallis justo. Nullam porta augue nec fermentum tempor.</p><p>Donec risus leo, blandit eu commodo et, scelerisque quis eros. In posuere efficitur dui, in pellentesque massa aliquet vel. Phasellus et suscipit neque. Proin eget felis eu est laoreet ultricies mattis eget elit.</p><p>Vivamus feugiat tortor in ornare egestas. Phasellus malesuada arcu tempor neque pellentesque commodo. Proin molestie quam turpis, non congue ex interdum ac. </p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\"1.3\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"%\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our Team</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3 last\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/82152160.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Michelle\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>VP of Marketing</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/141627649.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Ralph\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>CEO</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/180680633.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Bryan\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>CFO</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/user_miles-200x200.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Mike\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>Front-End Developer</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/112268515.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Claire\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>Photographer</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/demo_paria.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Annie\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>Designer</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/demo_peter.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Nick\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>Development Specialist</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/user_jolie.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Lauren\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>Social Media Specialist</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/86536909.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"title_image\\":\\"Stephen\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<em>Operations Manager</em>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our<br />Work</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/96796114.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"1000\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"600\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/196849997.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"1000\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"600\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>#01</h1><h4>Forward thinking</h4><p>Proin ut euismod erat. Praesent velit est, interdum ut nulla ac, ultrices maximus odio. Pellentesque nec arcu at eros euismod consectetur.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"12\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">#02</h1><h4 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Best Services</h4><p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Proin ut euismod erat. Praesent velit est, intercom ut nulla ac, ultrices maximus odio. Pellentesque nec arcu at eros euismod consectetur.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"12\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/134119568.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"1000\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"600\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":[]},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/90053719.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"1000\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"600\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>#03</h1><h4>Our works speak for us</h4><p>Proin ut euismod erat. Praesent velit est, interdum ut nulla ac, ultrices maximus odio. Pellentesque nec arcu at eros euismod consectetur.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"12\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":[]},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">#04</h1><h4 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Where our inspiration comes from</h4><p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Proin ut euismod erat. Praesent velit est, interdum ut nulla ac, ultrices maximus odio. Pellentesque nec arcu at eros euismod consectetur.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"10\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/175819034.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"1000\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"600\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_title\\":\\"default\\",\\"font_family_caption\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our Clients</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3 last\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/Windows_logo-7.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/Apple-Logo-splash.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/02/543c477e9547e.jpg.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/showposter.png\\",\\"appearance_image\\":\\"rounded\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/Logitech-logo.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"height_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/Facebook-logo-PSD.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/Screen-Shot-2015-02-04-at-3.51.03-PM.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/google-logo-e1423084165592.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/builder-layouts/files/2015/07/asus_logo.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"180\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Cool <br />Awards</h2>\\",\\"font_family\\":\\"default\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3 last\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>1st FAR Champion</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-trophy\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>Facebook\\\\\\\\\\\'s Best</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-thumbs-up\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>Medal of Honors</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-sun-o\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>Ride for Cancer </p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-bicycle\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>Github Champs</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-github\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>Research Nominee</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-html5\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>BitCoin Design Award</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-btc\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>Linux Epic Code Award</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-linux\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<p>WordPress Theme of the Year</p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"919191\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-wordpress\\",\\"icon_color_feature\\":\\"919191\\",\\"param_feature\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Our HQ</h1><h4 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Maps Module here</h4><p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">The Maps module allows you to insert your location with google map. </p><p style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\"> </p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"10\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"|\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"font_family_h1\\":\\"default\\",\\"font_family_h2\\":\\"default\\",\\"font_family_h3\\":\\"default\\",\\"font_family_h4\\":\\"default\\",\\"font_family_h5\\":\\"default\\",\\"font_family_h6\\":\\"default\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"mod_settings\\":{\\"map_display_type\\":\\"dynamic\\",\\"address_map\\":\\" 381 Yonge St, Toronto, ON M5B 1S1, Canada \\",\\"zoom_map\\":\\"8\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"w_map_static\\":\\"500\\",\\"h_map\\":\\"500\\",\\"unit_h\\":\\"px\\",\\"b_style_map\\":\\"solid\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_padding_apply_all_padding\\":\\"padding\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_margin_apply_all_margin\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_border_apply_all_border\\":\\"border\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_desktop_show\\":\\"show\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_tablet_show\\":\\"show\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"show\\",\\"visibility_mobile_show\\":\\"show\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3990,
  'post_date' => '2015-05-08 23:22:25',
  'post_date_gmt' => '2015-05-08 23:22:25',
  'post_content' => '<!--themify_builder_static--><h2 style="text-align: center;">Our clients</h2><h3 style="text-align: center;">Below are some of our clients</h3>
 <ul data-id="slider-0-" data-visible="3" data-scroll="1" data-auto-scroll="4" data-speed="1" data-wrap="yes" data-arrow="no" data-pagination="no" data-effect="continuously" data-height="variable" data-pause-on-hover="resume" > 
 <li> <a href="https://twitter.com/themify" alt=""> <img src="https://themify.me/demo/themes/landing/files/2015/02/twitter1.png" alt="" /> </a> </li> <li> <a href="https://www.youtube.com/user/themifyme" alt=""> <img src="https://themify.me/demo/themes/landing/files/2015/02/2YouTube.png" alt="" /> </a> </li> <li> <a href="http://instagram.com/" alt=""> <img src="https://themify.me/demo/themes/landing/files/2015/02/1Instagram.png" alt="" /> </a> </li> <li> <a href="https://www.facebook.com/themify" alt=""> <img src="https://themify.me/demo/themes/landing/files/2015/02/1facebook.png" alt="" /> </a> </li> </ul> 
 
 <h4>Tablet App</h4> <p>I&#8217;d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.</p>
 
 <a href="https://themify.me/" > Our Work </a> 
 
 <img src="https://themify.me/demo/themes/landing/files/2015/03/n9-1.jpg" width="560" alt="" /> 
 <p style="text-align: center;"><em>&#8220;I love working with Interface Design Studio. Their friendly and hands-on!&#8221;</em></p>
 
 <img src="https://themify.me/demo/themes/landing/files/2015/02/157472372.jpg" width="100" height="100" alt="Michael Porter CEO, X-Company www.companyx.com" /> <strong>Michael Porter</strong><br> CEO, X-Company<br> www.companyx.com 
 
 
 <img src="https://themify.me/demo/themes/landing/files/2015/03/BMW-i8-Konfigurator-Preise-Sonderausstattungen-Optionen-02.jpg" width="560" alt="" /> 
 <h4>Auto App</h4> <p>I&#8217;d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.</p>
 
 <a href="https://themify.me/" > Our Work </a> 
 <p style="text-align: center;"> <em>&#8220;Great people. Great service. These factors led to an amazing Interface.&#8221;</em></p>
 
 <img src="https://themify.me/demo/themes/landing/files/2015/02/164990474.jpg" width="100" height="100" alt="Stephanie Specialist, Auto-B www.autob.com" /> <strong>Stephanie</strong><br> Specialist, Auto-B<br> www.autob.com 
 
 <h4>Web App</h4> <p>I&#8217;d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. </p>
 
 <a href="https://themify.me/" > More </a> 
 
 <img src="https://themify.me/demo/themes/landing/files/2015/03/Leaderboard_Free.png" width="560" alt="" /> 
 <p style="text-align: center;"><em>&#8220;Enjoyed working with specialist who know exactly what they are doing!&#8221;</em></p>
 
 <img src="https://themify.me/demo/themes/landing/files/2015/02/131227259.jpg" width="100" height="100" alt="Steve Baker CEO, WebApp www.webapp.com" /> <strong>Steve Baker</strong><br> CEO, WebApp<br> www.webapp.com 
 
 
 <img src="https://themify.me/demo/themes/landing/files/2015/03/overview_display_hero.jpg" width="560" alt="" /> 
 <h4>Mix Panel</h4> <p>LI&#8217;d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.</p>
 
 <a href="https://themify.me/" > More </a> 
 <p style="text-align: center;"><em>&#8220;These guys know how to get things done! Always on-time with high quality results.&#8221;</em></p>
 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/82152160-100x100.jpg" width="100" height="100" alt="Kristina Dealey Mix Panel www.mixpanel.com" srcset="https://themify.me/demo/themes/ultra/files/2015/07/82152160-100x100.jpg 100w, https://themify.me/demo/themes/ultra/files/2015/07/82152160-150x150.jpg 150w, https://themify.me/demo/themes/ultra/files/2015/07/82152160-300x300.jpg 300w, https://themify.me/demo/themes/ultra/files/2015/07/82152160-180x180.jpg 180w, https://themify.me/demo/themes/ultra/files/2015/07/82152160.jpg 369w" sizes="(max-width: 100px) 100vw, 100px" /> <strong>Kristina Dealey</strong><br> Mix Panel<br> www.mixpanel.com 
 
 <h4 style="text-align: center;">Want to work with us?</h4> <p style="text-align: center;"><strong>Let&#8217;s it happen now!</strong> Enroll to our 2 year university program in just 2-month. Why wait millions are asking for it. Click the following button to register now!</p>
 
 <a href="https://themify.me/" > Register </a><!--/themify_builder_static-->',
  'post_title' => 'Animating Color',
  'post_excerpt' => '',
  'post_name' => 'animating-color',
  'post_modified' => '2017-10-28 16:04:55',
  'post_modified_gmt' => '2017-10-28 16:04:55',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3990',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-block',
    'exclude_header_widgets' => 'yes',
    'header_wrap' => 'colors',
    'headerwrap_text_color' => '#ffffff',
    'headerwrap_link_color' => '#ffffff',
    'footer_design' => 'footer-left-col',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our clients<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Below are some of our clients<\\\\/h3>\\",\\"cid\\":\\"c22\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/twitter1.png\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/2YouTube.png\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/user\\\\/themifyme\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/1Instagram.png\\",\\"img_link_slider\\":\\"http:\\\\/\\\\/instagram.com\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/1facebook.png\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\"}],\\"layout_slider\\":\\"slider-default\\",\\"visible_opt_slider\\":\\"3\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"continuously\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"no\\",\\"show_arrow_slider\\":\\"no\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"row_anchor\\":\\"clients\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\",\\"cid\\":\\"c37\\"}}]}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"30\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Tablet App<\\\\/h4>\\\\n<p>I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"Our Work\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"green\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/n9-1.jpg\\",\\"width_image\\":\\"560\\",\\"cid\\":\\"c64\\"}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>\\\\\\\\\\\\\\"I love working with Interface Design Studio. Their friendly and hands-on!\\\\\\\\\\\\\\"<\\\\/em><\\\\/p>\\",\\"font_size\\":\\"1.4\\",\\"font_size_unit\\":\\"em\\",\\"padding_top\\":\\"60\\",\\"margin_top\\":\\"60\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"cid\\":\\"c80\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/157472372.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"caption_image\\":\\"<strong>Michael Porter<\\\\/strong><br> \\\\nCEO, X-Company<br>\\\\nwww.companyx.com\\",\\"cid\\":\\"c100\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\",\\"cid\\":\\"c115\\"}}]}]},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/BMW-i8-Konfigurator-Preise-Sonderausstattungen-Optionen-02.jpg\\",\\"width_image\\":\\"560\\",\\"cid\\":\\"c134\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Auto App<\\\\/h4>\\\\n<p>I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"Our Work\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"green\\"}]}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <em>\\\\\\\\\\\\\\"Great people. Great service. These factors led to an amazing Interface.\\\\\\\\\\\\\\"<\\\\/em><\\\\/p>\\",\\"font_size\\":\\"1.4\\",\\"font_size_unit\\":\\"em\\",\\"padding_top\\":\\"60\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top\\":\\"60\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"cid\\":\\"c158\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/164990474.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"caption_image\\":\\"<strong>Stephanie<\\\\/strong><br>\\\\nSpecialist, Auto-B<br>\\\\nwww.autob.com\\",\\"cid\\":\\"c178\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\",\\"cid\\":\\"c193\\"}}]}]},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Web App<\\\\/h4>\\\\n<p>I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. <\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"green\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/Leaderboard_Free.png\\",\\"width_image\\":\\"560\\",\\"cid\\":\\"c220\\"}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>\\\\\\\\\\\\\\"Enjoyed working with specialist who know exactly what they are doing!\\\\\\\\\\\\\\"<\\\\/em><\\\\/p>\\",\\"font_size\\":\\"1.3\\",\\"font_size_unit\\":\\"em\\",\\"padding_top\\":\\"60\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top\\":\\"60\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"cid\\":\\"c236\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/131227259.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"caption_image\\":\\"<strong>Steve Baker<\\\\/strong><br>\\\\nCEO, WebApp<br>\\\\nwww.webapp.com\\",\\"cid\\":\\"c256\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\",\\"cid\\":\\"c271\\"}}]}]},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/overview_display_hero.jpg\\",\\"width_image\\":\\"560\\",\\"cid\\":\\"c290\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Mix Panel<\\\\/h4>\\\\n<p>LI\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"More\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"green\\"}]}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>\\\\\\\\\\\\\\"These guys know how to get things done! Always on-time with high quality results.\\\\\\\\\\\\\\"<\\\\/em><\\\\/p>\\",\\"font_size\\":\\"1.3\\",\\"font_size_unit\\":\\"em\\",\\"padding_top\\":\\"60\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top\\":\\"60\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"cid\\":\\"c314\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/82152160.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"caption_image\\":\\"<strong>Kristina Dealey<\\\\/strong><br>\\\\nMix Panel<br>\\\\nwww.mixpanel.com\\",\\"cid\\":\\"c334\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\",\\"cid\\":\\"c349\\"}}]}]},{\\"row_order\\":\\"10\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Want to work with us?<\\\\/h4>\\\\n<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><strong>Let\\\\\\\\\\\'s it happen now!<\\\\/strong> Enroll to our 2 year university program in just 2-month. Why wait millions are asking for it. Click the following button to register now!<\\\\/p>\\\\n\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c372\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"rounded\\",\\"content_button\\":[{\\"label\\":\\"Register\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"red\\"}],\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c376\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}],\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"11\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4249,
  'post_date' => '2015-07-01 18:48:36',
  'post_date_gmt' => '2015-07-01 18:48:36',
  'post_content' => '<!--themify_builder_static--><h1>New Music Landing Page.</h1><h5>We used the Audio, Button, and Pricing Table addon to show you how you can create an amazing music layout.</h5> 
 <iframe src="https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/203112765&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false" width="100%" height="166" frameborder="no" scrolling="no"></iframe> 
 <h2>Showcase Your Music.</h2><p><strong>Morbi augue lacus, malesuada id cursus a, consequat vel risus. Fusce non lectus nibh. Quisque tempor augue ut porttitor auctor. Suspendisse iaculis diam non est ultrices rhoncus. </strong><strong>Suspendisse potenti. Aenean ultrices nisl quis tempor sodales. </strong></p><h4><a href="https://themify.me/themes/landing"><b>Get it now</b></a></h4><h4><a href="https://themify.me/themes/landing"><b>Download now</b></a></h4> 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/ariana-grande-400x400.jpg" width="400" height="400" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/jason-derulo-400x400.jpg" width="400" height="400" alt="" /> 
 <img src="https://themify.me/demo/themes/ultra/files/2015/07/kanye-west-400x400.png" width="400" height="400" alt="" /> 
 <h2>Broadcast Your music.</h2><p><strong>Upload your tracks using the <a href="https://themify.me/addons/audio/">Audio addon</a>, and allow you users to get a taste of your music. </strong></p> 
 <ol> <li itemprop="track" itemscope="" itemtype="https://schema.org/MusicRecording"> <a href="#" itemprop="url">Helpless</a> <audio id="audio-0-1" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3?_=1" /><a href="https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3">https://themify.me/demo/themes/addon-audio/files/2015/06/Helpless.mp3</a></audio> </li> <li itemprop="track" itemscope="" itemtype="https://schema.org/MusicRecording"> <a href="#" itemprop="url">I\'ve Not Over Yet</a> <audio id="audio-0-2" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3?_=2" /><a href="https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3">https://themify.me/demo/themes/addon-audio/files/2015/06/myuu-ItsNotOverYet.mp3</a></audio> </li> <li itemprop="track" itemscope="" itemtype="https://schema.org/MusicRecording"> <a href="#" itemprop="url">O Song</a> <audio id="audio-0-3" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3?_=3" /><a href="https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3">https://themify.me/demo/themes/addon-audio/files/2015/06/o.mp3</a></audio> </li> </ol> 
 <h2>Get the new Music landing page</h2><p>Now available together with all the 25+ page layouts</p><!--/themify_builder_static-->',
  'post_title' => 'Top Bar',
  'post_excerpt' => '',
  'post_name' => 'top-bar',
  'post_modified' => '2018-07-17 17:16:39',
  'post_modified_gmt' => '2018-07-17 17:16:39',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4249',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-black',
    'header_design' => 'header-top-bar',
    'exclude_site_logo' => 'no',
    'exclude_site_tagline' => 'yes',
    'exclude_search_form' => 'no',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'no',
    'exclude_social_widget' => 'no',
    'exclude_menu_navigation' => 'no',
    'footer_design' => 'footer-horizontal-left',
    'exclude_footer_widgets' => 'default',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>New Music Landing Page.<\\\\/h1><h5>We used the Audio, Button, and Pricing Table addon to show you how you can create an amazing music layout.<\\\\/h5>\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\"}]}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/04\\\\/91078382.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_right\\":\\"4\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"4\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<iframe src=\\\\\\\\\\\\\\"https:\\\\/\\\\/w.soundcloud.com\\\\/player\\\\/?url=https%3A\\\\/\\\\/api.soundcloud.com\\\\/tracks\\\\/203112765&amp;color=ff5500&amp;auto_play=false&amp;hide_related=false&amp;show_comments=true&amp;show_user=true&amp;show_reposts=false\\\\\\\\\\\\\\" width=\\\\\\\\\\\\\\"100%\\\\\\\\\\\\\\" height=\\\\\\\\\\\\\\"166\\\\\\\\\\\\\\" frameborder=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\" scrolling=\\\\\\\\\\\\\\"no\\\\\\\\\\\\\\"><\\\\/iframe>\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Showcase Your Music.<\\\\/h2><p><strong>Morbi augue lacus, malesuada id cursus a, consequat vel risus. Fusce non lectus nibh. Quisque tempor augue ut porttitor auctor. Suspendisse iaculis diam non est ultrices rhoncus. <\\\\/strong><strong>Suspendisse potenti. Aenean ultrices nisl quis tempor sodales. <\\\\/strong><\\\\/p><h4><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/landing\\\\\\\\\\\\\\"><b>Get it now<\\\\/b><\\\\/a><\\\\/h4><h4><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/landing\\\\\\\\\\\\\\"><b>Download now<\\\\/b><\\\\/a><\\\\/h4>\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/06\\\\/139731562.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"45\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"10\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/ariana-grande-400x400.jpg\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/jason-derulo-400x400.jpg\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/07\\\\/kanye-west-400x400.png\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\"}}]}],\\"gutter\\":\\"gutter-none\\"},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Broadcast Your music.<\\\\/h2><p><strong>Upload your tracks using the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/audio\\\\/\\\\\\\\\\\\\\">Audio addon<\\\\/a>, and allow you users to get a taste of your music. <\\\\/strong><\\\\/p>\\",\\"background_color\\":\\"DCDDD8\\",\\"font_color\\":\\"475F77\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"D74B4B\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"audio\\",\\"mod_settings\\":{\\"font_color\\":\\"ffffff\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_button_link_padding_apply_all\\":\\"1\\",\\"checkbox_button_link_margin_apply_all\\":\\"1\\",\\"checkbox_button_link_border_apply_all\\":\\"1\\",\\"music_playlist\\":[{\\"audio_name\\":\\"Helpless\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addon-audio\\\\/files\\\\/2015\\\\/06\\\\/Helpless.mp3\\"},{\\"audio_name\\":\\"I\\\\\\\\\\\'ve Not Over Yet\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addon-audio\\\\/files\\\\/2015\\\\/06\\\\/myuu-ItsNotOverYet.mp3\\"},{\\"audio_name\\":\\"O Song\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addon-audio\\\\/files\\\\/2015\\\\/06\\\\/o.mp3\\"}],\\"hide_download_audio\\":\\"yes\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"475f77_1.00\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Get the new Music landing page<\\\\/h2><p>Now available together with all the 25+ page layouts<\\\\/p>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/06\\\\/193816727.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"dbdbdb_1.00\\",\\"font_color\\":\\"000000_1.00\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_bottom_color\\":\\"faf205_1.00\\",\\"border_bottom_width\\":\\"5\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5792,
  'post_date' => '2016-09-23 22:00:28',
  'post_date_gmt' => '2016-09-23 22:00:28',
  'post_content' => '<!--themify_builder_static--><ul><li><h4>Travel</h4><p>[list_posts category=\'travel\' style=\'grid3\' limit=\'3\' post_date=\'no\']</p></li><li><h4>Work</h4><p>[list_posts category=\'work\' style=\'grid3\' limit=\'3\' post_date=\'no\']</p></li><li><h4>Photography</h4><p>[list_posts category=\'photography\' style=\'grid3\' limit=\'3\' post_date=\'no\']</p></li></ul>
 <h4>Photography</h4>
 <h4>Work</h4><!--/themify_builder_static-->',
  'post_title' => 'Magazine Header',
  'post_excerpt' => '',
  'post_name' => 'magazine-header',
  'post_modified' => '2018-02-16 20:25:09',
  'post_modified_gmt' => '2018-02-16 20:25:09',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=5792',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar1',
    'hide_page_title' => 'yes',
    'header_design' => 'header-magazine',
    'footer_design' => 'footer-left-col',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"blog\\",\\"post_type\\":\\"post\\",\\"taxonomy\\":\\"category\\",\\"blog_category_slider\\":\\"work|multiple\\",\\"portfolio_category_slider\\":\\"|single\\",\\"posts_per_page_slider\\":\\"3\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"none\\",\\"hide_post_title_slider\\":\\"no\\",\\"unlink_post_title_slider\\":\\"no\\",\\"hide_feat_img_slider\\":\\"no\\",\\"unlink_feat_img_slider\\":\\"no\\",\\"layout_slider\\":\\"slider-overlay\\",\\"img_w_slider\\":\\"820\\",\\"img_h_slider\\":\\"480\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"height_slider\\":\\"variable\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"tab\\",\\"mod_settings\\":{\\"layout_tab\\":\\"minimal\\",\\"tab_content_tab\\":[{\\"title_tab\\":\\"Travel\\",\\"text_tab\\":\\"<p>[list_posts category=\\\\\\\\\\\'travel\\\\\\\\\\\' style=\\\\\\\\\\\'grid3\\\\\\\\\\\' limit=\\\\\\\\\\\'3\\\\\\\\\\\' post_date=\\\\\\\\\\\'no\\\\\\\\\\\']<\\\\/p>\\"},{\\"title_tab\\":\\"Work\\",\\"text_tab\\":\\"<p>[list_posts category=\\\\\\\\\\\'work\\\\\\\\\\\' style=\\\\\\\\\\\'grid3\\\\\\\\\\\' limit=\\\\\\\\\\\'3\\\\\\\\\\\' post_date=\\\\\\\\\\\'no\\\\\\\\\\\']<\\\\/p>\\"},{\\"title_tab\\":\\"Photography\\",\\"text_tab\\":\\"<p>[list_posts category=\\\\\\\\\\\'photography\\\\\\\\\\\' style=\\\\\\\\\\\'grid3\\\\\\\\\\\' limit=\\\\\\\\\\\'3\\\\\\\\\\\' post_date=\\\\\\\\\\\'no\\\\\\\\\\\']<\\\\/p>\\"}],\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"0\\",\\"title_text_align_left\\":\\"left\\",\\"title_text_align_center\\":\\"center\\",\\"title_text_align_right\\":\\"right\\",\\"title_text_align_justify\\":\\"justify\\",\\"title_checkbox_border_apply_all\\":\\"border\\",\\"content_checkbox_padding_apply_all\\":\\"padding\\",\\"content_checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c26\\"}}]}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Photography<\\\\/h4>\\",\\"background_image-type\\":\\"image\\",\\"padding_top\\":\\"5\\",\\"padding_bottom\\":\\"10\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"dbdbdb\\",\\"border_top_width\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c37\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"list-post\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"photography|multiple\\",\\"post_tag_post\\":\\"|single\\",\\"product_cat_post\\":\\"|single\\",\\"product_tag_post\\":\\"|single\\",\\"product_shipping_class_post\\":\\"|single\\",\\"portfolio-category_post\\":\\"|single\\",\\"post_per_page_post\\":\\"1\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"400\\",\\"img_height_post\\":\\"200\\",\\"hide_post_date_post\\":\\"yes\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_top\\":\\"5\\",\\"padding_bottom\\":\\"10\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border_top_color\\":\\"dbdbdb\\",\\"border_top_width\\":\\"1\\",\\"content_text\\":\\"<h4>Work<\\\\/h4>\\"}},{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_post\\":\\"list-post\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"work|multiple\\",\\"post_tag_post\\":\\"0|single\\",\\"product_cat_post\\":\\"0|single\\",\\"product_tag_post\\":\\"0|single\\",\\"product_shipping_class_post\\":\\"0|single\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"1\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"400\\",\\"img_height_post\\":\\"200\\",\\"hide_post_date_post\\":\\"yes\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\"}}]}]},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"layout_post\\":\\"list-thumb-image\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"photography|multiple\\",\\"post_tag_post\\":\\"|single\\",\\"product_cat_post\\":\\"|single\\",\\"product_tag_post\\":\\"|single\\",\\"product_shipping_class_post\\":\\"|single\\",\\"portfolio-category_post\\":\\"|single\\",\\"post_per_page_post\\":\\"3\\",\\"offset_post\\":\\"1\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"65\\",\\"img_height_post\\":\\"65\\",\\"hide_post_date_post\\":\\"yes\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"post\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_post\\":\\"list-thumb-image\\",\\"post_type_post\\":\\"post\\",\\"type_query_post\\":\\"category\\",\\"category_post\\":\\"work|multiple\\",\\"post_tag_post\\":\\"0|single\\",\\"product_cat_post\\":\\"0|single\\",\\"product_tag_post\\":\\"0|single\\",\\"product_shipping_class_post\\":\\"0|single\\",\\"post_filter\\":\\"no\\",\\"post_per_page_post\\":\\"3\\",\\"offset_post\\":\\"1\\",\\"order_post\\":\\"desc\\",\\"orderby_post\\":\\"date\\",\\"display_post\\":\\"none\\",\\"img_width_post\\":\\"65\\",\\"img_height_post\\":\\"65\\",\\"hide_post_date_post\\":\\"yes\\",\\"hide_post_meta_post\\":\\"yes\\",\\"hide_page_nav_post\\":\\"yes\\"}}]}]},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4272,
  'post_date' => '2015-07-03 16:29:59',
  'post_date_gmt' => '2015-07-03 16:29:59',
  'post_content' => '<h2 style="text-align: center;">Pre-built Layouts</h2>
<p style="text-align: center;">We\'ve made it easier for your to create landing pages. Below showcases various landing page layouts that are included in the theme package. Simply import to your site, edit the content, and done!</p>',
  'post_title' => 'Builder Layouts',
  'post_excerpt' => '',
  'post_name' => 'builder-layouts',
  'post_modified' => '2017-08-21 01:18:18',
  'post_modified_gmt' => '2017-08-21 01:18:18',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4272',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-magenta',
    'header_design' => 'header-top-bar',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'yes',
    'exclude_social_widget' => 'yes',
    'query_category' => 'layouts',
    'layout' => 'grid4',
    'more_posts' => 'infinite',
    'posts_per_page' => '12',
    'display_content' => 'none',
    'image_width' => '250',
    'image_height' => '290',
    'hide_date' => 'yes',
    'hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4020,
  'post_date' => '2015-05-09 22:40:46',
  'post_date_gmt' => '2015-05-09 22:40:46',
  'post_content' => '',
  'post_title' => 'Custom Styling',
  'post_excerpt' => '',
  'post_name' => 'custom-styling',
  'post_modified' => '2017-08-21 01:13:16',
  'post_modified_gmt' => '2017-08-21 01:13:16',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4020',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'body_background_color' => '#ffffff',
    'body_background_repeat' => 'repeat',
    'color_scheme_mode' => 'color-custom',
    'scheme_color' => '#6d7778',
    'scheme_link' => '#9c5e1f',
    'scheme_background' => '#dadec3',
    'typography_mode' => 'typography-custom',
    'body_font' => 'Ovo',
    'body_text_color' => '#647475',
    'body_link_color' => '#49497d',
    'heading_font' => 'Unica One',
    'heading_color' => '#656799',
    'header_design' => 'header-block',
    'background_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/f9c22c58.jpg',
    'headerwrap_text_color' => '#f0f0eb',
    'headerwrap_link_color' => '#ffffff',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Our clients</h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Below are some of our clients</h3>\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/02/twitter1.png\\",\\"img_link_slider\\":\\"https://twitter.com/themify\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/02/2YouTube.png\\",\\"img_link_slider\\":\\"https://www.youtube.com/user/themifyme\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/02/1Instagram.png\\",\\"img_link_slider\\":\\"http://instagram.com/\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/02/1facebook.png\\",\\"img_link_slider\\":\\"https://www.facebook.com/themify\\"}],\\"layout_slider\\":\\"slider-default\\",\\"visible_opt_slider\\":\\"3\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"continuously\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"no\\",\\"show_arrow_slider\\":\\"no\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"clients\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"style_divider\\":\\"solid\\",\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Tablet App</h4><p>I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.</p><p>[themify_button style=\\\\\\\\\\\\\\"medium green rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ]Our Work[/themify_button]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"30\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/n9-1.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"560\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>\\\\\\\\\\\\\\"I love working with Interface Design Studio. Their friendly and hands-on!\\\\\\\\\\\\\\"</em></p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\"1.4\\",\\"font_size_unit\\":\\"em\\",\\"padding_top\\":\\"60\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"60\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"border_top_style\\":\\"solid\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/02/157472372.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<strong>Michael Porter</strong><br> \\\\nCEO, X-Company<br>\\\\nwww.companyx.com\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"style_divider\\":\\"solid\\",\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/BMW-i8-Konfigurator-Preise-Sonderausstattungen-Optionen-02.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"560\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Auto App</h4><p>I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.</p><p>[themify_button style=\\\\\\\\\\\\\\"medium green rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing\\\\\\\\\\\\\\" ]Our Work[/themify_button]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"> <em>\\\\\\\\\\\\\\"Great people. Great service. These factors led to an amazing Interface.\\\\\\\\\\\\\\"</em></p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\"1.4\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"60\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top\\":\\"60\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"border_top_style\\":\\"solid\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/02/164990474.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<strong>Stephanie</strong><br>\\\\nSpecialist, Auto-B<br>\\\\nwww.autob.com\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"style_divider\\":\\"solid\\",\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Web App</h4><p>I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. </p><p>[themify_button style=\\\\\\\\\\\\\\"medium green rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing\\\\\\\\\\\\\\" ]Our Work[/themify_button]</p>\\",\\"font_family\\":\\"default\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/Leaderboard_Free.png\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"560\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>\\\\\\\\\\\\\\"Enjoyed working with specialist who know exactly what they are doing!\\\\\\\\\\\\\\"</em></p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\"1.3\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"60\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top\\":\\"60\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"border_top_style\\":\\"solid\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/02/131227259.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<strong>Steve Baker</strong><br>\\\\nCEO, WebApp<br>\\\\nwww.webapp.com\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"style_divider\\":\\"solid\\",\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/overview_display_hero.jpg\\",\\"appearance_image\\":\\"|\\",\\"width_image\\":\\"560\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Mix Panel</h4><p>LI\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. Integer vitae pulvinar tellus. Praesent a metus gravida, blandit mi ac, sagittis lectus. Etiam quis orci risus.</p><p>[themify_button style=\\\\\\\\\\\\\\"medium green rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing\\\\\\\\\\\\\\" ]Our Work[/themify_button]</p>\\",\\"font_family\\":\\"default\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>\\\\\\\\\\\\\\"These guys know how to get things done! Always on-time with high quality results.\\\\\\\\\\\\\\"</em></p>\\",\\"font_family\\":\\"default\\",\\"font_size\\":\\"1.3\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"60\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top\\":\\"60\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"eee\\",\\"border_top_width\\":\\"1\\",\\"border_top_style\\":\\"solid\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/02/104465753.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"param_image\\":\\"|\\",\\"caption_image\\":\\"<strong>Kristina Dealey</strong><br>\\\\nMix Panel<br>\\\\nwww.mixpanel.com\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"style_divider\\":\\"solid\\",\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"bdbdbd_1.00\\"}}],\\"styling\\":[]}],\\"styling\\":[]},{\\"row_order\\":\\"10\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Want to work with us?</h4><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><strong>Let\\\\\\\\\\\'s it happen now!</strong> Enroll to our 2 year university program in just 2-month. Why wait millions are asking for it. Click the following button to register now!</p><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">**Button below was built using our <a href=\\\\\\\\\\\\\\"https://themify.me/addons/button\\\\\\\\\\\\\\">Button Addon</a>**</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"gutter\\":\\"gutter-none\\",\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"11\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4023,
  'post_date' => '2015-05-09 23:13:26',
  'post_date_gmt' => '2015-05-09 23:13:26',
  'post_content' => '',
  'post_title' => 'Blog - Grid3 Masonry',
  'post_excerpt' => '',
  'post_name' => 'blog-grid3',
  'post_modified' => '2018-04-09 20:12:37',
  'post_modified_gmt' => '2018-04-09 20:12:37',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4023',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_header_widgets' => 'yes',
    'query_category' => '0',
    'layout' => 'grid3',
    'post_content_layout' => 'polaroid',
    'disable_masonry' => 'yes',
    'more_posts' => 'infinite',
    'posts_per_page' => '8',
    'display_content' => 'none',
    'image_width' => '365',
    'image_height' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4025,
  'post_date' => '2015-05-09 23:15:15',
  'post_date_gmt' => '2015-05-09 23:15:15',
  'post_content' => '',
  'post_title' => 'Blog - Grid2 Polaroid',
  'post_excerpt' => '',
  'post_name' => 'blog-grid2',
  'post_modified' => '2017-08-21 01:16:35',
  'post_modified_gmt' => '2017-08-21 01:16:35',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4025',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_header_widgets' => 'yes',
    'query_category' => '0',
    'layout' => 'grid2',
    'post_content_layout' => 'polaroid',
    'disable_masonry' => 'yes',
    'post_gutter' => 'no-gutter',
    'posts_per_page' => '8',
    'display_content' => 'none',
    'image_width' => '560',
    'image_height' => '330',
    'hide_date' => 'yes',
    'hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4031,
  'post_date' => '2015-05-09 23:28:26',
  'post_date_gmt' => '2015-05-09 23:28:26',
  'post_content' => '',
  'post_title' => 'Portfolio - Grid4',
  'post_excerpt' => '',
  'post_name' => 'portfolio-grid4',
  'post_modified' => '2017-08-21 01:18:32',
  'post_modified_gmt' => '2017-08-21 01:18:32',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4031',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_footer_widgets' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_layout' => 'grid4',
    'portfolio_posts_per_page' => '8',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '400',
    'portfolio_image_height' => '400',
    'portfolio_hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4033,
  'post_date' => '2015-05-09 23:33:24',
  'post_date_gmt' => '2015-05-09 23:33:24',
  'post_content' => '',
  'post_title' => 'Portfolio - Grid3',
  'post_excerpt' => '',
  'post_name' => 'portfolio-grid3',
  'post_modified' => '2017-08-21 01:18:30',
  'post_modified_gmt' => '2017-08-21 01:18:30',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4033',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_footer_widgets' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_layout' => 'grid3',
    'portfolio_posts_per_page' => '8',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '400',
    'portfolio_image_height' => '400',
    'portfolio_hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4035,
  'post_date' => '2015-05-09 23:34:27',
  'post_date_gmt' => '2015-05-09 23:34:27',
  'post_content' => '',
  'post_title' => 'Portfolio - Grid2',
  'post_excerpt' => '',
  'post_name' => 'portfolio-grid2',
  'post_modified' => '2017-08-21 01:18:30',
  'post_modified_gmt' => '2017-08-21 01:18:30',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4035',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'exclude_footer_widgets' => 'default',
    'portfolio_query_category' => '0',
    'portfolio_layout' => 'grid2',
    'portfolio_posts_per_page' => '8',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '600',
    'portfolio_image_height' => '600',
    'portfolio_hide_meta_all' => 'yes',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4037,
  'post_date' => '2015-05-09 23:35:58',
  'post_date_gmt' => '2015-05-09 23:35:58',
  'post_content' => '',
  'post_title' => 'Portfolio',
  'post_excerpt' => '',
  'post_name' => 'portfolio',
  'post_modified' => '2018-04-24 20:17:23',
  'post_modified_gmt' => '2018-04-24 20:17:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4037',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'hide_page_title' => 'yes',
    'exclude_header_widgets' => 'yes',
    'portfolio_query_category' => '0',
    'portfolio_layout' => 'grid3',
    'portfolio_content_layout' => 'overlay',
    'portfolio_disable_masonry' => 'yes',
    'portfolio_post_gutter' => 'no-gutter',
    'portfolio_posts_per_page' => '9',
    'portfolio_display_content' => 'none',
    'portfolio_image_width' => '366',
    'portfolio_image_height' => '230',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 2512,
  'post_date' => '2016-01-10 00:32:45',
  'post_date_gmt' => '2016-01-10 00:32:45',
  'post_content' => '<!--themify_builder_static--><h1>Themify Ultra</h1> <h3>The most powerful &amp; flexible WordPress theme created by Themify, making it easy to create any site quickly and beautifully (and responsive, of course). Take full control of your theme design from header to footer. Loaded with many layout options and features, it is by far the most versatile theme by Themify.</h3> 
 
 <h4>Drag &amp; Drop Builder</h4><h3>Build unlimited responsive layouts using Themify\'s popular drag &amp; drop Builder.</h3> 
 <a href="https://www.youtube.com/watch?v=waM20ewLj34" > <img src="https://themify.me/demo/themes/ultra/files/2016/02/themify-builder-1024x576-870x489.jpg" width="870" alt="themify builder" srcset="https://themify.me/demo/themes/ultra/files/2016/02/themify-builder-1024x576-870x489.jpg 870w, https://themify.me/demo/themes/ultra/files/2016/02/themify-builder-150x84.jpg 150w, https://themify.me/demo/themes/ultra/files/2016/02/themify-builder-300x169.jpg 300w, https://themify.me/demo/themes/ultra/files/2016/02/themify-builder-1024x576.jpg 1024w, https://themify.me/demo/themes/ultra/files/2016/02/themify-builder.jpg 1280w" sizes="(max-width: 870px) 100vw, 870px" /> </a> 
 <a href="https://themify.me/demo/themes/ultra/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/iphone-300x520.png" width="300" height="520" alt="iphone" /> </a> 
 <h2>Parallax Scrolling &amp; Responsive</h2><h3>Design stunning parallax floating effects that works on all devices &amp; resolution with the Builder.</h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/09/ipad-1-400x796.png" width="400" alt="ipad 1" srcset="https://themify.me/demo/themes/ultra/files/2016/09/ipad-1.png 400w, https://themify.me/demo/themes/ultra/files/2016/09/ipad-1-87x174.png 87w, https://themify.me/demo/themes/ultra/files/2016/09/ipad-1-151x300.png 151w, https://themify.me/demo/themes/ultra/files/2016/09/ipad-1-186x370.png 186w, https://themify.me/demo/themes/ultra/files/2016/09/ipad-1-302x600.png 302w" sizes="(max-width: 400px) 100vw, 400px" /> 
 <a href="https://www.youtube.com/watch?v=SENb0osYYXs" > 
 
 </a> 
 <h3><a href="https://www.youtube.com/watch?v=SENb0osYYXs">See how it works</a></h3> 
 
 <h2>Pre-made Demos</h2><h3>With just a single click, you can import the demo setup that includes the theme settings, content, menus, widgets, etc., exactly like our theme demos. This is a time saver for creating client sites.</h3> 
 <a href="https://themify.me/demo/themes/ultra-agency/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/agency-1-1024x708-360x248.jpg" width="360" title="Agency" alt="Agency" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-agency/" > Agency </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-restaurant/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/restaurant-1024x708-360x248.jpg" width="360" title="Restaurant" alt="Restaurant" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-restaurant/" > Restaurant </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-wedding/" > <img src="https://themify.me/demo/themes/ultra/files/2016/09/wedding-thumb-360x246.png" width="360" title="Wedding" alt="Wedding" srcset="https://themify.me/demo/themes/ultra/files/2016/09/wedding-thumb-360x246.png 360w, https://themify.me/demo/themes/ultra/files/2016/09/wedding-thumb-150x103.png 150w, https://themify.me/demo/themes/ultra/files/2016/09/wedding-thumb-300x206.png 300w, https://themify.me/demo/themes/ultra/files/2016/09/wedding-thumb.png 362w" sizes="(max-width: 360px) 100vw, 360px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-wedding/" > Wedding </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-fitness/" > <img src="https://themify.me/demo/themes/ultra/files/2016/10/fitness-360x248.png" width="360" title="Fitness" alt="Fitness" srcset="https://themify.me/demo/themes/ultra/files/2016/10/fitness.png 360w, https://themify.me/demo/themes/ultra/files/2016/10/fitness-150x103.png 150w, https://themify.me/demo/themes/ultra/files/2016/10/fitness-300x207.png 300w" sizes="(max-width: 360px) 100vw, 360px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-fitness/" > Fitness </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-ecommerce/" > <img src="https://themify.me/demo/themes/ultra/files/2016/10/ecommerce-thumb-360x248.png" width="360" title="eCommerce" alt="eCommerce" srcset="https://themify.me/demo/themes/ultra/files/2016/10/ecommerce-thumb.png 360w, https://themify.me/demo/themes/ultra/files/2016/10/ecommerce-thumb-150x103.png 150w, https://themify.me/demo/themes/ultra/files/2016/10/ecommerce-thumb-300x207.png 300w" sizes="(max-width: 360px) 100vw, 360px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-ecommerce/" > eCommerce </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-lawyer/" > <img src="https://themify.me/wp-content/uploads/2017/01/lawyer-demo-site.png" width="360" title="Lawyer" alt="Lawyer" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-lawyer/" > Lawyer </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-spa/" > <img src="https://themify.me/demo/themes/ultra/files/2017/01/ultra-spa-360x250.png" width="360" title="Spa" alt="Spa" srcset="https://themify.me/demo/themes/ultra/files/2017/01/ultra-spa.png 360w, https://themify.me/demo/themes/ultra/files/2017/01/ultra-spa-150x104.png 150w, https://themify.me/demo/themes/ultra/files/2017/01/ultra-spa-300x208.png 300w, https://themify.me/demo/themes/ultra/files/2017/01/ultra-spa-1x1.png 1w, https://themify.me/demo/themes/ultra/files/2017/01/ultra-spa-11x8.png 11w" sizes="(max-width: 360px) 100vw, 360px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-spa/" > Spa </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-games/" > <img src="https://themify.me/demo/themes/ultra/files/2017/05/ultra-games-skin-360x250.jpg" width="360" title="Games" alt="Games" srcset="https://themify.me/demo/themes/ultra/files/2017/05/ultra-games-skin.jpg 360w, https://themify.me/demo/themes/ultra/files/2017/05/ultra-games-skin-150x104.jpg 150w, https://themify.me/demo/themes/ultra/files/2017/05/ultra-games-skin-300x208.jpg 300w" sizes="(max-width: 360px) 100vw, 360px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-games/" > Games </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-accountant/" > <img src="https://themify.me/demo/themes/ultra/files/2017/08/accountant-thumb-360x257.jpg" width="360" title="Accountant" alt="Accountant" srcset="https://themify.me/demo/themes/ultra/files/2017/08/accountant-thumb-360x257.jpg 360w, https://themify.me/demo/themes/ultra/files/2017/08/accountant-thumb-150x107.jpg 150w, https://themify.me/demo/themes/ultra/files/2017/08/accountant-thumb-300x214.jpg 300w, https://themify.me/demo/themes/ultra/files/2017/08/accountant-thumb.jpg 350w" sizes="(max-width: 360px) 100vw, 360px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-accountant/" > Accountant </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-photography/" > <img src="https://themify.me/wp-content/uploads/2018/05/ultra-photography-thumb-2.jpg" title="Photography" alt="Photography" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-photography/" > Photography </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-app/" > <img src="https://themify.me/demo/themes/ultra/files/2018/06/ultra-app-skin-thumb.jpg" title="App" alt="App" srcset="https://themify.me/demo/themes/ultra/files/2018/06/ultra-app-skin-thumb.jpg 300w, https://themify.me/demo/themes/ultra/files/2018/06/ultra-app-skin-thumb-150x112.jpg 150w" sizes="(max-width: 300px) 100vw, 300px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-app/" > App </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra-education/" > <img src="https://themify.me/demo/themes/ultra/files/2018/08/education-thumb.jpg" title="Education" alt="Education" srcset="https://themify.me/demo/themes/ultra/files/2018/08/education-thumb.jpg 300w, https://themify.me/demo/themes/ultra/files/2018/08/education-thumb-150x112.jpg 150w" sizes="(max-width: 300px) 100vw, 300px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra-education/" > Education </a> </h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/more-1-360x248.png" width="360" title="Coming soon" alt="Coming soon" srcset="https://themify.me/demo/themes/ultra/files/2016/11/more-1.png 360w, https://themify.me/demo/themes/ultra/files/2016/11/more-1-150x103.png 150w, https://themify.me/demo/themes/ultra/files/2016/11/more-1-300x207.png 300w, https://themify.me/demo/themes/ultra/files/2016/11/more-1-325x223.png 325w" sizes="(max-width: 360px) 100vw, 360px" /> <h3> Coming soon </h3> 
 <h2>Smart Layout Options</h2><h3>Ultra gives you full control from header to footer, either site-wide or on a per-page basis. This means that you can make your entire site share the same look and feel or create a unique look for every page.</h3> 
 <h4>15 Header/Page Styles</h4><p>Select a header/page design from 15 styles (the no header option is perfect for making landing pages where you don\'t want to have header navigation). And yes, there is a sticky header option and this design list is growing!</p> 
 <a href="https://themify.me/demo/themes/ultra/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2017/01/header-layout-1024x555-1158x628.png" width="1158" height="628" alt="header layout" srcset="https://themify.me/demo/themes/ultra/files/2017/01/header-layout.png 1158w, https://themify.me/demo/themes/ultra/files/2017/01/header-layout-150x81.png 150w, https://themify.me/demo/themes/ultra/files/2017/01/header-layout-300x163.png 300w, https://themify.me/demo/themes/ultra/files/2017/01/header-layout-1024x555.png 1024w, https://themify.me/demo/themes/ultra/files/2017/01/header-layout-370x201.png 370w, https://themify.me/demo/themes/ultra/files/2017/01/header-layout-600x325.png 600w" sizes="(max-width: 1158px) 100vw, 1158px" /> </a> 
 <h4>6 Header Background Options</h4><p>Header background allows you to: upload a background image, pick a solid color, insert a slider, upload a video, set animating colors, or have it transparent if you want.</p> 
 <a href="https://themify.me/demo/themes/ultra/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2017/01/header-background-1024x154-1158x174.png" width="1158" height="174" alt="header background" srcset="https://themify.me/demo/themes/ultra/files/2017/01/header-background.png 1158w, https://themify.me/demo/themes/ultra/files/2017/01/header-background-150x23.png 150w, https://themify.me/demo/themes/ultra/files/2017/01/header-background-300x45.png 300w, https://themify.me/demo/themes/ultra/files/2017/01/header-background-1024x154.png 1024w, https://themify.me/demo/themes/ultra/files/2017/01/header-background-370x56.png 370w, https://themify.me/demo/themes/ultra/files/2017/01/header-background-600x90.png 600w" sizes="(max-width: 1158px) 100vw, 1158px" /> </a> 
 <h4>6 Footer Layouts</h4><p>6 footer layout choices with options to toggle visibility of footer logo, menu, widget, and credit text.</p> 
 <a href="https://themify.me/demo/themes/ultra/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2017/01/footer-layout-1024x155-1157x175.png" width="1157" height="175" alt="footer layout" srcset="https://themify.me/demo/themes/ultra/files/2017/01/footer-layout.png 1157w, https://themify.me/demo/themes/ultra/files/2017/01/footer-layout-150x23.png 150w, https://themify.me/demo/themes/ultra/files/2017/01/footer-layout-300x45.png 300w, https://themify.me/demo/themes/ultra/files/2017/01/footer-layout-1024x155.png 1024w, https://themify.me/demo/themes/ultra/files/2017/01/footer-layout-370x56.png 370w, https://themify.me/demo/themes/ultra/files/2017/01/footer-layout-600x91.png 600w" sizes="(max-width: 1157px) 100vw, 1157px" /> </a> 
 <h4>5 Single Post Layouts</h4><p>In term of single post layout, there is a default layout plus 4 unique layouts.</p> 
 <a href="https://themify.me/demo/themes/ultra/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2017/01/single-post-layout-759x175.png" width="759" height="175" alt="single post layout" srcset="https://themify.me/demo/themes/ultra/files/2017/01/single-post-layout.png 759w, https://themify.me/demo/themes/ultra/files/2017/01/single-post-layout-150x35.png 150w, https://themify.me/demo/themes/ultra/files/2017/01/single-post-layout-300x69.png 300w, https://themify.me/demo/themes/ultra/files/2017/01/single-post-layout-370x85.png 370w, https://themify.me/demo/themes/ultra/files/2017/01/single-post-layout-600x138.png 600w" sizes="(max-width: 759px) 100vw, 759px" /> </a> 
 <h4>6 Archive Layouts</h4><p>For the archive layouts, we have 6 different styles that you can choose from: slider, fullwidth, masonry, grids, polaroid, and overlay. You may also toggle the visibility of the post elements such as post title, featured image, meta, content, etc.</p> 
 <a href="https://themify.me/demo/themes/ultra/all-layouts/" > <img src="https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts-1024x154-1157x174.png" width="1157" height="174" alt="alt text" srcset="https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts.png 1157w, https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts-150x23.png 150w, https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts-300x45.png 300w, https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts-1024x154.png 1024w, https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts-370x56.png 370w, https://themify.me/demo/themes/ultra/files/2017/01/archive-layouts-600x90.png 600w" sizes="(max-width: 1157px) 100vw, 1157px" /> </a> 
 <h4>Section Scrolling (*New)</h4> <p>Inspired by our <a href="https://themify.me/themes/fullpane">Fullpane</a> theme, full section scrolling feature allows viewers to scroll through your page design one row at a time like a presentation slideshow. Full section scrolling now comes with Horizontal and Vertical scrolling.</p> 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/slide-out-header/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/slide-out-scrolling-160x135.png" width="160" height="135" title="Vertical Slide Out Header &lt;strong&gt;(Mix*)&lt;/strong&gt;" alt="Vertical Slide Out Header &lt;strong&gt;(Mix*)&lt;/strong&gt;" srcset="https://themify.me/demo/themes/ultra/files/2016/11/slide-out-scrolling.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/slide-out-scrolling-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/slide-out-header/" > Vertical + Slide Out Header <strong>(Mix*)</strong> </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/overlay-header/" > <img src="https://themify.me/demo/themes/ultra/files/2016/11/overlay-scrolling-160x135.png" width="160" height="135" title="Vertical Overlay Header" alt="Vertical Overlay Header" srcset="https://themify.me/demo/themes/ultra/files/2016/11/overlay-scrolling.png 160w, https://themify.me/demo/themes/ultra/files/2016/11/overlay-scrolling-150x127.png 150w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/overlay-header/" > Vertical + Overlay Header </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-min-bar-header/" > <img src="https://themify.me/demo/themes/ultra/files/2018/04/minbar-header-160x135.png" width="160" height="135" title="Horizontal Min Bar Header" alt="Horizontal Min Bar Header" srcset="https://themify.me/demo/themes/ultra/files/2018/04/minbar-header-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2018/04/minbar-header-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2018/04/minbar-header.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-min-bar-header/" > Horizontal + Min Bar Header </a> </h3> 
 <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-top-bar-header/" > <img src="https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header-160x135.png" width="160" height="135" title="Horizontal Top Bar Header" alt="Horizontal Top Bar Header" srcset="https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header-160x135.png 160w, https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header-150x127.png 150w, https://themify.me/demo/themes/ultra/files/2018/04/top-bar-header.png 192w" sizes="(max-width: 160px) 100vw, 160px" /> </a> <h3> <a href="https://themify.me/demo/themes/ultra/theme-appearance/horizontal-top-bar-header/" > Horizontal + Top Bar Header </a> </h3> 
 <h2>140+ Pre-designed Layouts</h2> <h3>The Builder includes a huge library of pre-made layouts designed by professional designers. Simply import a layout, replace the text and images, and you\'re done! You can get an awesome parallax landing page done in minutes.</h3> 
 <a href="https://themify.me/demo/themes/builder-layouts" >VIEW DEMOS</a> 
 <h2>12 Bonus Addons</h2> <h3>Get the exact same layouts as our pre-made sites with 12 free Builder addons. Valued at $120, purchasing the Ultra theme will give you access to all these bonus addons for free.</h3> 
 <a href="https://themify.me/addons/progress-bar" > <img src="https://themify.me/wp-content/product-img/addons/progress-bar-thumb.jpg" width="40" title="Progress Bar" alt="Progress Bar" /> </a> <h3> <a href="https://themify.me/addons/progress-bar" > Progress Bar </a> </h3> 
 <a href="https://themify.me/addons/counter" > <img src="https://themify.me/wp-content/product-img/addons/counter-thumb.jpg" width="40" height="40" title="Counter" alt="Counter" /> </a> <h3> <a href="https://themify.me/addons/counter" > Counter </a> </h3> 
 <a href="https://themify.me/addons/timeline" > <img src="https://themify.me/wp-content/product-img/addons/timeline-thumb.jpg" width="40" height="40" title="Timeliine" alt="Timeliine" /> </a> <h3> <a href="https://themify.me/addons/timeline" > Timeliine </a> </h3> 
 <a href="https://themify.me/addons/contact" > <img src="https://themify.me/wp-content/product-img/addons/contact-thumb.jpg" width="40" height="40" title="Contact" alt="Contact" /> </a> <h3> <a href="https://themify.me/addons/contact" > Contact </a> </h3> 
 <a href="https://themify.me/addons/image-pro" > <img src="https://themify.me/wp-content/product-img/addons/image-pro-thumb.jpg" width="40" height="40" title="Image Pro" alt="Image Pro" /> </a> <h3> <a href="https://themify.me/addons/image-pro" > Image Pro </a> </h3> 
 <a href="https://themify.me/addons/typewriter" > <img src="https://themify.me/wp-content/product-img/addons/typewriter-thumb.jpg" width="40" height="40" title="Typewriter" alt="Typewriter" /> </a> <h3> <a href="https://themify.me/addons/typewriter" > Typewriter </a> </h3> 
 <a href="https://themify.me/addons/maps-pro" > <img src="https://themify.me/wp-content/product-img/addons/maps-pro-thumb.jpg" width="40" height="40" title="Maps Pro" alt="Maps Pro" /> </a> <h3> <a href="https://themify.me/addons/maps-pro" > Maps Pro </a> </h3> 
 <a href="https://themify.me/addons/woocommerce" > <img src="https://themify.me/wp-content/product-img/addons/woocommerce-thumb.jpg" width="40" height="40" title="Woocommerce" alt="Woocommerce" /> </a> <h3> <a href="https://themify.me/addons/woocommerce" > Woocommerce </a> </h3> 
 <a href="https://themify.me/addons/pricing-table" > <img src="https://themify.me/wp-content/product-img/addons/pricing-table-thumb.jpg" width="40" height="40" title="Pricing Table" alt="Pricing Table" /> </a> <h3> <a href="https://themify.me/addons/pricing-table" > Pricing Table </a> </h3> 
 <a href="https://themify.me/addons/countdown" > <img src="https://themify.me/wp-content/product-img/addons/countdown-thumb.jpg" width="40" height="40" title="Countdown" alt="Countdown" /> </a> <h3> <a href="https://themify.me/addons/countdown" > Countdown </a> </h3> 
 <h2 style="text-align: center;">Animating Colors</h2> 
 <h2 style="text-align: center;">Gradient</h2> 
 <h2 style="text-align: center;">Overlay</h2> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/ultra-mega-menu-image-614x251.jpg" width="614" height="251" alt="ultra mega menu image" srcset="https://themify.me/demo/themes/ultra/files/2016/11/ultra-mega-menu-image.jpg 614w, https://themify.me/demo/themes/ultra/files/2016/11/ultra-mega-menu-image-150x61.jpg 150w, https://themify.me/demo/themes/ultra/files/2016/11/ultra-mega-menu-image-300x123.jpg 300w, https://themify.me/demo/themes/ultra/files/2016/11/ultra-mega-menu-image-370x151.jpg 370w, https://themify.me/demo/themes/ultra/files/2016/11/ultra-mega-menu-image-600x245.jpg 600w" sizes="(max-width: 614px) 100vw, 614px" /> 
 <h2>Mega Menu</h2><h3>Mega menu allows you to display recent posts, multi-column menus, and even the ability to add widgets into the menu.</h3> 
 <h2>Image Filters</h2><h3>Auto-apply Grayscale, Blur, and Sephia filters to your images without editing the original image source (no Photoshop needed). Image filter and hover filter can apply globally or individually as you want.</h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/love-260x210.jpg" width="260" height="210" title="Sepia" alt="Sepia" srcset="https://themify.me/demo/themes/ultra/files/2016/11/love.jpg 260w, https://themify.me/demo/themes/ultra/files/2016/11/love-150x121.jpg 150w, https://themify.me/demo/themes/ultra/files/2016/11/love-1x1.jpg 1w, https://themify.me/demo/themes/ultra/files/2016/11/love-11x9.jpg 11w" sizes="(max-width: 260px) 100vw, 260px" /> <h3> Sepia </h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/cafe-260x210.jpg" width="260" height="210" title="Blur" alt="Blur" srcset="https://themify.me/demo/themes/ultra/files/2016/11/cafe.jpg 260w, https://themify.me/demo/themes/ultra/files/2016/11/cafe-150x121.jpg 150w, https://themify.me/demo/themes/ultra/files/2016/11/cafe-1x1.jpg 1w, https://themify.me/demo/themes/ultra/files/2016/11/cafe-11x9.jpg 11w" sizes="(max-width: 260px) 100vw, 260px" /> <h3> Blur </h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/peoples-260x210.jpg" width="260" height="210" title="Grayscale" alt="Grayscale" srcset="https://themify.me/demo/themes/ultra/files/2016/11/peoples.jpg 260w, https://themify.me/demo/themes/ultra/files/2016/11/peoples-150x121.jpg 150w" sizes="(max-width: 260px) 100vw, 260px" /> <h3> Grayscale </h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/09/portfolio-image.jpg" alt="portfolio-image" srcset="https://themify.me/demo/themes/ultra/files/2016/09/portfolio-image.jpg 800w, https://themify.me/demo/themes/ultra/files/2016/09/portfolio-image-150x115.jpg 150w, https://themify.me/demo/themes/ultra/files/2016/09/portfolio-image-300x230.jpg 300w, https://themify.me/demo/themes/ultra/files/2016/09/portfolio-image-370x284.jpg 370w, https://themify.me/demo/themes/ultra/files/2016/09/portfolio-image-600x460.jpg 600w" sizes="(max-width: 800px) 100vw, 800px" /> 
 <h2 style="text-align: center;">Portfolio</h2><h3 style="text-align: center;">Looking to showcase your work and services? Ultra includes an optional portfolio that works seamlessly with all of the post layouts available for the blog posts. We even throw in a post filter as a bonus.</h3> 
 <h2 style="text-align: center;">WooCommerce Shop</h2><h3 style="text-align: center;">Wanna sell something? Great, Ultra has WooCommerce integration which matches the shop with the overall theme appearance.</h3> 
 <img src="https://themify.me/demo/themes/ultra/files/2016/11/shop-image-630x504.jpg" width="630" height="504" alt="shop image" srcset="https://themify.me/demo/themes/ultra/files/2016/11/shop-image.jpg 630w, https://themify.me/demo/themes/ultra/files/2016/11/shop-image-150x120.jpg 150w, https://themify.me/demo/themes/ultra/files/2016/11/shop-image-300x240.jpg 300w, https://themify.me/demo/themes/ultra/files/2016/11/shop-image-370x296.jpg 370w, https://themify.me/demo/themes/ultra/files/2016/11/shop-image-600x480.jpg 600w" sizes="(max-width: 630px) 100vw, 630px" /> 
 <h2 style="text-align: center;">30 Day Money Back</h2><h3 style="text-align: center;">Buy it with confidence. If you don\'t like it, simply request a full refund within 30 days.</h3> 
 <a href="https://themify.me/themes/ultra" >Buy Now</a><!--/themify_builder_static-->',
  'post_title' => 'Home',
  'post_excerpt' => '',
  'post_name' => 'demo-pages',
  'post_modified' => '2018-10-23 19:44:55',
  'post_modified_gmt' => '2018-10-23 19:44:55',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/landing/?page_id=2512',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-top-bar',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'yes',
    'exclude_social_widget' => 'yes',
    'header_wrap' => 'transparent',
    'footer_design' => 'none',
    'exclude_footer_widgets' => 'yes',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"3752eb3\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"b630e31\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"21de73d\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Themify Ultra<\\\\/h1>\\\\n<h3>The most powerful &amp; flexible WordPress theme created by Themify, making it easy to create any site quickly and beautifully (and responsive, of course). Take full control of your theme design from header to footer. Loaded with many layout options and features, it is by far the most versatile theme by Themify.<\\\\/h3>\\"}},{\\"mod_name\\":\\"divider\\",\\"element_id\\":\\"374d318\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"ffffff_1.00\\",\\"bottom_margin_divider\\":\\"50\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"center\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"7142334\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Drag &amp; Drop Builder<\\\\/h4><h3>Build unlimited responsive layouts using Themify\\\\\\\\\\\'s popular drag &amp; drop Builder.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"a5ef80e\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/02\\\\/themify-builder-1024x576.jpg\\",\\"width_image\\":\\"870\\",\\"link_image\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/watch?v=waM20ewLj34\\",\\"param_image\\":\\"lightbox\\",\\"image_zoom_icon\\":\\"zoom\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_right\\":\\"10\\",\\"margin_right_unit\\":\\"%\\",\\"margin_bottom\\":\\"5\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"10\\",\\"margin_left_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"background_type\\":\\"gradient\\",\\"background_gradient-gradient\\":\\"0% rgb(110, 74, 255)|69% rgb(49, 245, 245)|98% rgb(255, 255, 255)\\",\\"cover_color\\":\\"_\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"136a9d0\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"efb9797\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"c0cb1f4\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/iphone-325x520.png\\",\\"width_image\\":\\"300\\",\\"height_image\\":\\"520\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_zindex\\":\\"1\\"}}]},{\\"element_id\\":\\"561a86e\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"4591236\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Parallax Scrolling &amp; Responsive<\\\\/h2><h3>Design stunning parallax floating effects that works on all devices &amp; resolution with the Builder.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"a90f8bb\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"7c82adf\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/09\\\\/ipad-1.png\\",\\"width_image\\":\\"400\\",\\"param_image\\":\\"regular\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"4\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"c76f425\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"d0cc39f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"a205ce6\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"title_feature\\":\\"See how it works\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"000000\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-play\\",\\"icon_color_feature\\":\\"#000\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/watch?v=SENb0osYYXs\\",\\"link_options\\":\\"regular\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"8fe5e67\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Pre-made Demos<\\\\/h2><h3>With just a single click, you can import the demo setup that includes the theme settings, content, menus, widgets, etc., exactly like our theme demos. This is a time saver for creating client sites.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"element_id\\":\\"2989cb8\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"f2cf341\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"2cc958c\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/agency-1-1024x708-360x248.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Agency\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-agency\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"36e6edf\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"4ecfb88\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/restaurant-1024x708-360x248.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Restaurant\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-restaurant\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]},{\\"element_id\\":\\"b401e3b\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"399283a\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/09\\\\/wedding-thumb-360x246.png\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Wedding\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-wedding\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"dfac344\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"c0beb63\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/10\\\\/fitness.png\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Fitness\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-fitness\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]},{\\"element_id\\":\\"3758ce4\\",\\"row_order\\":\\"3\\",\\"cols\\":[{\\"element_id\\":\\"9cce89c\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"fd43323\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/10\\\\/ecommerce-thumb.png\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"eCommerce\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-ecommerce\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"24bf8e8\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"dbb9ad9\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/uploads\\\\/2017\\\\/01\\\\/lawyer-demo-site.png\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Lawyer\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-lawyer\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"34c804f\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"3eb0a04\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/01\\\\/ultra-spa.png\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Spa\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-spa\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"text_align_module_title_left\\":\\"left\\",\\"text_align_module_title_center\\":\\"center\\",\\"text_align_module_title_right\\":\\"right\\",\\"text_align_module_title_justify\\":\\"justify\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"86a8f11\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"72dea3a\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/05\\\\/ultra-games-skin.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Games\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-games\\\\/\\",\\"param_image\\":\\"lightbox\\",\\"margin_bottom\\":\\"20\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]},{\\"element_id\\":\\"930530f\\",\\"row_order\\":\\"4\\",\\"cols\\":[{\\"element_id\\":\\"02aadbb\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"0e562ac\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_decoration\\":\\"none\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/08\\\\/accountant-thumb.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Accountant\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-accountant\\\\/\\",\\"param_image\\":\\"lightbox\\"}}]},{\\"element_id\\":\\"c57e388\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"478594d\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_decoration\\":\\"none\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/uploads\\\\/2018\\\\/05\\\\/ultra-photography-thumb-2.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"title_image\\":\\"Photography\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-photography\\\\/\\",\\"param_image\\":\\"lightbox\\"}}]},{\\"element_id\\":\\"1a7d8ae\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"b52ef24\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"text_decoration\\":\\"none\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/06\\\\/ultra-app-skin-thumb.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"title_image\\":\\"App\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-app\\\\/\\",\\"param_image\\":\\"lightbox\\"}}]},{\\"element_id\\":\\"146898f\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"5894787\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"text_decoration\\":\\"none\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"border-type\\":\\"top\\",\\"checkbox_title_margin_apply_all\\":\\"1\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/08\\\\/education-thumb.jpg\\",\\"appearance_image\\":\\"bordered\\",\\"title_image\\":\\"Education\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra-education\\\\/\\",\\"param_image\\":\\"lightbox\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]},{\\"element_id\\":\\"983e8ab\\",\\"row_order\\":\\"5\\",\\"cols\\":[{\\"element_id\\":\\"4fe5dc1\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"c40c43e\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/more-1.png\\",\\"appearance_image\\":\\"bordered\\",\\"width_image\\":\\"360\\",\\"title_image\\":\\"Coming soon\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"a8780c9\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"fa2c622\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"e85378d\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"fb99ee9\\",\\"row_order\\":\\"3\\",\\"cols\\":[{\\"element_id\\":\\"f6bd5c4\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"a63b9ed\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Smart Layout Options<\\\\/h2><h3>Ultra gives you full control from header to footer, either site-wide or on a per-page basis. This means that you can make your entire site share the same look and feel or create a unique look for every page.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"309d32f\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>15 Header\\\\/Page Styles<\\\\/h4><p>Select a header\\\\/page design from 15 styles (the no header option is perfect for making landing pages where you don\\\\\\\\\\\'t want to have header navigation). And yes, there is a sticky header option and this design list is growing!<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"e4d34fc\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/01\\\\/header-layout-1024x555.png\\",\\"width_image\\":\\"1158\\",\\"height_image\\":\\"628\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"6a66b78\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>6 Header Background Options<\\\\/h4><p>Header background allows you to: upload a background image, pick a solid color, insert a slider, upload a video, set animating colors, or have it transparent if you want.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"8188aa7\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/01\\\\/header-background-1024x154.png\\",\\"width_image\\":\\"1158\\",\\"height_image\\":\\"174\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"828f8d3\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>6 Footer Layouts<\\\\/h4><p>6 footer layout choices with options to toggle visibility of footer logo, menu, widget, and credit text.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"0324a7f\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/01\\\\/footer-layout-1024x155.png\\",\\"width_image\\":\\"1157\\",\\"height_image\\":\\"175\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"ca6f516\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>5 Single Post Layouts<\\\\/h4><p>In term of single post layout, there is a default layout plus 4 unique layouts.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"86f7977\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/01\\\\/single-post-layout.png\\",\\"width_image\\":\\"759\\",\\"height_image\\":\\"175\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"b0864a1\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>6 Archive Layouts<\\\\/h4><p>For the archive layouts, we have 6 different styles that you can choose from: slider, fullwidth, masonry, grids, polaroid, and overlay. You may also toggle the visibility of the post elements such as post title, featured image, meta, content, etc.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"e2a5f04\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2017\\\\/01\\\\/archive-layouts-1024x154.png\\",\\"width_image\\":\\"1157\\",\\"height_image\\":\\"174\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/all-layouts\\\\/\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"9a81f6a\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top\\":\\"7\\",\\"margin_top_unit\\":\\"%\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h4>Section Scrolling (*New)<\\\\/h4>\\\\n<p>Inspired by our <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/fullpane\\\\\\\\\\\\\\">Fullpane<\\\\/a> theme, full section scrolling feature allows viewers to scroll through your page design one row at a time like a presentation slideshow. Full section scrolling now comes with Horizontal and Vertical scrolling.<\\\\/p>\\",\\"animation_effect\\":\\"fadeInDown\\"}},{\\"element_id\\":\\"533c852\\",\\"row_order\\":\\"12\\",\\"cols\\":[{\\"element_id\\":\\"a2223fa\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"6a755c4\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/slide-out-scrolling.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Vertical + Slide Out Header <strong>(Mix*)<\\\\/strong>\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/slide-out-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]},{\\"element_id\\":\\"5485e14\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"ea9537f\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/overlay-scrolling.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Vertical + Overlay Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/overlay-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]},{\\"element_id\\":\\"8dcf89e\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"1e103d1\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/04\\\\/minbar-header.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Horizontal + Min Bar Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/horizontal-min-bar-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]},{\\"element_id\\":\\"b7fd84a\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"6917ce5\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_title\\":\\"000000\\",\\"font_size_title\\":\\"16\\",\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2018\\\\/04\\\\/top-bar-header.png\\",\\"width_image\\":\\"160\\",\\"height_image\\":\\"135\\",\\"title_image\\":\\"Horizontal + Top Bar Header\\",\\"link_image\\":\\"https://themify.me/demo/themes/ultra\\\\/theme-appearance\\\\/horizontal-top-bar-header\\\\/\\",\\"param_image\\":\\"regular\\",\\"animation_effect\\":\\"fadeInUp\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"cd980f3\\",\\"row_order\\":\\"4\\",\\"cols\\":[{\\"element_id\\":\\"32bced0\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"element_id\\":\\"31e75af\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"19bd8cc\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"grid_width\\":\\"14.7704\\"},{\\"element_id\\":\\"8a5cc33\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"d099054\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"font_color\\":\\"ffffff\\",\\"margin_bottom\\":\\"3\\",\\"margin_bottom_unit\\":\\"%\\",\\"content_text\\":\\"<h2>140+ Pre-designed Layouts<\\\\/h2>\\\\n<h3>The Builder includes a huge library of pre-made layouts designed by professional designers. Simply import a layout, replace the text and images, and you\\\\\\\\\\\'re done! You can get an awesome parallax landing page done in minutes.<\\\\/h3>\\\\n\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"cad1a10\\",\\"mod_settings\\":{\\"buttons_size\\":\\"xlarge\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"VIEW DEMOS\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\",\\"link_options\\":\\"regular\\"}],\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"grid_width\\":\\"62.3866\\"},{\\"element_id\\":\\"ce555f6\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"grid_width\\":\\"16.4345\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/parallax\\\\/files\\\\/2016\\\\/05\\\\/predesigned-layout-2-1400x817.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"cover_gradient\\",\\"cover_color\\":\\"3831c2_0.83\\",\\"cover_gradient-gradient-angle\\":\\"285\\",\\"cover_gradient-gradient\\":\\"0% rgba(68, 31, 255, 0.933)|73% rgba(255, 92, 92, 0.933)|100% rgba(255, 255, 158, 0.933)\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"12\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"12\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth-content\\"}},{\\"element_id\\":\\"5c350f1\\",\\"row_order\\":\\"5\\",\\"cols\\":[{\\"element_id\\":\\"9d4cbcf\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"52b04d0\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"text_align\\":\\"center\\",\\"margin_bottom\\":\\"7\\",\\"margin_bottom_unit\\":\\"%\\",\\"content_text\\":\\"<h2>12 Bonus Addons<\\\\/h2>\\\\n<h3>Get the exact same layouts as our pre-made sites with 12 free Builder addons. Valued at $120, purchasing the Ultra theme will give you access to all these bonus addons for free.<\\\\/h3>\\",\\"animation_effect\\":\\"fadeInLeft\\"}},{\\"element_id\\":\\"e066faa\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"c7f7c00\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"b07a1d4\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/progress-bar-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"title_image\\":\\"Progress Bar\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/progress-bar\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"0\\"}}}]},{\\"element_id\\":\\"ab04387\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"bf78aa8\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/counter-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Counter\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/counter\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"0\\"}}}]},{\\"element_id\\":\\"19e5f7e\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"940c2e8\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/timeline-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Timeliine\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/timeline\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"0\\"}}}]},{\\"element_id\\":\\"92e2aa4\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"e00b0fc\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/contact-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Contact\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/contact\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"0\\"}}}]},{\\"element_id\\":\\"618ffd5\\",\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"38e8388\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/image-pro-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Image Pro\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/image-pro\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"gutter\\":\\"gutter-narrow\\",\\"col_mobile\\":\\"mobile3-1\\",\\"styling\\":{\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"8112ebc\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"9439235\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"54203f7\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/typewriter-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Typewriter\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/typewriter\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"08e03c9\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"6cac04b\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/maps-pro-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Maps Pro\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/maps-pro\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"c3baa2c\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"ca171d1\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/woocommerce-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Woocommerce\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/woocommerce\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"16\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"782369d\\",\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"decc4ba\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/pricing-table-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Pricing Table\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/pricing-table\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"3d3e01c\\",\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"69c48be\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/wp-content\\\\/product-img\\\\/addons\\\\/countdown-thumb.jpg\\",\\"appearance_image\\":\\"rounded|bordered\\",\\"width_image\\":\\"40\\",\\"height_image\\":\\"40\\",\\"title_image\\":\\"Countdown\\",\\"link_image\\":\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/countdown\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"font_color_title\\":\\"000000_1.00\\",\\"font_size_title\\":\\"18\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"gutter\\":\\"gutter-narrow\\",\\"col_mobile\\":\\"mobile3-1\\"}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"f405184\\",\\"row_order\\":\\"6\\",\\"cols\\":[{\\"element_id\\":\\"8a9f39b\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"4a5429c\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Animating Colors<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"zoomInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"150\\",\\"padding_bottom\\":\\"150\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_css_column\\":\\"animated-bg\\"}},{\\"element_id\\":\\"548ccd2\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"1f1d9dc\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Gradient<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"zoomIn\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"gradient\\",\\"background_gradient-gradient-angle\\":\\"64\\",\\"background_gradient-gradient\\":\\"0% rgb(87, 250, 185)|98% rgba(163, 40, 235, 0.611765)\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"150\\",\\"padding_bottom\\":\\"150\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"499ce30\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"d09d614\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Overlay<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"zoomInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/10\\\\/girl-4.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-top\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"af15d6_0.61\\",\\"cover_color_hover-type\\":\\"hover_gradient\\",\\"cover_gradient_hover-gradient\\":\\"0% rgba(175, 21, 214, 0.83)|100% rgba(117, 255, 234, 0.64)\\",\\"padding_top\\":\\"150\\",\\"padding_bottom\\":\\"150\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"custom_css_row\\":\\"animated-bg\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"fafafa_1.00\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff_1.00\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"f0ec889\\",\\"row_order\\":\\"7\\",\\"cols\\":[{\\"element_id\\":\\"d220a69\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"b25a8f6\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/ultra-mega-menu-image.jpg\\",\\"width_image\\":\\"614\\",\\"height_image\\":\\"251\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"swing\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"687b330\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"3280332\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Mega Menu<\\\\/h2><h3>Mega menu allows you to display recent posts, multi-column menus, and even the ability to add widgets into the menu.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"f3191bc\\",\\"row_order\\":\\"8\\",\\"cols\\":[{\\"element_id\\":\\"d2077bf\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"50f7ffd\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Image Filters<\\\\/h2><h3>Auto-apply Grayscale, Blur, and Sephia filters to your images without editing the original image source (no Photoshop needed). Image filter and hover filter can apply globally or individually as you want.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"right\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"5\\",\\"margin_bottom_unit\\":\\"%\\",\\"animation_effect\\":\\"fadeInUp\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"ac19a8a\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"element_id\\":\\"9380347\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"35edf09\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"d470369\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/love.jpg\\",\\"width_image\\":\\"260\\",\\"height_image\\":\\"210\\",\\"title_image\\":\\"Sepia\\",\\"param_image\\":\\"regular\\",\\"css_image\\":\\"filter-sepia filter-hover-none\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"flipInX\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"ae55f66\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"fd6865f\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/cafe.jpg\\",\\"width_image\\":\\"260\\",\\"height_image\\":\\"210\\",\\"title_image\\":\\"Blur\\",\\"param_image\\":\\"regular\\",\\"css_image\\":\\"filter-blur filter-hover-none\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"animation_effect\\":\\"flipInX\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"4f98bff\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"59fba7f\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/peoples.jpg\\",\\"width_image\\":\\"260\\",\\"height_image\\":\\"210\\",\\"title_image\\":\\"Grayscale\\",\\"param_image\\":\\"regular\\",\\"css_image\\":\\"filter-grayscale filter-hover-none\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"animation_effect\\":\\"flipInX\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"d96563a\\",\\"row_order\\":\\"9\\",\\"cols\\":[{\\"element_id\\":\\"e94ab53\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"c32f2c1\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/09\\\\/portfolio-image.jpg\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"pulse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"4032822\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"dcfcb84\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Portfolio<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Looking to showcase your work and services? Ultra includes an optional portfolio that works seamlessly with all of the post layouts available for the blog posts. We even throw in a post filter as a bonus.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"70\\",\\"padding_left\\":\\"70\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"0d7f9e3\\",\\"row_order\\":\\"10\\",\\"cols\\":[{\\"element_id\\":\\"9370481\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"7c53949\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">WooCommerce Shop<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Wanna sell something? Great, Ultra has WooCommerce integration which matches the shop with the overall theme appearance.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"50\\",\\"padding_left\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"8ed020b\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"element_id\\":\\"2e4ea5c\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"b2b1202\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"1763775\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2016\\\\/11\\\\/shop-image.jpg\\",\\"width_image\\":\\"630\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"504\\",\\"param_image\\":\\"regular\\",\\"background_image-type\\":\\"image\\",\\"padding_bottom\\":\\"0\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_fade_fade\\":\\"fade\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"padding_top\\":\\"0\\",\\"padding_right\\":\\"0\\",\\"padding_bottom\\":\\"0\\",\\"padding_left\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"0\\",\\"margin_right\\":\\"0\\",\\"margin_bottom\\":\\"0\\",\\"margin_left\\":\\"0\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]},{\\"element_id\\":\\"a6d5798\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\"}]}],\\"styling\\":{\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"0\\",\\"padding_right\\":\\"0\\",\\"padding_bottom\\":\\"0\\",\\"padding_left\\":\\"0\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}}}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"0\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"54f79e3\\",\\"row_order\\":\\"11\\",\\"cols\\":[{\\"element_id\\":\\"f336584\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"f158386\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">30 Day Money Back<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Buy it with confidence. If you don\\\\\\\\\\\'t like it, simply request a full refund within 30 days.<\\\\/h3>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"3\\",\\"margin_bottom_unit\\":\\"em\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"59e7954\\",\\"mod_settings\\":{\\"buttons_size\\":\\"xlarge\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"Buy Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/ultra\\"}],\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"custom_css_row\\":\\"animated-bg\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"element_id\\":\\"9dc496b\\",\\"row_order\\":\\"12\\",\\"cols\\":[{\\"element_id\\":\\"a3ad4db\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5617,
  'post_date' => '2016-08-29 14:25:42',
  'post_date_gmt' => '2016-08-29 14:25:42',
  'post_content' => '<!--themify_builder_static--><img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/pen-pencil.png" width="329" height="471" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/paper-clips-246x266.png" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/john-1024x684-400x400.jpg" width="400" height="400" alt="" /> 
 
 <h1>John Smith</h1><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation.</p> 
 <a href="https://www.facebook.com/themify"> </a> <a href="https://twitter.com/themify"> </a> <a href="https://www.youtube.com/user/themifyme"> </a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/mac-keyboard.png" alt="" /> 
 
 <h2>Skills</h2> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/macair-650x550.png" width="650" height="550" alt="" /> 
 <h2>Web Design</h2><p>At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores. Nam libero tempore, nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda sed do eiusmod tempor incididunt ut labore et nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit,  sed quia consequuntur magni dolores.</p> 
 <a href="https://themify.me/" >View Portfolio</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/ipad.png" width="400" height="786" alt="" /> 
 <h2>Mobile App</h2><p>Similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga. Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores.</p> 
 <a href="https://themify.me/" >Download Apps</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/iphone.png" width="350" height="579" alt="" /> 
 <h2>Logo Design</h2><p>Nam libero tempore, nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda sed do eiusmod tempor incididunt ut labore et nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit,  sed quia consequuntur magni dolores.</p> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/08/desk-931928_1280-1024x681-400x400.jpg" width="400" height="400" alt="" /> 
 
 <h2>Profile</h2> 
 <h4>July 2016</h4><p> </p> 
 
 
 
 <h3>Received a Design Award</h3> <p>Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores  qui dolorem ipsum quia dolor sit amet, consectetur.</p> 
 
 
 
 
 <h3>Launched My First App</h3> <p>Quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda.</p> 
 
 <h4>March 2016</h4><p> </p> 
 <h4>March 2015</h4><p> </p> 
 
 
 
 <h3>12 Sites Created</h3> <p>Aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus.</p> 
 
 
 
 
 <h3>Graduated From College</h3> <p>Consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commod.</p> 
 
 <h4>April 2014</h4><p> </p> 
 
 <h2>Contact</h2> 
 email@gmail.com 416-122-2882 123 Street Ave. Toronto, ON 
 <p>Use Builder Contact addon to add a contact form below.</p> 
 <form action="https://themify.me/demo/themes/ultra/wp-admin/admin-ajax.php" id="contact-0--form" method="post"> 
 <label for="contact-0--contact-name">Name *</label> <input type="text" name="contact-name" placeholder="" id="contact-0--contact-name" value="" required /> 
 <label for="contact-0--contact-email">Email *</label> <input type="text" name="contact-email" placeholder="" id="contact-0--contact-email" value="" required /> 
 <label for="contact-0--contact-subject">Subject </label> <input type="text" name="contact-subject" placeholder="" id="contact-0--contact-subject" value="" /> <label for="contact-0--contact-message">Message *</label> <textarea name="contact-message" placeholder="" id="contact-0--contact-message" rows="8" cols="45" required></textarea> <button type="submit"> Send </button> </form><!--/themify_builder_static-->',
  'post_title' => 'Stripe',
  'post_excerpt' => '',
  'post_name' => 'stripe',
  'post_modified' => '2018-09-26 23:50:10',
  'post_modified_gmt' => '2018-09-26 23:50:10',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=5617',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-stripe',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"element_id\\":\\"8546dbb\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"f4e251d\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"cac13ba\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/pen-pencil.png\\",\\"width_image\\":\\"329\\",\\"height_image\\":\\"471\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"0a87227\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/paper-clips-246x266.png\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInLeft\\",\\"custom_parallax_scroll_speed\\":\\"5\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"a4ee0f5\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"2458b31\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/john-1024x684-400x400.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInDown\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"divider\\",\\"element_id\\":\\"f67840f\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"000\\",\\"bottom_margin_divider\\":\\"40\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"center\\",\\"animation_effect\\":\\"bounceInDown\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"495d82f\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>John Smith<\\\\/h1><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInUp\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"icon\\",\\"element_id\\":\\"4832ffe\\",\\"mod_settings\\":{\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"circle\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"fa-facebook\\",\\"icon_color_bg\\":\\"blue\\",\\"link\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\",\\"new_window\\":\\"\\"},{\\"icon\\":\\"fa-twitter\\",\\"icon_color_bg\\":\\"light-blue\\",\\"link\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\",\\"new_window\\":\\"\\"},{\\"icon\\":\\"fa-youtube\\",\\"icon_color_bg\\":\\"red\\",\\"link\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/user\\\\/themifyme\\",\\"new_window\\":\\"\\"}],\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInUp\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"icon_position\\":\\"icon_position_left\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"10\\",\\"padding_left\\":\\"10\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"bfd4737\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"fd4e78e\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/mac-keyboard.png\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"fadeInRight\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"49f84f5\\",\\"row_order\\":\\"1\\",\\"cols\\":[{\\"element_id\\":\\"8cdea76\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"element_id\\":\\"5aa0e27\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"7c319f6\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"745d2f2\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"element_id\\":\\"f761980\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"000\\",\\"bottom_margin_divider\\":\\"40\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"center\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"2de57cd\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Skills<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"font_size\\":\\"2.1\\",\\"font_size_unit\\":\\"em\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"961078c\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}]}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"4eef61c\\",\\"row_order\\":\\"2\\",\\"cols\\":[{\\"element_id\\":\\"891613c\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"37e0757\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/macair-650x550.png\\",\\"width_image\\":\\"650\\",\\"height_image\\":\\"550\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"2\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"padding_bottom\\":\\"40\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]},{\\"element_id\\":\\"290a9d0\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"element_id\\":\\"f383ca1\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"e519d1a\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"99ba0d4\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Web Design<\\\\/h2><p>At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores. Nam libero tempore, nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda sed do eiusmod tempor incididunt ut labore et nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit,  sed quia consequuntur magni dolores.<\\\\/p>\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"3ec258d\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"View Portfolio\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\"}],\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"padding_bottom\\":\\"30\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\"}}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"7658f56\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\"}]}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"a90e034\\",\\"row_order\\":\\"3\\",\\"cols\\":[{\\"element_id\\":\\"a83f0ee\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"element_id\\":\\"d85c773\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"43c48e1\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"28b0478\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/ipad.png\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"786\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"2\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"bd6a53b\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"455dc29\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Mobile App<\\\\/h2><p>Similique sunt in culpa qui officia deserunt mollitia animi, id est laborum et dolorum fuga. Et harum quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda est, omnis dolor repellendus. At vero eos et accusamus et iusto odio dignissimos ducimus qui blanditiis praesentium voluptatum deleniti atque corrupti quos dolores.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"buttons\\",\\"element_id\\":\\"50daf15\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"content_button\\":[{\\"label\\":\\"Download Apps\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\"}],\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"padding_bottom\\":\\"30\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_link_padding_apply_all\\":\\"padding\\",\\"link_checkbox_margin_apply_all\\":\\"margin\\",\\"link_checkbox_border_apply_all\\":\\"border\\"}}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"b4d29db\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"5a2e5fd\\",\\"mod_settings\\":{\\"style_image\\":\\"image-right\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/iphone.png\\",\\"width_image\\":\\"350\\",\\"height_image\\":\\"579\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"6\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"padding_bottom\\":\\"30\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}]}],\\"column_alignment\\":\\"col_align_middle\\"}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"c8c094e\\",\\"row_order\\":\\"4\\",\\"cols\\":[{\\"element_id\\":\\"94ce3e5\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"element_id\\":\\"49e5f20\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"aab06d3\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"element_id\\":\\"ce5808a\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"971a7ce\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Logo Design<\\\\/h2><p>Nam libero tempore, nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda sed do eiusmod tempor incididunt ut labore et nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit,  sed quia consequuntur magni dolores.<\\\\/p>\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"right\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"breakpoint_mobile\\":{\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\"}}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}]},{\\"element_id\\":\\"12d66e9\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"element_id\\":\\"53ea4fd\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/08\\\\/desk-931928_1280-1024x681-400x400.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"400\\",\\"height_image\\":\\"400\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"2\\",\\"custom_parallax_scroll_reverse_reverse\\":\\"reverse\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"6406429\\",\\"row_order\\":\\"5\\",\\"cols\\":[{\\"element_id\\":\\"9c7af6d\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"element_id\\":\\"ebf42b3\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"22dc9da\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\"},{\\"element_id\\":\\"9052e4d\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"element_id\\":\\"8a59263\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"000\\",\\"bottom_margin_divider\\":\\"40\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"left\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"8d3a311\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Profile<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"font_size\\":\\"2.1\\",\\"font_size_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"10\\",\\"padding_left\\":\\"10\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\"}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"1a56f10\\",\\"row_order\\":\\"6\\",\\"cols\\":[{\\"element_id\\":\\"87b1333\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"be48256\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>July 2016<\\\\/h4><p> <\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"right\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"0540cdc\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"element_id\\":\\"2c7fb65\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"f0192ab\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"53f28d2\\",\\"mod_settings\\":{\\"title_feature\\":\\"Received a Design Award\\",\\"content_feature\\":\\"<p>Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores  qui dolorem ipsum quia dolor sit amet, consectetur.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-trophy\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"91d1e6_1.00\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"link_options\\":\\"\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"8d6853b\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\"}]}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"30c31b0\\",\\"row_order\\":\\"7\\",\\"cols\\":[{\\"element_id\\":\\"b520f8f\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"element_id\\":\\"f541477\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"90138d2\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"c581937\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"f4dcfd7\\",\\"mod_settings\\":{\\"title_feature\\":\\"Launched My First App\\",\\"content_feature\\":\\"<p>Quidem rerum facilis est et expedita distinctio. Nam libero tempore, cum soluta nobis est eligendi optio cumque nihil impedit quo minus id quod maxime placeat facere possimus, omnis voluptas assumenda.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-rocket\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"e6b345_1.00\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"link_options\\":\\"\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}]},{\\"element_id\\":\\"33cc95b\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"0d1fe51\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>March 2016<\\\\/h4><p> <\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"a7c2354\\",\\"row_order\\":\\"8\\",\\"cols\\":[{\\"element_id\\":\\"aa6b69a\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"7e313f4\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>March 2015<\\\\/h4><p> <\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"right\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"element_id\\":\\"5bc120f\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"element_id\\":\\"a3f8480\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"f4ce9d3\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"ba23813\\",\\"mod_settings\\":{\\"title_feature\\":\\"12 Sites Created\\",\\"content_feature\\":\\"<p>Aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus.<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-file-code-o\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"cd92e8_1.00\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"link_options\\":\\"\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"fa70b67\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-1\\"}]}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"dashed\\",\\"border_right_style\\":\\"dashed\\",\\"border_bottom_style\\":\\"dashed\\",\\"border_left_style\\":\\"dashed\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"8b2af42\\",\\"row_order\\":\\"9\\",\\"cols\\":[{\\"element_id\\":\\"35388c1\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"element_id\\":\\"ffcc798\\",\\"row_order\\":\\"0\\",\\"cols\\":[{\\"element_id\\":\\"5eb89ac\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"609a79f\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"element_id\\":\\"102cb7d\\",\\"mod_settings\\":{\\"title_feature\\":\\"Graduated From College\\",\\"content_feature\\":\\"<p>Consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commod.<\\\\/p>\\",\\"layout_feature\\":\\"icon-right\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-graduation-cap\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"icon_bg_feature\\":\\"68d1b5_1.00\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_speed\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"circle_percentage_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"link_options\\":\\"\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}}]}]},{\\"element_id\\":\\"c5dd3bc\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"0f1a58a\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>April 2014<\\\\/h4><p> <\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"dashed\\",\\"border_right_style\\":\\"dashed\\",\\"border_bottom_style\\":\\"dashed\\",\\"border_left_style\\":\\"dashed\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"7592a71\\",\\"row_order\\":\\"10\\",\\"cols\\":[{\\"element_id\\":\\"181e3c9\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"element_id\\":\\"180a1c2\\",\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"divider\\",\\"element_id\\":\\"cb1a9e9\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"1\\",\\"color_divider\\":\\"000\\",\\"bottom_margin_divider\\":\\"40\\",\\"divider_type\\":\\"custom\\",\\"divider_width\\":\\"100\\",\\"divider_align\\":\\"left\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"fe42909\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2>Contact<\\\\/h2>\\",\\"background_image-type\\":\\"image\\",\\"font_size\\":\\"2.1\\",\\"font_size_unit\\":\\"em\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"40\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"custom_parallax_scroll_zindex\\":\\"1\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"icon\\",\\"element_id\\":\\"a88d116\\",\\"mod_settings\\":{\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_vertical\\",\\"content_icon\\":[{\\"icon\\":\\"fa-envelope\\",\\"label\\":\\"email@gmail.com\\",\\"new_window\\":\\"\\"},{\\"icon\\":\\"fa-phone\\",\\"label\\":\\"416-122-2882\\",\\"new_window\\":\\"\\"},{\\"icon\\":\\"fa-map-marker\\",\\"label\\":\\"123 Street Ave. Toronto, ON\\",\\"new_window\\":\\"\\"}],\\"background_image-type\\":\\"image\\",\\"text_align\\":\\"left\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_bottom\\":\\"50\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"element_id\\":\\"c1ac907\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>Use Builder Contact addon to add a contact form below.<\\\\/p>\\",\\"background_image-type\\":\\"image\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}},{\\"mod_name\\":\\"contact\\",\\"element_id\\":\\"6aa2a15\\",\\"mod_settings\\":{\\"layout_contact\\":\\"style2\\",\\"field_subject_active\\":\\"yes\\",\\"background_color\\":\\"f5f5f5_1.00\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_right\\":\\"15\\",\\"padding_left\\":\\"15\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"17998b5\\",\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}],\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"element_id\\":\\"5c5c04e\\",\\"row_order\\":\\"11\\",\\"cols\\":[{\\"element_id\\":\\"d355185\\",\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3385,
  'post_date' => '2015-04-16 20:19:17',
  'post_date_gmt' => '2015-04-16 20:19:17',
  'post_content' => '<!--themify_builder_static--><h1>Company</h1> <h3>Design your own company landing page with the Company Page 2 layout</h3> 
 <a href="https://themify.me/themes/" >Buy Now</a> 
 <img src="https://themify.me/demo/themes/landing/files/2015/03/Leaderboard_Free.png" width="500" alt="Horizontal" /> 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 <h3 style="text-align: left;"><em>Market Industry Expertise</em></h3><ul><li style="text-align: left;">Sales Revenue</li><li style="text-align: left;">Cost Associated Per Lead Acquisition</li><li style="text-align: left;">Online Marketing ROI</li><li style="text-align: left;">Site Traffic: Lead Ratio</li></ul> 
 <img src="https://themify.me/demo/themes/landing/files/2015/03/overview_display_hero.jpg" width="700" alt="Horizontal" /> 
 <h2 style="text-align: center;">OS Support</h2> 
 <p>[themify_icon icon="fa-quote-left" icon_color="#4A478F" ] It takes 20 years to build a reputation and five minutes to ruin it. If you think about that, you’ll do things differently.</p><p style="text-align: left;">– <em>Warren Buffett<br /></em>CEO of Berkshire Hathaway</p> 
 <h4>A Vision and Strategy for the Future</h4><p>Diversity and inclusion are integral to Microsoft’s vision, strategy and business success. We recognize that leadership in today’s global marketplace requires that we create a corporate culture and an inclusive business environment where the best and brightest diverse minds—employees with varied perspectives, skills, and experiences--work together to meet global consumer demands.  The collaboration of cultures, ideas, and different perspectives is an organizational asset and brings forth greater creativity and innovation.</p><p>Learn about our commitment to global diversity and inclusion, including our <a href="http://www.microsoft.com/about/en/xm/importedcontent/about/diversity/en/us/vision.aspx#Our Global Diversity &amp; Inclusion Vision Statement">vision</a>, <a href="http://www.microsoft.com/about/en/xm/importedcontent/about/diversity/en/us/vision.aspx#Key Growth Strategies">strategy</a>, and plans for the future.  <a href="http://www.microsoft.com/about/en/xm/importedcontent/about/diversity/en/us/vision.aspx">Read More...</a></p><p><a href="https://themify.me/demo/themes/landing/files/2015/03/microsoftlogov3.png"><img src="https://themify.me/demo/themes/landing/files/2015/03/microsoftlogov3.png" alt="microsoftlogov3" width="94" height="20" /></a></p> 
 <img src="https://themify.me/demo/themes/ultra/files/2015/06/model-2-1024x683-600x400.jpg" width="600" height="400" alt="model-2" srcset="https://themify.me/demo/themes/ultra/files/2015/06/model-2-1024x683-600x400.jpg 600w, https://themify.me/demo/themes/ultra/files/2015/06/model-2-300x200.jpg 300w, https://themify.me/demo/themes/ultra/files/2015/06/model-2-1024x683.jpg 1024w, https://themify.me/demo/themes/ultra/files/2015/06/model-2.jpg 1200w" sizes="(max-width: 600px) 100vw, 600px" /> 
 <img src="https://themify.me/demo/themes/ultra/files/2015/06/model-1-1024x614-1200x400.jpg" width="1200" height="400" alt="model-1" /> 
 <h4>Join Our Team</h4><ul><li><a href="#">Frontend Developer</a></li><li><a href="#">Designer</a></li><li><a href="#">Customer Support</a></li><li><a href="#">Social Media Strategist</a></li></ul> 
 <h4>Corporate Culture</h4><p><em><strong>Why work with US?</strong></em></p><p>Donec vehicula mi augue, eu vehicula lacus dapibus nec. Donec elementum tristique faucibus. Proin vitae turpis vel sem mattis egestas. Quisque vehicula, risus scelerisque porta malesuada, enim urna sodales lacus, laoreet venenatis nibh odio in metus. Donec pellentesque nisl sit amet dolor interdum, ac hendrerit elit ultricies. Vestibulum eget erat a dui porttitor blandit sed id leo. Duis commodo tincidunt dolor eu vulputate.</p><p><strong>Our Benefits:</strong></p><ul><li>Work from home flexibility</li><li>Competitive Salary </li><li>Health Care Benefits</li><li>Hardware of Choice at Work</li><li>Opportunities for Growth</li><li>Kitchen Snacks (Fruits, Chips, &amp; Pop)</li></ul><!--/themify_builder_static-->',
  'post_title' => 'Horizontal',
  'post_excerpt' => '',
  'post_name' => 'horizontal',
  'post_modified' => '2018-09-06 03:17:05',
  'post_modified_gmt' => '2018-09-06 03:17:05',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3385',
  'menu_order' => 1,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-horizontal',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'no',
    'footer_design' => 'footer-left-col',
    'exclude_footer_widgets' => 'no',
    'exclude_footer_back' => 'no',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_color\\":\\"ffffff\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Company<\\\\/h1>\\\\n<h3>Design your own company landing page with the Company Page 2 layout<\\\\/h3>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"font_weight\\":\\"bold\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"button_background_color\\":\\"#7933ac\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"Buy Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"purple\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/Leaderboard_Free.png\\",\\"width_image\\":\\"500\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\"}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_stroke_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#f59393_0.45\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-android\\",\\"icon_color_feature\\":\\"4A478F\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_stroke_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#f59393_0.46\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-linkedin-square\\",\\"icon_color_feature\\":\\"4A478F\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_stroke_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#f59393_0.46\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-pinterest\\",\\"icon_color_feature\\":\\"4A478F\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_stroke_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#f59393_0.46\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-slideshare\\",\\"icon_color_feature\\":\\"4A478F\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_stroke_feature\\":\\"0\\",\\"circle_color_feature\\":\\"#e68a8a_0.45\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-reddit\\",\\"icon_color_feature\\":\\"4A478F\\",\\"link_options\\":\\"regular\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"6D69C5\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"link_color\\":\\"ffffff\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\"><em>Market Industry Expertise<\\\\/em><\\\\/h3><ul><li style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Sales Revenue<\\\\/li><li style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Cost Associated Per Lead Acquisition<\\\\/li><li style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Online Marketing ROI<\\\\/li><li style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Site Traffic: Lead Ratio<\\\\/li><\\\\/ul>\\",\\"padding_top_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-3\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/overview_display_hero.jpg\\",\\"width_image\\":\\"700\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">OS Support<\\\\/h2>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/os_x_yosemite_2-wallpaper-1366x768.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"22\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"22\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<p>[themify_icon icon=\\\\\\\\\\\\\\"fa-quote-left\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#4A478F\\\\\\\\\\\\\\" ] It takes 20 years to build a reputation and five minutes to ruin it. If you think about that, you’ll do things differently.<\\\\/p><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">– <em>Warren Buffett<br \\\\/><\\\\/em>CEO of Berkshire Hathaway<\\\\/p>\\",\\"font_color\\":\\"ffffff\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>A Vision and Strategy for the Future<\\\\/h4><p class=\\\\\\\\\\\\\\"alParagraph\\\\\\\\\\\\\\">Diversity and inclusion are integral to Microsoft’s vision, strategy and business success. We recognize that leadership in today’s global marketplace requires that we create a corporate culture and an inclusive business environment where the best and brightest diverse minds—employees with varied perspectives, skills, and experiences--work together to meet global consumer demands.  The collaboration of cultures, ideas, and different perspectives is an organizational asset and brings forth greater creativity and innovation.<\\\\/p><p class=\\\\\\\\\\\\\\"alParagraph\\\\\\\\\\\\\\">Learn about our commitment to global diversity and inclusion, including our <a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/www.microsoft.com\\\\/about\\\\/en\\\\/xm\\\\/importedcontent\\\\/about\\\\/diversity\\\\/en\\\\/us\\\\/vision.aspx#Our Global Diversity &amp; Inclusion Vision Statement\\\\\\\\\\\\\\">vision<\\\\/a>, <a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/www.microsoft.com\\\\/about\\\\/en\\\\/xm\\\\/importedcontent\\\\/about\\\\/diversity\\\\/en\\\\/us\\\\/vision.aspx#Key Growth Strategies\\\\\\\\\\\\\\">strategy<\\\\/a>, and plans for the future.  <a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/www.microsoft.com\\\\/about\\\\/en\\\\/xm\\\\/importedcontent\\\\/about\\\\/diversity\\\\/en\\\\/us\\\\/vision.aspx\\\\\\\\\\\\\\">Read More...<\\\\/a><\\\\/p><p class=\\\\\\\\\\\\\\"alParagraph\\\\\\\\\\\\\\"><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/microsoftlogov3.png\\\\\\\\\\\\\\"><img class=\\\\\\\\\\\\\\"alignnone size-full wp-image-3142\\\\\\\\\\\\\\" src=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/microsoftlogov3.png\\\\\\\\\\\\\\" alt=\\\\\\\\\\\\\\"microsoftlogov3\\\\\\\\\\\\\\" width=\\\\\\\\\\\\\\"94\\\\\\\\\\\\\\" height=\\\\\\\\\\\\\\"20\\\\\\\\\\\\\\" \\\\/><\\\\/a><\\\\/p>\\",\\"background_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"6d69c5_1.00\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/06\\\\/model-2.jpg\\",\\"width_image\\":\\"600\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"400\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/ultra\\\\/files\\\\/2015\\\\/06\\\\/model-1.jpg\\",\\"width_image\\":\\"1200\\",\\"auto_fullwidth\\":\\"1\\",\\"height_image\\":\\"400\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Join Our Team<\\\\/h4><ul><li><a href=\\\\\\\\\\\\\\"#\\\\\\\\\\\\\\">Frontend Developer<\\\\/a><\\\\/li><li><a href=\\\\\\\\\\\\\\"#\\\\\\\\\\\\\\">Designer<\\\\/a><\\\\/li><li><a href=\\\\\\\\\\\\\\"#\\\\\\\\\\\\\\">Customer Support<\\\\/a><\\\\/li><li><a href=\\\\\\\\\\\\\\"#\\\\\\\\\\\\\\">Social Media Strategist<\\\\/a><\\\\/li><\\\\/ul>\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Corporate Culture<\\\\/h4><p><em><strong>Why work with US?<\\\\/strong><\\\\/em><\\\\/p><p>Donec vehicula mi augue, eu vehicula lacus dapibus nec. Donec elementum tristique faucibus. Proin vitae turpis vel sem mattis egestas. Quisque vehicula, risus scelerisque porta malesuada, enim urna sodales lacus, laoreet venenatis nibh odio in metus. Donec pellentesque nisl sit amet dolor interdum, ac hendrerit elit ultricies. Vestibulum eget erat a dui porttitor blandit sed id leo. Duis commodo tincidunt dolor eu vulputate.<\\\\/p><p class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\"><strong>Our Benefits:<\\\\/strong><\\\\/p><ul><li class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\">Work from home flexibility<\\\\/li><li class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\">Competitive Salary <\\\\/li><li class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\">Health Care Benefits<\\\\/li><li class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\">Hardware of Choice at Work<\\\\/li><li class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\">Opportunities for Growth<\\\\/li><li class=\\\\\\\\\\\\\\"&quot;alParagraph&quot;\\\\\\\\\\\\\\">Kitchen Snacks (Fruits, Chips, &amp; Pop)<\\\\/li><\\\\/ul>\\",\\"background_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"5\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"5\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"5\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"5\\",\\"padding_left_unit\\":\\"%\\"}}]}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_color\\":\\"f4f4f4_1.00\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3389,
  'post_date' => '2015-04-16 20:29:53',
  'post_date_gmt' => '2015-04-16 20:29:53',
  'post_content' => '',
  'post_title' => 'Block',
  'post_excerpt' => '',
  'post_name' => 'block',
  'post_modified' => '2017-08-21 01:16:21',
  'post_modified_gmt' => '2017-08-21 01:16:21',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3389',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-yellow',
    'header_design' => 'header-block',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'yes',
    'footer_design' => 'footer-horizontal-left',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'portfolio_more_posts' => 'pagination',
    'portfolio_posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Capture Moments</h1><h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Eye-Spy App</h2>\\",\\"font_family\\":\\"default\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"fullheight\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/162596999.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"000000_0.76\\",\\"cover_color_hover\\":\\"000000_0.72\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffe733_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"ffbb00_1.00\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Download</h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Available in App Store</h3>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https://themify.me/demo/themes/landing/files/2015/03/download.png\\",\\"appearance_image\\":\\"rounded\\",\\"width_image\\":\\"200\\",\\"link_image\\":\\"http://store.apple.com/us\\",\\"param_image\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"ffe312_1.00\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Highlights</h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">I\\\\\\\\\\\'d imperdiet leo aliquet ut. Aenean rutrum lorem ac augue lobortis venenatis. Donec pulvinar bibendum magna id cursus. </h3>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/03/iphone6p-gold-select-2014.png\\",\\"img_title_slider\\":\\"Rose Gold\\",\\"img_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce eu mattis augue. Suspendisse lobortis elementum nunc in volutpat. Morbi vestibulum ut erat vitae luctus. Integer finibus enim sit amet accumsan posuere. In at imperdiet quam, quis placerat ipsum. Nulla facilisi. Nulla ornare a erat eu faucibus. Vivamus vel purus libero. Ut facilisis ultrices nibh, in fringilla sem venenatis nec. Praesent a sagittis justo. Duis dignissim lorem in eros aliquam cursus. Donec et enim tincidunt neque laoreet consectetur. Aenean in venenatis orci. Donec malesuada erat eget ante dignissim blandit. Praesent a efficitur lacus, id placerat eros. Suspendisse a accumsan risus, eget mattis ante.</p>\\\\n\\\\n[themify_button style=\\\\\\\\\\\\\\"large blue rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ] Got to Demo [/themify_button]\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/03/iphone6p-silver-select-2014.png\\",\\"img_title_slider\\":\\"Silver \\",\\"img_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce eu mattis augue. Suspendisse lobortis elementum nunc in volutpat. Morbi vestibulum ut erat vitae luctus. Integer finibus enim sit amet accumsan posuere. In at imperdiet quam, quis placerat ipsum. Nulla facilisi. Nulla ornare a erat eu faucibus. Vivamus vel purus libero. Ut facilisis ultrices nibh, in fringilla sem venenatis nec. Praesent a sagittis justo. Duis dignissim lorem in eros aliquam cursus. Donec et enim tincidunt neque laoreet consectetur. Aenean in venenatis orci. Donec malesuada erat eget ante dignissim blandit. Praesent a efficitur lacus, id placerat eros. Suspendisse a accumsan risus, eget mattis ante.</p>\\\\n\\\\n[themify_button style=\\\\\\\\\\\\\\"large blue rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ] Got to Demo [/themify_button]\\"},{\\"img_url_slider\\":\\"https://themify.me/demo/themes/landing/files/2015/03/iphone6p-gray-select-2014.png\\",\\"img_title_slider\\":\\"Space Gray \\",\\"img_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Fusce eu mattis augue. Suspendisse lobortis elementum nunc in volutpat. Morbi vestibulum ut erat vitae luctus. Integer finibus enim sit amet accumsan posuere. In at imperdiet quam, quis placerat ipsum. Nulla facilisi. Nulla ornare a erat eu faucibus. Vivamus vel purus libero. Ut facilisis ultrices nibh, in fringilla sem venenatis nec. Praesent a sagittis justo. Duis dignissim lorem in eros aliquam cursus. Donec et enim tincidunt neque laoreet consectetur. Aenean in venenatis orci. Donec malesuada erat eget ante dignissim blandit. Praesent a efficitur lacus, id placerat eros. Suspendisse a accumsan risus, eget mattis ante.</p>\\\\n\\\\n[themify_button style=\\\\\\\\\\\\\\"large blue rect flat\\\\\\\\\\\\\\" text=\\\\\\\\\\\\\\"#ffffff\\\\\\\\\\\\\\" target=\\\\\\\\\\\\\\"https://themify.me/demo/themes/landing/\\\\\\\\\\\\\\" ] Got to Demo [/themify_button]\\"}],\\"layout_slider\\":\\"slider-agency\\",\\"img_w_slider\\":\\"400\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Amazing Time Lapse</h4>\\",\\"font_family\\":\\"default\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"fullheight\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\",\\"background_type\\":\\"video\\",\\"background_slider\\":\\"\\",\\"background_slider_size\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"https://themify.me/demo/demo-videos/Timelapse_Flower.mp4\\",\\"background_image\\":\\"https://themify.me/demo/demo-videos/flower-1024x572.jpg\\",\\"background_repeat\\":\\"\\",\\"background_position\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"animation_effect\\":\\"\\",\\"animation_effect_delay\\":\\"\\",\\"animation_effect_repeat\\":\\"\\",\\"visibility_desktop\\":\\"show\\",\\"visibility_tablet\\":\\"show\\",\\"visibility_mobile\\":\\"show\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Gallery</h2>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"mod_name\\":\\"gallery\\",\\"mod_settings\\":{\\"layout_gallery\\":\\"showcase\\",\\"shortcode_gallery\\":\\"[gallery ids=\\\\\\\\\\\\\\"3305,3301,3299,3296\\\\\\\\\\\\\\"]\\",\\"thumb_w_gallery\\":\\"80\\",\\"thumb_h_gallery\\":\\"60\\",\\"appearance_gallery\\":\\"|\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">FAQ</h2><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Click button below to expand to see our FAQ Page. Button below was built using our <a href=\\\\\\\\\\\\\\"https://themify.me/addons/button\\\\\\\\\\\\\\">Button Addon</a>.</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>What is your refund policy?</h4><p>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu.</p><h4 id=\\\\\\\\\\\\\\"2\\\\\\\\\\\\\\">Can the app do this?</h4><p>Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.</p>\\",\\"font_family\\":\\"default\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 id=\\\\\\\\\\\\\\"2\\\\\\\\\\\\\\">Do you guys provide this?</h4><p>Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.</p><h4>Does it work with?</h4><p>Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu.</p>\\",\\"font_family\\":\\"default\\",\\"font_size_unit\\":\\"em\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1 first\\",\\"modules\\":[],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Subscribe to Themify</h4><p>[mc4wp_form]</p>\\",\\"font_family\\":\\"default\\",\\"text_align_left\\":\\"left\\",\\"text_align_center\\":\\"center\\",\\"text_align_right\\":\\"right\\",\\"text_align_justify\\":\\"justify\\",\\"padding_top_unit\\":\\"px\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom_unit\\":\\"px\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left_unit\\":\\"px\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1 last\\",\\"modules\\":[],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]}],\\"styling\\":[]}],\\"styling\\":{\\"row_width\\":\\"\\",\\"row_height\\":\\"\\",\\"animation_effect\\":\\"\\",\\"background_type\\":\\"image\\",\\"background_slider\\":\\"\\",\\"background_slider_mode\\":\\"\\",\\"background_video\\":\\"\\",\\"background_image\\":\\"\\",\\"background_repeat\\":\\"\\",\\"background_color\\":\\"\\",\\"cover_color\\":\\"\\",\\"cover_color_hover\\":\\"\\",\\"font_family\\":\\"default\\",\\"font_color\\":\\"\\",\\"font_size\\":\\"\\",\\"font_size_unit\\":\\"\\",\\"line_height\\":\\"\\",\\"line_height_unit\\":\\"\\",\\"text_align\\":\\"center\\",\\"link_color\\":\\"\\",\\"text_decoration\\":\\"\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"\\",\\"padding_right_unit\\":\\"px\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"\\",\\"padding_left_unit\\":\\"px\\",\\"margin_top\\":\\"\\",\\"margin_top_unit\\":\\"px\\",\\"margin_right\\":\\"\\",\\"margin_right_unit\\":\\"px\\",\\"margin_bottom\\":\\"\\",\\"margin_bottom_unit\\":\\"px\\",\\"margin_left\\":\\"\\",\\"margin_left_unit\\":\\"px\\",\\"border_top_color\\":\\"\\",\\"border_top_width\\":\\"\\",\\"border_top_style\\":\\"\\",\\"border_right_color\\":\\"\\",\\"border_right_width\\":\\"\\",\\"border_right_style\\":\\"\\",\\"border_bottom_color\\":\\"\\",\\"border_bottom_width\\":\\"\\",\\"border_bottom_style\\":\\"\\",\\"border_left_color\\":\\"\\",\\"border_left_width\\":\\"\\",\\"border_left_style\\":\\"\\",\\"custom_css_row\\":\\"\\",\\"row_anchor\\":\\"\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3391,
  'post_date' => '2015-04-16 20:30:26',
  'post_date_gmt' => '2015-04-16 20:30:26',
  'post_content' => '<!--themify_builder_static--><h1 style="text-align: center;">Android UI App Kit</h1><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco</h3>
 
 <a href="https://themify.me/" > GET STARTED FOR FREE </a> 
 <h2 style="text-align: center;">Androind UI Kit For Your App Project</h2><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</h3>
 
 
 
 
 <h3> FREE TO USE </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p> 
 
 
 
 
 
 <h3> LAYERED FILE </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p> 
 
 
 
 
 
 <h3> SAVE TIME </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p> 
 
 <h2 style="text-align: center;">Inside The Package</h2><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</h3>
 <h3 style="text-align: left;"><strong>Create Event UI Kit</strong></h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p>
 
 
 
 
 <h3> Event Location Pointer </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore</p> 
 
 
 
 
 
 <h3> Multi Color Design </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore</p> 
 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/event-1-400x551.png" width="400" alt="" /> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/calendar-ui-kit-1-400x515.png" width="400" alt="" /> 
 <h3 style="text-align: left;"><strong>Calendar UI Kit</strong></h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p>
 
 
 
 
 <h3> Calendar Template </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore</p> 
 
 
 
 
 
 <h3> Editable Layer </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore</p> 
 
 <h3 style="text-align: left;"><strong>Messaging UI Kit</strong></h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p>
 
 
 
 
 <h3> High Detailed Design </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore</p> 
 
 
 
 
 
 <h3> Smart Interface Tools </h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore</p> 
 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/Messanging-UI-kit-2-400x539.png" width="400" alt="" /> 
 <h2 style="text-align: center;">Get The UI Kit</h2><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip</h3>
 
 <a href="https://themify.me/" > GET STARTED FOR FREE </a><!--/themify_builder_static-->',
  'post_title' => 'Boxed Content',
  'post_excerpt' => '',
  'post_name' => 'boxed-content',
  'post_modified' => '2017-12-12 21:38:48',
  'post_modified_gmt' => '2017-12-12 21:38:48',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3391',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'hide_page_title' => 'yes',
    'body_background_image' => 'https://themify.me/demo/themes/ultra/files/2015/06/193816727.jpg',
    'body_background_repeat' => 'fullcover',
    'header_design' => 'boxed-content',
    'exclude_header_widgets' => 'yes',
    'footer_design' => 'footer-left-col',
    'exclude_footer_widgets' => 'no',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Android UI App Kit<\\\\/h1><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"cid\\":\\"c19\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"circle\\",\\"content_button\\":[{\\"label\\":\\"GET STARTED FOR FREE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"red\\",\\"new_window\\":\\"0\\"}],\\"text_align\\":\\"center\\",\\"margin_bottom\\":\\"2\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c23\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/bg-1024x455-1024x455.png\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"005072\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.85\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Androind UI Kit For Your App Project<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/h3>\\",\\"cid\\":\\"c34\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"f2f2f2\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"FREE TO USE\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ababab\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-download\\",\\"icon_color_feature\\":\\"fe5967\\",\\"font_color\\":\\"000000_1.00\\",\\"cid\\":\\"c45\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"LAYERED FILE\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ababab\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-bars\\",\\"icon_color_feature\\":\\"fe5967\\",\\"font_color\\":\\"000000_1.00\\",\\"cid\\":\\"c53\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"SAVE TIME\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"2\\",\\"circle_color_feature\\":\\"ababab\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-hourglass-start\\",\\"icon_color_feature\\":\\"fe5967\\",\\"font_color\\":\\"030303_1.00\\",\\"cid\\":\\"c61\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"f2f2f2\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Inside The Package<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/h3>\\",\\"cid\\":\\"c72\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\"><strong>Create Event UI Kit<\\\\/strong><\\\\/h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"font_color\\":\\"000000_1.00\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c83\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Event Location Pointer\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"e69393\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-street-view\\",\\"icon_color_feature\\":\\"e69393\\",\\"font_color\\":\\"000000_1.00\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"cid\\":\\"c87\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Multi Color Design\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"e69393_1.00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-paint-brush\\",\\"icon_color_feature\\":\\"e69393\\",\\"font_color\\":\\"000000_1.00\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"cid\\":\\"c91\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/event-1-400x551.png\\",\\"width_image\\":\\"400\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c99\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/calendar-ui-kit-1-400x515.png\\",\\"width_image\\":\\"400\\",\\"cid\\":\\"c110\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\"><strong>Calendar UI Kit<\\\\/strong><\\\\/h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"font_color\\":\\"000000_1.00\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c118\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Calendar Template \\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"e69393_1.00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-calendar\\",\\"icon_color_feature\\":\\"e69393\\",\\"font_color\\":\\"000000_1.00\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"cid\\":\\"c122\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Editable Layer\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"e69393_1.00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-bars\\",\\"icon_color_feature\\":\\"e69393\\",\\"font_color\\":\\"030303_1.00\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"cid\\":\\"c126\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\"><strong>Messaging UI Kit<\\\\/strong><\\\\/h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"font_color\\":\\"000000_1.00\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\",\\"cid\\":\\"c137\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"High Detailed Design\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"e69393_1.00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-search\\",\\"icon_color_feature\\":\\"e69393\\",\\"font_color\\":\\"000000_1.00\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"cid\\":\\"c141\\"}},{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Smart Interface Tools\\",\\"content_feature\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore<\\\\/p>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"1\\",\\"circle_color_feature\\":\\"e69393_1.00\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-crop\\",\\"icon_color_feature\\":\\"e69393\\",\\"font_color\\":\\"000000_1.00\\",\\"margin_top\\":\\"5\\",\\"margin_top_unit\\":\\"%\\",\\"cid\\":\\"c145\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/Messanging-UI-kit-2-400x539.png\\",\\"width_image\\":\\"400\\",\\"cid\\":\\"c153\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Get The UI Kit<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c164\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"circle\\",\\"content_button\\":[{\\"label\\":\\"GET STARTED FOR FREE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"red\\",\\"new_window\\":\\"0\\"}],\\"text_align\\":\\"center\\",\\"margin_bottom\\":\\"10\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c168\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"053e87_0.65\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_mobile\\":{\\"text_align\\":\\"center\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"3\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"3\\",\\"padding_left_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3393,
  'post_date' => '2015-04-16 20:31:49',
  'post_date_gmt' => '2015-04-16 20:31:49',
  'post_content' => '<!--themify_builder_static--><h1>Marketer</h1>  Get 10,000 likes on Facebook<br /> Interact with real Twitter followers<br />  Create special rate and discount for select customers<br />  Unlimited support through chat</p>
 
 <a href="https://themify.me/themes/ultra" > Buy Now </a> <a href="https://themify.me/themes" > More Themes </a> 
 
 <img src="https://themify.me/demo/themes/landing/files/2015/02/165980035.jpg" width="400" alt="" /> 
 <h2 style="text-align: center;">Voted as the #1 Theme of All Time</h2><h3 style="text-align: center;"><em>With over 40,000 users, We are very proud to say that we&#8217;ve got an ever improving product with an in-depth documentation page.</em></h3>
 
 
 <iframe src="https://player.vimeo.com/video/118589137" width="1165" height="655" title="BRNS - Many Chances" webkitallowfullscreen mozallowfullscreen allowfullscreen></iframe> 
 
 <h3 style="text-align: left;">With amazing features, built-in Addons, and multiple layouts. This is our best theme yet!</h3><p style="text-align: left;">Pellentesque id hendrerit lacus, quis viverra justo. Integer nec leo pretium, mattis nulla vel, facilisis eros. Donec quis pharetra elit. Interdum et malesuada fames ac ante ipsum primis in faucibus. Vestibulum vel aliquet augue, eget accumsan justo.</p>
 <h2 style="text-align: center;">Feature Module in Action</h2>
 
 
 
 
 <h3> Pre-Built Layouts </h3> <p>Multiple pre-built layouts that allows you use it on any page on your site.</p> 
 
 
 
 
 
 <h3> Built-in Addons </h3> <p>Packed with built-in addons: Timeline, Progress bar Chart, and Contact form plugin</p> 
 
 
 
 
 
 <h3> Header Styles </h3> <p>The theme is also built with various header styles. You have the option to make it transparent, hide, or place it on the left. </p> 
 
 <h2 style="text-align: center;">What people are saying&#8230;</h2>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/141627649.jpg" width="100" height="100" title="Mark Peterson" alt="Love this theme! It&#039;s so easy to use.." /> <h3> Mark Peterson </h3> Love this theme! It&#8217;s so easy to use.. 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/82152160.jpg" width="100" height="100" title="Stephanie Chapman" alt="This is one of the most versatile theme i&#039;ve ever used. So many layouts to choose from. I&#039;m constantly updating my site to keep my content and design fresh." /> <h3> Stephanie Chapman </h3> This is one of the most versatile theme i&#8217;ve ever used. So many layouts to choose from. I&#8217;m constantly updating my site to keep my content and design fresh. 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/112268515.jpg" width="100" height="100" title="Sara Lee" alt="Why code when Themify does all the work for you? I saved so much time allowing to take on more clients, and make more money. This is amazing, I love it!" /> <h3> Sara Lee </h3> Why code when Themify does all the work for you? I saved so much time allowing to take on more clients, and make more money. This is amazing, I love it! 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/180680633.jpg" width="100" height="100" title="James Jamieson" alt="This is a must have theme. As a developer, this theme has helped me finish so many projects!" /> <h3> James Jamieson </h3> This is a must have theme. As a developer, this theme has helped me finish so many projects! 
 <h2 style="text-align: center;">As Featured on&#8230;</h2>
 <ul data-id="slider-0-" data-visible="3" data-scroll="1" data-auto-scroll="3" data-speed="1" data-wrap="yes" data-arrow="no" data-pagination="no" data-effect="continuously" data-height="variable" data-pause-on-hover="resume" > 
 <li> <a href="https://twitter.com/themify" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/twitter1.png" alt="" /> </a> </li> <li> <a href="https://www.youtube.com/user/themifyme" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/2YouTube.png" alt="" /> </a> </li> <li> <a href="http://instagram.com/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/1Instagram.png" alt="" /> </a> </li> <li> <a href="https://www.facebook.com/themify" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/1facebook.png" alt="" /> </a> </li> </ul><!--/themify_builder_static-->',
  'post_title' => 'Boxed Layout',
  'post_excerpt' => '',
  'post_name' => 'boxed-layout',
  'post_modified' => '2017-10-28 15:46:04',
  'post_modified_gmt' => '2017-10-28 15:46:04',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3393',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'body_background_image' => 'https://themify.me/demo/themes/ultra/files/2015/05/photo-1421091242698-34f6ad7fc088.jpg',
    'body_background_repeat' => 'fullcover',
    'color_design' => 'theme-color-turquoise',
    'header_design' => 'boxed-layout',
    'exclude_search_form' => 'yes',
    'exclude_rss' => 'yes',
    'exclude_header_widgets' => 'yes',
    'exclude_social_widget' => 'yes',
    'footer_design' => 'footer-block',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"padding_top\\":\\"40\\",\\"padding_bottom\\":\\"40\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1>Marketer<\\\\/h1>\\\\n<p>[themify_icon icon=\\\\\\\\\\\\\\"fa-facebook\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"large\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#7BB31A\\\\\\\\\\\\\\" ] Get 10,000 likes on Facebook<br \\\\/> [themify_icon icon=\\\\\\\\\\\\\\"fa-twitter\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"large\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#7BB31A\\\\\\\\\\\\\\" ] Interact with real Twitter followers<br \\\\/> [themify_icon icon=\\\\\\\\\\\\\\"fa-dollar\\\\\\\\\\\\\\" stle=\\\\\\\\\\\\\\"large\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#7BB31A\\\\\\\\\\\\\\" ] Create special rate and discount for select customers<br \\\\/> [themify_icon icon=\\\\\\\\\\\\\\"fa-comments\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"large\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#7BB31A\\\\\\\\\\\\\\" ] Unlimited support through chat<\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"font_weight\\":\\"bold\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"button_hover_background_color\\":\\"#8cc051\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"Buy Now\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/ultra\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"light-green\\"},{\\"label\\":\\"More Themes\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"black\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/02\\\\/165980035.jpg\\",\\"width_image\\":\\"400\\",\\"background_color\\":\\"ffffff_1.00\\",\\"border_top_color\\":\\"363636\\",\\"border_top_width\\":\\"1\\",\\"border_right_color\\":\\"363636\\",\\"border_right_width\\":\\"1\\",\\"border_bottom_color\\":\\"363636\\",\\"border_bottom_width\\":\\"1\\",\\"border_left_color\\":\\"363636\\",\\"border_left_width\\":\\"1\\",\\"cid\\":\\"c32\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"ebebeb_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Voted as the <span style=\\\\\\\\\\\\\\"color: #7bb31a;\\\\\\\\\\\\\\">#1<\\\\/span> Theme of All Time<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><em>With over <span style=\\\\\\\\\\\\\\"color: #7bb31a;\\\\\\\\\\\\\\">40,000 users<\\\\/span>, We are very proud to say that we\\\\\\\\\\\'ve got an <span style=\\\\\\\\\\\\\\"color: #7bb31a;\\\\\\\\\\\\\\">ever improving product with an in-depth documentation page<\\\\/span>.<\\\\/em><\\\\/h3>\\",\\"margin_bottom\\":\\"50\\",\\"cid\\":\\"c43\\"}},{\\"mod_name\\":\\"divider\\",\\"mod_settings\\":{\\"stroke_w_divider\\":\\"5\\",\\"color_divider\\":\\"7bb31a\\",\\"top_margin_divider\\":\\"30\\",\\"bottom_margin_divider\\":\\"50\\",\\"cid\\":\\"c47\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"video\\",\\"mod_settings\\":{\\"style_video\\":\\"video-overlay\\",\\"url_video\\":\\"http:\\\\/\\\\/vimeo.com\\\\/channels\\\\/staffpicks\\\\/118589137\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">With amazing features, built-in Addons, and multiple layouts. This is our best theme yet!<\\\\/h3><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Pellentesque id hendrerit lacus, quis viverra justo. Integer nec leo pretium, mattis nulla vel, facilisis eros. Donec quis pharetra elit. Interdum et malesuada fames ac ante ipsum primis in faucibus. Vestibulum vel aliquet augue, eget accumsan justo.<\\\\/p>\\",\\"cid\\":\\"c67\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Feature Module in Action<\\\\/h2>\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"cid\\":\\"c78\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Pre-Built Layouts\\",\\"content_feature\\":\\"<p>Multiple pre-built layouts that allows you use it on any page on your site.<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"80\\",\\"circle_stroke_feature\\":\\"10\\",\\"circle_color_feature\\":\\"FF9C00\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-newspaper-o\\",\\"icon_color_feature\\":\\"FF9C00\\",\\"cid\\":\\"c90\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Built-in Addons\\",\\"content_feature\\":\\"<p>Packed with built-in addons: Timeline, Progress bar Chart, and Contact form plugin<\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"10\\",\\"circle_color_feature\\":\\"8B88FF\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-plus\\",\\"icon_color_feature\\":\\"8B88FF\\",\\"cid\\":\\"c98\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"title_feature\\":\\"Header Styles\\",\\"content_feature\\":\\"<p>The theme is also built with various header styles. You have the option to make it transparent, hide, or place it on the left. <\\\\/p>\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"90\\",\\"circle_stroke_feature\\":\\"10\\",\\"circle_color_feature\\":\\"7BB31A\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-building\\",\\"icon_color_feature\\":\\"7BB31A\\",\\"cid\\":\\"c106\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"ebebeb_1.00\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">What people are saying...<\\\\/h2>\\",\\"cid\\":\\"c117\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/141627649.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"Mark Peterson\\",\\"caption_image\\":\\"Love this theme! It\\\\\\\\\\\'s so easy to use..\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c129\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/82152160.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"Stephanie Chapman\\",\\"caption_image\\":\\"This is one of the most versatile theme i\\\\\\\\\\\'ve ever used. So many layouts to choose from. I\\\\\\\\\\\'m constantly updating my site to keep my content and design fresh.\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c133\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/112268515.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"Sara Lee\\",\\"caption_image\\":\\"Why code when Themify does all the work for you? I saved so much time allowing to take on more clients, and make more money. This is amazing, I love it!\\",\\"padding_top\\":\\"2\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"2\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c141\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-left\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/180680633.jpg\\",\\"appearance_image\\":\\"circle\\",\\"width_image\\":\\"100\\",\\"height_image\\":\\"100\\",\\"title_image\\":\\"James Jamieson\\",\\"caption_image\\":\\"This is a must have theme. As a developer, this theme has helped me finish so many projects!\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c145\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">As Featured on...<\\\\/h2>\\",\\"cid\\":\\"c156\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/twitter1.png\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/2YouTube.png\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/user\\\\/themifyme\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/1Instagram.png\\",\\"img_link_slider\\":\\"http:\\\\/\\\\/instagram.com\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/1facebook.png\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\"}],\\"layout_slider\\":\\"slider-default\\",\\"visible_opt_slider\\":\\"3\\",\\"auto_scroll_opt_slider\\":\\"3\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"continuously\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"no\\",\\"show_arrow_slider\\":\\"no\\",\\"height_slider\\":\\"variable\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"f0f0f0_1.00\\",\\"padding_top\\":\\"3\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4919,
  'post_date' => '2016-03-14 21:17:33',
  'post_date_gmt' => '2016-03-14 21:17:33',
  'post_content' => '<!--themify_builder_static--><h1>Course Manager</h1><h3>Create and manage online courses</h3>
 
 <a href="https://themify.me/" > SIGN UP FOR FREE </a> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/dashboard-2-800x436.png" width="800" alt="" /> 
 <h2 style="text-align: left;">What is Course Manager?</h2><p style="text-align: left;">Course Manager is application for creating online course and monitoring all courses you created in one single dashboard. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p>
 
 <a href="https://themify.me/" > SIGN UP FOR FREE </a> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/big8-1024x760-1024x760.png" width="1024" alt="" /> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/big6-1024x760.png" width="1024" alt="" /> 
 <h2 style="text-align: left;">Course and Exam Monitoring</h2><p style="text-align: left;">Course Manager is application for creating online course and monitoring all courses you created in one single dashboard. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod.</p>
 
 <a href="https://themify.me/" > SIGN UP FOR FREE </a> 
 <h2 style="text-align: left;">Interactive interface</h2><p style="text-align: left;">Course Manager is application for creating online course and monitoring all courses you created in one single dashboard. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.</p>
 
 <a href="https://themify.me/" > SIGN UP FOR FREE </a> 
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/big9-1024x760.png" width="1024" alt="" /> 
 <h1>Share your online course</h1> <h3>Join with million users around the world</h3>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/report-illegal-and-harmful-content-gt-grey-world-map-free-31918-2-1024x492.png" width="1024" alt="" /> 
 <h1>Testimonials</h1><h3>What they say about Course Manager</h3>
 <ul data-id="slider-0-" data-visible="1" data-scroll="1" data-auto-scroll="4" data-speed="1" data-wrap="yes" data-arrow="yes" data-pagination="yes" data-effect="scroll" data-height="variable" data-pause-on-hover="resume" > <li> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p><p><strong>Jane Doe</strong><br /> <em>founder of somewebsite</em></p> </li> <li> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p><p><strong>John Doe</strong><br /> <em>founder of somewebsite</em></p> </li> <li> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p><p><strong>Patrick Schurle</strong><br /> <em>founder of somewebsite</em></p> </li> <li> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.</p><p><strong>Didier</strong><br /> <em>founder of somewebsite</em></p> </li> </ul> 
 <h1>Get Course Manager</h1><h3>Available for iOS and Android</h3>
 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/big-iphone-4-900x581.png" width="900" alt="" /> 
 <h3 style="text-align: left;">Download Now</h3> <p style="text-align: left;">Course Manager is powerful tool to create and manage online course. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.Ut enim ad minimveniam, Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu.</p> <p><a href="http://themify.me/"><img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/badge_ios_english-en-4.png" alt="badge_ios_english-en" width="169" height="52" /></a>     <a href="http://themify.me/"><img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/english_get-3.png" alt="english_get" width="150" height="52" /></a></p><!--/themify_builder_static-->',
  'post_title' => 'Right Pane',
  'post_excerpt' => '',
  'post_name' => 'right-pane',
  'post_modified' => '2017-12-12 21:40:42',
  'post_modified_gmt' => '2017-12-12 21:40:42',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=4919',
  'menu_order' => 5,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'custom_menu' => 'right-pane',
    'color_design' => 'theme-color-turquoise',
    'header_design' => 'header-rightpane',
    'footer_design' => 'none',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Course Manager<\\\\/h1><h3>Create and manage online courses<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c18\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"rounded\\",\\"content_button\\":[{\\"label\\":\\"SIGN UP FOR FREE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\",\\"new_window\\":\\"0\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"margin_bottom\\":\\"8\\",\\"margin_bottom_unit\\":\\"%\\",\\"cid\\":\\"c22\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/dashboard-2-800x436.png\\",\\"width_image\\":\\"800\\",\\"cid\\":\\"c26\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat-none\\"}}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_anchor\\":\\"course-manager\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/office-932926_1920-1024x683.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.87\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">What is Course Manager?<\\\\/h2><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Course Manager is application for creating online course and monitoring all courses you created in one single dashboard. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"font_color\\":\\"000000\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"15\\",\\"padding_left_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInLeft\\",\\"cid\\":\\"c37\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"rounded\\",\\"content_button\\":[{\\"label\\":\\"SIGN UP FOR FREE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\",\\"new_window\\":\\"0\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"margin_bottom\\":\\"8\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"15\\",\\"margin_left_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInLeft\\",\\"cid\\":\\"c41\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/big8-1024x760-1024x760.png\\",\\"width_image\\":\\"1024\\",\\"animation_effect\\":\\"bounceInRight\\",\\"cid\\":\\"c49\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"what\\",\\"background_type\\":\\"image\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"7\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_top_color\\":\\"ebebeb_1.00\\",\\"border_top_width\\":\\"1\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/big6-1024x760.png\\",\\"width_image\\":\\"1024\\",\\"auto_fullwidth\\":\\"1\\",\\"animation_effect\\":\\"bounceInUp\\",\\"cid\\":\\"c60\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Course and Exam Monitoring<\\\\/h2><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Course Manager is application for creating online course and monitoring all courses you created in one single dashboard. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod.<\\\\/p>\\",\\"font_color\\":\\"000000\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"15\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"20\\",\\"padding_left_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInDown\\",\\"cid\\":\\"c68\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"rounded\\",\\"content_button\\":[{\\"label\\":\\"SIGN UP FOR FREE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\",\\"new_window\\":\\"0\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"margin_bottom\\":\\"8\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"20\\",\\"margin_left_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInDown\\",\\"cid\\":\\"c72\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"course-exam\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"fafafa\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_top_color\\":\\"ebebeb\\",\\"border_top_width\\":\\"1\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Interactive interface<\\\\/h2><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Course Manager is application for creating online course and monitoring all courses you created in one single dashboard. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.<\\\\/p>\\",\\"font_color\\":\\"000000\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"10\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"15\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"20\\",\\"padding_left_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInDown\\",\\"cid\\":\\"c83\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"rounded\\",\\"content_button\\":[{\\"label\\":\\"SIGN UP FOR FREE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"blue\\",\\"new_window\\":\\"0\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"margin_bottom\\":\\"8\\",\\"margin_bottom_unit\\":\\"%\\",\\"margin_left\\":\\"20\\",\\"margin_left_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInDown\\",\\"cid\\":\\"c87\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/big9-1024x760.png\\",\\"width_image\\":\\"1024\\",\\"auto_fullwidth\\":\\"1\\",\\"animation_effect\\":\\"fadeInUp\\",\\"cid\\":\\"c95\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\"}}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"interactive-interface\\",\\"background_type\\":\\"image\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"border_top_color\\":\\"ebebeb_1.00\\",\\"border_top_width\\":\\"1\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Share your online course<\\\\/h1>\\\\n<h3>Join with million users around the world<\\\\/h3>\\\\n\\",\\"font_color\\":\\"ffffff_1.00\\",\\"text_align\\":\\"center\\",\\"animation_effect\\":\\"fadeInDownBig\\",\\"cid\\":\\"c106\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/report-illegal-and-harmful-content-gt-grey-world-map-free-31918-2-1024x492.png\\",\\"width_image\\":\\"1024\\",\\"animation_effect\\":\\"fadeInUpBig\\",\\"cid\\":\\"c110\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"share\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"252d32\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Testimonials<\\\\/h1><h3>What they say about Course Manager<\\\\/h3>\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"animation_effect\\":\\"fadeIn\\",\\"cid\\":\\"c121\\"}},{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"text\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"text_content_slider\\":[{\\"text_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.<\\\\/p><p><strong>Jane Doe<\\\\/strong><br \\\\/> <em>founder of somewebsite<\\\\/em><\\\\/p>\\"},{\\"text_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.<\\\\/p><p><strong>John Doe<\\\\/strong><br \\\\/> <em>founder of somewebsite<\\\\/em><\\\\/p>\\"},{\\"text_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.<\\\\/p><p><strong>Patrick Schurle<\\\\/strong><br \\\\/> <em>founder of somewebsite<\\\\/em><\\\\/p>\\"},{\\"text_caption_slider\\":\\"<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.<\\\\/p><p><strong>Didier<\\\\/strong><br \\\\/> <em>founder of somewebsite<\\\\/em><\\\\/p>\\"}],\\"layout_slider\\":\\"slider-default\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"height_slider\\":\\"variable\\"}}]}],\\"styling\\":{\\"row_anchor\\":\\"testimonial\\",\\"background_type\\":\\"image\\",\\"text_align\\":\\"center\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1>Get Course Manager<\\\\/h1><h3>Available for iOS and Android<\\\\/h3>\\",\\"text_align\\":\\"center\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"cid\\":\\"c136\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/big-iphone-4-900x581.png\\",\\"width_image\\":\\"900\\",\\"animation_effect\\":\\"bounceInLeft\\",\\"cid\\":\\"c148\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Download Now<\\\\/h3>\\\\n<p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Course Manager is powerful tool to create and manage online course. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.Ut enim ad minimveniam, Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu.<\\\\/p>\\\\n<p><a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/themify.me\\\\/\\\\\\\\\\\\\\"><img class=\\\\\\\\\\\\\\"alignnone size-full wp-image-4419\\\\\\\\\\\\\\" src=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/badge_ios_english-en-4.png\\\\\\\\\\\\\\" alt=\\\\\\\\\\\\\\"badge_ios_english-en\\\\\\\\\\\\\\" width=\\\\\\\\\\\\\\"169\\\\\\\\\\\\\\" height=\\\\\\\\\\\\\\"52\\\\\\\\\\\\\\" \\\\/><\\\\/a>     <a href=\\\\\\\\\\\\\\"http:\\\\/\\\\/themify.me\\\\/\\\\\\\\\\\\\\"><img class=\\\\\\\\\\\\\\"alignnone size-full wp-image-4420\\\\\\\\\\\\\\" src=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/english_get-3.png\\\\\\\\\\\\\\" alt=\\\\\\\\\\\\\\"english_get\\\\\\\\\\\\\\" width=\\\\\\\\\\\\\\"150\\\\\\\\\\\\\\" height=\\\\\\\\\\\\\\"52\\\\\\\\\\\\\\" \\\\/><\\\\/a><\\\\/p>\\\\n\\",\\"padding_top\\":\\"7\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"animation_effect\\":\\"bounceInRight\\",\\"cid\\":\\"c156\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\"}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_anchor\\":\\"get\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"fafafa\\",\\"border_top_color\\":\\"ebebeb\\",\\"border_top_width\\":\\"1\\",\\"border_bottom_color\\":\\"ebebeb\\",\\"border_bottom_width\\":\\"1\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3397,
  'post_date' => '2015-04-16 20:36:46',
  'post_date_gmt' => '2015-04-16 20:36:46',
  'post_content' => '<!--themify_builder_static--><h2 style="text-align: center;">Welcome</h2><h3 style="text-align: center;">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat</h3> 
 <a href="https://themify.me/" >BUY THEME</a> 
 <h3><strong><a href="https://themify.me">Elegant Gothic</a></strong></h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon="fa-chevron-right" link="https://themify.me" style="rounded small" icon_color="#fff" ]</p> 
 <h3><strong><a href="https://themify.me">Magnificent Retro</a></strong></h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon="fa-chevron-right" link="https://themify.me" style="rounded small" icon_color="#fff" ]</p> 
 <h3><strong><a href="https://themify.me">Beautiful Night</a><br /> </strong></h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon="fa-chevron-right" link="https://themify.me" style="rounded small" icon_color="#fff" ]</p> 
 <h3><strong><a href="https://themify.me">Perfect Beach</a><br /> </strong></h3> <p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon="fa-chevron-right" link="https://themify.me" style="rounded small" icon_color="#fff" ]</p> 
 <h3>I am English professional model and fashion designer. Check out my new collections</h3> 
 <a href="https://themify.me/" >READ MORE</a> 
 <ul data-id="slider-0-" data-visible="5" data-mob-visible="" data-scroll="1" data-auto-scroll="4" data-speed="1" data-wrap="yes" data-arrow="no" data-pagination="no" data-effect="continuously" data-height="variable" data-pause-on-hover="resume" > 
 <li> <a href="https://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/184724801-1-1024x775-475x320.jpg" width="475" height="320" alt="" /> </a> </li> <li> <a href="https://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/155256980-1024x683-475x320.jpg" width="475" height="320" alt="" /> </a> </li> <li> <a href="https://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/197408744-1024x684-475x320.jpg" width="475" height="320" alt="" /> </a> </li> <li> <a href="https://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/140830399-1-1024x686-475x320.jpg" width="475" height="320" alt="" /> </a> </li> <li> <a href="https://themify.me/" alt=""> <img src="https://themify.me/demo/themes/builder-layouts/files/2016/01/133815968-1024x683-475x320.jpg" width="475" height="320" alt="" /> </a> </li> </ul><!--/themify_builder_static-->',
  'post_title' => 'Left Pane',
  'post_excerpt' => '',
  'post_name' => 'left-pane',
  'post_modified' => '2018-07-17 17:46:25',
  'post_modified_gmt' => '2018-07-17 17:46:25',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3397',
  'menu_order' => 5,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'color_design' => 'theme-color-purple',
    'header_design' => 'header-leftpane',
    'footer_design' => 'none',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Welcome<\\\\/h2><h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat<\\\\/h3>\\",\\"font_color\\":\\"ffffff_1.00\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"font_size\\":\\"18\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"text_decoration\\":\\"none\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"outline\\",\\"display\\":\\"buttons-horizontal\\",\\"content_button\\":[{\\"label\\":\\"BUY THEME\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"link_options\\":\\"regular\\"}]}}]}],\\"styling\\":{\\"row_height\\":\\"fullheight\\",\\"custom_css_row\\":\\"full-height\\",\\"background_type\\":\\"video\\",\\"background_video\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/demo-videos\\\\/girl-street.mp4\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/demo-videos\\\\/girl-street.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"background_color\\":\\"ebe8b7\\",\\"cover_color\\":\\"000000_0.28\\",\\"font_color\\":\\"0a0a0a\\",\\"link_color\\":\\"000000\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3><strong><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\">Elegant Gothic<\\\\/a><\\\\/strong><\\\\/h3>\\\\n<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon=\\\\\\\\\\\\\\"fa-chevron-right\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"rounded small\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#fff\\\\\\\\\\\\\\" ]<\\\\/p>\\\\n\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/90849914-4-1024x685.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.42\\",\\"cover_color_hover\\":\\"421175_0.60\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3><strong><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\">Magnificent Retro<\\\\/a><\\\\/strong><\\\\/h3><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon=\\\\\\\\\\\\\\"fa-chevron-right\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"rounded small\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#fff\\\\\\\\\\\\\\" ]<\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/97591061-1024x683.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"030303_0.36\\",\\"cover_color_hover\\":\\"c49227_0.41\\"}}],\\"gutter\\":\\"gutter-none\\"},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3><strong><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\">Beautiful Night<\\\\/a><br \\\\/>\\\\n<\\\\/strong><\\\\/h3>\\\\n<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon=\\\\\\\\\\\\\\"fa-chevron-right\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"rounded small\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#fff\\\\\\\\\\\\\\" ]<\\\\/p>\\\\n\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/99449315-1024x724.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.39\\",\\"cover_color_hover\\":\\"000000_0.73\\"}},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3><strong><a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\">Perfect Beach<\\\\/a><br \\\\/>\\\\n<\\\\/strong><\\\\/h3>\\\\n<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor [themify_icon icon=\\\\\\\\\\\\\\"fa-chevron-right\\\\\\\\\\\\\\" link=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\\\\\\\\\\\" style=\\\\\\\\\\\\\\"rounded small\\\\\\\\\\\\\\" icon_color=\\\\\\\\\\\\\\"#fff\\\\\\\\\\\\\\" ]<\\\\/p>\\\\n\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"35\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"20\\",\\"padding_right_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/194739149-1024x683.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.48\\",\\"cover_color_hover\\":\\"3876bd_0.53\\"}}],\\"gutter\\":\\"gutter-none\\"}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>I am English professional model and fashion designer. Check out my new collections<\\\\/h3>\\",\\"font_color\\":\\"000000_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"40\\",\\"padding_top_unit\\":\\"%\\",\\"padding_right\\":\\"30\\",\\"padding_right_unit\\":\\"%\\",\\"padding_left\\":\\"8\\",\\"padding_left_unit\\":\\"%\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"buttons_size\\":\\"normal\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"READ MORE\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/\\",\\"button_color_bg\\":\\"black\\",\\"new_window\\":\\"0\\"}],\\"font_color\\":\\"ffffff_1.00\\",\\"font_size\\":\\"18\\",\\"link_color\\":\\"ffffff_1.00\\",\\"text_decoration\\":\\"none\\",\\"margin_left\\":\\"8\\",\\"margin_left_unit\\":\\"%\\"}}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/96732010-2-1024x768.jpg\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color\\":\\"000000_0.20\\",\\"cover_color_hover\\":\\"000000_0.29\\"}}],\\"gutter\\":\\"gutter-none\\",\\"styling\\":{\\"row_width\\":\\"fullwidth-content\\",\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"fullcover\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"0|multiple\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"posts_per_page_slider\\":\\"6\\",\\"offset_slider\\":\\"4\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/184724801-1-1024x775-475x320.jpg\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/155256980-1024x683-475x320.jpg\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/197408744-1024x684-475x320.jpg\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/140830399-1-1024x686-475x320.jpg\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2016\\\\/01\\\\/133815968-1024x683-475x320.jpg\\",\\"img_link_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/\\"}],\\"layout_slider\\":\\"slider-default\\",\\"img_w_slider\\":\\"475\\",\\"img_h_slider\\":\\"320\\",\\"visible_opt_slider\\":\\"5\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"continuously\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"no\\",\\"show_arrow_slider\\":\\"no\\",\\"height_slider\\":\\"variable\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\",\\"visibility_desktop_hide\\":\\"hide\\",\\"visibility_tablet_hide\\":\\"hide\\",\\"visibility_mobile_hide\\":\\"hide\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"custom_css_row\\":\\"fullwidth\\",\\"background_type\\":\\"image\\",\\"font_color\\":\\"7b0e35\\",\\"link_color\\":\\"7b0e35\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3400,
  'post_date' => '2015-04-16 20:38:35',
  'post_date_gmt' => '2015-04-16 20:38:35',
  'post_content' => '<!--themify_builder_static--><h1 style="text-align: right;">BMW i8</h1><h5 style="text-align: right;">Designed for Maximum Performance and Style</h5> 
 <a href="https://www.youtube.com/watch?v=XgxsUiY_n0w" > 
 
 </a> 
 <h4><br />To the Future</h4> 
 
 <h3>Performance</h3> 
 
 
 <h3>320 Nm Torque</h3> 
 
 <h3>Electric Driving</h3> 
 
 
 <h3>100% Electric</h3> 
 
 <h3>All-Wheel Drive</h3> 
 
 
 <h3>250 Km/h</h3> 
 
 <h1 style="text-align: center;">Impressive Design without Compromise</h1> 
 <ul data-id="slider-0-" data-visible="1" data-mob-visible="" data-scroll="1" data-auto-scroll="4" data-speed="1" data-wrap="yes" data-arrow="yes" data-pagination="yes" data-effect="scroll" data-height="variable" data-pause-on-hover="resume" > 
 <li> <img src="https://themify.me/demo/themes/landing/files/2015/03/4-wheel-01.jpg" width="800" alt="Efficiency &amp; Dyamics" /> 
 <h3> Efficiency & Dyamics </h3> <em>An Athlete in Top Form</em>
<ul> <li>Aerodynamic Design</li> <li>Aerodynamic Features</li> <li>Intelligent Lightweight Construction</li> </ul> </li> <li> <img src="https://themify.me/demo/themes/landing/files/2015/03/visions-01.jpg" width="800" alt="Design" /> 
 <h3> Design </h3> <em>Time for a new ideal</em>
<ul> <li>Ambient Light</li> <li>Sustainable Materials</li> <li>Exterior Colours</li> <li>Scissor Doors</li> </ul> </li> <li> <img src="https://themify.me/demo/themes/landing/files/2015/03/service-inclusive.jpg" width="800" alt="Safety" /> 
 <h3> Safety </h3> <em>Innovations that you can trust</em>
<ul> <li>Charging Assistant</li> <li>BMW TeleServices</li> <li>Mobility Assistance</li> <li>Maintenance and Repair Packages</li> </ul> </li> </ul> 
 <h3>Track Race Test</h3><p>The animation done on the right was through the use of the <a href="https://themify.me/addons/progress-bar">Progress Bar Addon</a>. Create your own progress bar now. See our demo page for the Progress Bar addon <a href="https://themify.me/demo/themes/addons/demo/progress-bar/">here</a>.</p> 
 <i>i8</i> <i>Test A</i> <i>Test B</i> <i>Test C</i><!--/themify_builder_static-->',
  'post_title' => 'Min Bar',
  'post_excerpt' => '',
  'post_name' => 'min-bar',
  'post_modified' => '2018-07-16 19:45:12',
  'post_modified_gmt' => '2018-07-16 19:45:12',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3400',
  'menu_order' => 6,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'header-minbar',
    'footer_design' => 'none',
    'more_posts' => 'pagination',
    'posts_per_page' => '2',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">BMW i8<\\\\/h1><h5 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Designed for Maximum Performance and Style<\\\\/h5>\\",\\"background_color\\":\\"000000_0.67\\",\\"padding_top\\":\\"10\\",\\"padding_right\\":\\"15\\",\\"padding_bottom\\":\\"10\\",\\"padding_left\\":\\"15\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"content_feature\\":\\"<h4><br \\\\/>To the Future<\\\\/h4>\\",\\"layout_feature\\":\\"icon-left\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"3\\",\\"circle_color_feature\\":\\"ffffff_1.00\\",\\"circle_size_feature\\":\\"medium\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-play\\",\\"icon_color_feature\\":\\"ffffff_1.00\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.youtube.com\\\\/watch?v=XgxsUiY_n0w\\",\\"param_feature\\":\\"lightbox\\",\\"link_options\\":\\"\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/bg-driving-pleasure-01.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color\\":\\"000000_0.69\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"cover_color_hover\\":\\"000000_0.69\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"font_color\\":\\"ffffff\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"10\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"fullheight\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_module_title\\":\\"#ffffff\\",\\"f_s_t_regular\\":\\"italic\\",\\"f_t_b\\":\\"bold\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"checkbox_c_m_apply_all\\":\\"1\\",\\"checkbox_c_b_apply_all\\":\\"1\\",\\"mod_title_feature\\":\\"Performance\\",\\"title_feature\\":\\"320 Nm Torque\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"3\\",\\"circle_color_feature\\":\\"ffffff\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-gears\\",\\"icon_color_feature\\":\\"ffffff\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_module_title\\":\\"#ffffff\\",\\"font_color_title\\":\\"#ffffff\\",\\"f_t_b\\":\\"bold\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"checkbox_c_m_apply_all\\":\\"1\\",\\"checkbox_c_b_apply_all\\":\\"1\\",\\"mod_title_feature\\":\\"Electric Driving\\",\\"title_feature\\":\\"100% Electric\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"3\\",\\"circle_color_feature\\":\\"ffffff\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-battery-full\\",\\"icon_color_feature\\":\\"ffffff\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"text_align\\":\\"center\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"font_color_module_title\\":\\"#ffffff\\",\\"f_t_b\\":\\"bold\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"checkbox_c_m_apply_all\\":\\"1\\",\\"checkbox_c_b_apply_all\\":\\"1\\",\\"mod_title_feature\\":\\"All-Wheel Drive\\",\\"title_feature\\":\\"250 Km\\\\/h\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_percentage_feature\\":\\"100\\",\\"circle_stroke_feature\\":\\"3\\",\\"circle_color_feature\\":\\"ffffff\\",\\"circle_size_feature\\":\\"large\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-car\\",\\"icon_color_feature\\":\\"ffffff\\",\\"link_options\\":\\"regular\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_color\\":\\"0069d2_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Impressive Design without Compromise<\\\\/h1>\\",\\"background_color\\":\\"000000_0.45\\",\\"padding_top\\":\\"15\\",\\"padding_right\\":\\"15\\",\\"padding_bottom\\":\\"5\\",\\"padding_left\\":\\"15\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"row_height\\":\\"fullheight\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/exterior-fw-05.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"font_color\\":\\"ffffff_1.00\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"slider\\",\\"mod_settings\\":{\\"layout_display_slider\\":\\"image\\",\\"blog_category_slider\\":\\"|single\\",\\"slider_category_slider\\":\\"|single\\",\\"portfolio_category_slider\\":\\"|single\\",\\"testimonial_category_slider\\":\\"|single\\",\\"order_slider\\":\\"desc\\",\\"orderby_slider\\":\\"date\\",\\"display_slider\\":\\"content\\",\\"img_content_slider\\":[{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/4-wheel-01.jpg\\",\\"img_title_slider\\":\\"Efficiency & Dyamics\\",\\"img_caption_slider\\":\\"<em>An Athlete in Top Form<\\\\/em>\\\\n\\\\n<ul>\\\\n <li>Aerodynamic Design<\\\\/li>\\\\n <li>Aerodynamic Features<\\\\/li>\\\\n <li>Intelligent Lightweight Construction<\\\\/li>\\\\n<\\\\/ul>\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/visions-01.jpg\\",\\"img_title_slider\\":\\"Design\\",\\"img_caption_slider\\":\\"<em>Time for a new ideal<\\\\/em>\\\\n\\\\n<ul>\\\\n <li>Ambient Light<\\\\/li>\\\\n <li>Sustainable Materials<\\\\/li>\\\\n <li>Exterior Colours<\\\\/li>\\\\n <li>Scissor Doors<\\\\/li>\\\\n<\\\\/ul>\\"},{\\"img_url_slider\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/landing\\\\/files\\\\/2015\\\\/03\\\\/service-inclusive.jpg\\",\\"img_title_slider\\":\\"Safety\\",\\"img_caption_slider\\":\\"<em>Innovations that you can trust<\\\\/em>\\\\n\\\\n<ul>\\\\n <li>Charging Assistant<\\\\/li>\\\\n <li>BMW TeleServices<\\\\/li>\\\\n <li>Mobility Assistance<\\\\/li>\\\\n <li>Maintenance and Repair Packages<\\\\/li>\\\\n<\\\\/ul>\\"}],\\"layout_slider\\":\\"slider-agency\\",\\"img_w_slider\\":\\"800\\",\\"visible_opt_slider\\":\\"1\\",\\"auto_scroll_opt_slider\\":\\"4\\",\\"scroll_opt_slider\\":\\"1\\",\\"speed_opt_slider\\":\\"normal\\",\\"effect_slider\\":\\"scroll\\",\\"pause_on_hover_slider\\":\\"resume\\",\\"wrap_slider\\":\\"yes\\",\\"show_nav_slider\\":\\"yes\\",\\"show_arrow_slider\\":\\"yes\\",\\"height_slider\\":\\"variable\\",\\"padding_top_unit\\":\\"%\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Track Race Test<\\\\/h3><p>The animation done on the right was through the use of the <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/addons\\\\/progress-bar\\\\\\\\\\\\\\">Progress Bar Addon<\\\\/a>. Create your own progress bar now. See our demo page for the Progress Bar addon <a href=\\\\\\\\\\\\\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/addons\\\\/demo\\\\/progress-bar\\\\/\\\\\\\\\\\\\\">here<\\\\/a>.<\\\\/p>\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"progressbar\\",\\"mod_settings\\":{\\"progress_bars\\":[{\\"bar_label\\":\\"i8\\",\\"bar_percentage\\":\\"100\\",\\"bar_color\\":\\"49d8f5\\"},{\\"bar_label\\":\\"Test A\\",\\"bar_percentage\\":\\"70\\",\\"bar_color\\":\\"ff0000\\"},{\\"bar_label\\":\\"Test B\\",\\"bar_percentage\\":\\"50\\",\\"bar_color\\":\\"b730ff\\"},{\\"bar_label\\":\\"Test C\\",\\"bar_percentage\\":\\"65\\",\\"bar_color\\":\\"ff5e00\\"}],\\"hide_percentage_text\\":\\"no\\"}}]}],\\"styling\\":{\\"row_width\\":\\"fullwidth\\",\\"background_color\\":\\"edebf0_1.00\\",\\"font_color\\":\\"72747d_1.00\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"6\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3398,
  'post_date' => '2015-04-16 20:45:21',
  'post_date_gmt' => '2015-04-16 20:45:21',
  'post_content' => '<!--themify_builder_static--><h1 style="text-align: left;">Company Page</h1> <h3>Showoff Your Company Profile<br /> By importing this layout using the<br /> Builder Landing Theme</h3> <p style="text-align: left;"><i>Create your company landing page with this new layout with the Themify Landing Theme. Simply import using the Builder plugin, simple and easy. Get this layout now!</i></p> 
 <a href="https://themify.me/themes/landing/" >Buy Landing</a> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/mac.png" width="800" alt="" /> 
 <h1 style="text-align: center;">About Us</h1><p style="text-align: center;"><i>Phasellus scelerisque lacus imperdiet turpis iaculis tristique. Nam ornare, dui id faucibus tincidunt, ante lorem congue nibh, vitae auctor purus arcu et libero. Nullam semper, urna in efficitur consectetur, ipsum leo aliquam nisi, in ornare tellus lacus id velit. Pellentesque vulputate ipsum eu porta aliquam. Mauris pretium nunc sed metus vulputate interdum.</i></p> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/Leaderboard_Free1.png" width="600" alt="" /> 
 <h4 style="text-align: right;">Yay!</h4> 
 <h3 style="text-align: left;">Mission</h3><p style="text-align: left;">Phasellus scelerisque lacus imperdiet turpis iaculis tristique. Nam ornare, dui id faucibus tincidunt, ante lorem congue nibh, vitae auctor purus arcu et libero. </p> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/N9-cover-mint-16001.jpg" width="350" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/google-nexus-lime.jpg" width="350" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/3YNGIU4yRTO4DDifrEfA__MG_2885-1024x576-500x250.jpg" width="500" height="250" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/r2Xmw0IESdeCCu4eBb6d_33F3F57EBEB3600F3B377F32425EE595_B1280_1280_1200_800-1024x682-500x250.jpg" width="500" height="250" alt="" /> 
 <img src="https://themify.me/demo/themes/builder-layouts/files/2015/07/camera-man-1024x682-500x500.jpg" width="500" height="500" alt="" /> 
 <h3>Our Work</h3><p>Phasellus scelerisque lacus imperdiet turpis iaculis tristique. Nam ornare, dui id faucibus tincidunt, ante lorem congue nibh, vitae auctor purus arcu et libero. </p> 
 <h2 style="text-align: center;">Services</h2> 
 Newsletter 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Auto edit 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Images 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Live Chat Support 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Multi Layouts 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Color Pallete 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Easy Panel 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Unlimited Storages 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 Shortcodes 
 <p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.</p> 
 <h4>Subscribe to Themify Newsletter</h4><p>We\'ve got a lot of things in store for all of you. New system updates, themes, extendable Addons, and promotions! Be sure to stay connected by being a part of our mailing list. <br />[mc4wp_form]</p> 
 <h3 style="text-align: center;">Connect With Us</h3> 
 <a href="https://www.facebook.com/themify" > 
 
 </a> 
 
 
 <a href="https://twitter.com/themify" > 
 
 </a> 
 
 
 <a href="https://plus.google.com/u/0/b/109280316400365629341/109280316400365629341" > 
 
 </a> 
 
 
 <a href="https://www.rss.com/" > 
 
 </a> 
 
 
 <a href="https://www.linkedin.com/" > 
 
 </a><!--/themify_builder_static-->',
  'post_title' => 'No Header',
  'post_excerpt' => '',
  'post_name' => 'no-header',
  'post_modified' => '2018-08-27 19:16:07',
  'post_modified_gmt' => '2018-08-27 19:16:07',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?page_id=3398',
  'menu_order' => 7,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'full_width',
    'hide_page_title' => 'yes',
    'header_design' => 'none',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Company Page<\\\\/h1>\\\\n<h3>Showoff Your Company Profile<br \\\\/> By importing this layout using the<br \\\\/> Builder Landing Theme<\\\\/h3>\\\\n<p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\"><i>Create your company landing page with this new layout with the Themify Landing Theme. Simply import using the Builder plugin, simple and easy. Get this layout now!<\\\\/i><\\\\/p>\\"}},{\\"mod_name\\":\\"buttons\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"font_weight\\":\\"bold\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"link_color\\":\\"#ffffff\\",\\"checkbox_padding_link_apply_all\\":\\"1\\",\\"checkbox_link_margin_apply_all\\":\\"1\\",\\"checkbox_link_border_apply_all\\":\\"1\\",\\"buttons_size\\":\\"large\\",\\"buttons_style\\":\\"squared\\",\\"content_button\\":[{\\"label\\":\\"Buy Landing\\",\\"link\\":\\"https:\\\\/\\\\/themify.me\\\\/themes\\\\/landing\\\\/\\",\\"link_options\\":\\"regular\\",\\"button_color_bg\\":\\"light-green\\"}]}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/mac.png\\",\\"width_image\\":\\"800\\",\\"margin_top\\":\\"10\\",\\"margin_top_unit\\":\\"%\\"}}]}],\\"column_alignment\\":\\"col_align_middle\\",\\"gutter\\":\\"gutter-narrow\\",\\"styling\\":{\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/lady-beach-hat-1024x720.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"cover_color\\":\\"000000_0.77\\",\\"cover_color_hover\\":\\"000000_0.79\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h1 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">About Us<\\\\/h1><p style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\"><i>Phasellus scelerisque lacus imperdiet turpis iaculis tristique. Nam ornare, dui id faucibus tincidunt, ante lorem congue nibh, vitae auctor purus arcu et libero. Nullam semper, urna in efficitur consectetur, ipsum leo aliquam nisi, in ornare tellus lacus id velit. Pellentesque vulputate ipsum eu porta aliquam. Mauris pretium nunc sed metus vulputate interdum.<\\\\/i><\\\\/p>\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/Leaderboard_Free1.png\\",\\"width_image\\":\\"600\\",\\"margin_top\\":\\"30\\",\\"margin_bottom\\":\\"30\\"}}]}],\\"styling\\":{\\"row_height\\":\\"fullheight\\",\\"background_type\\":\\"image\\",\\"background_color\\":\\"5e754f_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"link_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4 style=\\\\\\\\\\\\\\"text-align: right;\\\\\\\\\\\\\\">Yay!<\\\\/h4>\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/google-nexus.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Mission<\\\\/h3><p style=\\\\\\\\\\\\\\"text-align: left;\\\\\\\\\\\\\\">Phasellus scelerisque lacus imperdiet turpis iaculis tristique. Nam ornare, dui id faucibus tincidunt, ante lorem congue nibh, vitae auctor purus arcu et libero. <\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/N9-cover-mint-16001.jpg\\",\\"appearance_image\\":\\"rounded\\",\\"width_image\\":\\"350\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-center\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/google-nexus-lime.jpg\\",\\"appearance_image\\":\\"rounded\\",\\"width_image\\":\\"350\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"729fa8_1.00\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"4\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/nexus-image.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"15\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"15\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"5\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/3YNGIU4yRTO4DDifrEfA__MG_2885-1024x576-500x250.jpg\\",\\"width_image\\":\\"500\\",\\"height_image\\":\\"250\\"}},{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/r2Xmw0IESdeCCu4eBb6d_33F3F57EBEB3600F3B377F32425EE595_B1280_1280_1200_800-1024x682-500x250.jpg\\",\\"width_image\\":\\"500\\",\\"height_image\\":\\"250\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"image\\",\\"mod_settings\\":{\\"style_image\\":\\"image-top\\",\\"url_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/camera-man-1024x682-500x500.jpg\\",\\"width_image\\":\\"500\\",\\"height_image\\":\\"500\\"}}]}],\\"gutter\\":\\"gutter-none\\"}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Our Work<\\\\/h3><p>Phasellus scelerisque lacus imperdiet turpis iaculis tristique. Nam ornare, dui id faucibus tincidunt, ante lorem congue nibh, vitae auctor purus arcu et libero. <\\\\/p>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"7b5d80_1.00\\",\\"padding_top\\":\\"8\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"8\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"6\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_image\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/builder-layouts\\\\/files\\\\/2015\\\\/07\\\\/nexus-iggy.jpg\\",\\"background_repeat\\":\\"builder-parallax-scrolling\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"padding_top\\":\\"20\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"20\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}},{\\"row_order\\":\\"7\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h2 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Services<\\\\/h2>\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top_unit\\":\\"%\\",\\"margin_top_unit\\":\\"%\\",\\"margin_left_unit\\":\\"%\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"fa-newspaper-o\\",\\"label\\":\\"Newsletter\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-pencil-alt\\",\\"label\\":\\"Auto edit\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-image\\",\\"label\\":\\"Images\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-comment\\",\\"label\\":\\"Live Chat Support\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-layers-alt\\",\\"label\\":\\"Multi Layouts\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-palette\\",\\"label\\":\\"Color Pallete\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]}]},{\\"row_order\\":\\"3\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-panel\\",\\"label\\":\\"Easy Panel\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-harddrives\\",\\"label\\":\\"Unlimited Storages\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col3-1\\",\\"modules\\":[{\\"mod_name\\":\\"icon\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"text_transform\\":\\"uppercase\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"margin_bottom\\":\\"20\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"icon_size\\":\\"large\\",\\"icon_style\\":\\"none\\",\\"icon_arrangement\\":\\"icon_horizontal\\",\\"content_icon\\":[{\\"icon\\":\\"ti-shortcode\\",\\"label\\":\\"Shortcodes\\",\\"link_options\\":\\"regular\\"}],\\"icon_position\\":\\"icon_position_left\\"}},{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"content_text\\":\\"<p>Ut suscipit eget lacus id dictum. Praesent dapibus interdum lorem nec tempor. Maecenas finibus tristique neque, id placerat lorem venenatis vitae.<\\\\/p>\\"}}]}]}]}],\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_color\\":\\"666696_1.00\\",\\"font_color\\":\\"ffffff_1.00\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"8\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col4-1\\"},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col4-2\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h4>Subscribe to Themify Newsletter<\\\\/h4><p>We\\\\\\\\\\\'ve got a lot of things in store for all of you. New system updates, themes, extendable Addons, and promotions! Be sure to stay connected by being a part of our mailing list. <br \\\\/>[mc4wp_form]<\\\\/p>\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col4-1\\"}]}]}],\\"styling\\":{\\"background_type\\":\\"video\\",\\"background_color\\":\\"c9ab32_1.00\\",\\"font_color\\":\\"000000_1.00\\",\\"link_color\\":\\"000000_1.00\\",\\"padding_top\\":\\"6\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\"}},{\\"row_order\\":\\"9\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3 style=\\\\\\\\\\\\\\"text-align: center;\\\\\\\\\\\\\\">Connect With Us<\\\\/h3>\\"}},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"link_color\\":\\"5A71BB\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-facebook\\",\\"icon_color_feature\\":\\"7B7A7A\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.facebook.com\\\\/themify\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\"}}]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"link_color\\":\\"5A71BB\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"checkbox_c_m_apply_all\\":\\"1\\",\\"checkbox_c_b_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-twitter\\",\\"icon_color_feature\\":\\"7B7A7A\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/twitter.com\\\\/themify\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\"}}]},{\\"column_order\\":\\"2\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_position\\":\\"left-top\\",\\"link_color\\":\\"5A71BB\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"border-type\\":\\"top\\",\\"checkbox_c_p_apply_all\\":\\"1\\",\\"checkbox_c_m_apply_all\\":\\"1\\",\\"c_b-type\\":\\"top\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-google-plus\\",\\"icon_color_feature\\":\\"7B7A7A\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/plus.google.com\\\\/u\\\\/0\\\\/b\\\\/109280316400365629341\\\\/109280316400365629341\\",\\"link_options\\":\\"regular\\"}}]},{\\"column_order\\":\\"3\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"link_color\\":\\"5A71BB\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-rss\\",\\"icon_color_feature\\":\\"7B7A7A\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.rss.com\\\\/\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\"}}]},{\\"column_order\\":\\"4\\",\\"grid_class\\":\\"col5-1\\",\\"modules\\":[{\\"mod_name\\":\\"feature\\",\\"mod_settings\\":{\\"background_image-type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"link_color\\":\\"5A71BB\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"layout_feature\\":\\"icon-top\\",\\"circle_color_feature\\":\\"#de5d5d\\",\\"circle_size_feature\\":\\"small\\",\\"icon_type_feature\\":\\"icon\\",\\"icon_feature\\":\\"fa-linkedin\\",\\"icon_color_feature\\":\\"7B7A7A\\",\\"icon_bg_feature\\":\\"ffffff\\",\\"link_feature\\":\\"https:\\\\/\\\\/www.linkedin.com\\\\/\\",\\"link_options\\":\\"regular\\",\\"circle_percentage_feature\\":\\"0\\"}}]}],\\"col_mobile\\":\\"column5-1\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_video_options\\":\\"mute\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top\\":\\"9\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"3\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"breakpoint_tablet\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top\\":\\"1\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"},\\"breakpoint_tablet_landscape\\":{\\"background_type\\":\\"image\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"background_repeat_inner\\":\\"repeat\\",\\"background_attachment_inner\\":\\"scroll\\",\\"background_position_inner\\":\\"center-center\\",\\"checkbox_padding_inner_apply_all\\":\\"1\\",\\"checkbox_border_inner_apply_all\\":\\"1\\",\\"top-frame_type\\":\\"top-presets\\",\\"top-frame_width_unit\\":\\"%\\",\\"top-frame_height_unit\\":\\"%\\",\\"bottom-frame_type\\":\\"bottom-presets\\",\\"bottom-frame_width_unit\\":\\"%\\",\\"bottom-frame_height_unit\\":\\"%\\",\\"left-frame_type\\":\\"left-presets\\",\\"left-frame_width_unit\\":\\"%\\",\\"left-frame_height_unit\\":\\"%\\",\\"right-frame_type\\":\\"right-presets\\",\\"right-frame_width_unit\\":\\"%\\",\\"right-frame_height_unit\\":\\"%\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\"}}}]}],\\"gutter\\":\\"gutter-none\\",\\"col_mobile\\":\\"column-full\\",\\"styling\\":{\\"background_type\\":\\"image\\",\\"background_slider_size\\":\\"large\\",\\"background_slider_mode\\":\\"fullcover\\",\\"background_repeat\\":\\"repeat\\",\\"background_attachment\\":\\"scroll\\",\\"background_position\\":\\"center-center\\",\\"background_color\\":\\"#d46060\\",\\"cover_color-type\\":\\"color\\",\\"cover_color_hover-type\\":\\"hover_color\\",\\"font_color\\":\\"ffffff\\",\\"link_color\\":\\"ffffff\\",\\"padding_top\\":\\"4\\",\\"padding_top_unit\\":\\"%\\",\\"padding_bottom\\":\\"4\\",\\"padding_bottom_unit\\":\\"%\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"row_width\\":\\"fullwidth\\"}},{\\"row_order\\":\\"10\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6438,
  'post_date' => '2017-08-03 19:11:09',
  'post_date_gmt' => '2017-08-03 19:11:09',
  'post_content' => '<!--themify_builder_static--><ol> <li itemprop="track" itemscope="" itemtype="http://schema.org/MusicRecording"> <a href="#" itemprop="url">Song Title</a> <audio id="audio-0-1" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/themes/wp-content/uploads/addon-samples/sample-song.mp3?_=1" /><a href="https://themify.me/demo/themes/themes/wp-content/uploads/addon-samples/sample-song.mp3">https://themify.me/demo/themes/themes/wp-content/uploads/addon-samples/sample-song.mp3</a></audio> </li> </ol> 
<h1>Menu<br/>Our Finest Recipe</h1>
 
 <ol> <li itemprop="track" itemscope="" itemtype="http://schema.org/MusicRecording"> <a href="#" itemprop="url">Song Title</a> <audio id="audio-0-2" preload="none" style="width: 100%;" controls="controls"><source type="audio/mpeg" src="https://themify.me/demo/themes/themes/wp-content/uploads/addon-samples/sample-song.mp3?_=2" /><a href="https://themify.me/demo/themes/themes/wp-content/uploads/addon-samples/sample-song.mp3">https://themify.me/demo/themes/themes/wp-content/uploads/addon-samples/sample-song.mp3</a></audio> </li> </ol><!--/themify_builder_static-->',
  'post_title' => 'Sample Layout Part',
  'post_excerpt' => '',
  'post_name' => '6438',
  'post_modified' => '2018-04-09 22:41:06',
  'post_modified_gmt' => '2018-04-09 22:41:06',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=tbuilder_layout_part&#038;p=6438',
  'menu_order' => 0,
  'post_type' => 'tbuilder_layout_part',
  'meta_input' => 
  array (
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"audio\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"music_playlist\\":[{\\"audio_name\\":\\"Song Title\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/themes\\\\/wp-content\\\\/uploads\\\\/addon-samples\\\\/sample-song.mp3\\"}],\\"hide_download_audio\\":\\"yes\\"}},{\\"mod_name\\":\\"fancy-heading\\",\\"mod_settings\\":{\\"heading\\":\\"Menu\\",\\"sub_heading\\":\\"Our Finest Recipe\\",\\"heading_tag\\":\\"h1\\",\\"text_alignment\\":\\"themify-text-center\\",\\"breakpoint_mobile\\":{\\"padding_top\\":\\"50\\",\\"padding_bottom\\":\\"50\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"checkbox_border_apply_all\\":\\"border\\"}}}]}]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\",\\"modules\\":[{\\"mod_name\\":\\"audio\\",\\"mod_settings\\":{\\"checkbox_padding_apply_all\\":\\"1\\",\\"checkbox_margin_apply_all\\":\\"1\\",\\"checkbox_border_apply_all\\":\\"1\\",\\"music_playlist\\":[{\\"audio_name\\":\\"Song Title\\",\\"audio_url\\":\\"https:\\\\/\\\\/themify.me\\\\/demo\\\\/themes\\\\/themes\\\\/wp-content\\\\/uploads\\\\/addon-samples\\\\/sample-song.mp3\\"}],\\"hide_download_audio\\":\\"yes\\"}}]}]},{\\"row_order\\":\\"2\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full\\"}]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3336,
  'post_date' => '2015-04-09 22:27:33',
  'post_date_gmt' => '2015-04-09 22:27:33',
  'post_content' => '<div id="lipsum">

Vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc.

</div>
&nbsp;',
  'post_title' => 'Kids Baby Doll Dress',
  'post_excerpt' => 'Magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc.',
  'post_name' => 'kids-baby-doll-dress',
  'post_modified' => '2017-08-21 01:22:44',
  'post_modified_gmt' => '2017-08-21 01:22:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3336',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278456:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '45',
    '_sale_price' => '35',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '35',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5481',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/8897806.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'mickey-shirt',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'top',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3337,
  'post_date' => '2015-04-09 22:28:22',
  'post_date_gmt' => '2015-04-09 22:28:22',
  'post_content' => '<div id="lipsum">

Placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Esem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Black Dress',
  'post_excerpt' => 'Esem enim maximus ipsum, sed ullamcorper est urna suscipit massa.',
  'post_name' => 'black-dress',
  'post_modified' => '2017-08-21 01:22:43',
  'post_modified_gmt' => '2017-08-21 01:22:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3337',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278455:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '1',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '300',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '300',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5453',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/65342323.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'top',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3338,
  'post_date' => '2015-04-09 22:29:41',
  'post_date_gmt' => '2015-04-09 22:29:41',
  'post_content' => '<div id="lipsum">

Blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum.

</div>
&nbsp;',
  'post_title' => 'Blush Satin High Heels',
  'post_excerpt' => 'Morbi pretium non ex ut volutpat.',
  'post_name' => 'blush-satin-high-heels',
  'post_modified' => '2017-08-21 01:22:41',
  'post_modified_gmt' => '2017-08-21 01:22:41',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3338',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278454:172',
    '_edit_last' => '172',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/91217936.jpg',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '1',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '400',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '400',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5488',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_primary_product_cat' => '18',
    '_wp_old_slug' => 'bow-dress',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3339,
  'post_date' => '2015-04-09 22:30:49',
  'post_date_gmt' => '2015-04-09 22:30:49',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida.

</div>
&nbsp;',
  'post_title' => 'Man\'s Office Clothes Set',
  'post_excerpt' => 'Pretium non ex ut volutpat',
  'post_name' => 'mans-office-clothes-set',
  'post_modified' => '2017-08-21 01:22:39',
  'post_modified_gmt' => '2017-08-21 01:22:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3339',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278453:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '1200',
    '_sale_price' => '1000',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '1000',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5456',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/131096918.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_wp_old_slug' => 'full-vintage-top-set',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'top',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3340,
  'post_date' => '2015-04-09 22:31:45',
  'post_date_gmt' => '2015-04-09 22:31:45',
  'post_content' => '<div id="lipsum">

Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Ripped Jeans',
  'post_excerpt' => 'Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.',
  'post_name' => 'ripped-jeans',
  'post_modified' => '2017-08-21 01:22:36',
  'post_modified_gmt' => '2017-08-21 01:22:36',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3340',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278452:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '120',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '120',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'construction-joe',
    '_product_version' => '3.1.1',
    '_thumbnail_id' => '5480',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/shutterstock_62898826.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'pants',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3341,
  'post_date' => '2015-04-09 22:32:32',
  'post_date_gmt' => '2015-04-09 22:32:32',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

</div>
&nbsp;',
  'post_title' => 'Women\'s Grey Dress',
  'post_excerpt' => 'Turpis dignissim massa, et venenatis leo justo id urna.',
  'post_name' => 'womens-grey-dress',
  'post_modified' => '2017-08-21 01:22:34',
  'post_modified_gmt' => '2017-08-21 01:22:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3341',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278451:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '130',
    '_sale_price' => '100',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '100',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'maiden-blues',
    '_product_version' => '3.1.1',
    '_thumbnail_id' => '5482',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/shutterstock_125139458.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'top',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3342,
  'post_date' => '2015-04-09 22:33:39',
  'post_date_gmt' => '2015-04-09 22:33:39',
  'post_content' => '<div id="lipsum">

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Men\'s Blazer',
  'post_excerpt' => 'Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo',
  'post_name' => 'mens-blazer',
  'post_modified' => '2017-08-21 01:22:32',
  'post_modified_gmt' => '2017-08-21 01:22:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3342',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278451:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '800',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '800',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5471',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/shutterstock_22387285.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'simple-green',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'top',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3343,
  'post_date' => '2015-04-09 22:41:24',
  'post_date_gmt' => '2015-04-09 22:41:24',
  'post_content' => '<div id="lipsum">

Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum.

</div>
&nbsp;',
  'post_title' => 'Orange Clutch',
  'post_excerpt' => 'Bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum.',
  'post_name' => 'orange-clutch',
  'post_modified' => '2017-08-21 01:22:30',
  'post_modified_gmt' => '2017-08-21 01:22:30',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3343',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278450:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '100',
    '_featured' => 'no',
    '_sku' => '125',
    '_product_attributes' => 
    array (
    ),
    '_price' => '100',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5485',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/102945938.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'bag',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3861,
  'post_date' => '2015-05-06 00:05:02',
  'post_date_gmt' => '2015-05-06 00:05:02',
  'post_content' => 'Sed gravida turpis at lacus semper lobortis. Aenean consectetur ex lectus, et feugiat arcu vestibulum nec. Ut dolor risus, porta sit amet ante vitae, interdum dictum enim.',
  'post_title' => 'Straight Jeans',
  'post_excerpt' => 'Nulla fermentum felis pretium, rutrum enim at, varius felis.',
  'post_name' => 'straight-jeans',
  'post_modified' => '2017-08-21 01:22:16',
  'post_modified_gmt' => '2017-08-21 01:22:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3861',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1526343117:2',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '150',
    '_sale_price' => '110',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '110',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_review_count' => '0',
    '_wc_average_rating' => '0',
    '_thumbnail_id' => '5459',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'morning',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/05/132204857.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'pants',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3863,
  'post_date' => '2015-05-06 00:02:25',
  'post_date_gmt' => '2015-05-06 00:02:25',
  'post_content' => 'Cras sagittis ipsum nisl, non dignissim nulla cursus et. Proin dictum leo nec ligula pharetra commodo. Duis turpis sem, egestas eu nibh in, tempor tempus mi.',
  'post_title' => 'Men\'s Fedora Hat',
  'post_excerpt' => 'Phasellus et erat aliquet, pretium nulla blandit, lobortis velit. Nulla facilisi.',
  'post_name' => 'mens-fedora-hat',
  'post_modified' => '2017-08-21 01:22:18',
  'post_modified_gmt' => '2017-08-21 01:22:18',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3863',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1528401597:113',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '1',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '40',
    '_sale_price' => '30',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '30',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_thumbnail_id' => '5461',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'fun',
    '_product_version' => '3.1.1',
    '_wc_rating_count' => 
    array (
      5 => 1,
    ),
    '_wc_average_rating' => '5.00',
    '_wc_review_count' => '1',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/05/61925014.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_visibility' => 'rated-5',
    'product_cat' => 'accessories',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3352,
  'post_date' => '2015-05-06 00:01:04',
  'post_date_gmt' => '2015-05-06 00:01:04',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Leather Bag',
  'post_excerpt' => 'Suspendisse viverra nibh a fringilla viverra.',
  'post_name' => 'leather-bag',
  'post_modified' => '2017-08-21 01:22:20',
  'post_modified_gmt' => '2017-08-21 01:22:20',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3352',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1523668770:2',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '220',
    '_sale_price' => '190',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '190',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5486',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/ce04c26184c31cadb12e284326a40492-1.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'bag',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3353,
  'post_date' => '2015-04-09 22:43:00',
  'post_date_gmt' => '2015-04-09 22:43:00',
  'post_content' => '<div id="lipsum">

Wulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Boot Cut Jeans',
  'post_excerpt' => 'Wulla tortor ex, sodales id mollis ac, feugiat sit amet leo',
  'post_name' => 'boot-cut-jeans',
  'post_modified' => '2017-08-21 01:22:28',
  'post_modified_gmt' => '2017-08-21 01:22:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3353',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278449:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '180',
    '_sale_price' => '150',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '150',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5477',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/133289399.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'green-duffle',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'pants',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3865,
  'post_date' => '2015-04-09 00:00:23',
  'post_date_gmt' => '2015-04-09 00:00:23',
  'post_content' => 'Aliquam erat volutpat. Aenean ac pulvinar justo, eu pharetra nisl. Integer sit amet massa in sapien ornare semper sit amet id mauris. Ut vitae suscipit enim, sed vestibulum sapien.',
  'post_title' => 'Hiking Boots',
  'post_excerpt' => 'Pellentesque ultricies neque ut lorem lobortis, nec rhoncus ipsum aliquam.',
  'post_name' => 'hiking-boots',
  'post_modified' => '2017-08-21 01:23:45',
  'post_modified_gmt' => '2017-08-21 01:23:45',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3865',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278488:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '500',
    '_sale_price' => '400',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '400',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5463',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_primary_product_cat' => '18',
    '_wp_old_slug' => 'evening',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/05/101412127.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3354,
  'post_date' => '2015-04-09 22:43:56',
  'post_date_gmt' => '2015-04-09 22:43:56',
  'post_content' => '<div id="lipsum">

Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Black Shoes and Bag Set',
  'post_excerpt' => 'Maecenas consequat, justo sed rutrum sollicitudin',
  'post_name' => 'black-shoes-and-bag-set',
  'post_modified' => '2017-08-21 01:22:26',
  'post_modified_gmt' => '2017-08-21 01:22:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3354',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278448:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '3',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '1200',
    '_sale_price' => '1000',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '1000',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5469',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/96121718.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'on-the-go-leather-carry-bag',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_primary_product_cat' => '20',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'bag, shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3355,
  'post_date' => '2015-04-09 22:44:43',
  'post_date_gmt' => '2015-04-09 22:44:43',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Black Bag',
  'post_excerpt' => 'Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus',
  'post_name' => 'black-bag',
  'post_modified' => '2017-08-21 01:22:24',
  'post_modified_gmt' => '2017-08-21 01:22:24',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3355',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503950498:72',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '2',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '333',
    '_sale_price' => '233',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '233',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5454',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/100625434.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'black-bag-pack',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'bag',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3356,
  'post_date' => '2015-04-09 22:45:35',
  'post_date_gmt' => '2015-04-09 22:45:35',
  'post_content' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque vitae quam sed leo luctus sagittis. Fusce ut metus scelerisque dui facilisis auctor at sit amet eros. Donec sit amet nibh ac ipsum commodo tempor a a nibh. Suspendisse ornare neque id massa sollicitudin maximus. Vivamus vel dui Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.',
  'post_title' => 'Party Shoes and Bag Set',
  'post_excerpt' => 'Donec sit amet nibh ac ipsum commodo',
  'post_name' => 'party-shoes-and-bag-set',
  'post_modified' => '2017-08-21 01:22:22',
  'post_modified_gmt' => '2017-08-21 01:22:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3356',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278447:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '670',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '670',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5483',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/79502293.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'peachy-bahamas',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_primary_product_cat' => '20',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'bag, shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3313,
  'post_date' => '2015-04-09 22:11:55',
  'post_date_gmt' => '2015-04-09 22:11:55',
  'post_content' => '<div id="lipsum">Magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.</div>
&nbsp;',
  'post_title' => 'Leather Shoes',
  'post_excerpt' => '<div id="lipsum">

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringill elementum.

</div>',
  'post_name' => 'leather-shoes',
  'post_modified' => '2017-08-21 01:23:43',
  'post_modified_gmt' => '2017-08-21 01:23:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3313',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278487:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '1',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '400',
    '_sale_price' => '350',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '350',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5455',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'black-and-white-retro',
    '_product_version' => '3.1.1',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/126119468.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3321,
  'post_date' => '2015-04-09 22:14:13',
  'post_date_gmt' => '2015-04-09 22:14:13',
  'post_content' => '<div id="lipsum">

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida.

</div>
&nbsp;',
  'post_title' => 'Brown Clarks',
  'post_excerpt' => 'Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.',
  'post_name' => 'brown-clarks',
  'post_modified' => '2017-08-21 01:23:43',
  'post_modified_gmt' => '2017-08-21 01:23:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3321',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278485:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '1',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '400',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '400',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5479',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/94623082-1.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3322,
  'post_date' => '2015-04-09 22:15:21',
  'post_date_gmt' => '2015-04-09 22:15:21',
  'post_content' => 'Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.
<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

</div>
&nbsp;',
  'post_title' => 'Vintage Sneakers',
  'post_excerpt' => 'Donec accumsan ipsum nec dolor aliquam pretium.',
  'post_name' => 'vintage-sneakers',
  'post_modified' => '2017-08-21 01:22:53',
  'post_modified_gmt' => '2017-08-21 01:22:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3322',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278461:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '99',
    '_sale_price' => '90',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '90',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5466',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/shutterstock_88353775.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3323,
  'post_date' => '2015-04-09 22:16:54',
  'post_date_gmt' => '2015-04-09 22:16:54',
  'post_content' => '<div id="lipsum">

Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies.

</div>
&nbsp;',
  'post_title' => 'Women\'s Black Shoes and Bag Set',
  'post_excerpt' => 'Dignissim massa, et venenatis leo justo id urna.',
  'post_name' => 'womens-black-shoes-and-bag-set',
  'post_modified' => '2017-08-21 01:22:51',
  'post_modified_gmt' => '2017-08-21 01:22:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3323',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278459:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '600',
    '_sale_price' => '500',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '500',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5475',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/64049515.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'relax-loafers',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_primary_product_cat' => '20',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'bag, shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3324,
  'post_date' => '2015-04-09 22:17:53',
  'post_date_gmt' => '2015-04-09 22:17:53',
  'post_content' => '<div id="lipsum">

Welit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Workman Boots',
  'post_excerpt' => 'Sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin,',
  'post_name' => 'workman-boots',
  'post_modified' => '2017-08-21 01:22:49',
  'post_modified_gmt' => '2017-08-21 01:22:49',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3324',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278458:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '1000',
    '_sale_price' => '800',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '800',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_thumbnail_id' => '5487',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/100100117.jpg',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3325,
  'post_date' => '2015-04-09 22:18:38',
  'post_date_gmt' => '2015-04-09 22:18:38',
  'post_content' => 'Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin,',
  'post_title' => 'Women\'s Red Boots',
  'post_excerpt' => 'Suspendisse porttitor laoreet neque',
  'post_name' => 'womens-red-boots',
  'post_modified' => '2017-08-21 01:22:48',
  'post_modified_gmt' => '2017-08-21 01:22:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3325',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278458:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '250',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '250',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5473',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/103653464.jpg',
    'builder_switch_frontend' => '0',
    '_wp_old_slug' => 'polka-bow',
    '_product_version' => '3.1.1',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3326,
  'post_date' => '2015-04-09 22:19:28',
  'post_date_gmt' => '2015-04-09 22:19:28',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Men\'s Accessories',
  'post_excerpt' => 'Suspendisse viverra nibh a fringilla viverra.',
  'post_name' => 'mens-accessories',
  'post_modified' => '2017-08-21 01:22:46',
  'post_modified_gmt' => '2017-08-21 01:22:46',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=product&#038;p=3326',
  'menu_order' => 0,
  'post_type' => 'product',
  'meta_input' => 
  array (
    '_edit_lock' => '1503278601:172',
    '_edit_last' => '172',
    '_visibility' => 'visible',
    '_stock_status' => 'instock',
    'total_sales' => '0',
    '_downloadable' => 'no',
    '_virtual' => 'no',
    '_regular_price' => '1300',
    '_sale_price' => '1200',
    '_featured' => 'no',
    '_product_attributes' => 
    array (
    ),
    '_price' => '1200',
    '_manage_stock' => 'no',
    '_backorders' => 'no',
    '_stock' => NULL,
    '_upsell_ids' => 
    array (
    ),
    '_crosssell_ids' => 
    array (
    ),
    '_wc_rating_count' => 
    array (
    ),
    '_wc_average_rating' => '0',
    '_wc_review_count' => '0',
    '_thumbnail_id' => '5474',
    'post_image' => 'https://themify.me/demo/themes/ultra/files/2015/04/shutterstock_73533424.jpg',
    'builder_switch_frontend' => '0',
    '_product_version' => '3.1.1',
    '_yoast_wpseo_primary_product_cat' => '29',
    '_wp_old_slug' => 'vintage-golf',
    '_tax_status' => 'taxable',
    '_default_attributes' => 
    array (
    ),
    '_download_limit' => '-1',
    '_download_expiry' => '-1',
    '_yoast_wpseo_content_score' => '30',
  ),
  'tax_input' => 
  array (
    'product_type' => 'simple',
    'product_cat' => 'accessories, shoes',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5121,
  'post_date' => '2016-06-08 20:12:57',
  'post_date_gmt' => '2016-06-08 20:12:57',
  'post_content' => 'Sodales ipsum potenti, nisl tristique vulputate viverra tortor. Dapibus cubilia proin, venenatis orci integer. Nec fermentum nostra arcu bibendum tortor. Etiam sociis euismod facilisi sem. Nisi volutpat feugiat neque adipiscing consectetur dui sed mauris risus quam tristique feugiat. Faucibus at porta facilisis cubilia nam. Etiam hendrerit at penatibus, ultrices porttitor erat augue ornare feugiat dictumst proin! Aliquet consectetur euismod.',
  'post_title' => 'Gallery Portfolio',
  'post_excerpt' => '',
  'post_name' => 'gallery-portfolio',
  'post_modified' => '2017-08-21 01:20:23',
  'post_modified_gmt' => '2017-08-21 01:20:23',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=5121',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'post_layout' => 'gallery',
    'post_layout_gallery' => '[gallery link="file" size="large" ids="4997,4996,4995,4766,4754,4149,4212,4211,4216,4215,3694,4224"]',
    'project_date' => 'December, 21, 2014',
    'project_client' => 'Mrs Smith',
    'project_services' => 'Design',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5124,
  'post_date' => '2016-06-08 20:21:32',
  'post_date_gmt' => '2016-06-08 20:21:32',
  'post_content' => 'Duis dignissim curae; neque per mi placerat nibh tortor, venenatis diam litora. Eget ridiculus risus vehicula aliquet et ullamcorper porttitor magnis. Magnis, magnis metus vehicula. Tellus aptent elementum aliquet faucibus phasellus nostra sociosqu amet sapien in hendrerit. Massa pellentesque phasellus, ad leo euismod. Rutrum dictumst in facilisi. Pretium auctor dignissim lacus ridiculus lobortis etiam commodo sapien pellentesque lorem varius? Malesuada class class pretium torquent consequat praesent venenatis! Elementum sit molestie mi curae; cursus eget lacinia feugiat. Tellus nec interdum nisi quis lacinia a nibh.',
  'post_title' => 'Slider Portfolio',
  'post_excerpt' => '',
  'post_name' => 'slider-portfolio',
  'post_modified' => '2017-08-21 01:20:22',
  'post_modified_gmt' => '2017-08-21 01:20:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=5124',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'slider',
    'post_layout_slider' => '[gallery link="file" ids="5092,5094,5097,5090"]',
    'image_width' => '1400',
    'image_height' => '700',
    'project_date' => 'December, 21, 2014',
    'project_client' => 'The Tube',
    'project_services' => 'Interior Design',
    'project_launch' => 'https://themify.me',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'products',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3272,
  'post_date' => '2013-03-30 20:35:30',
  'post_date_gmt' => '2013-03-30 20:35:30',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.',
  'post_title' => 'First Camera',
  'post_excerpt' => '',
  'post_name' => 'first-camera',
  'post_modified' => '2017-08-21 01:20:46',
  'post_modified_gmt' => '2017-08-21 01:20:46',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3272',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'March 30, 2013',
    'project_client' => 'Argo/LCX Camera',
    'project_services' => 'Photography, Photo Edits, Model Scouting',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'cameras',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3276,
  'post_date' => '2013-07-13 20:36:39',
  'post_date_gmt' => '2013-07-13 20:36:39',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.',
  'post_title' => 'My View',
  'post_excerpt' => '',
  'post_name' => 'view',
  'post_modified' => '2017-08-21 01:20:40',
  'post_modified_gmt' => '2017-08-21 01:20:40',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3276',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'July 13, 2013',
    'project_client' => 'Vintage Shots',
    'project_services' => 'Photography, Photo Edits',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'cameras',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3277,
  'post_date' => '2013-11-03 20:37:52',
  'post_date_gmt' => '2013-11-03 20:37:52',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.',
  'post_title' => 'Close Shot Magic',
  'post_excerpt' => '',
  'post_name' => 'close-shot-magic',
  'post_modified' => '2017-08-21 01:20:35',
  'post_modified_gmt' => '2017-08-21 01:20:35',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3277',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'November 3, 2013',
    'project_client' => 'Yashica Camera',
    'project_services' => 'Photography, Creative Image Placement, Photo Edits',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'cameras',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3278,
  'post_date' => '2013-10-18 20:39:53',
  'post_date_gmt' => '2013-10-18 20:39:53',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.',
  'post_title' => 'Vintage Camera',
  'post_excerpt' => '',
  'post_name' => 'vintage-camera',
  'post_modified' => '2017-08-21 01:20:37',
  'post_modified_gmt' => '2017-08-21 01:20:37',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3278',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'October 18, 2013',
    'project_client' => 'Michelle Reitman',
    'project_services' => 'Photography, Photo Edits',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'cameras',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3280,
  'post_date' => '2013-08-02 20:44:51',
  'post_date_gmt' => '2013-08-02 20:44:51',
  'post_content' => 'In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus.',
  'post_title' => 'Travel Essentials',
  'post_excerpt' => '',
  'post_name' => 'travel-essentials',
  'post_modified' => '2017-08-21 01:20:39',
  'post_modified_gmt' => '2017-08-21 01:20:39',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3280',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'August 2, 2013',
    'project_client' => 'Gentlemen\'s Club',
    'project_services' => 'Photography, Creative Product Placement',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'products',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3283,
  'post_date' => '2013-06-16 20:50:23',
  'post_date_gmt' => '2013-06-16 20:50:23',
  'post_content' => 'Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus.',
  'post_title' => 'Tool Shed',
  'post_excerpt' => '',
  'post_name' => 'tool-shed',
  'post_modified' => '2017-08-21 01:20:42',
  'post_modified_gmt' => '2017-08-21 01:20:42',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3283',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'June 16, 2013',
    'project_client' => 'Farmers house',
    'project_services' => 'Project Management, Photography',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'products',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3285,
  'post_date' => '2016-03-23 20:52:35',
  'post_date_gmt' => '2016-03-23 20:52:35',
  'post_content' => 'Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus.',
  'post_title' => 'Office Desk Set',
  'post_excerpt' => '',
  'post_name' => 'office-desk-set',
  'post_modified' => '2017-09-20 14:35:28',
  'post_modified_gmt' => '2017-09-20 14:35:28',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3285',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'lightbox_link' => 'https://themify.me/demo/themes/ultra/project/office-desk-set/',
    'project_date' => 'March 23, 2013',
    'project_client' => 'Apple Accessories',
    'project_services' => 'Photography, Creative Material Placement',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'products',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3289,
  'post_date' => '2013-01-09 20:55:13',
  'post_date_gmt' => '2013-01-09 20:55:13',
  'post_content' => 'Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at.',
  'post_title' => 'Back-to-School Toolkit',
  'post_excerpt' => '',
  'post_name' => 'back-to-school-toolkit',
  'post_modified' => '2017-08-21 01:20:50',
  'post_modified_gmt' => '2017-08-21 01:20:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3289',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'January 9, 2013',
    'project_client' => 'Brian Hemington',
    'project_services' => 'Photography, Creative Design',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'products',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3291,
  'post_date' => '2013-04-03 20:56:41',
  'post_date_gmt' => '2013-04-03 20:56:41',
  'post_content' => 'Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at.',
  'post_title' => 'Mezo Espresso',
  'post_excerpt' => '',
  'post_name' => 'mezo-espresso',
  'post_modified' => '2017-08-21 01:20:44',
  'post_modified_gmt' => '2017-08-21 01:20:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3291',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'April 3, 2013',
    'project_client' => 'Mezo Espresso',
    'project_services' => 'Interior Design',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3293,
  'post_date' => '2014-02-20 21:20:21',
  'post_date_gmt' => '2014-02-20 21:20:21',
  'post_content' => 'Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at.',
  'post_title' => 'Rosy',
  'post_excerpt' => '',
  'post_name' => 'rosy',
  'post_modified' => '2017-08-21 01:20:32',
  'post_modified_gmt' => '2017-08-21 01:20:32',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3293',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'February 20, 2014',
    'project_client' => 'Blue Mountain Cottage',
    'project_services' => 'Interior Design',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3295,
  'post_date' => '2014-09-14 21:28:08',
  'post_date_gmt' => '2014-09-14 21:28:08',
  'post_content' => 'Donec vitae volutpat erat. Donec non molestie lacus. Integer euismod leo euismod, fermentum tellus sed, consequat leo. Cras lobortis nisl non dapibus tempor. Donec a finibus tellus. Vivamus laoreet lacinia imperdiet. Fusce tincidunt metus ac sapien feugiat, sit amet laoreet lorem aliquam. Integer pharetra egestas mi vel aliquam.

Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.',
  'post_title' => 'Model Shots',
  'post_excerpt' => '',
  'post_name' => 'model-shots',
  'post_modified' => '2017-08-21 01:20:29',
  'post_modified_gmt' => '2017-08-21 01:20:29',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3295',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'project_date' => 'Oct 2014',
    'project_client' => 'Cafe Americano',
    'project_services' => 'Interior Design',
    'project_launch' => 'https://themify.me',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'photos',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3300,
  'post_date' => '2014-01-01 21:33:56',
  'post_date_gmt' => '2014-01-01 21:33:56',
  'post_content' => 'Donec vitae volutpat erat. Donec non molestie lacus. Integer euismod leo euismod, fermentum tellus sed, consequat leo. Cras lobortis nisl non dapibus tempor. Donec a finibus tellus. Vivamus laoreet lacinia imperdiet. Fusce tincidunt metus ac sapien feugiat, sit amet laoreet lorem aliquam. Integer pharetra egestas mi vel aliquam.

Mauris pulvinar, massa eget semper imperdiet, sapien nisl vulputate mi, ut commodo mi erat et sapien. Interdum et malesuada fames ac ante ipsum primis in faucibus. Curabitur pellentesque augue nec nisl ultricies aliquet. Integer ipsum ante, interdum ac varius quis, ullamcorper vel ante. Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.',
  'post_title' => 'Underwater Shot',
  'post_excerpt' => '',
  'post_name' => 'underwater-shot',
  'post_modified' => '2017-08-21 01:20:34',
  'post_modified_gmt' => '2017-08-21 01:20:34',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3300',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'January 1, 2014',
    'project_client' => 'Euro Tourists',
    'project_services' => 'Photography, Photo Edits',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3302,
  'post_date' => '2014-03-08 21:38:19',
  'post_date_gmt' => '2014-03-08 21:38:19',
  'post_content' => 'Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue,',
  'post_title' => 'New York Lights',
  'post_excerpt' => '',
  'post_name' => 'new-york-lights',
  'post_modified' => '2017-08-21 01:20:31',
  'post_modified_gmt' => '2017-08-21 01:20:31',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3302',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'March 8, 2014',
    'project_client' => 'Old Medley',
    'project_services' => 'Photography, Photo Edits',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3303,
  'post_date' => '2014-12-01 21:41:02',
  'post_date_gmt' => '2014-12-01 21:41:02',
  'post_content' => 'Sedd aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula.<!--more-->
<h3>Sub Heading</h3>
Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.',
  'post_title' => 'Split Portfolio Layout',
  'post_excerpt' => '',
  'post_name' => 'split-portfolio-layout',
  'post_modified' => '2017-08-21 01:20:25',
  'post_modified_gmt' => '2017-08-21 01:20:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3303',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'split',
    'image_width' => '800',
    'image_height' => '1000',
    'project_date' => 'July 2014',
    'project_client' => 'Chinatown - Boston',
    'project_services' => 'Photography, Photo Edit, Creative Styling',
    'project_launch' => 'https://themify.me/',
    'header_design' => 'header-top-bar',
    'header_wrap' => 'video',
    'footer_design' => 'none',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3304,
  'post_date' => '2014-11-11 21:43:04',
  'post_date_gmt' => '2014-11-11 21:43:04',
  'post_content' => 'Donec eu mi vitae ex aliquam porttitor. Donec a mi in mauris finibus venenatis vitae at augue. Maecenas non pulvinar purus. Vestibulum posuere faucibus libero, eu dapibus magna mollis quis. Etiam non ante urna. Curabitur tincidunt ultrices sagittis. Donec quis felis leo. Cras ullamcorper, est eget convallis dapibus, diam lacus viverra magna, volutpat maximus lorem urna ac purus. Nam felis metus, eleifend ut fringilla a, sagittis nec mauris. In id congue justo.

&nbsp;',
  'post_title' => 'Fullwidth Image Layout',
  'post_excerpt' => '',
  'post_name' => 'fullwidth-image-layout',
  'post_modified' => '2017-08-21 01:20:27',
  'post_modified_gmt' => '2017-08-21 01:20:27',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3304',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'layout' => 'sidebar-none',
    'post_layout' => 'fullwidth',
    'project_date' => 'Nov 2014',
    'project_client' => 'iBeauty',
    'project_services' => 'Photo Edits',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3306,
  'post_date' => '2012-04-01 21:46:35',
  'post_date_gmt' => '2012-04-01 21:46:35',
  'post_content' => 'Donec vitae volutpat erat. Donec non molestie lacus. Integer euismod leo euismod, fermentum tellus sed, consequat leo. Cras lobortis nisl non dapibus tempor. Donec a finibus tellus. Vivamus laoreet lacinia imperdiet. Fusce tincidunt metus ac sapien feugiat, sit amet laoreet lorem aliquam. Integer pharetra egestas mi vel aliquam.',
  'post_title' => 'Old English',
  'post_excerpt' => '',
  'post_name' => 'old-english',
  'post_modified' => '2017-08-21 01:20:57',
  'post_modified_gmt' => '2017-08-21 01:20:57',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3306',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'April 1, 2012',
    'project_client' => 'Old Maiden',
    'project_services' => 'Photography, Photo Edits',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3307,
  'post_date' => '2012-09-05 21:48:03',
  'post_date_gmt' => '2012-09-05 21:48:03',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Camera Lightbox',
  'post_excerpt' => '',
  'post_name' => 'camera-lightbox',
  'post_modified' => '2017-08-21 01:20:51',
  'post_modified_gmt' => '2017-08-21 01:20:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3307',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'September 5, 2012',
    'project_client' => 'Vintage Classic',
    'project_services' => 'Creative Product Placement, Photography, Photo Edits',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'cameras',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3309,
  'post_date' => '2012-05-29 21:54:07',
  'post_date_gmt' => '2012-05-29 21:54:07',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Blacksmith Toolkit',
  'post_excerpt' => '',
  'post_name' => 'blacksmith-toolkit',
  'post_modified' => '2017-08-21 01:20:55',
  'post_modified_gmt' => '2017-08-21 01:20:55',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3309',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'May 29, 2012',
    'project_client' => 'Vintage Limited',
    'project_services' => 'Creative Material Placement, Photography',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'products',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3311,
  'post_date' => '2012-06-09 21:58:04',
  'post_date_gmt' => '2012-06-09 21:58:04',
  'post_content' => '<div id="lipsum">

Donec accumsan ipsum nec dolor aliquam pretium. Suspendisse consequat condimentum augue, vel ultricies quam efficitur quis. Aenean sapien turpis, tincidunt congue risus ac, eleifend condimentum nunc. Quisque porta nulla erat, et maximus nisi venenatis at. Aliquam arcu ante, sagittis eu rutrum a, efficitur eget nibh. In venenatis metus est, a sagittis turpis cursus quis. Fusce odio neque, placerat ut porttitor eget, congue vestibulum purus. In pretium posuere elit sed lobortis. Praesent finibus ultrices augue, eget blandit mauris. Duis pulvinar, quam ut tristique euismod, velit turpis dignissim massa, et venenatis leo justo id urna.

Nulla tortor ex, sodales id mollis ac, feugiat sit amet leo. Suspendisse porttitor laoreet neque, et bibendum lacus euismod id. In tincidunt, tortor vel fringilla elementum, magna purus lacinia ante, id egestas nisi justo vel eros. Pellentesque orci lorem, accumsan sed aliquam sed, pretium sed nunc. Maecenas consequat, justo sed rutrum sollicitudin, velit ante ultricies ante, et euismod arcu purus et leo. Morbi pretium non ex ut volutpat. Lorem ipsum dolor sit amet, consectetur adipiscing elit. In consequat rutrum nisl quis condimentum. Sed eget tincidunt nulla, posuere elementum ligula. Nulla facilisi. Praesent luctus, neque dictum feugiat maximus, sem enim maximus ipsum, sed ullamcorper est urna suscipit massa. Cras commodo eros nec eleifend vehicula. Praesent auctor augue in massa porta gravida. Nullam et ex eget diam mollis hendrerit id dignissim sem. Suspendisse viverra nibh a fringilla viverra.

</div>
&nbsp;',
  'post_title' => 'Summer Rush',
  'post_excerpt' => '',
  'post_name' => 'summer-rush',
  'post_modified' => '2017-08-21 01:20:53',
  'post_modified_gmt' => '2017-08-21 01:20:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?post_type=portfolio&#038;p=3311',
  'menu_order' => 0,
  'post_type' => 'portfolio',
  'meta_input' => 
  array (
    'project_date' => 'June 9, 2012',
    'project_client' => 'Morning Rush Mexico',
    'project_services' => 'Photography, Photo Edits',
    'project_launch' => 'https://themify.me/',
    'header_wrap' => 'video',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'portfolio-category' => 'fashion',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3625,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'About',
  'post_excerpt' => '',
  'post_name' => 'about',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3625',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3625',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#about',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5182,
  'post_date' => '2016-06-08 23:04:29',
  'post_date_gmt' => '2016-06-08 23:04:29',
  'post_content' => '',
  'post_title' => 'Layouts',
  'post_excerpt' => '',
  'post_name' => 'layouts-3',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5182',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '5182',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => 'https://themify.me/demo/themes/ultra/all-layouts/',
    '_themify_mega_menu_column' => '1',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4929,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'Course Manager',
  'post_excerpt' => '',
  'post_name' => 'course-manager',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4929',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4929',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#course-manager',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3680,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Guests',
  'post_excerpt' => '',
  'post_name' => 'guests',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3680',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3680',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#guests',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3689,
  'post_date' => '2015-04-21 01:02:25',
  'post_date_gmt' => '2015-04-21 01:02:25',
  'post_content' => '',
  'post_title' => 'Bride & Groom',
  'post_excerpt' => '',
  'post_name' => 'bride-groom',
  'post_modified' => '2015-04-21 01:02:25',
  'post_modified_gmt' => '2015-04-21 01:02:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3689',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3689',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#bg',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'wedding-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3767,
  'post_date' => '2015-04-21 17:39:31',
  'post_date_gmt' => '2015-04-21 17:39:31',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3767',
  'post_modified' => '2017-01-17 03:06:11',
  'post_modified_gmt' => '2017-01-17 03:06:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3767',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2512',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-menu-2',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5316,
  'post_date' => '2016-06-09 22:00:35',
  'post_date_gmt' => '2016-06-09 22:00:35',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5316',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5316',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2512',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3626,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'Skills',
  'post_excerpt' => '',
  'post_name' => 'skills',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3626',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3626',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#skills',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6195,
  'post_date' => '2017-01-17 03:06:10',
  'post_date_gmt' => '2017-01-17 03:06:10',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '6195',
  'post_modified' => '2017-01-17 03:06:11',
  'post_modified_gmt' => '2017-01-17 03:06:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=6195',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '6167',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-menu-2',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5184,
  'post_date' => '2016-06-08 23:04:29',
  'post_date_gmt' => '2016-06-08 23:04:29',
  'post_content' => '',
  'post_title' => 'Archive Layouts',
  'post_excerpt' => '',
  'post_name' => 'archive-layouts',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5184',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5182',
    '_menu_item_object_id' => '5184',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4930,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'What is a CM?',
  'post_excerpt' => '',
  'post_name' => 'what-is-a-cm',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4930',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4930',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#what',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3681,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Schedule',
  'post_excerpt' => '',
  'post_name' => 'schedule',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3681',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3681',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#schedule',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3690,
  'post_date' => '2015-04-21 01:02:25',
  'post_date_gmt' => '2015-04-21 01:02:25',
  'post_content' => '',
  'post_title' => 'Wedding Party',
  'post_excerpt' => '',
  'post_name' => 'wedding-party',
  'post_modified' => '2015-04-21 01:02:25',
  'post_modified_gmt' => '2015-04-21 01:02:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3690',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3690',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#wedding-party',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'wedding-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5317,
  'post_date' => '2016-06-09 22:00:35',
  'post_date_gmt' => '2016-06-09 22:00:35',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5317',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5317',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3899',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3627,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'Resume',
  'post_excerpt' => '',
  'post_name' => 'resume',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3627',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3627',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#resume',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4931,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'Becoming a CM',
  'post_excerpt' => '',
  'post_name' => 'becoming-a-cm',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4931',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4931',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#course-exam',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3682,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Location',
  'post_excerpt' => '',
  'post_name' => 'location',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3682',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3682',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#location',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3691,
  'post_date' => '2015-04-21 01:02:25',
  'post_date_gmt' => '2015-04-21 01:02:25',
  'post_content' => '',
  'post_title' => 'When & Where',
  'post_excerpt' => '',
  'post_name' => 'when-where',
  'post_modified' => '2015-04-21 01:02:25',
  'post_modified_gmt' => '2015-04-21 01:02:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3691',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3691',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#whenwhere',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'wedding-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6283,
  'post_date' => '2017-02-18 17:02:24',
  'post_date_gmt' => '2017-02-18 17:02:24',
  'post_content' => '',
  'post_title' => 'Blog – Tiles',
  'post_excerpt' => '',
  'post_name' => 'blog-tiles',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=6283',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5184',
    '_menu_item_object_id' => '6279',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3768,
  'post_date' => '2015-04-21 17:39:31',
  'post_date_gmt' => '2015-04-21 17:39:31',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3768',
  'post_modified' => '2017-01-17 03:06:11',
  'post_modified_gmt' => '2017-01-17 03:06:11',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3768',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2894',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-menu-2',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5320,
  'post_date' => '2016-06-09 22:00:35',
  'post_date_gmt' => '2016-06-09 22:00:35',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5320',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5320',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5317',
    '_menu_item_object_id' => '2894',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3628,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'Status',
  'post_excerpt' => '',
  'post_name' => 'status',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3628',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3628',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#status',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5185,
  'post_date' => '2016-06-08 23:04:29',
  'post_date_gmt' => '2016-06-08 23:04:29',
  'post_content' => '',
  'post_title' => 'Blog – Grid2 Polaroid',
  'post_excerpt' => '',
  'post_name' => 'blog-grid2-polaroid',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5185',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5184',
    '_menu_item_object_id' => '4025',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4932,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'Learnings',
  'post_excerpt' => '',
  'post_name' => 'learnings',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4932',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4932',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#interactive-interface',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3683,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Sponsors',
  'post_excerpt' => '',
  'post_name' => 'sponsors',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3683',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3683',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#sponsors',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3692,
  'post_date' => '2015-04-21 01:02:25',
  'post_date_gmt' => '2015-04-21 01:02:25',
  'post_content' => '',
  'post_title' => 'RSVP',
  'post_excerpt' => '',
  'post_name' => 'rsvp',
  'post_modified' => '2015-04-21 01:02:25',
  'post_modified_gmt' => '2015-04-21 01:02:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3692',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3692',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#rsvp',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'wedding-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3769,
  'post_date' => '2015-04-21 17:39:31',
  'post_date_gmt' => '2015-04-21 17:39:31',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3769',
  'post_modified' => '2017-01-17 03:06:11',
  'post_modified_gmt' => '2017-01-17 03:06:11',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3769',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2896',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-menu-2',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5321,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => '',
  'post_title' => 'Blog – Grid2 Polaroid',
  'post_excerpt' => '',
  'post_name' => 'blog-grid2-polaroid-2',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5321',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5317',
    '_menu_item_object_id' => '4025',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3629,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'Portfolio',
  'post_excerpt' => '',
  'post_name' => 'portfolio-2',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3629',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3629',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#portfolio',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5186,
  'post_date' => '2016-06-08 23:04:29',
  'post_date_gmt' => '2016-06-08 23:04:29',
  'post_content' => '',
  'post_title' => 'Blog – Grid3 Masonry',
  'post_excerpt' => '',
  'post_name' => 'blog-grid3-masonry',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5186',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5184',
    '_menu_item_object_id' => '4023',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4933,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'Share Your Skills',
  'post_excerpt' => '',
  'post_name' => 'share-your-skills',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4933',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4933',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#share',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3684,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Press',
  'post_excerpt' => '',
  'post_name' => 'press',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3684',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3684',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#press',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3688,
  'post_date' => '2015-04-21 01:02:25',
  'post_date_gmt' => '2015-04-21 01:02:25',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3688',
  'post_modified' => '2015-04-21 01:02:25',
  'post_modified_gmt' => '2015-04-21 01:02:25',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3688',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2512',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'wedding-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3765,
  'post_date' => '2015-04-21 17:39:31',
  'post_date_gmt' => '2015-04-21 17:39:31',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3765',
  'post_modified' => '2017-01-17 03:06:11',
  'post_modified_gmt' => '2017-01-17 03:06:11',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3765',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2693',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-menu-2',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5322,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => '',
  'post_title' => 'Blog – Grid3 Masonry',
  'post_excerpt' => '',
  'post_name' => 'blog-grid3-masonry-2',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5322',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5317',
    '_menu_item_object_id' => '4023',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3630,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'Connect',
  'post_excerpt' => '',
  'post_name' => 'connect',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3630',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3630',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#connect',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5187,
  'post_date' => '2016-06-08 23:04:29',
  'post_date_gmt' => '2016-06-08 23:04:29',
  'post_content' => '',
  'post_title' => 'Blog – Grid4',
  'post_excerpt' => '',
  'post_name' => 'blog-grid4',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5187',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5184',
    '_menu_item_object_id' => '3896',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4934,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'Testimonials',
  'post_excerpt' => '',
  'post_name' => 'testimonials',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4934',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4934',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#testimonial',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3685,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Past Event Galleries',
  'post_excerpt' => '',
  'post_name' => 'past-event-galleries',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3685',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3685',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#past-event-galleries',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5323,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => '',
  'post_title' => 'Blog – Grid4',
  'post_excerpt' => '',
  'post_name' => 'blog-grid4-2',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5323',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5317',
    '_menu_item_object_id' => '3896',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3631,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => '',
  'post_title' => 'Contact',
  'post_excerpt' => '',
  'post_name' => 'contact',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3631',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3631',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#contact',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5188,
  'post_date' => '2016-06-08 23:04:29',
  'post_date_gmt' => '2016-06-08 23:04:29',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5188',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3899,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5188',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5184',
    '_menu_item_object_id' => '2894',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4935,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => '',
  'post_title' => 'Get it now!',
  'post_excerpt' => '',
  'post_name' => 'get-it-now',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4935',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4935',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#get',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3686,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'Pricing',
  'post_excerpt' => '',
  'post_name' => 'pricing',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3686',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3686',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#pricing',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5318,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5318',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5318',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4037',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3633,
  'post_date' => '2015-04-21 00:31:55',
  'post_date_gmt' => '2015-04-21 00:31:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3633',
  'post_modified' => '2016-06-08 21:38:01',
  'post_modified_gmt' => '2016-06-08 21:38:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3633',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2512',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'personal-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 4928,
  'post_date' => '2016-03-14 22:06:43',
  'post_date_gmt' => '2016-03-14 22:06:43',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '4928',
  'post_modified' => '2016-03-14 22:06:43',
  'post_modified_gmt' => '2016-03-14 22:06:43',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=4928',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2512',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'right-pane',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5190,
  'post_date' => '2016-06-08 23:14:46',
  'post_date_gmt' => '2016-06-08 23:14:46',
  'post_content' => '',
  'post_title' => 'Post Layouts',
  'post_excerpt' => '',
  'post_name' => 'post-layouts',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5190',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5182',
    '_menu_item_object_id' => '5190',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3687,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => '',
  'post_title' => 'FAQ',
  'post_excerpt' => '',
  'post_name' => 'faq',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3687',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3687',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#faq',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5324,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => '',
  'post_title' => 'Portfolio – Grid2',
  'post_excerpt' => '',
  'post_name' => 'portfolio-grid2',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5324',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5318',
    '_menu_item_object_id' => '4035',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5193,
  'post_date' => '2016-06-08 23:14:46',
  'post_date_gmt' => '2016-06-08 23:14:46',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5193',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5193',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5190',
    '_menu_item_object_id' => '5080',
    '_menu_item_object' => 'post',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 3661,
  'post_date' => '2015-04-21 01:00:48',
  'post_date_gmt' => '2015-04-21 01:00:48',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '3661',
  'post_modified' => '2018-11-11 00:27:02',
  'post_modified_gmt' => '2018-11-11 00:27:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=3661',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2512',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'event-page-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5325,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => '',
  'post_title' => 'Portfolio – Grid3',
  'post_excerpt' => '',
  'post_name' => 'portfolio-grid3',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5325',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5318',
    '_menu_item_object_id' => '4033',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5191,
  'post_date' => '2016-06-08 23:14:47',
  'post_date_gmt' => '2016-06-08 23:14:47',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5191',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5191',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5190',
    '_menu_item_object_id' => '5088',
    '_menu_item_object' => 'post',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5326,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => '',
  'post_title' => 'Portfolio – Grid4',
  'post_excerpt' => '',
  'post_name' => 'portfolio-grid4',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5326',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5318',
    '_menu_item_object_id' => '4031',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5192,
  'post_date' => '2016-06-08 23:14:47',
  'post_date_gmt' => '2016-06-08 23:14:47',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5192',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5192',
  'menu_order' => 11,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5190',
    '_menu_item_object_id' => '5101',
    '_menu_item_object' => 'post',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5327,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5327',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 4037,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5327',
  'menu_order' => 11,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5318',
    '_menu_item_object_id' => '2896',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5194,
  'post_date' => '2016-06-08 23:14:47',
  'post_date_gmt' => '2016-06-08 23:14:47',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5194',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5194',
  'menu_order' => 12,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5190',
    '_menu_item_object_id' => '5075',
    '_menu_item_object' => 'post',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5319,
  'post_date' => '2016-06-09 22:00:36',
  'post_date_gmt' => '2016-06-09 22:00:36',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5319',
  'post_modified' => '2016-06-10 00:24:22',
  'post_modified_gmt' => '2016-06-10 00:24:22',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5319',
  'menu_order' => 12,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2693',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'header-overlay-menu',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5195,
  'post_date' => '2016-06-08 23:14:47',
  'post_date_gmt' => '2016-06-08 23:14:47',
  'post_content' => '',
  'post_title' => 'Portfolio Layouts',
  'post_excerpt' => '',
  'post_name' => 'portfolio-layouts',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5195',
  'menu_order' => 13,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5182',
    '_menu_item_object_id' => '5195',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5498,
  'post_date' => '2016-08-14 08:39:55',
  'post_date_gmt' => '2016-08-14 08:39:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5498',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5498',
  'menu_order' => 14,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5195',
    '_menu_item_object_id' => '5124',
    '_menu_item_object' => 'portfolio',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5499,
  'post_date' => '2016-08-14 08:39:55',
  'post_date_gmt' => '2016-08-14 08:39:55',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5499',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5499',
  'menu_order' => 15,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5195',
    '_menu_item_object_id' => '5121',
    '_menu_item_object' => 'portfolio',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5500,
  'post_date' => '2016-08-14 08:39:55',
  'post_date_gmt' => '2016-08-14 08:39:55',
  'post_content' => '',
  'post_title' => 'Fullwidth Portfolio',
  'post_excerpt' => '',
  'post_name' => 'fullwidth-portfolio-2',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5500',
  'menu_order' => 16,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5195',
    '_menu_item_object_id' => '3304',
    '_menu_item_object' => 'portfolio',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5501,
  'post_date' => '2016-08-14 08:39:55',
  'post_date_gmt' => '2016-08-14 08:39:55',
  'post_content' => '',
  'post_title' => 'Split Portfolio',
  'post_excerpt' => '',
  'post_name' => 'split-portfolio-2',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5501',
  'menu_order' => 17,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5195',
    '_menu_item_object_id' => '3303',
    '_menu_item_object' => 'portfolio',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5200,
  'post_date' => '2016-06-08 23:14:47',
  'post_date_gmt' => '2016-06-08 23:14:47',
  'post_content' => '',
  'post_title' => 'Section Scrolling',
  'post_excerpt' => '',
  'post_name' => 'section-scroll-2',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5200',
  'menu_order' => 18,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5182',
    '_menu_item_object_id' => '5200',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5206,
  'post_date' => '2016-06-08 23:14:47',
  'post_date_gmt' => '2016-06-08 23:14:47',
  'post_content' => '',
  'post_title' => 'Vertical & Horizontal Scroll',
  'post_excerpt' => '',
  'post_name' => '5206',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5206',
  'menu_order' => 19,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5200',
    '_menu_item_object_id' => '5153',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7144,
  'post_date' => '2018-04-16 21:14:00',
  'post_date_gmt' => '2018-04-16 21:14:00',
  'post_content' => '',
  'post_title' => 'Horizontal + Top Bar',
  'post_excerpt' => '',
  'post_name' => 'top-bar-header',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=7144',
  'menu_order' => 20,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5200',
    '_menu_item_object_id' => '7052',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7145,
  'post_date' => '2018-04-16 21:14:00',
  'post_date_gmt' => '2018-04-16 21:14:00',
  'post_content' => '',
  'post_title' => 'Horizontal + Min Bar',
  'post_excerpt' => '',
  'post_name' => 'min-bar-header',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=7145',
  'menu_order' => 21,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5200',
    '_menu_item_object_id' => '7033',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7266,
  'post_date' => '2018-04-18 21:29:31',
  'post_date_gmt' => '2018-04-18 21:29:31',
  'post_content' => '',
  'post_title' => 'About',
  'post_excerpt' => '',
  'post_name' => 'about-2',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=7266',
  'menu_order' => 22,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5182',
    '_menu_item_object_id' => '7266',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7267,
  'post_date' => '2018-04-18 21:29:31',
  'post_date_gmt' => '2018-04-18 21:29:31',
  'post_content' => '',
  'post_title' => 'Text',
  'post_excerpt' => '',
  'post_name' => 'text',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=7267',
  'menu_order' => 23,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '7266',
    '_menu_item_object_id' => '7267',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#WP_Widget_Text',
    '_themify_menu_widget' => 
    array (
      'title' => '',
      'text' => 'Introducing the most powerful and flexible WordPress theme created by Themify, making it easy to create any site quickly and beautifully (and responsive, of course).',
      'filter' => 'on',
      'visual' => 'on',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5211,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => '',
  'post_title' => 'Appearance',
  'post_excerpt' => '',
  'post_name' => 'appearance-2',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5211',
  'menu_order' => 24,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '5211',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5212,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => '',
  'post_title' => 'Header Design',
  'post_excerpt' => '',
  'post_name' => 'header-design-1',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5212',
  'menu_order' => 25,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5211',
    '_menu_item_object_id' => '5212',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
    '_themify_dropdown_columns' => '3',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5795,
  'post_date' => '2016-09-23 22:05:57',
  'post_date_gmt' => '2016-09-23 22:05:57',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5795',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5795',
  'menu_order' => 26,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '5792',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5216,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5216',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5216',
  'menu_order' => 27,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '5132',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5213,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5213',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5213',
  'menu_order' => 28,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '4194',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5214,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5214',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5214',
  'menu_order' => 29,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '4907',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5215,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5215',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5215',
  'menu_order' => 30,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '4911',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5217,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5217',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5217',
  'menu_order' => 31,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '4249',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 7775,
  'post_date' => '2018-11-11 00:28:01',
  'post_date_gmt' => '2018-11-11 00:28:01',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '7775',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=7775',
  'menu_order' => 32,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '7767',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5219,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5219',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5219',
  'menu_order' => 33,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3385',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5220,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5220',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5220',
  'menu_order' => 34,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3389',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5221,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5221',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5221',
  'menu_order' => 35,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3391',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5222,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5222',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5222',
  'menu_order' => 36,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3393',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5223,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5223',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5223',
  'menu_order' => 37,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3397',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5224,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5224',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5224',
  'menu_order' => 38,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '4919',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5225,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5225',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5225',
  'menu_order' => 39,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3400',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5621,
  'post_date' => '2016-08-29 14:38:15',
  'post_date_gmt' => '2016-08-29 14:38:15',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5621',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5621',
  'menu_order' => 40,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '5617',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6930,
  'post_date' => '2018-02-28 18:53:34',
  'post_date_gmt' => '2018-02-28 18:53:34',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '6930',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=6930',
  'menu_order' => 41,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '6916',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 6929,
  'post_date' => '2018-02-28 18:53:34',
  'post_date_gmt' => '2018-02-28 18:53:34',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '6929',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=6929',
  'menu_order' => 42,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '6922',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5226,
  'post_date' => '2016-06-09 17:38:06',
  'post_date_gmt' => '2016-06-09 17:38:06',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5226',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5226',
  'menu_order' => 43,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5212',
    '_menu_item_object_id' => '3398',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5234,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => '',
  'post_title' => 'Footer',
  'post_excerpt' => '',
  'post_name' => 'footer',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5234',
  'menu_order' => 44,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5211',
    '_menu_item_object_id' => '5234',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
    '_themify_dropdown_columns' => '2',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5235,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5235',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5235',
  'menu_order' => 45,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5234',
    '_menu_item_object_id' => '3584',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5236,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5236',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5236',
  'menu_order' => 46,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5234',
    '_menu_item_object_id' => '3590',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5237,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5237',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5237',
  'menu_order' => 47,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5234',
    '_menu_item_object_id' => '3592',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5238,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5238',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5238',
  'menu_order' => 48,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5234',
    '_menu_item_object_id' => '3586',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5239,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5239',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5239',
  'menu_order' => 49,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5234',
    '_menu_item_object_id' => '3588',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5229,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => '',
  'post_title' => 'Header BG',
  'post_excerpt' => '',
  'post_name' => 'header-background-2',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5229',
  'menu_order' => 50,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'custom',
    '_menu_item_menu_item_parent' => '5211',
    '_menu_item_object_id' => '5229',
    '_menu_item_object' => 'custom',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_menu_item_url' => '#',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5924,
  'post_date' => '2016-10-05 18:45:25',
  'post_date_gmt' => '2016-10-05 18:45:25',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5924',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5924',
  'menu_order' => 51,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5229',
    '_menu_item_object_id' => '5916',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5232,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5232',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5232',
  'menu_order' => 52,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5229',
    '_menu_item_object_id' => '3985',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5230,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5230',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5230',
  'menu_order' => 53,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5229',
    '_menu_item_object_id' => '3990',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5231,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5231',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5231',
  'menu_order' => 54,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5229',
    '_menu_item_object_id' => '3975',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5233,
  'post_date' => '2016-06-09 17:41:28',
  'post_date_gmt' => '2016-06-09 17:41:28',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5233',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 3420,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5233',
  'menu_order' => 55,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '5229',
    '_menu_item_object_id' => '3983',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5240,
  'post_date' => '2016-06-09 17:42:21',
  'post_date_gmt' => '2016-06-09 17:42:21',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5240',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5240',
  'menu_order' => 56,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '3899',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_themify_mega_menu_item' => '1',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5243,
  'post_date' => '2016-06-09 17:46:36',
  'post_date_gmt' => '2016-06-09 17:46:36',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5243',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 33,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5243',
  'menu_order' => 57,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5240',
    '_menu_item_object_id' => '9',
    '_menu_item_object' => 'category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5244,
  'post_date' => '2016-06-09 17:46:36',
  'post_date_gmt' => '2016-06-09 17:46:36',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5244',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 33,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5244',
  'menu_order' => 58,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5240',
    '_menu_item_object_id' => '8',
    '_menu_item_object' => 'category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5255,
  'post_date' => '2016-06-09 17:47:35',
  'post_date_gmt' => '2016-06-09 17:47:35',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5255',
  'post_modified' => '2018-11-11 00:28:01',
  'post_modified_gmt' => '2018-11-11 00:28:01',
  'post_content_filtered' => '',
  'post_parent' => 33,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5255',
  'menu_order' => 59,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5240',
    '_menu_item_object_id' => '11',
    '_menu_item_object' => 'category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5246,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5246',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 33,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5246',
  'menu_order' => 60,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5240',
    '_menu_item_object_id' => '10',
    '_menu_item_object' => 'category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5241,
  'post_date' => '2016-06-09 17:42:21',
  'post_date_gmt' => '2016-06-09 17:42:21',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5241',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5241',
  'menu_order' => 61,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '4037',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_themify_mega_menu_item' => '1',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5247,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5247',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5247',
  'menu_order' => 62,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5241',
    '_menu_item_object_id' => '13',
    '_menu_item_object' => 'portfolio-category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5248,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5248',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5248',
  'menu_order' => 63,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5241',
    '_menu_item_object_id' => '17',
    '_menu_item_object' => 'portfolio-category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5249,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5249',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5249',
  'menu_order' => 64,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5241',
    '_menu_item_object_id' => '12',
    '_menu_item_object' => 'portfolio-category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5250,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5250',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5250',
  'menu_order' => 65,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5241',
    '_menu_item_object_id' => '16',
    '_menu_item_object' => 'portfolio-category',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5242,
  'post_date' => '2016-06-09 17:42:21',
  'post_date_gmt' => '2016-06-09 17:42:21',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5242',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5242',
  'menu_order' => 66,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '2693',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
    '_themify_mega_menu_item' => '1',
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5251,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5251',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5251',
  'menu_order' => 67,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5242',
    '_menu_item_object_id' => '18',
    '_menu_item_object' => 'product_cat',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5252,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5252',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5252',
  'menu_order' => 68,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5242',
    '_menu_item_object_id' => '19',
    '_menu_item_object' => 'product_cat',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5253,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5253',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5253',
  'menu_order' => 69,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5242',
    '_menu_item_object_id' => '20',
    '_menu_item_object' => 'product_cat',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5254,
  'post_date' => '2016-06-09 17:46:37',
  'post_date_gmt' => '2016-06-09 17:46:37',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '5254',
  'post_modified' => '2018-11-11 00:28:02',
  'post_modified_gmt' => '2018-11-11 00:28:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/ultra/?p=5254',
  'menu_order' => 70,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'taxonomy',
    '_menu_item_menu_item_parent' => '5242',
    '_menu_item_object_id' => '29',
    '_menu_item_object' => 'product_cat',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}


function themify_import_get_term_id_from_slug( $slug ) {
	$menu = get_term_by( "slug", $slug, "nav_menu" );
	return is_wp_error( $menu ) ? 0 : (int) $menu->term_id;
}

	$widgets = get_option( "widget_themify-social-links" );
$widgets[1002] = array (
  'title' => '',
  'show_link_name' => NULL,
  'open_new_window' => NULL,
  'icon_size' => 'icon-medium',
  'orientation' => 'horizontal',
);
update_option( "widget_themify-social-links", $widgets );

$widgets = get_option( "widget_themify-feature-posts" );
$widgets[1003] = array (
  'title' => 'Recent Posts',
  'category' => '0',
  'show_count' => '3',
  'show_date' => 'on',
  'show_thumb' => 'on',
  'display' => 'none',
  'hide_title' => NULL,
  'thumb_width' => '50',
  'thumb_height' => '50',
  'excerpt_length' => '55',
  'orderby' => 'date',
  'order' => 'DESC',
);
update_option( "widget_themify-feature-posts", $widgets );

$widgets = get_option( "widget_text" );
$widgets[1004] = array (
  'title' => '',
  'text' => '',
  'filter' => true,
  'visual' => true,
);
update_option( "widget_text", $widgets );

$widgets = get_option( "widget_themify-twitter" );
$widgets[1005] = array (
  'title' => 'Latest Tweets',
  'username' => 'themify',
  'show_count' => '3',
  'hide_timestamp' => NULL,
  'show_follow' => 'on',
  'follow_text' => '→ Follow me',
  'include_retweets' => 'on',
  'exclude_replies' => NULL,
);
update_option( "widget_themify-twitter", $widgets );

$widgets = get_option( "widget_woocommerce_products" );
$widgets[1006] = array (
  'title' => 'Products',
  'number' => 3,
  'show' => '',
  'orderby' => 'date',
  'order' => 'desc',
  'hide_free' => 0,
  'show_hidden' => 0,
);
update_option( "widget_woocommerce_products", $widgets );

$widgets = get_option( "widget_woocommerce_product_categories" );
$widgets[1007] = array (
  'title' => 'Product Categories',
  'orderby' => 'name',
  'dropdown' => 0,
  'count' => 0,
  'hierarchical' => 1,
  'show_children_only' => 0,
  'hide_empty' => 0,
);
update_option( "widget_woocommerce_product_categories", $widgets );

$widgets = get_option( "widget_themify-social-links" );
$widgets[1008] = array (
  'title' => '',
  'show_link_name' => NULL,
  'open_new_window' => NULL,
  'icon_size' => 'icon-medium',
  'orientation' => 'horizontal',
);
update_option( "widget_themify-social-links", $widgets );

$widgets = get_option( "widget_themify-social-links" );
$widgets[1009] = array (
  'title' => '',
  'show_link_name' => NULL,
  'open_new_window' => NULL,
  'icon_size' => 'icon-medium',
  'orientation' => 'horizontal',
);
update_option( "widget_themify-social-links", $widgets );

$widgets = get_option( "widget_text" );
$widgets[1010] = array (
  'title' => 'Widget 1',
  'text' => 'Optional widget here',
  'filter' => false,
);
update_option( "widget_text", $widgets );

$widgets = get_option( "widget_text" );
$widgets[1011] = array (
  'title' => 'Widget 2',
  'text' => 'Display any widget here',
  'filter' => false,
);
update_option( "widget_text", $widgets );

$widgets = get_option( "widget_text" );
$widgets[1012] = array (
  'title' => 'Widget 3',
  'text' => 'For example, phone #: 123-333-4567',
  'filter' => false,
);
update_option( "widget_text", $widgets );

$widgets = get_option( "widget_themify-feature-posts" );
$widgets[1013] = array (
  'title' => 'Recent Posts',
  'category' => '0',
  'show_count' => '3',
  'show_date' => 'on',
  'show_thumb' => 'on',
  'display' => 'none',
  'hide_title' => NULL,
  'thumb_width' => '50',
  'thumb_height' => '50',
  'excerpt_length' => '55',
  'orderby' => 'date',
  'order' => 'DESC',
);
update_option( "widget_themify-feature-posts", $widgets );

$widgets = get_option( "widget_text" );
$widgets[1014] = array (
  'title' => 'About',
  'text' => 'The Ultra theme is Themify\'s flagship theme. It\'s a WordPress designed to give you more control on the design of your theme. Built to work seamlessly with our drag & drop Builder plugin, it gives you the ability to customize the look and feel of your content. ',
  'filter' => false,
);
update_option( "widget_text", $widgets );

$widgets = get_option( "widget_themify-twitter" );
$widgets[1015] = array (
  'title' => 'Latest Tweets',
  'username' => 'themify',
  'show_count' => '2',
  'hide_timestamp' => NULL,
  'show_follow' => NULL,
  'follow_text' => '→ Follow me',
  'include_retweets' => NULL,
  'exclude_replies' => NULL,
);
update_option( "widget_themify-twitter", $widgets );



$sidebars_widgets = array (
  'wp_inactive_widgets' => 
  array (
    0 => 'themify-social-links-1002',
  ),
  'sidebar-main' => 
  array (
    0 => 'themify-feature-posts-1003',
    1 => 'text-1004',
    2 => 'themify-twitter-1005',
  ),
  'sidebar-alt' => 
  array (
    0 => 'woocommerce_products-1006',
    1 => 'woocommerce_product_categories-1007',
  ),
  'social-widget' => 
  array (
    0 => 'themify-social-links-1008',
  ),
  'footer-social-widget' => 
  array (
    0 => 'themify-social-links-1009',
  ),
  'header-widget-1' => 
  array (
    0 => 'text-1010',
  ),
  'header-widget-2' => 
  array (
    0 => 'text-1011',
  ),
  'header-widget-3' => 
  array (
    0 => 'text-1012',
  ),
  'footer-widget-1' => 
  array (
    0 => 'themify-feature-posts-1013',
  ),
  'footer-widget-2' => 
  array (
    0 => 'text-1014',
  ),
  'footer-widget-3' => 
  array (
    0 => 'themify-twitter-1015',
  ),
); 
update_option( "sidebars_widgets", $sidebars_widgets );

$menu_locations = array();
$menu = get_terms( "nav_menu", array( "slug" => "main-nav" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["main-nav"] = $menu[0]->term_id;
$menu = get_terms( "nav_menu", array( "slug" => "footer-menu-2" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["footer-nav"] = $menu[0]->term_id;
set_theme_mod( "nav_menu_locations", $menu_locations );


$homepage = get_posts( array( 'name' => 'demo-pages', 'post_type' => 'page' ) );
			if( is_array( $homepage ) && ! empty( $homepage ) ) {
				update_option( 'show_on_front', 'page' );
				update_option( 'page_on_front', $homepage[0]->ID );
			}
			
	ob_start(); ?>a:100:{s:16:"setting-page_404";s:1:"0";s:21:"setting-webfonts_list";s:11:"recommended";s:22:"setting-default_layout";s:8:"sidebar1";s:27:"setting-default_post_layout";s:9:"list-post";s:19:"setting-post_filter";s:3:"yes";s:23:"setting-disable_masonry";s:3:"yes";s:19:"setting-post_gutter";s:6:"gutter";s:30:"setting-default_layout_display";s:7:"content";s:25:"setting-default_more_text";s:4:"More";s:21:"setting-index_orderby";s:4:"date";s:19:"setting-index_order";s:4:"DESC";s:30:"setting-default_media_position";s:5:"above";s:31:"setting-image_post_feature_size";s:5:"blank";s:32:"setting-default_page_post_layout";s:8:"sidebar1";s:37:"setting-default_page_post_layout_type";s:7:"classic";s:42:"setting-default_page_single_media_position";s:5:"above";s:38:"setting-image_post_single_feature_size";s:5:"blank";s:27:"setting-default_page_layout";s:8:"sidebar1";s:38:"setting-default_portfolio_index_layout";s:12:"sidebar-none";s:43:"setting-default_portfolio_index_post_layout";s:5:"grid3";s:29:"setting-portfolio_post_filter";s:3:"yes";s:33:"setting-portfolio_disable_masonry";s:3:"yes";s:24:"setting-portfolio_gutter";s:6:"gutter";s:39:"setting-default_portfolio_index_display";s:4:"none";s:50:"setting-default_portfolio_index_post_meta_category";s:3:"yes";s:49:"setting-default_portfolio_index_unlink_post_image";s:3:"yes";s:39:"setting-default_portfolio_single_layout";s:12:"sidebar-none";s:54:"setting-default_portfolio_single_portfolio_layout_type";s:9:"fullwidth";s:50:"setting-default_portfolio_single_unlink_post_image";s:3:"yes";s:22:"themify_portfolio_slug";s:7:"project";s:19:"setting-shop_layout";s:8:"sidebar1";s:27:"setting-shop_archive_layout";s:12:"sidebar-none";s:23:"setting-products_layout";s:5:"grid3";s:31:"setting-product_disable_masonry";s:3:"yes";s:29:"setting-single_product_layout";s:8:"sidebar1";s:30:"setting-related_products_limit";s:1:"3";s:53:"setting-customizer_responsive_design_tablet_landscape";s:4:"1024";s:43:"setting-customizer_responsive_design_tablet";s:3:"768";s:43:"setting-customizer_responsive_design_mobile";s:3:"480";s:33:"setting-mobile_menu_trigger_point";s:4:"1000";s:24:"setting-gallery_lightbox";s:8:"lightbox";s:26:"setting-page_builder_cache";s:2:"on";s:18:"setting-cache_gzip";s:2:"on";s:27:"setting-page_builder_expiry";s:1:"2";s:27:"setting-script_minification";s:7:"disable";s:21:"setting-header_design";s:17:"header-horizontal";s:19:"setting-exclude_rss";s:2:"on";s:22:"setting-header_widgets";s:17:"headerwidget-3col";s:21:"setting-footer_design";s:15:"footer-left-col";s:22:"setting-use_float_back";s:2:"on";s:22:"setting-footer_widgets";s:17:"footerwidget-3col";s:23:"setting-mega_menu_posts";s:1:"5";s:29:"setting-mega_menu_image_width";s:3:"180";s:30:"setting-mega_menu_image_height";s:3:"120";s:29:"setting-imagefilter_applyto_1";s:12:"featuredonly";s:29:"setting-color_animation_speed";s:1:"5";s:29:"setting-relationship_taxonomy";s:8:"category";s:37:"setting-relationship_taxonomy_entries";s:1:"3";s:45:"setting-relationship_taxonomy_display_content";s:4:"none";s:30:"setting-single_slider_autoplay";s:3:"off";s:27:"setting-single_slider_speed";s:6:"normal";s:28:"setting-single_slider_effect";s:5:"slide";s:28:"setting-single_slider_height";s:4:"auto";s:18:"setting-more_posts";s:8:"infinite";s:19:"setting-entries_nav";s:8:"numbered";s:25:"setting-img_php_base_size";s:5:"large";s:27:"setting-global_feature_size";s:5:"blank";s:22:"setting-link_icon_type";s:9:"font-icon";s:32:"setting-link_type_themify-link-0";s:10:"image-icon";s:33:"setting-link_title_themify-link-0";s:7:"Twitter";s:31:"setting-link_img_themify-link-0";s:99:"https://themify.me/demo/themes/ultra/wp-content/themes/themify-ultra/themify/img/social/twitter.png";s:32:"setting-link_type_themify-link-1";s:10:"image-icon";s:33:"setting-link_title_themify-link-1";s:8:"Facebook";s:31:"setting-link_img_themify-link-1";s:100:"https://themify.me/demo/themes/ultra/wp-content/themes/themify-ultra/themify/img/social/facebook.png";s:32:"setting-link_type_themify-link-2";s:10:"image-icon";s:33:"setting-link_title_themify-link-2";s:6:"Google";s:31:"setting-link_img_themify-link-2";s:103:"https://themify.me/demo/themes/ultra/wp-content/themes/themify-ultra/themify/img/social/google-plus.png";s:32:"setting-link_type_themify-link-3";s:10:"image-icon";s:33:"setting-link_title_themify-link-3";s:7:"YouTube";s:31:"setting-link_img_themify-link-3";s:99:"https://themify.me/demo/themes/ultra/wp-content/themes/themify-ultra/themify/img/social/youtube.png";s:32:"setting-link_type_themify-link-4";s:10:"image-icon";s:33:"setting-link_title_themify-link-4";s:9:"Pinterest";s:31:"setting-link_img_themify-link-4";s:101:"https://themify.me/demo/themes/ultra/wp-content/themes/themify-ultra/themify/img/social/pinterest.png";s:32:"setting-link_type_themify-link-5";s:9:"font-icon";s:33:"setting-link_title_themify-link-5";s:7:"Twitter";s:32:"setting-link_link_themify-link-5";s:27:"https://twitter.com/themify";s:33:"setting-link_ficon_themify-link-5";s:10:"fa-twitter";s:32:"setting-link_type_themify-link-6";s:9:"font-icon";s:33:"setting-link_title_themify-link-6";s:8:"Facebook";s:32:"setting-link_link_themify-link-6";s:28:"https://facebook.com/themify";s:33:"setting-link_ficon_themify-link-6";s:11:"fa-facebook";s:32:"setting-link_type_themify-link-8";s:9:"font-icon";s:33:"setting-link_title_themify-link-8";s:7:"YouTube";s:32:"setting-link_link_themify-link-8";s:32:"https://youtube.com/user/themify";s:33:"setting-link_ficon_themify-link-8";s:10:"fa-youtube";s:22:"setting-link_field_ids";s:273:"{"themify-link-0":"themify-link-0","themify-link-1":"themify-link-1","themify-link-2":"themify-link-2","themify-link-3":"themify-link-3","themify-link-4":"themify-link-4","themify-link-5":"themify-link-5","themify-link-6":"themify-link-6","themify-link-8":"themify-link-8"}";s:23:"setting-link_field_hash";s:2:"10";s:30:"setting-page_builder_is_active";s:6:"enable";s:46:"setting-page_builder_animation_parallax_scroll";s:6:"mobile";s:4:"skin";s:92:"https://themify.me/demo/themes/ultra/wp-content/themes/themify-ultra/skins/default/style.css";}<?php $themify_data = unserialize( ob_get_clean() );

	// fix the weird way "skin" is saved
	if( isset( $themify_data['skin'] ) ) {
		$parsed_skin = parse_url( $themify_data['skin'], PHP_URL_PATH );
		$basedir_skin = basename( dirname( $parsed_skin ) );
		$themify_data['skin'] = trailingslashit( get_template_directory_uri() ) . 'skins/' . $basedir_skin . '/style.css';
	}

	themify_set_data( $themify_data );
	
}
themify_do_demo_import();